package TRAMI_L3_HEV
  package ETC
    model Dot
    equation

      annotation(
        Icon(graphics = {Ellipse(fillPattern = FillPattern.Solid, extent = {{-15, 15}, {15, -15}}, endAngle = 360)}, coordinateSystem(extent = {{-40, -40}, {40, 40}}, initialScale = 0.1)));
    end Dot;
  end ETC;

  package Thermal
    constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
    constant Modelica.SIunits.Mass Volumemass = 1;
    constant Modelica.SIunits.VolumeFlowRate Volumeflowinit = 1;
    constant Modelica.SIunits.Temperature Tempinit = 293.15;

    package thermal_parts
      model radiator
        parameter String RAD_Filename = currDir + "/param/pnt/RadResi.txt";
        parameter String RAD_tableName = "tab1";
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation(
          Placement(visible = true, transformation(origin = {-94, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-94, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ConvectiveResistor convectiveResistor annotation(
          Placement(visible = true, transformation(origin = {4, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable2D combiTable2D(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = RAD_Filename, tableName = RAD_tableName, tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {4, 44}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {10, 96}, extent = {{-14, -14}, {14, 14}}, rotation = -90), iconTransformation(origin = {40, 94}, extent = {{-14, -14}, {14, 14}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput RAD annotation(
          Placement(visible = true, transformation(origin = {-14, 96}, extent = {{-14, -14}, {14, 14}}, rotation = -90), iconTransformation(origin = {-42, 96}, extent = {{-14, -14}, {14, 14}}, rotation = -90)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {36, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput heatFlow annotation(
          Placement(visible = true, transformation(origin = {106, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {106, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Temperature annotation(
          Placement(visible = true, transformation(origin = {104, 6}, extent = {{12, -12}, {-12, 12}}, rotation = 0), iconTransformation(origin = {104, 40}, extent = {{12, -12}, {-12, 12}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {68, 6}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      equation
        connect(combiTable2D.u1, VSP) annotation(
          Line(points = {{10, 56}, {10, 96}}, color = {0, 0, 127}));
        connect(RAD, combiTable2D.u2) annotation(
          Line(points = {{-14, 96}, {-14, 66}, {-2, 66}, {-2, 56}}, color = {0, 0, 127}));
        connect(combiTable2D.y, convectiveResistor.Rc) annotation(
          Line(points = {{4, 33}, {4, 16}}, color = {0, 0, 127}));
        connect(port_b, convectiveResistor.solid) annotation(
          Line(points = {{-94, 6}, {-6, 6}}, color = {191, 0, 0}));
        connect(heatFlowSensor.Q_flow, heatFlow) annotation(
          Line(points = {{36, -4}, {36, -40}, {106, -40}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.T, Temperature) annotation(
          Line(points = {{80, 6}, {96, 6}, {96, 6}, {104, 6}}, color = {0, 0, 127}));
        connect(heatFlowSensor.port_b, prescribedTemperature1.port) annotation(
          Line(points = {{46, 6}, {58, 6}, {58, 6}, {58, 6}}, color = {191, 0, 0}));
        connect(convectiveResistor.fluid, heatFlowSensor.port_a) annotation(
          Line(points = {{14, 6}, {26, 6}, {26, 6}, {26, 6}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Text(origin = {-31, 7}, extent = {{-69, 15}, {131, -21}}, textString = "%name"), Rectangle(origin = {-4, 2}, extent = {{-96, 98}, {104, -102}})}, coordinateSystem(initialScale = 0.1)));
      end radiator;

      model heated_block
        parameter Modelica.SIunits.HeatCapacity c = 4.2;
        parameter Modelica.SIunits.ThermalResistance r = 1.6;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = c, T(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {-32, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = r) annotation(
          Placement(visible = true, transformation(origin = {4, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation(
          Placement(visible = true, transformation(origin = {92, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {106, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-60, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Q annotation(
          Placement(visible = true, transformation(origin = {-108, -14}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, 54}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {-48, -58}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput K annotation(
          Placement(visible = true, transformation(origin = {-106, -58}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, -74}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      equation
        connect(thermalResistor.port_b, port_b) annotation(
          Line(points = {{14, -14}, {92, -14}, {92, -12}, {92, -12}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow.port, thermalResistor.port_a) annotation(
          Line(points = {{-50, -14}, {-6, -14}}, color = {191, 0, 0}));
        connect(heatCapacitor.port, thermalResistor.port_a) annotation(
          Line(points = {{-32, 24}, {-32, 24}, {-32, -14}, {-6, -14}, {-6, -14}}, color = {191, 0, 0}));
        connect(Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-108, -14}, {-72, -14}, {-72, -14}, {-70, -14}}, color = {0, 0, 127}));
        connect(temperatureSensor.port, thermalResistor.port_a) annotation(
          Line(points = {{-38, -58}, {-6, -58}, {-6, -14}, {-6, -14}}, color = {191, 0, 0}));
        connect(K, temperatureSensor.T) annotation(
          Line(points = {{-106, -58}, {-58, -58}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-31, 65}, extent = {{-53, 35}, {115, -165}}, textString = "%name"), Rectangle(extent = {{-100, 100}, {100, -100}})}, coordinateSystem(initialScale = 0.1)));
      end heated_block;

      model thermal_heat_block
        parameter Modelica.SIunits.HeatCapacity c = 4.2;
        parameter Modelica.SIunits.ThermalResistance r = 1.6;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = c, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {-32, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = r) annotation(
          Placement(visible = true, transformation(origin = {4, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-60, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Q_in annotation(
          Placement(visible = true, transformation(origin = {-108, -14}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, 54}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {-48, -58}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput K_out annotation(
          Placement(visible = true, transformation(origin = {-106, -58}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-104, -70}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Q_out annotation(
          Placement(visible = true, transformation(origin = {104, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput K_in annotation(
          Placement(visible = true, transformation(origin = {106, -14}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {94, 56}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {69, -15}, extent = {{7, -7}, {-7, 7}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {40, -14}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      equation
        connect(prescribedHeatFlow.port, thermalResistor.port_a) annotation(
          Line(points = {{-50, -14}, {-6, -14}}, color = {191, 0, 0}));
        connect(heatCapacitor.port, thermalResistor.port_a) annotation(
          Line(points = {{-32, 24}, {-32, 24}, {-32, -14}, {-6, -14}, {-6, -14}}, color = {191, 0, 0}));
        connect(Q_in, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-108, -14}, {-72, -14}, {-72, -14}, {-70, -14}}, color = {0, 0, 127}));
        connect(temperatureSensor.port, thermalResistor.port_a) annotation(
          Line(points = {{-38, -58}, {-6, -58}, {-6, -14}, {-6, -14}}, color = {191, 0, 0}));
        connect(K_out, temperatureSensor.T) annotation(
          Line(points = {{-106, -58}, {-58, -58}}, color = {0, 0, 127}));
        connect(thermalResistor.port_b, heatFlowSensor.port_b) annotation(
          Line(points = {{14, -14}, {30, -14}, {30, -14}, {30, -14}}, color = {191, 0, 0}));
        connect(heatFlowSensor.port_a, prescribedTemperature.port) annotation(
          Line(points = {{50, -14}, {62, -14}, {62, -14}, {62, -14}}, color = {191, 0, 0}));
        connect(prescribedTemperature.T, K_in) annotation(
          Line(points = {{78, -14}, {106, -14}}, color = {0, 0, 127}));
        connect(heatFlowSensor.Q_flow, Q_out) annotation(
          Line(points = {{40, -24}, {40, -60}, {104, -60}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-31, 65}, extent = {{-53, 35}, {115, -165}}, textString = "%name"), Rectangle(extent = {{-100, 100}, {100, -100}})}, coordinateSystem(initialScale = 0.1)));
      end thermal_heat_block;

      model hvac
        parameter Modelica.SIunits.HeatCapacity hvac_C = 4.2 "HVAC heat capacity";
        parameter Modelica.SIunits.ThermalResistance hvac_water_R = 1.6 "HVAC thermal resistance for water";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = hvac_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_cabin_Q annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 196}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_cabin_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 150}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_condenser_Q annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_ac_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_condenser_T annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -188}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_ac_T annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -70}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hightempthermal_T annotation(
          Placement(visible = true, transformation(origin = {-118, 92}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature2 annotation(
          Placement(visible = true, transformation(origin = {-60, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor2 annotation(
          Placement(visible = true, transformation(origin = {-20, 92}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hightempthermal_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 68}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 50}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor3(R = hvac_water_R) annotation(
          Placement(visible = true, transformation(origin = {32, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-20, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {16, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-20, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-20, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_hightempthermal_T, prescribedTemperature2.T) annotation(
          Line(points = {{-118, 92}, {-74, 92}, {-74, 92}, {-72, 92}}, color = {0, 0, 127}));
        connect(heatFlowSensor2.Q_flow, to_hightempthermal_Q) annotation(
          Line(points = {{-20, 82}, {-20, 68}, {-110, 68}}, color = {0, 0, 127}));
        connect(prescribedTemperature2.port, heatFlowSensor2.port_b) annotation(
          Line(points = {{-50, 92}, {-30, 92}, {-30, 92}, {-30, 92}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.port_a, thermalResistor3.port_a) annotation(
          Line(points = {{-10, 92}, {22, 92}, {22, 92}, {22, 92}}, color = {191, 0, 0}));
        connect(thermalResistor3.port_b, heatCapacitor.port) annotation(
          Line(points = {{42, 92}, {92, 92}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(from_ac_Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-120, 40}, {-30, 40}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-10, 40}, {92, 40}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(to_ac_T, temperatureSensor.T) annotation(
          Line(points = {{-110, 20}, {6, 20}}, color = {0, 0, 127}));
        connect(temperatureSensor.port, heatCapacitor.port) annotation(
          Line(points = {{26, 20}, {92, 20}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow1.port, heatCapacitor.port) annotation(
          Line(points = {{-10, -10}, {92, -10}, {92, 122}}, color = {191, 0, 0}));
        connect(from_condenser_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-116, -10}, {-30, -10}}, color = {0, 0, 127}));
        connect(to_condenser_T, temperatureSensor.T) annotation(
          Line(points = {{-110, -38}, {-48, -38}, {-48, 20}, {6, 20}, {6, 20}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow2.port, heatCapacitor.port) annotation(
          Line(points = {{-10, -66}, {92, -66}, {92, 122}}, color = {191, 0, 0}));
        connect(from_cabin_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-112, -66}, {-30, -66}}, color = {0, 0, 127}));
        connect(temperatureSensor.T, to_cabin_T) annotation(
          Line(points = {{6, 20}, {-48, 20}, {-48, -90}, {-110, -90}, {-110, -90}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-89, 123}, extent = {{-53, 35}, {215, -281}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end hvac;

      model radiator_comp
        parameter Modelica.SIunits.HeatCapacity radiator_C = 0.1;
        parameter Modelica.SIunits.HeatCapacity low_radiator_C = 0.1;
        parameter Modelica.SIunits.HeatCapacity bat_radiator_C = 0.1;
        parameter Modelica.SIunits.ThermalResistance low_rad_R = 0.1;
        parameter Modelica.SIunits.ThermalResistance bat_rad_R = 0.1;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = radiator_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {90, 166}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = low_rad_R) annotation(
          Placement(visible = true, transformation(origin = {34, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_low_rad annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 74}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_lowrad_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-208, 28}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_batrad_Q annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -138}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_air_T annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 36}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = bat_rad_R) annotation(
          Placement(visible = true, transformation(origin = {42, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_battrad_T annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -186}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor2(R = 0.0001) annotation(
          Placement(visible = true, transformation(origin = {10, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-20, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_air_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {-44, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-52, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor1 annotation(
          Placement(visible = true, transformation(origin = {-48, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-56, 134}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hightemp_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 134}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 180}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hightemp_T annotation(
          Placement(visible = true, transformation(origin = {-114, 106}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 130}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor2 annotation(
          Placement(visible = true, transformation(origin = {-52, 106}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor2(C = low_radiator_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {8, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor3(C = bat_radiator_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {8, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(heatCapacitor.port, thermalResistor.port_b) annotation(
          Line(points = {{90, 156}, {90, -66}, {44, -66}}, color = {191, 0, 0}));
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{52, -10}, {90, -10}, {90, 156}}, color = {191, 0, 0}));
        connect(thermalResistor2.port_b, heatCapacitor.port) annotation(
          Line(points = {{20, 40}, {90, 40}, {90, 156}}, color = {191, 0, 0}));
        connect(from_air_T, prescribedTemperature1.T) annotation(
          Line(points = {{-120, 40}, {-72, 40}, {-72, 40}, {-72, 40}}, color = {0, 0, 127}));
        connect(to_air_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, 20}, {-20, 20}, {-20, 30}}, color = {0, 0, 127}));
        connect(from_low_rad, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow.port, thermalResistor.port_a) annotation(
          Line(points = {{-44, -66}, {24, -66}}, color = {191, 0, 0}));
        connect(thermalResistor.port_a, temperatureSensor.port) annotation(
          Line(points = {{24, -66}, {-16, -66}, {-16, -90}, {-34, -90}}, color = {191, 0, 0}));
        connect(temperatureSensor.T, to_lowrad_T) annotation(
          Line(points = {{-54, -90}, {-106, -90}, {-106, -90}, {-110, -90}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-50, 40}, {-30, 40}, {-30, 40}, {-30, 40}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.port_a, thermalResistor2.port_a) annotation(
          Line(points = {{-10, 40}, {0, 40}, {0, 40}, {0, 40}}, color = {191, 0, 0}));
        connect(from_batrad_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-116, -10}, {-62, -10}, {-62, -10}, {-62, -10}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow1.port, thermalResistor1.port_a) annotation(
          Line(points = {{-42, -10}, {32, -10}}, color = {191, 0, 0}));
        connect(to_battrad_T, temperatureSensor1.T) annotation(
          Line(points = {{-110, -38}, {-58, -38}}, color = {0, 0, 127}));
        connect(temperatureSensor1.port, thermalResistor1.port_a) annotation(
          Line(points = {{-38, -38}, {-10, -38}, {-10, -10}, {32, -10}}, color = {191, 0, 0}));
        connect(to_hightemp_T, temperatureSensor2.T) annotation(
          Line(points = {{-114, 106}, {-62, 106}}, color = {0, 0, 127}));
        connect(from_hightemp_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-120, 134}, {-66, 134}}, color = {0, 0, 127}));
        connect(heatCapacitor2.port, thermalResistor.port_a) annotation(
          Line(points = {{8, -50}, {8, -50}, {8, -66}, {24, -66}, {24, -66}}, color = {191, 0, 0}));
        connect(heatCapacitor3.port, thermalResistor1.port_a) annotation(
          Line(points = {{8, 4}, {8, 4}, {8, -10}, {32, -10}, {32, -10}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow2.port, heatCapacitor.port) annotation(
          Line(points = {{-46, 134}, {90, 134}, {90, 156}, {90, 156}}, color = {191, 0, 0}));
        connect(temperatureSensor2.port, heatCapacitor.port) annotation(
          Line(points = {{-42, 106}, {90, 106}, {90, 156}, {90, 156}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Text(origin = {-129, 151}, extent = {{-53, 35}, {315, -343}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end radiator_comp;

      model condenser_comp
        parameter Modelica.SIunits.HeatCapacity condenser_C = 1.0 "condenser heat capacity";
        parameter Modelica.SIunits.ThermalResistance condenser_highrad_R = 0.1 "condenser thermal resistance for high rad";
        parameter Modelica.SIunits.ThermalResistance chiller_condenser_R = 0.1 "chiller thermal resistance for condenser";
        parameter Modelica.SIunits.ThermalResistance condenser_hvac_R = 0.1 "condenser thermal resistance for hvac";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = condenser_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hig_rad annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_highvrad_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-208, -46}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hvac_T annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_lowrad_T annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hvac_Q annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 52}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-20, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_lowrad_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 150}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {-44, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-60, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {-22, 100}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_chiller_T annotation(
          Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -144}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_chiller_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 74}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -190}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor2(R = chiller_condenser_R) annotation(
          Placement(visible = true, transformation(origin = {36, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature2 annotation(
          Placement(visible = true, transformation(origin = {-62, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor2 annotation(
          Placement(visible = true, transformation(origin = {-18, -10}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = condenser_hvac_R) annotation(
          Placement(visible = true, transformation(origin = {32, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor dummy1(R = condenser_highrad_R) annotation(
          Placement(visible = true, transformation(origin = {34, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_lowrad_T, prescribedTemperature1.T) annotation(
          Line(points = {{-120, 40}, {-72, 40}, {-72, 40}, {-72, 40}}, color = {0, 0, 127}));
        connect(to_lowrad_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, 20}, {-20, 20}, {-20, 30}}, color = {0, 0, 127}));
        connect(from_hig_rad, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(temperatureSensor.T, to_highvrad_T) annotation(
          Line(points = {{-54, -90}, {-106, -90}, {-106, -90}, {-110, -90}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-50, 40}, {-30, 40}, {-30, 40}, {-30, 40}}, color = {191, 0, 0}));
        connect(prescribedTemperature.port, heatFlowSensor.port_b) annotation(
          Line(points = {{-50, 100}, {-32, 100}}, color = {191, 0, 0}));
        connect(from_chiller_T, prescribedTemperature.T) annotation(
          Line(points = {{-120, 100}, {-72, 100}}, color = {0, 0, 127}));
        connect(to_chiller_Q, heatFlowSensor.Q_flow) annotation(
          Line(points = {{-110, 74}, {-22, 74}, {-22, 90}, {-22, 90}}, color = {0, 0, 127}));
        connect(heatFlowSensor.port_a, thermalResistor2.port_a) annotation(
          Line(points = {{-12, 100}, {26, 100}, {26, 100}, {26, 100}}, color = {191, 0, 0}));
        connect(thermalResistor2.port_b, heatCapacitor.port) annotation(
          Line(points = {{46, 100}, {92, 100}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(prescribedTemperature2.port, heatFlowSensor2.port_b) annotation(
          Line(points = {{-52, -10}, {-28, -10}, {-28, -10}, {-28, -10}, {-28, -10}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.port_a, thermalResistor1.port_a) annotation(
          Line(points = {{-8, -10}, {22, -10}, {22, -10}, {22, -10}}, color = {191, 0, 0}));
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{42, -10}, {92, -10}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(from_hvac_T, prescribedTemperature2.T) annotation(
          Line(points = {{-116, -10}, {-74, -10}, {-74, -10}, {-74, -10}}, color = {0, 0, 127}));
        connect(to_hvac_Q, heatFlowSensor2.Q_flow) annotation(
          Line(points = {{-110, -38}, {-18, -38}, {-18, -20}, {-18, -20}}, color = {0, 0, 127}));
        connect(heatFlowSensor1.port_a, dummy1.port_a) annotation(
          Line(points = {{-10, 40}, {24, 40}, {24, 40}, {24, 40}}, color = {191, 0, 0}));
        connect(dummy1.port_b, heatCapacitor.port) annotation(
          Line(points = {{44, 40}, {92, 40}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-44, -66}, {92, -66}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(temperatureSensor.port, heatCapacitor.port) annotation(
          Line(points = {{-34, -90}, {92, -90}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Text(origin = {-133, 153}, extent = {{-53, 35}, {327, -343}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end condenser_comp;

      model chiller_comp
        parameter Modelica.SIunits.ThermalResistance ac_chiller_R = 0.1 "ac thermal resistance for chiller";
        parameter Modelica.SIunits.HeatCapacity chiller_C = 4.2 "chillerheat capacity";
        parameter Modelica.SIunits.ThermalResistance chiller_water_R = 1.6 "chiller thermal resistance for water";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = chiller_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_condenser_Q annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 196}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_batrad_T annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 22}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_condenser_T annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-212, 148}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-20, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_batrad_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -28}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-52, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor1 annotation(
          Placement(visible = true, transformation(origin = {-48, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-60, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {-22, 100}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_ac_T annotation(
          Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -138}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_ac_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 74}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-212, -184}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor chiller_R(R = chiller_water_R) annotation(
          Placement(visible = true, transformation(origin = {42, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = ac_chiller_R) annotation(
          Placement(visible = true, transformation(origin = {42, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_batrad_T, prescribedTemperature1.T) annotation(
          Line(points = {{-120, 40}, {-72, 40}, {-72, 40}, {-72, 40}}, color = {0, 0, 127}));
        connect(to_batrad_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, 20}, {-20, 20}, {-20, 30}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-50, 40}, {-30, 40}, {-30, 40}, {-30, 40}}, color = {191, 0, 0}));
        connect(from_condenser_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-116, -10}, {-62, -10}, {-62, -10}, {-62, -10}}, color = {0, 0, 127}));
        connect(to_condenser_T, temperatureSensor1.T) annotation(
          Line(points = {{-110, -38}, {-58, -38}}, color = {0, 0, 127}));
        connect(prescribedTemperature.port, heatFlowSensor.port_b) annotation(
          Line(points = {{-50, 100}, {-32, 100}}, color = {191, 0, 0}));
        connect(from_ac_T, prescribedTemperature.T) annotation(
          Line(points = {{-120, 100}, {-72, 100}}, color = {0, 0, 127}));
        connect(to_ac_Q, heatFlowSensor.Q_flow) annotation(
          Line(points = {{-110, 74}, {-22, 74}, {-22, 90}, {-22, 90}}, color = {0, 0, 127}));
        connect(heatFlowSensor1.port_a, chiller_R.port_a) annotation(
          Line(points = {{-10, 40}, {30, 40}, {30, 40}, {32, 40}}, color = {191, 0, 0}));
        connect(chiller_R.port_b, heatCapacitor.port) annotation(
          Line(points = {{52, 40}, {92, 40}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(heatFlowSensor.port_a, thermalResistor.port_a) annotation(
          Line(points = {{-12, 100}, {34, 100}, {34, 100}, {32, 100}, {32, 100}}, color = {191, 0, 0}));
        connect(thermalResistor.port_b, heatCapacitor.port) annotation(
          Line(points = {{52, 100}, {92, 100}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow1.port, heatCapacitor.port) annotation(
          Line(points = {{-42, -10}, {92, -10}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(temperatureSensor1.port, heatCapacitor.port) annotation(
          Line(points = {{-38, -38}, {92, -38}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Text(origin = {-31, 65}, extent = {{-169, 131}, {221, -253}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end chiller_comp;

      model el_ac_comp
        parameter Modelica.SIunits.HeatCapacity el_ac_C = 300;
        parameter Modelica.SIunits.ThermalResistance ac_hvac_R = 0.1 "ac thermal resistance for hvac";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = el_ac_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {94, 132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_chiller_Q annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 194}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_chiller_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 148}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hvac_T annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hvac_Q annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-212, -188}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {-44, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_AC_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 90}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -2}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-56, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = ac_hvac_R) annotation(
          Placement(visible = true, transformation(origin = {18, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-34, -10}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-68, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_chiller_Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(temperatureSensor.T, to_chiller_T) annotation(
          Line(points = {{-54, -90}, {-106, -90}, {-106, -90}, {-110, -90}}, color = {0, 0, 127}));
        connect(from_AC_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-120, 90}, {-66, 90}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow2.port, heatCapacitor.port) annotation(
          Line(points = {{-46, 90}, {94, 90}, {94, 122}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-44, -66}, {94, -66}, {94, 122}}, color = {191, 0, 0}));
        connect(temperatureSensor.port, heatCapacitor.port) annotation(
          Line(points = {{-34, -90}, {94, -90}, {94, 122}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.port_a, thermalResistor1.port_a) annotation(
          Line(points = {{-24, -10}, {8, -10}}, color = {191, 0, 0}));
        connect(to_hvac_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, -38}, {-34, -38}, {-34, -20}, {-34, -20}}, color = {0, 0, 127}));
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{28, -10}, {94, -10}, {94, 122}, {94, 122}}, color = {191, 0, 0}));
        connect(from_hvac_T, prescribedTemperature.T) annotation(
          Line(points = {{-116, -10}, {-80, -10}, {-80, -10}, {-80, -10}}, color = {0, 0, 127}));
        connect(prescribedTemperature.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-58, -10}, {-44, -10}, {-44, -10}, {-44, -10}, {-44, -10}}, color = {191, 0, 0}));
        connect(to_hvac_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, -38}, {-34, -38}, {-34, -20}, {-34, -20}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-39, 75}, extent = {{-149, 117}, {221, -267}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)));
      end el_ac_comp;

      model engine_comp
        parameter Modelica.SIunits.HeatCapacity c = 4.2;
        parameter Modelica.SIunits.ThermalResistance engine1_water_R = 1.6;
        parameter Modelica.SIunits.ThermalResistance engine2_water_R = 1.6;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = c, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {98, 188}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engineloss annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_engine_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-208, -166}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_launch_Q annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -18}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_case_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -140}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_launch_TempEng annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -68}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_case_TempEng annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -190}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hightempthermal_T annotation(
          Placement(visible = true, transformation(origin = {-118, 92}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 98}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature2 annotation(
          Placement(visible = true, transformation(origin = {-60, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor2 annotation(
          Placement(visible = true, transformation(origin = {-20, 92}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hightempthermal_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 68}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 48}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {72, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor3 annotation(
          Placement(visible = true, transformation(origin = {-22, 154}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature3 annotation(
          Placement(visible = true, transformation(origin = {-62, 154}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hightempthermal2_T annotation(
          Placement(visible = true, transformation(origin = {-120, 154}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 200}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hightempthermal2_Q annotation(
          Placement(visible = true, transformation(origin = {-112, 130}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = engine1_water_R) annotation(
          Placement(visible = true, transformation(origin = {36, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor2(R = engine2_water_R) annotation(
          Placement(visible = true, transformation(origin = {36, 154}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-56, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-56, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_hightempthermal_T, prescribedTemperature2.T) annotation(
          Line(points = {{-118, 92}, {-72, 92}}, color = {0, 0, 127}));
        connect(heatFlowSensor2.Q_flow, to_hightempthermal_Q) annotation(
          Line(points = {{-20, 82}, {-20, 68}, {-110, 68}}, color = {0, 0, 127}));
        connect(from_engineloss, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(temperatureSensor.T, to_engine_T) annotation(
          Line(points = {{62, -90}, {-110, -90}}, color = {0, 0, 127}));
        connect(prescribedTemperature2.port, heatFlowSensor2.port_b) annotation(
          Line(points = {{-50, 92}, {-30, 92}}, color = {191, 0, 0}));
        connect(from_hightempthermal2_T, prescribedTemperature3.T) annotation(
          Line(points = {{-120, 154}, {-74, 154}}, color = {0, 0, 127}));
        connect(prescribedTemperature3.port, heatFlowSensor3.port_b) annotation(
          Line(points = {{-52, 154}, {-32, 154}}, color = {191, 0, 0}));
        connect(to_hightempthermal2_Q, heatFlowSensor3.Q_flow) annotation(
          Line(points = {{-112, 130}, {-22, 130}, {-22, 144}}, color = {0, 0, 127}));
        connect(heatFlowSensor2.port_a, thermalResistor1.port_a) annotation(
          Line(points = {{-10, 92}, {26, 92}, {26, 92}, {26, 92}}, color = {191, 0, 0}));
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{46, 92}, {98, 92}, {98, 178}}, color = {191, 0, 0}));
        connect(heatFlowSensor3.port_a, thermalResistor2.port_a) annotation(
          Line(points = {{-12, 154}, {26, 154}, {26, 154}, {26, 154}}, color = {191, 0, 0}));
        connect(thermalResistor2.port_b, heatCapacitor.port) annotation(
          Line(points = {{46, 154}, {98, 154}, {98, 178}, {98, 178}, {98, 178}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-44, -66}, {98, -66}, {98, 178}, {98, 178}, {98, 178}}, color = {191, 0, 0}));
        connect(heatCapacitor.port, temperatureSensor.port) annotation(
          Line(points = {{98, 178}, {98, 178}, {98, -90}, {82, -90}, {82, -90}}, color = {191, 0, 0}));
        connect(from_case_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-120, 40}, {-66, 40}, {-66, 40}, {-66, 40}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow1.port, heatCapacitor.port) annotation(
          Line(points = {{-46, 40}, {98, 40}, {98, 178}, {98, 178}, {98, 178}}, color = {191, 0, 0}));
        connect(temperatureSensor.T, to_case_TempEng) annotation(
          Line(points = {{62, -90}, {54, -90}, {54, 20}, {-110, 20}, {-110, 20}}, color = {0, 0, 127}));
        connect(from_launch_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-116, -10}, {-68, -10}, {-68, -10}, {-66, -10}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow2.port, heatCapacitor.port) annotation(
          Line(points = {{-46, -10}, {98, -10}, {98, 178}, {98, 178}, {98, 178}}, color = {191, 0, 0}));
        connect(temperatureSensor.T, to_launch_TempEng) annotation(
          Line(points = {{62, -90}, {54, -90}, {54, -38}, {-110, -38}, {-110, -38}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-31, 65}, extent = {{-161, 127}, {217, -255}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end engine_comp;

      model at_cooler_comp
        parameter Modelica.SIunits.HeatCapacity at_cooler_C = 4.2 "at_cooler heat capacity";
        parameter Modelica.SIunits.ThermalResistance at_cooler_water_R = 1.6 "at_cooler thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance at_cooler_oil_R = 0.01 "at_cooler thermal resistance for oil";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = at_cooler_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 124}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = at_cooler_water_R) annotation(
          Placement(visible = true, transformation(origin = {28, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hightempthermal_T annotation(
          Placement(visible = true, transformation(origin = {-118, 92}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 180}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature2 annotation(
          Placement(visible = true, transformation(origin = {-60, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor2 annotation(
          Placement(visible = true, transformation(origin = {-22, 92}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hightempthermal_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 68}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = at_cooler_oil_R) annotation(
          Placement(visible = true, transformation(origin = {28, -24}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oil_T annotation(
          Placement(visible = true, transformation(origin = {-116, -24}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -100}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-62, -24}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-22, -24}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oil_Q annotation(
          Placement(visible = true, transformation(origin = {-110, -60}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_hightempthermal_T, prescribedTemperature2.T) annotation(
          Line(points = {{-118, 92}, {-74, 92}, {-74, 92}, {-72, 92}}, color = {0, 0, 127}));
        connect(heatFlowSensor2.Q_flow, to_hightempthermal_Q) annotation(
          Line(points = {{-22, 82}, {-22, 68}, {-110, 68}}, color = {0, 0, 127}));
        connect(prescribedTemperature2.port, heatFlowSensor2.port_b) annotation(
          Line(points = {{-50, 92}, {-32, 92}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.port_a, thermalResistor.port_a) annotation(
          Line(points = {{-12, 92}, {18, 92}}, color = {191, 0, 0}));
        connect(thermalResistor.port_b, heatCapacitor.port) annotation(
          Line(points = {{38, 92}, {92, 92}, {92, 114}}, color = {191, 0, 0}));
        connect(from_oil_T, prescribedTemperature.T) annotation(
          Line(points = {{-116, -24}, {-74, -24}}, color = {0, 0, 127}));
        connect(prescribedTemperature.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-52, -24}, {-32, -24}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.port_a, thermalResistor1.port_a) annotation(
          Line(points = {{-12, -24}, {18, -24}}, color = {191, 0, 0}));
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{38, -24}, {92, -24}, {92, 114}}, color = {191, 0, 0}));
        connect(to_oil_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, -60}, {-22, -60}, {-22, -34}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {25, 27}, extent = {{-165, 129}, {115, -165}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end at_cooler_comp;

      model MG_comp
        parameter Modelica.SIunits.HeatCapacity c = 4.2;
        Modelica.Blocks.Interfaces.RealInput from_mg_loss_Q annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_mg_loss_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 114}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oil_Q annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 200}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_case_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -100}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oil_Tmg annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_case_Tmg annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_lowtempthermal_Q annotation(
          Placement(visible = true, transformation(origin = {-118, 92}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_lowtempthermal_T annotation(
          Placement(visible = true, transformation(origin = {-110, 68}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -150}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-62, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor1 annotation(
          Placement(visible = true, transformation(origin = {32, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-62, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor1(C = c, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {80, 138}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow3 annotation(
          Placement(visible = true, transformation(origin = {-60, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_mg_loss_Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(from_case_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-120, 40}, {-74, 40}, {-74, 40}, {-72, 40}}, color = {0, 0, 127}));
        connect(temperatureSensor1.T, to_case_Tmg) annotation(
          Line(points = {{22, 20}, {-104, 20}, {-104, 20}, {-110, 20}}, color = {0, 0, 127}));
        connect(from_oil_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-116, -10}, {-72, -10}, {-72, -10}, {-72, -10}}, color = {0, 0, 127}));
        connect(to_oil_Tmg, temperatureSensor1.T) annotation(
          Line(points = {{-110, -38}, {20, -38}, {20, 20}, {22, 20}, {22, 20}}, color = {0, 0, 127}));
        connect(temperatureSensor1.T, to_mg_loss_T) annotation(
          Line(points = {{22, 20}, {20, 20}, {20, -90}, {-110, -90}, {-110, -90}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow1.port, heatCapacitor1.port) annotation(
          Line(points = {{-52, 40}, {80, 40}, {80, 128}, {80, 128}, {80, 128}}, color = {191, 0, 0}));
        connect(temperatureSensor1.port, heatCapacitor1.port) annotation(
          Line(points = {{42, 20}, {80, 20}, {80, 128}, {80, 128}, {80, 128}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow2.port, heatCapacitor1.port) annotation(
          Line(points = {{-52, -10}, {80, -10}, {80, 128}, {80, 128}, {80, 128}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow.port, heatCapacitor1.port) annotation(
          Line(points = {{-44, -66}, {80, -66}, {80, 128}, {80, 128}, {80, 128}}, color = {191, 0, 0}));
        connect(from_lowtempthermal_Q, prescribedHeatFlow3.Q_flow) annotation(
          Line(points = {{-118, 92}, {-72, 92}, {-72, 92}, {-70, 92}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow3.port, heatCapacitor1.port) annotation(
          Line(points = {{-50, 92}, {80, 92}, {80, 128}, {80, 128}}, color = {191, 0, 0}));
        connect(to_lowtempthermal_T, temperatureSensor1.T) annotation(
          Line(points = {{-110, 68}, {20, 68}, {20, 20}, {22, 20}, {22, 20}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-139, 155}, extent = {{-53, 35}, {331, -345}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end MG_comp;

      model case_comp
        parameter Modelica.SIunits.ThermalResistance oil_case_R = 0.0057 "oil thermal resistance for case";
        parameter Modelica.SIunits.ThermalResistance case_air_R = 1.6 "case thermal resistance for air";
        parameter Modelica.SIunits.ThermalResistance case_mg_R = 1.6 "case thermal resistance for mg";
        parameter Modelica.SIunits.ThermalResistance case_engine_R = 1.6 "case thermal resistance for engine";
        parameter Modelica.SIunits.ThermalResistance case_launch_R = 1.6 "case thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance case_var_R = 1.6 "case thermal resistance for variator";
        parameter Modelica.SIunits.ThermalResistance case_enginecase_R = 100000 "case thermal resistance for enginecase";
        parameter Modelica.SIunits.HeatCapacity case_C = 29.7;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = case_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {100, 236}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = case_mg_R) annotation(
          Placement(visible = true, transformation(origin = {38, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_mG_T annotation(
          Placement(visible = true, transformation(origin = {-104, 52}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 122}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_MG_Q annotation(
          Placement(visible = true, transformation(origin = {-102, 28}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engine_T annotation(
          Placement(visible = true, transformation(origin = {-108, 108}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 192}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oil_T annotation(
          Placement(visible = true, transformation(origin = {-112, 158}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 20}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = case_engine_R) annotation(
          Placement(visible = true, transformation(origin = {38, 108}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_engine_Q annotation(
          Placement(visible = true, transformation(origin = {-102, 80}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-208, 144}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-52, 158}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-12, 158}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oil_Q annotation(
          Placement(visible = true, transformation(origin = {-102, 138}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-52, 218}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {-14, 218}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_airtemp annotation(
          Placement(visible = true, transformation(origin = {-112, 218}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 300}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_air_Q annotation(
          Placement(visible = true, transformation(origin = {-102, 192}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-212, 254}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_launch_Q annotation(
          Placement(visible = true, transformation(origin = {-102, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -128}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_launch_T annotation(
          Placement(visible = true, transformation(origin = {-108, -12}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -78}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor4(R = case_launch_R) annotation(
          Placement(visible = true, transformation(origin = {38, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_ratio_Q annotation(
          Placement(visible = true, transformation(origin = {-104, -102}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -236}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor5(R = case_var_R) annotation(
          Placement(visible = true, transformation(origin = {38, -74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_ratio_T annotation(
          Placement(visible = true, transformation(origin = {-110, -74}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -188}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor2(R = case_air_R) annotation(
          Placement(visible = true, transformation(origin = {38, 218}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor3(R = oil_case_R) annotation(
          Placement(visible = true, transformation(origin = {38, 158}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature2 annotation(
          Placement(visible = true, transformation(origin = {-52, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor2 annotation(
          Placement(visible = true, transformation(origin = {-12, 52}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature3 annotation(
          Placement(visible = true, transformation(origin = {-52, 108}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor3 annotation(
          Placement(visible = true, transformation(origin = {-12, 108}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature4 annotation(
          Placement(visible = true, transformation(origin = {-52, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor4 annotation(
          Placement(visible = true, transformation(origin = {-12, -12}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature5 annotation(
          Placement(visible = true, transformation(origin = {-52, -74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor5 annotation(
          Placement(visible = true, transformation(origin = {-12, -74}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor6(R = case_enginecase_R) annotation(
          Placement(visible = true, transformation(origin = {38, -132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor6 annotation(
          Placement(visible = true, transformation(origin = {-12, -132}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature6 annotation(
          Placement(visible = true, transformation(origin = {-52, -132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor7 annotation(
          Placement(visible = true, transformation(origin = {-12, -192}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature7 annotation(
          Placement(visible = true, transformation(origin = {-52, -192}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_enginecase_Q annotation(
          Placement(visible = true, transformation(origin = {-104, -160}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-212, -58}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_enginecase_T annotation(
          Placement(visible = true, transformation(origin = {-110, -132}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 14}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_transcase_T annotation(
          Placement(visible = true, transformation(origin = {-108, -192}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -126}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_transcase_Q annotation(
          Placement(visible = true, transformation(origin = {-102, -220}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -178}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ConvectiveResistor convectiveResistor annotation(
          Placement(visible = true, transformation(origin = {36, -192}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable1D combiTable1D(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/param/pnt/transcaseResi.txt", tableName = "tab1", tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {-8, -238}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {-162, -238}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -298}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      equation
        connect(heatCapacitor.port, thermalResistor.port_b) annotation(
          Line(points = {{100, 226}, {100, 52}, {48, 52}}, color = {191, 0, 0}));
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{48, 108}, {100, 108}, {100, 226}}, color = {191, 0, 0}));
        connect(from_oil_T, prescribedTemperature1.T) annotation(
          Line(points = {{-112, 158}, {-64, 158}}, color = {0, 0, 127}));
        connect(to_oil_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-102, 138}, {-12, 138}, {-12, 148}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-42, 158}, {-22, 158}}, color = {191, 0, 0}));
        connect(prescribedTemperature.port, heatFlowSensor.port_b) annotation(
          Line(points = {{-42, 218}, {-24, 218}}, color = {191, 0, 0}));
        connect(from_airtemp, prescribedTemperature.T) annotation(
          Line(points = {{-112, 218}, {-64, 218}}, color = {0, 0, 127}));
        connect(to_air_Q, heatFlowSensor.Q_flow) annotation(
          Line(points = {{-102, 192}, {-14, 192}, {-14, 208}}, color = {0, 0, 127}));
        connect(thermalResistor4.port_b, heatCapacitor.port) annotation(
          Line(points = {{48, -12}, {100, -12}, {100, 226}}, color = {191, 0, 0}));
        connect(thermalResistor5.port_b, heatCapacitor.port) annotation(
          Line(points = {{48, -74}, {100, -74}, {100, 226}}, color = {191, 0, 0}));
        connect(heatFlowSensor.port_a, thermalResistor2.port_a) annotation(
          Line(points = {{-4, 218}, {28, 218}}, color = {191, 0, 0}));
        connect(thermalResistor2.port_b, heatCapacitor.port) annotation(
          Line(points = {{48, 218}, {100, 218}, {100, 226}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.port_a, thermalResistor3.port_a) annotation(
          Line(points = {{-2, 158}, {28, 158}}, color = {191, 0, 0}));
        connect(thermalResistor3.port_b, heatCapacitor.port) annotation(
          Line(points = {{48, 158}, {100, 158}, {100, 226}}, color = {191, 0, 0}));
        connect(from_mG_T, prescribedTemperature2.T) annotation(
          Line(points = {{-104, 52}, {-64, 52}}, color = {0, 0, 127}));
        connect(prescribedTemperature2.port, heatFlowSensor2.port_b) annotation(
          Line(points = {{-42, 52}, {-22, 52}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.port_a, thermalResistor.port_a) annotation(
          Line(points = {{-2, 52}, {28, 52}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.Q_flow, to_MG_Q) annotation(
          Line(points = {{-12, 42}, {-12, 28}, {-102, 28}}, color = {0, 0, 127}));
        connect(from_engine_T, prescribedTemperature3.T) annotation(
          Line(points = {{-108, 108}, {-64, 108}}, color = {0, 0, 127}));
        connect(prescribedTemperature3.port, heatFlowSensor3.port_b) annotation(
          Line(points = {{-42, 108}, {-22, 108}}, color = {191, 0, 0}));
        connect(heatFlowSensor3.port_a, thermalResistor1.port_a) annotation(
          Line(points = {{-2, 108}, {28, 108}}, color = {191, 0, 0}));
        connect(heatFlowSensor3.Q_flow, to_engine_Q) annotation(
          Line(points = {{-12, 98}, {-12, 80}, {-102, 80}}, color = {0, 0, 127}));
        connect(from_launch_T, prescribedTemperature4.T) annotation(
          Line(points = {{-108, -12}, {-64, -12}}, color = {0, 0, 127}));
        connect(prescribedTemperature4.port, heatFlowSensor4.port_b) annotation(
          Line(points = {{-42, -12}, {-22, -12}}, color = {191, 0, 0}));
        connect(heatFlowSensor4.port_a, thermalResistor4.port_a) annotation(
          Line(points = {{-2, -12}, {28, -12}}, color = {191, 0, 0}));
        connect(heatFlowSensor4.Q_flow, to_launch_Q) annotation(
          Line(points = {{-12, -22}, {-12, -40}, {-102, -40}}, color = {0, 0, 127}));
        connect(from_ratio_T, prescribedTemperature5.T) annotation(
          Line(points = {{-110, -74}, {-64, -74}}, color = {0, 0, 127}));
        connect(prescribedTemperature5.port, heatFlowSensor5.port_b) annotation(
          Line(points = {{-42, -74}, {-22, -74}}, color = {191, 0, 0}));
        connect(heatFlowSensor5.port_a, thermalResistor5.port_a) annotation(
          Line(points = {{-2, -74}, {28, -74}}, color = {191, 0, 0}));
        connect(to_ratio_Q, heatFlowSensor5.Q_flow) annotation(
          Line(points = {{-104, -102}, {-12, -102}, {-12, -84}}, color = {0, 0, 127}));
        connect(thermalResistor6.port_b, heatCapacitor.port) annotation(
          Line(points = {{48, -132}, {100, -132}, {100, 226}}, color = {191, 0, 0}));
        connect(heatFlowSensor6.port_a, thermalResistor6.port_a) annotation(
          Line(points = {{-2, -132}, {28, -132}}, color = {191, 0, 0}));
        connect(prescribedTemperature6.port, heatFlowSensor6.port_b) annotation(
          Line(points = {{-42, -132}, {-22, -132}}, color = {191, 0, 0}));
        connect(prescribedTemperature7.port, heatFlowSensor7.port_b) annotation(
          Line(points = {{-42, -192}, {-22, -192}}, color = {191, 0, 0}));
        connect(from_enginecase_T, prescribedTemperature6.T) annotation(
          Line(points = {{-110, -132}, {-64, -132}}, color = {0, 0, 127}));
        connect(to_enginecase_Q, heatFlowSensor6.Q_flow) annotation(
          Line(points = {{-104, -160}, {-12, -160}, {-12, -142}}, color = {0, 0, 127}));
        connect(to_transcase_Q, heatFlowSensor7.Q_flow) annotation(
          Line(points = {{-102, -220}, {-12, -220}, {-12, -202}}, color = {0, 0, 127}));
        connect(from_transcase_T, prescribedTemperature7.T) annotation(
          Line(points = {{-108, -192}, {-64, -192}}, color = {0, 0, 127}));
        connect(heatFlowSensor7.port_a, convectiveResistor.solid) annotation(
          Line(points = {{-2, -192}, {26, -192}}, color = {191, 0, 0}));
        connect(convectiveResistor.fluid, heatCapacitor.port) annotation(
          Line(points = {{46, -192}, {100, -192}, {100, 226}}, color = {191, 0, 0}));
        connect(combiTable1D.y[1], convectiveResistor.Rc) annotation(
          Line(points = {{4, -238}, {36, -238}, {36, -202}, {36, -202}}, color = {0, 0, 127}));
        connect(VSP, combiTable1D.u[1]) annotation(
          Line(points = {{-162, -238}, {-20, -238}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-35, 81}, extent = {{-155, 123}, {219, -245}}, textString = "%name"), Rectangle(origin = {-104, 98}, extent = {{-96, 202}, {304, -396}})}, coordinateSystem(extent = {{-200, -300}, {200, 300}})),
          Diagram(coordinateSystem(extent = {{-200, -300}, {200, 300}})));
      end case_comp;

      model launch_comp
        parameter Modelica.SIunits.HeatCapacity launch_C = 9600;
        parameter Modelica.SIunits.ThermalResistance launch_engine_R = 1.6;
        parameter Modelica.SIunits.ThermalResistance engineshaft_launch_R = 100000;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = launch_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_launchloss_Q annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_launchloss_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -146}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engine_T annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oil_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -120}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor1(R = launch_engine_R) annotation(
          Placement(visible = true, transformation(origin = {12, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_engine_Q annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 90}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oil_Tlaunch annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -188}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_case_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 200}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_case_Tlaunch annotation(
          Placement(visible = true, transformation(origin = {-110, 74}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 132}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-50, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor2 annotation(
          Placement(visible = true, transformation(origin = {60, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-60, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-24, -10}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-50, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-62, -130}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {-26, -130}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = engineshaft_launch_R) annotation(
          Placement(visible = true, transformation(origin = {10, -130}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engineshaft_T annotation(
          Placement(visible = true, transformation(origin = {-116, -130}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_enigineshaft_Q annotation(
          Placement(visible = true, transformation(origin = {-114, -154}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -28}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      equation
        connect(thermalResistor1.port_b, heatCapacitor.port) annotation(
          Line(points = {{22, -10}, {92, -10}, {92, 122}}, color = {191, 0, 0}));
        connect(from_launchloss_Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(from_oil_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-120, 40}, {-62, 40}, {-62, 40}, {-60, 40}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow2.port, heatCapacitor.port) annotation(
          Line(points = {{-40, 40}, {92, 40}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(temperatureSensor2.T, to_oil_Tlaunch) annotation(
          Line(points = {{50, 20}, {-102, 20}, {-102, 20}, {-110, 20}}, color = {0, 0, 127}));
        connect(temperatureSensor2.port, heatCapacitor.port) annotation(
          Line(points = {{70, 20}, {92, 20}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(from_engine_T, prescribedTemperature1.T) annotation(
          Line(points = {{-116, -10}, {-72, -10}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-50, -10}, {-34, -10}, {-34, -10}, {-34, -10}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.port_a, thermalResistor1.port_a) annotation(
          Line(points = {{-14, -10}, {2, -10}, {2, -10}, {2, -10}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.Q_flow, to_engine_Q) annotation(
          Line(points = {{-24, -20}, {-24, -20}, {-24, -38}, {-110, -38}, {-110, -38}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-44, -66}, {92, -66}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(temperatureSensor2.T, to_launchloss_T) annotation(
          Line(points = {{50, 20}, {38, 20}, {38, -90}, {-110, -90}, {-110, -90}}, color = {0, 0, 127}));
        connect(from_case_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-120, 100}, {-62, 100}, {-62, 100}, {-60, 100}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow1.port, heatCapacitor.port) annotation(
          Line(points = {{-40, 100}, {92, 100}, {92, 122}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(temperatureSensor2.T, to_case_Tlaunch) annotation(
          Line(points = {{50, 20}, {38, 20}, {38, 74}, {-110, 74}, {-110, 74}}, color = {0, 0, 127}));
        connect(heatFlowSensor.port_a, thermalResistor.port_a) annotation(
          Line(points = {{-16, -130}, {0, -130}, {0, -130}, {0, -130}}, color = {191, 0, 0}));
        connect(prescribedTemperature.port, heatFlowSensor.port_b) annotation(
          Line(points = {{-52, -130}, {-36, -130}, {-36, -130}, {-36, -130}}, color = {191, 0, 0}));
        connect(thermalResistor.port_b, heatCapacitor.port) annotation(
          Line(points = {{20, -130}, {92, -130}, {92, 122}, {92, 122}}, color = {191, 0, 0}));
        connect(from_engineshaft_T, prescribedTemperature.T) annotation(
          Line(points = {{-116, -130}, {-76, -130}, {-76, -130}, {-74, -130}}, color = {0, 0, 127}));
        connect(heatFlowSensor.Q_flow, to_enigineshaft_Q) annotation(
          Line(points = {{-26, -140}, {-26, -140}, {-26, -154}, {-114, -154}, {-114, -154}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-37, 69}, extent = {{-151, 119}, {223, -257}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end launch_comp;

      model vat_comp
        parameter Modelica.SIunits.HeatCapacity variator_C = 17000;
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = variator_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_var_loss_Q annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_var_loss_T annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-208, -166}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oil_Q annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -140}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_case_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 178}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oil_Tvat annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -188}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_case_Tvat annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 128}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-54, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-54, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor1 annotation(
          Placement(visible = true, transformation(origin = {58, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow2 annotation(
          Placement(visible = true, transformation(origin = {-54, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_var_loss_Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-112, -66}, {-64, -66}, {-64, -66}, {-64, -66}}, color = {0, 0, 127}));
        connect(from_oil_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-116, -10}, {-64, -10}, {-64, -10}, {-64, -10}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow1.port, heatCapacitor.port) annotation(
          Line(points = {{-44, -10}, {92, -10}, {92, 80}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        connect(temperatureSensor1.T, to_oil_Tvat) annotation(
          Line(points = {{48, -38}, {-104, -38}, {-104, -38}, {-110, -38}}, color = {0, 0, 127}));
        connect(temperatureSensor1.port, heatCapacitor.port) annotation(
          Line(points = {{68, -38}, {92, -38}, {92, 80}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        connect(from_case_Q, prescribedHeatFlow2.Q_flow) annotation(
          Line(points = {{-120, 40}, {-66, 40}, {-66, 40}, {-64, 40}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow2.port, heatCapacitor.port) annotation(
          Line(points = {{-44, 40}, {92, 40}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        connect(temperatureSensor1.T, to_case_Tvat) annotation(
          Line(points = {{48, -38}, {40, -38}, {40, 20}, {-110, 20}, {-110, 20}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-44, -66}, {92, -66}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        connect(temperatureSensor1.T, to_var_loss_T) annotation(
          Line(points = {{48, -38}, {40, -38}, {40, -90}, {-110, -90}, {-110, -90}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Text(origin = {-31, 65}, extent = {{-159, 123}, {215, -251}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end vat_comp;

      model oil_comp
        parameter Modelica.SIunits.HeatCapacity oil_C = 9400;
        parameter Modelica.SIunits.ThermalResistance oil_mg_R = 0.05 "oil thermal resistance for mg";
        parameter Modelica.SIunits.ThermalResistance oil_case_R = 0.0057 "oil thermal resistance for case";
        parameter Modelica.SIunits.ThermalResistance oil_launch_R = 0.00073 "oil thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance oil_variator_R = 0.047 "oil thermal resistance for variator";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = oil_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {104, 222}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = oil_mg_R) annotation(
          Placement(visible = true, transformation(origin = {56, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_mG_T annotation(
          Placement(visible = true, transformation(origin = {-102, -14}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, -140}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_MG_Q annotation(
          Placement(visible = true, transformation(origin = {-100, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -190}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_case_Q annotation(
          Placement(visible = true, transformation(origin = {-106, 42}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 0}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_case_Toil annotation(
          Placement(visible = true, transformation(origin = {-100, 14}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -48}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow1 annotation(
          Placement(visible = true, transformation(origin = {-42, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_launch_Q annotation(
          Placement(visible = true, transformation(origin = {-100, -106}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 200}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_launch_T annotation(
          Placement(visible = true, transformation(origin = {-106, -78}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 250}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor4(R = oil_launch_R) annotation(
          Placement(visible = true, transformation(origin = {54, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_ratio_Q annotation(
          Placement(visible = true, transformation(origin = {-102, -170}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor5(R = oil_variator_R) annotation(
          Placement(visible = true, transformation(origin = {54, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_ratio_T annotation(
          Placement(visible = true, transformation(origin = {-108, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {220, 120}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor4 annotation(
          Placement(visible = true, transformation(origin = {0, 152}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput oil_temp annotation(
          Placement(visible = true, transformation(origin = {-100, 152}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -188}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oilcooler_Q annotation(
          Placement(visible = true, transformation(origin = {-106, 106}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-224, 182}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow4 annotation(
          Placement(visible = true, transformation(origin = {-42, 106}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-42, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {-2, -14}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-42, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-2, -78}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature2 annotation(
          Placement(visible = true, transformation(origin = {-42, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor2 annotation(
          Placement(visible = true, transformation(origin = {-2, -140}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oilcooler_Toil annotation(
          Placement(visible = true, transformation(origin = {-100, 78}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-212, 112}, extent = {{-10, -10}, {10, 10}}, rotation = 180)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {-44, 196}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hyd_Q annotation(
          Placement(visible = true, transformation(origin = {-106, 196}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -28}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
      equation
        connect(heatCapacitor.port, thermalResistor.port_b) annotation(
          Line(points = {{104, 212}, {104, -14}, {66, -14}}, color = {191, 0, 0}));
        connect(from_case_Q, prescribedHeatFlow1.Q_flow) annotation(
          Line(points = {{-106, 42}, {-52, 42}}, color = {0, 0, 127}));
        connect(thermalResistor4.port_b, heatCapacitor.port) annotation(
          Line(points = {{64, -78}, {104, -78}, {104, 212}}, color = {191, 0, 0}));
        connect(thermalResistor5.port_b, heatCapacitor.port) annotation(
          Line(points = {{64, -140}, {104, -140}, {104, 212}}, color = {191, 0, 0}));
        connect(temperatureSensor4.port, heatCapacitor.port) annotation(
          Line(points = {{10, 152}, {104, 152}, {104, 212}}, color = {191, 0, 0}));
        connect(temperatureSensor4.T, oil_temp) annotation(
          Line(points = {{-10, 152}, {-100, 152}}, color = {0, 0, 127}));
        connect(from_oilcooler_Q, prescribedHeatFlow4.Q_flow) annotation(
          Line(points = {{-106, 106}, {-52, 106}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow4.port, heatCapacitor.port) annotation(
          Line(points = {{-32, 106}, {104, 106}, {104, 212}}, color = {191, 0, 0}));
        connect(prescribedHeatFlow1.port, heatCapacitor.port) annotation(
          Line(points = {{-32, 42}, {104, 42}, {104, 212}}, color = {191, 0, 0}));
        connect(temperatureSensor4.T, to_case_Toil) annotation(
          Line(points = {{-10, 152}, {-72, 152}, {-72, 14}, {-100, 14}}, color = {0, 0, 127}));
        connect(from_mG_T, prescribedTemperature.T) annotation(
          Line(points = {{-102, -14}, {-54, -14}}, color = {0, 0, 127}));
        connect(prescribedTemperature.port, heatFlowSensor.port_b) annotation(
          Line(points = {{-32, -14}, {-12, -14}}, color = {191, 0, 0}));
        connect(heatFlowSensor.port_a, thermalResistor.port_a) annotation(
          Line(points = {{8, -14}, {46, -14}}, color = {191, 0, 0}));
        connect(heatFlowSensor.Q_flow, to_MG_Q) annotation(
          Line(points = {{-2, -24}, {-2, -38}, {-100, -38}}, color = {0, 0, 127}));
        connect(from_launch_T, prescribedTemperature1.T) annotation(
          Line(points = {{-106, -78}, {-54, -78}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-32, -78}, {-12, -78}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.port_a, thermalResistor4.port_a) annotation(
          Line(points = {{8, -78}, {44, -78}}, color = {191, 0, 0}));
        connect(heatFlowSensor1.Q_flow, to_launch_Q) annotation(
          Line(points = {{-2, -88}, {-2, -106}, {-100, -106}}, color = {0, 0, 127}));
        connect(from_ratio_T, prescribedTemperature2.T) annotation(
          Line(points = {{-108, -140}, {-54, -140}}, color = {0, 0, 127}));
        connect(prescribedTemperature2.port, heatFlowSensor2.port_b) annotation(
          Line(points = {{-32, -140}, {-12, -140}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.port_a, thermalResistor5.port_a) annotation(
          Line(points = {{8, -140}, {44, -140}}, color = {191, 0, 0}));
        connect(heatFlowSensor2.Q_flow, to_ratio_Q) annotation(
          Line(points = {{-2, -150}, {-2, -170}, {-102, -170}}, color = {0, 0, 127}));
        connect(temperatureSensor4.T, to_oilcooler_Toil) annotation(
          Line(points = {{-10, 152}, {-72, 152}, {-72, 78}, {-100, 78}}, color = {0, 0, 127}));
        connect(from_hyd_Q, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-106, 196}, {-54, 196}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow.port, heatCapacitor.port) annotation(
          Line(points = {{-34, 196}, {104, 196}, {104, 212}, {104, 212}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Text(origin = {-141, 157}, extent = {{-53, 35}, {331, -339}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 150}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 250}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 250}})));
      end oil_comp;

      model ptc_cont_Q
        parameter Modelica.SIunits.Temperature ptc_threshold1 = 263.15;
        parameter Modelica.SIunits.Temperature ptc_threshold2 = 253.15;
        parameter Modelica.SIunits.Temperature ptc_threshold3 = 243.15;
        Modelica.Blocks.Tables.CombiTable1D combiTable1D(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/param/pnt/ptc_Q.txt", tableName = "tab1", tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {-64, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum(nu = 3) annotation(
          Placement(visible = true, transformation(origin = {40, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Logical.Switch switch1 annotation(
          Placement(visible = true, transformation(origin = {0, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Logical.Switch switch annotation(
          Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Logical.Switch switch2 annotation(
          Placement(visible = true, transformation(origin = {0, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const(k = 0) annotation(
          Placement(visible = true, transformation(origin = {-43, -85}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
        Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold = ptc_threshold1) annotation(
          Placement(visible = true, transformation(origin = {-38, 52}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Logical.LessThreshold lessThreshold3(threshold = ptc_threshold2) annotation(
          Placement(visible = true, transformation(origin = {-38, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Logical.LessThreshold lessThreshold4(threshold = ptc_threshold3) annotation(
          Placement(visible = true, transformation(origin = {-38, -60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ptc_temp_in annotation(
          Placement(visible = true, transformation(origin = {-113, 69}, extent = {{-9, -9}, {9, 9}}, rotation = 0), iconTransformation(origin = {-113, 69}, extent = {{-9, -9}, {9, 9}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput coolant_temp_in annotation(
          Placement(visible = true, transformation(origin = {-111, 43}, extent = {{-9, -9}, {9, 9}}, rotation = 0), iconTransformation(origin = {-111, 43}, extent = {{-9, -9}, {9, 9}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PTC_Q annotation(
          Placement(visible = true, transformation(origin = {108, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {108, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable1D combiTable1D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/param/pnt/ptc_Q.txt", tableName = "tab1", tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {-64, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable1D combiTable1D2(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/param/pnt/ptc_Q.txt", tableName = "tab1", tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {-64, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Logical.Switch switch3 annotation(
          Placement(visible = true, transformation(origin = {76, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.BooleanInput AC_Onoff annotation(
          Placement(visible = true, transformation(origin = {-112, -96}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-112, -96}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      equation
        connect(switch1.y, multiSum.u[1]) annotation(
          Line(points = {{12, 52}, {20, 52}, {20, 0}, {30, 0}, {30, 0}}, color = {0, 0, 127}));
        connect(switch.y, multiSum.u[2]) annotation(
          Line(points = {{12, 0}, {30, 0}, {30, 0}, {30, 0}}, color = {0, 0, 127}));
        connect(switch2.y, multiSum.u[3]) annotation(
          Line(points = {{12, -60}, {20, -60}, {20, 0}, {30, 0}, {30, 0}}, color = {0, 0, 127}));
        connect(combiTable1D.y[1], switch1.u1) annotation(
          Line(points = {{-52, 60}, {-12, 60}, {-12, 60}, {-12, 60}}, color = {0, 0, 127}));
        connect(lessThreshold.y, switch1.u2) annotation(
          Line(points = {{-31, 52}, {-12, 52}}, color = {255, 0, 255}));
        connect(lessThreshold4.y, switch2.u2) annotation(
          Line(points = {{-32, -60}, {-12, -60}, {-12, -60}, {-12, -60}}, color = {255, 0, 255}));
        connect(ptc_temp_in, combiTable1D.u[1]) annotation(
          Line(points = {{-112, 70}, {-88, 70}, {-88, 60}, {-76, 60}, {-76, 60}}, color = {0, 0, 127}));
        connect(coolant_temp_in, lessThreshold.u) annotation(
          Line(points = {{-110, 44}, {-50, 44}, {-50, 52}, {-46, 52}, {-46, 52}}, color = {0, 0, 127}));
        connect(coolant_temp_in, lessThreshold3.u) annotation(
          Line(points = {{-110, 44}, {-50, 44}, {-50, 0}, {-45, 0}}, color = {0, 0, 127}));
        connect(coolant_temp_in, lessThreshold4.u) annotation(
          Line(points = {{-110, 44}, {-50, 44}, {-50, -60}, {-46, -60}, {-46, -60}}, color = {0, 0, 127}));
        connect(const.y, switch1.u3) annotation(
          Line(points = {{-36, -84}, {-20, -84}, {-20, 44}, {-12, 44}, {-12, 44}}, color = {0, 0, 127}));
        connect(const.y, switch.u3) annotation(
          Line(points = {{-36, -84}, {-20, -84}, {-20, -8}, {-12, -8}, {-12, -8}}, color = {0, 0, 127}));
        connect(const.y, switch2.u3) annotation(
          Line(points = {{-36, -84}, {-20, -84}, {-20, -68}, {-12, -68}, {-12, -68}}, color = {0, 0, 127}));
        connect(lessThreshold3.y, switch.u2) annotation(
          Line(points = {{-32, 0}, {-12, 0}, {-12, 0}, {-12, 0}}, color = {255, 0, 255}));
        connect(combiTable1D1.y[1], switch.u1) annotation(
          Line(points = {{-53, 8}, {-12, 8}}, color = {0, 0, 127}));
        connect(combiTable1D2.y[1], switch2.u1) annotation(
          Line(points = {{-52, -50}, {-14, -50}, {-14, -52}, {-12, -52}}, color = {0, 0, 127}));
        connect(ptc_temp_in, combiTable1D1.u[1]) annotation(
          Line(points = {{-112, 70}, {-88, 70}, {-88, 8}, {-76, 8}, {-76, 8}}, color = {0, 0, 127}));
        connect(ptc_temp_in, combiTable1D2.u[1]) annotation(
          Line(points = {{-112, 70}, {-88, 70}, {-88, -50}, {-76, -50}, {-76, -50}}, color = {0, 0, 127}));
        connect(switch3.y, PTC_Q) annotation(
          Line(points = {{88, 0}, {100, 0}, {100, 0}, {108, 0}}, color = {0, 0, 127}));
        connect(multiSum.y, switch3.u1) annotation(
          Line(points = {{52, 0}, {56, 0}, {56, 8}, {64, 8}, {64, 8}}, color = {0, 0, 127}));
        connect(const.y, switch3.u3) annotation(
          Line(points = {{-36, -84}, {58, -84}, {58, -8}, {64, -8}, {64, -8}}, color = {0, 0, 127}));
        connect(AC_Onoff, switch3.u2) annotation(
          Line(points = {{-112, -96}, {60, -96}, {60, 0}, {64, 0}, {64, 0}}, color = {255, 0, 255}));
      end ptc_cont_Q;

      model rad_wp
        parameter String controlFile = currDir + "/param/cnt/coolant_WP_Q.txt", controlTable = "tab1", powerFile = currDir + "/param/pnt/Q_W.txt", powerTable = "tab1";
        Modelica.Blocks.Tables.CombiTable1D combiTable1D(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = controlFile, tableName = controlTable, tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {-16, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable1D combiTable1D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = powerFile, tableName = powerTable, tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {24, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput y annotation(
          Placement(visible = true, transformation(origin = {104, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput coolant_temp annotation(
          Placement(visible = true, transformation(origin = {-102, 42}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-102, 42}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput power annotation(
          Placement(visible = true, transformation(origin = {104, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {104, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(combiTable1D.y[1], combiTable1D1.u[1]) annotation(
          Line(points = {{-4, 42}, {2, 42}, {2, -12}, {12, -12}, {12, -12}}, color = {0, 0, 127}, thickness = 0.5));
        connect(combiTable1D.y[1], y) annotation(
          Line(points = {{-4, 42}, {104, 42}}, color = {0, 0, 127}));
        connect(coolant_temp, combiTable1D.u[1]) annotation(
          Line(points = {{-102, 42}, {-30, 42}, {-30, 42}, {-28, 42}}, color = {0, 0, 127}));
        connect(combiTable1D1.y[1], power) annotation(
          Line(points = {{36, -12}, {96, -12}, {96, -12}, {104, -12}}, color = {0, 0, 127}));
      end rad_wp;

      model valve_sw_cont
        parameter Modelica.SIunits.Temperature hysLOW = 343.15;
        parameter Modelica.SIunits.Temperature hysHIGH = 358.15;
        parameter Modelica.SIunits.DimensionlessRatio ONrate = 1;
        parameter Modelica.SIunits.DimensionlessRatio OFFrate = 0;
        Modelica.Blocks.Logical.Hysteresis hysteresis(uHigh = hysHIGH, uLow = hysLOW) annotation(
          Placement(visible = true, transformation(origin = {-40, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Logical.Switch switch1 annotation(
          Placement(visible = true, transformation(origin = {40, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const(k = ONrate) annotation(
          Placement(visible = true, transformation(origin = {0, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant constant1(k = OFFrate) annotation(
          Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput switch_temp annotation(
          Placement(visible = true, transformation(origin = {-110, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput valve_rate annotation(
          Placement(visible = true, transformation(origin = {108, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {108, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(hysteresis.y, switch1.u2) annotation(
          Line(points = {{-28, 0}, {28, 0}, {28, 0}, {28, 0}}, color = {255, 0, 255}));
        connect(const.y, switch1.u1) annotation(
          Line(points = {{11, 20}, {18, 20}, {18, 8}, {28, 8}}, color = {0, 0, 127}));
        connect(constant1.y, switch1.u3) annotation(
          Line(points = {{12, -20}, {18, -20}, {18, -8}, {28, -8}, {28, -8}}, color = {0, 0, 127}));
        connect(switch_temp, hysteresis.u) annotation(
          Line(points = {{-110, 0}, {-52, 0}, {-52, 0}, {-52, 0}}, color = {0, 0, 127}));
        connect(switch1.y, valve_rate) annotation(
          Line(points = {{52, 0}, {100, 0}, {100, 0}, {108, 0}}, color = {0, 0, 127}));
      end valve_sw_cont;

      model ac_control
        parameter String ACcontrolFile = currDir + "/param/cnt/difftemp_AC_Q.txt", ACcontrolTable = "tab1", ACpowerFile = currDir + "/param/pnt/Q_W_AC.txt", ACpowerTable = "tab1";
        Modelica.Blocks.Tables.CombiTable1D combiTable1D(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = ACcontrolFile, tableName = ACcontrolTable, tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {-18, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable1D combiTable1D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = ACpowerFile, tableName = ACpowerTable, tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {46, -42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput y annotation(
          Placement(visible = true, transformation(origin = {102, 12}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {102, 12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput cabin_temp annotation(
          Placement(visible = true, transformation(origin = {-110, 28}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, 28}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput power annotation(
          Placement(visible = true, transformation(origin = {102, -42}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {102, -42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Logical.Switch switch1 annotation(
          Placement(visible = true, transformation(origin = {16, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const(k = 0) annotation(
          Placement(visible = true, transformation(origin = {-22, -54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Add add(k1 = -1) annotation(
          Placement(visible = true, transformation(origin = {-58, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.BooleanInput AC_OnOff annotation(
          Placement(visible = true, transformation(origin = {-110, -16}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, -16}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ac_set_temp annotation(
          Placement(visible = true, transformation(origin = {-110, 82}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, 82}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      equation
        connect(combiTable1D1.y[1], power) annotation(
          Line(points = {{57, -42}, {102, -42}}, color = {0, 0, 127}));
        connect(combiTable1D.y[1], switch1.u1) annotation(
          Line(points = {{-7, 28}, {-1, 28}, {-1, 12}, {4, 12}}, color = {0, 0, 127}));
        connect(switch1.y, y) annotation(
          Line(points = {{27, 4}, {56, 4}, {56, 12}, {102, 12}}, color = {0, 0, 127}));
        connect(switch1.y, combiTable1D1.u[1]) annotation(
          Line(points = {{27, 4}, {30, 4}, {30, -42}, {34, -42}}, color = {0, 0, 127}));
        connect(const.y, switch1.u3) annotation(
          Line(points = {{-11, -54}, {-4, -54}, {-4, -4}, {4, -4}}, color = {0, 0, 127}));
        connect(cabin_temp, add.u2) annotation(
          Line(points = {{-110, 28}, {-70, 28}}, color = {0, 0, 127}));
        connect(add.y, combiTable1D.u[1]) annotation(
          Line(points = {{-47, 34}, {-40, 34}, {-40, 28}, {-30, 28}}, color = {0, 0, 127}));
        connect(AC_OnOff, switch1.u2) annotation(
          Line(points = {{-110, -16}, {-8, -16}, {-8, 4}, {4, 4}}, color = {255, 0, 255}));
        connect(ac_set_temp, add.u1) annotation(
          Line(points = {{-110, 82}, {-80, 82}, {-80, 40}, {-70, 40}, {-70, 40}}, color = {0, 0, 127}));
        annotation(
          uses(Modelica(version = "3.2.3")));
      end ac_control;

      model valve_t
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a PORT_IN(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b PORT_OUT(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {100, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient2(constantAmbientPressure(displayUnit = "Pa") = 100000, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(extent = {{-40, -10}, {-20, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sensors.VolumeFlowSensor volumeFlowSensor1(T(fixed = false), V_flow(fixed = false), medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-68, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient1(constantAmbientPressure(displayUnit = "Pa") = 100000, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useTemperatureInput = true) annotation(
          Placement(visible = true, transformation(extent = {{34, 30}, {14, 50}}, rotation = 0)));
        Modelica.Blocks.Math.Product product annotation(
          Placement(visible = true, transformation(origin = {-28, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeFlow(T(fixed = true), T0 = Tempinit, V_flow(fixed = false), constantVolumeFlow = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useVolumeFlowInput = true) annotation(
          Placement(visible = true, transformation(origin = {64, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor temperatureSensor(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-34, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {100, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {102, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeFlow1(T(fixed = true), T0 = Tempinit, V_flow(fixed = false), constantVolumeFlow = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useVolumeFlowInput = true) annotation(
          Placement(visible = true, transformation(origin = {68, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient(constantAmbientPressure(displayUnit = "Pa") = 100000, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useTemperatureInput = true) annotation(
          Placement(visible = true, transformation(extent = {{36, -50}, {16, -30}}, rotation = 0)));
        Modelica.Blocks.Math.Add add(k2 = -1) annotation(
          Placement(visible = true, transformation(origin = {-26, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput u annotation(
          Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Math.Add add1 annotation(
          Placement(visible = true, transformation(origin = {36, 76}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const(k = 1e-7) annotation(
          Placement(visible = true, transformation(origin = {2, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const1(k = 1e-7) annotation(
          Placement(visible = true, transformation(origin = {-10, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Add add2 annotation(
          Placement(visible = true, transformation(origin = {26, -72}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(volumeFlowSensor1.flowPort_a, PORT_IN) annotation(
          Line(points = {{-78, 0}, {-94, 0}, {-94, 0}, {-100, 0}}, color = {255, 0, 0}));
        connect(volumeFlowSensor1.flowPort_b, ambient2.flowPort) annotation(
          Line(points = {{-58, 0}, {-42, 0}, {-42, 0}, {-40, 0}, {-40, 0}}, color = {255, 0, 0}));
        connect(volumeFlowSensor1.y, product.u1) annotation(
          Line(points = {{-68, -12}, {-68, -24}, {-58, -24}, {-58, 76}, {-40, 76}}, color = {0, 0, 127}));
        connect(volumeFlow.flowPort_b, PORT_OUT) annotation(
          Line(points = {{74, 40}, {100, 40}}, color = {255, 0, 0}));
        connect(ambient1.flowPort, volumeFlow.flowPort_a) annotation(
          Line(points = {{34, 40}, {54, 40}}, color = {255, 0, 0}));
        connect(temperatureSensor.y, ambient1.ambientTemperature) annotation(
          Line(points = {{-23, 34}, {14, 34}}, color = {0, 0, 127}));
        connect(temperatureSensor.flowPort, PORT_IN) annotation(
          Line(points = {{-44, 34}, {-84, 34}, {-84, 0}, {-100, 0}}, color = {255, 0, 0}));
        connect(volumeFlow1.flowPort_b, flowPort_b) annotation(
          Line(points = {{78, -40}, {94, -40}, {94, -40}, {100, -40}}, color = {255, 0, 0}));
        connect(ambient.flowPort, volumeFlow1.flowPort_a) annotation(
          Line(points = {{36, -40}, {58, -40}}, color = {255, 0, 0}));
        connect(temperatureSensor.y, ambient.ambientTemperature) annotation(
          Line(points = {{-22, 34}, {2, 34}, {2, -46}, {16, -46}, {16, -46}}, color = {0, 0, 127}));
        connect(volumeFlowSensor1.y, add.u1) annotation(
          Line(points = {{-68, -10}, {-68, -10}, {-68, -60}, {-38, -60}, {-38, -60}}, color = {0, 0, 127}));
        connect(product.y, add.u2) annotation(
          Line(points = {{-16, 70}, {-10, 70}, {-10, -40}, {-50, -40}, {-50, -72}, {-38, -72}, {-38, -72}}, color = {0, 0, 127}));
        connect(u, product.u2) annotation(
          Line(points = {{-120, 80}, {-86, 80}, {-86, 64}, {-40, 64}, {-40, 64}, {-40, 64}}, color = {0, 0, 127}));
        connect(product.y, add1.u2) annotation(
          Line(points = {{-16, 70}, {24, 70}}, color = {0, 0, 127}));
        connect(const.y, add1.u1) annotation(
          Line(points = {{14, 90}, {18, 90}, {18, 82}, {24, 82}, {24, 82}}, color = {0, 0, 127}));
        connect(add1.y, volumeFlow.volumeFlow) annotation(
          Line(points = {{48, 76}, {64, 76}, {64, 50}, {64, 50}}, color = {0, 0, 127}));
        connect(add.y, add2.u1) annotation(
          Line(points = {{-14, -66}, {14, -66}, {14, -66}, {14, -66}}, color = {0, 0, 127}));
        connect(const1.y, add2.u2) annotation(
          Line(points = {{2, -90}, {8, -90}, {8, -78}, {14, -78}, {14, -78}}, color = {0, 0, 127}));
        connect(add2.y, volumeFlow1.volumeFlow) annotation(
          Line(points = {{38, -72}, {46, -72}, {46, -20}, {68, -20}, {68, -30}, {68, -30}}, color = {0, 0, 127}));
      end valve_t;

      model water_pump_t
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient1(constantAmbientPressure(displayUnit = "Pa") = 100000, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useTemperatureInput = true) annotation(
          Placement(visible = true, transformation(extent = {{14, -4}, {-6, 16}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor temperatureSensor(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-76, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeFlow(T(fixed = true), T0 = Tempinit, V_flow(fixed = false), constantVolumeFlow = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useVolumeFlowInput = true) annotation(
          Placement(visible = true, transformation(origin = {40, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient2(constantAmbientPressure(displayUnit = "Pa") = 100000, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(extent = {{-66, -50}, {-46, -30}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.1, y(fixed = true), y_start = Tempinit) annotation(
          Placement(visible = true, transformation(origin = {-32, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowPort_a(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-100, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-102, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput pump_m3ps annotation(
          Placement(visible = true, transformation(origin = {-106, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const(k = 1e-7) annotation(
          Placement(visible = true, transformation(origin = {-20, 64}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Add add annotation(
          Placement(visible = true, transformation(origin = {18, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(ambient1.flowPort, volumeFlow.flowPort_a) annotation(
          Line(points = {{14, 6}, {30, 6}}, color = {255, 0, 0}));
        connect(temperatureSensor.y, firstOrder.u) annotation(
          Line(points = {{-65, 0}, {-44, 0}}, color = {0, 0, 127}));
        connect(firstOrder.y, ambient1.ambientTemperature) annotation(
          Line(points = {{-20, 0}, {-6, 0}}, color = {0, 0, 127}));
        connect(ambient2.flowPort, flowPort_a) annotation(
          Line(points = {{-66, -40}, {-94, -40}, {-94, -40}, {-100, -40}}, color = {255, 0, 0}));
        connect(temperatureSensor.flowPort, flowPort_a) annotation(
          Line(points = {{-86, 0}, {-92, 0}, {-92, -40}, {-100, -40}}, color = {255, 0, 0}));
        connect(volumeFlow.flowPort_b, flowPort_b) annotation(
          Line(points = {{50, 6}, {66, 6}, {66, 0}, {100, 0}, {100, 0}}, color = {255, 0, 0}));
        connect(flowPort_a, ambient2.flowPort) annotation(
          Line(points = {{-100, -40}, {-66, -40}, {-66, -40}, {-66, -40}}, color = {255, 0, 0}));
        connect(pump_m3ps, add.u2) annotation(
          Line(points = {{-106, 40}, {6, 40}}, color = {0, 0, 127}));
        connect(const.y, add.u1) annotation(
          Line(points = {{-8, 64}, {-2, 64}, {-2, 52}, {6, 52}, {6, 52}}, color = {0, 0, 127}));
        connect(add.y, volumeFlow.volumeFlow) annotation(
          Line(points = {{30, 46}, {40, 46}, {40, 16}, {40, 16}}, color = {0, 0, 127}));
        annotation(
          Diagram(coordinateSystem(initialScale = 0.1)));
      end water_pump_t;

      model branch_t
        parameter Real vfrate = 0.5;
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a PORT_IN(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b PORT_OUT(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {100, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient2(constantAmbientPressure = 0, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(extent = {{-40, -10}, {-20, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sensors.VolumeFlowSensor volumeFlowSensor1(T(fixed = false), V_flow(fixed = false), medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-68, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient1(constantAmbientPressure = 0, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useTemperatureInput = true) annotation(
          Placement(visible = true, transformation(extent = {{34, 30}, {14, 50}}, rotation = 0)));
        Modelica.Blocks.Math.Product product annotation(
          Placement(visible = true, transformation(origin = {-28, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeFlow(T(fixed = true), T0 = Tempinit, V_flow(fixed = false), constantVolumeFlow = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useVolumeFlowInput = true) annotation(
          Placement(visible = true, transformation(origin = {64, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor temperatureSensor(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {-34, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {100, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {102, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeFlow1(T(fixed = true), T0 = Tempinit, V_flow(fixed = false), constantVolumeFlow = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useVolumeFlowInput = true) annotation(
          Placement(visible = true, transformation(origin = {68, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient(constantAmbientPressure = 0, constantAmbientTemperature = Tempinit, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useTemperatureInput = true) annotation(
          Placement(visible = true, transformation(extent = {{36, -50}, {16, -30}}, rotation = 0)));
        Modelica.Blocks.Math.Add add(k2 = -1) annotation(
          Placement(visible = true, transformation(origin = {-26, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant vflowrate(k = vfrate) annotation(
          Placement(visible = true, transformation(origin = {-78, 64}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(volumeFlowSensor1.flowPort_a, PORT_IN) annotation(
          Line(points = {{-78, 0}, {-94, 0}, {-94, 0}, {-100, 0}}, color = {255, 0, 0}));
        connect(volumeFlowSensor1.flowPort_b, ambient2.flowPort) annotation(
          Line(points = {{-58, 0}, {-42, 0}, {-42, 0}, {-40, 0}, {-40, 0}}, color = {255, 0, 0}));
        connect(volumeFlowSensor1.y, product.u1) annotation(
          Line(points = {{-68, -12}, {-68, -24}, {-58, -24}, {-58, 76}, {-40, 76}}, color = {0, 0, 127}));
        connect(product.y, volumeFlow.volumeFlow) annotation(
          Line(points = {{-17, 70}, {64, 70}, {64, 50}}, color = {0, 0, 127}));
        connect(volumeFlow.flowPort_b, PORT_OUT) annotation(
          Line(points = {{74, 40}, {100, 40}}, color = {255, 0, 0}));
        connect(ambient1.flowPort, volumeFlow.flowPort_a) annotation(
          Line(points = {{34, 40}, {54, 40}}, color = {255, 0, 0}));
        connect(temperatureSensor.y, ambient1.ambientTemperature) annotation(
          Line(points = {{-23, 34}, {14, 34}}, color = {0, 0, 127}));
        connect(temperatureSensor.flowPort, PORT_IN) annotation(
          Line(points = {{-44, 34}, {-84, 34}, {-84, 0}, {-100, 0}}, color = {255, 0, 0}));
        connect(volumeFlow1.flowPort_b, flowPort_b) annotation(
          Line(points = {{78, -40}, {94, -40}, {94, -40}, {100, -40}}, color = {255, 0, 0}));
        connect(ambient.flowPort, volumeFlow1.flowPort_a) annotation(
          Line(points = {{36, -40}, {58, -40}}, color = {255, 0, 0}));
        connect(temperatureSensor.y, ambient.ambientTemperature) annotation(
          Line(points = {{-22, 34}, {2, 34}, {2, -46}, {16, -46}, {16, -46}}, color = {0, 0, 127}));
        connect(volumeFlowSensor1.y, add.u1) annotation(
          Line(points = {{-68, -10}, {-68, -10}, {-68, -60}, {-38, -60}, {-38, -60}}, color = {0, 0, 127}));
        connect(product.y, add.u2) annotation(
          Line(points = {{-16, 70}, {-10, 70}, {-10, -40}, {-50, -40}, {-50, -72}, {-38, -72}, {-38, -72}}, color = {0, 0, 127}));
        connect(add.y, volumeFlow1.volumeFlow) annotation(
          Line(points = {{-14, -66}, {46, -66}, {46, -16}, {68, -16}, {68, -30}, {68, -30}}, color = {0, 0, 127}));
        connect(vflowrate.y, product.u2) annotation(
          Line(points = {{-66, 64}, {-40, 64}, {-40, 64}, {-40, 64}}, color = {0, 0, 127}));
      end branch_t;

      model Thermal_QinTout
        Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow prescribedHeatFlow annotation(
          Placement(visible = true, transformation(origin = {0, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Qin annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Tout annotation(
          Placement(visible = true, transformation(origin = {-110, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {0, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation(
          Placement(visible = true, transformation(origin = {106, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {106, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(Qin, prescribedHeatFlow.Q_flow) annotation(
          Line(points = {{-120, 40}, {-12, 40}, {-12, 40}, {-10, 40}}, color = {0, 0, 127}));
        connect(temperatureSensor.T, Tout) annotation(
          Line(points = {{-10, -40}, {-102, -40}, {-102, -40}, {-110, -40}}, color = {0, 0, 127}));
        connect(prescribedHeatFlow.port, port_b) annotation(
          Line(points = {{10, 40}, {60, 40}, {60, 0}, {106, 0}, {106, 0}}, color = {191, 0, 0}));
        connect(temperatureSensor.port, port_b) annotation(
          Line(points = {{10, -40}, {60, -40}, {60, 0}, {106, 0}, {106, 0}}, color = {191, 0, 0}));
      end Thermal_QinTout;

      model Thermal_TinQout
        parameter Modelica.SIunits.ThermalResistance r = 1.6;
        Modelica.Blocks.Interfaces.RealInput Tin annotation(
          Placement(visible = true, transformation(origin = {-120, 46}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 46}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qout annotation(
          Placement(visible = true, transformation(origin = {-110, -36}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, -36}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b port_b annotation(
          Placement(visible = true, transformation(origin = {100, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-50, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {46, 8}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = r) annotation(
          Placement(visible = true, transformation(origin = {8, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(Tin, prescribedTemperature.T) annotation(
          Line(points = {{-120, 46}, {-62, 46}}, color = {0, 0, 127}));
        connect(heatFlowSensor.Q_flow, Qout) annotation(
          Line(points = {{46, -2}, {46, -36}, {-110, -36}}, color = {0, 0, 127}));
        connect(prescribedTemperature.port, thermalResistor.port_a) annotation(
          Line(points = {{-40, 46}, {-2, 46}, {-2, 46}, {-2, 46}}, color = {191, 0, 0}));
        connect(thermalResistor.port_b, heatFlowSensor.port_b) annotation(
          Line(points = {{18, 46}, {24, 46}, {24, 8}, {36, 8}, {36, 8}}, color = {191, 0, 0}));
        connect(heatFlowSensor.port_a, port_b) annotation(
          Line(points = {{56, 8}, {98, 8}, {98, 8}, {100, 8}}, color = {191, 0, 0}));
      end Thermal_TinQout;
    end thermal_parts;

    package thermal_circuits
      model lowtemp_water
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_charge_air_cooler annotation(
          Placement(visible = true, transformation(origin = {-102, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-102, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_motor_generator annotation(
          Placement(visible = true, transformation(origin = {-100, 66}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_turbo_charger annotation(
          Placement(visible = true, transformation(origin = {0, 98}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 98}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-52, 14}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow volumeFlow(T(fixed = false), T0 = Tempinit, V_flow(fixed = false, start = 0), constantVolumeFlow = Volumeflowinit, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useVolumeFlowInput = true) annotation(
          Placement(visible = true, transformation(origin = {-46, -64}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_flow branch_flow(flow1_rate = 0.96) annotation(
          Placement(visible = true, transformation(origin = {-46, -18}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_radiator annotation(
          Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe1(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-52, 66}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Sources.AbsolutePressure absolutePressure(T(start = Tempinit), medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), p = 1) annotation(
          Placement(visible = true, transformation(origin = {88, 74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe2(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {0, 12}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe3(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {68, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealInput volume_flow_lowtemp annotation(
          Placement(visible = true, transformation(origin = {-107, -65}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-107, -65}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.01, y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-78, -66}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(port_charge_air_cooler, pipe.heatPort) annotation(
          Line(points = {{-102, 14}, {-62, 14}}, color = {191, 0, 0}));
        connect(pipe.flowPort_a, branch_flow.flowPort_out1) annotation(
          Line(points = {{-52, 4}, {-50, 4}, {-50, -8}}, color = {255, 0, 0}));
        connect(port_motor_generator, pipe1.heatPort) annotation(
          Line(points = {{-100, 66}, {-62, 66}, {-62, 66}, {-62, 66}, {-62, 66}}, color = {191, 0, 0}));
        connect(pipe1.flowPort_a, pipe.flowPort_b) annotation(
          Line(points = {{-52, 56}, {-52, 56}, {-52, 24}, {-52, 24}}, color = {255, 0, 0}));
        connect(branch_flow.flowPort_out2, pipe2.flowPort_a) annotation(
          Line(points = {{-42, -8}, {-40, -8}, {-40, 12}, {-10, 12}, {-10, 12}}, color = {255, 0, 0}));
        connect(branch_flow.flowPort_in, volumeFlow.flowPort_b) annotation(
          Line(points = {{-46, -28}, {-46, -54}}, color = {255, 0, 0}));
        connect(pipe3.heatPort, port_radiator) annotation(
          Line(points = {{78, 0}, {98, 0}, {98, 0}, {100, 0}}, color = {191, 0, 0}));
        connect(pipe2.flowPort_b, pipe3.flowPort_b) annotation(
          Line(points = {{10, 12}, {68, 12}, {68, 10}, {68, 10}}, color = {255, 0, 0}));
        connect(pipe1.flowPort_b, pipe3.flowPort_b) annotation(
          Line(points = {{-52, 76}, {68, 76}, {68, 10}, {68, 10}}, color = {255, 0, 0}));
        connect(absolutePressure.flowPort, pipe3.flowPort_b) annotation(
          Line(points = {{78, 74}, {68, 74}, {68, 10}, {68, 10}}, color = {255, 0, 0}));
        connect(pipe3.flowPort_a, volumeFlow.flowPort_a) annotation(
          Line(points = {{68, -10}, {68, -10}, {68, -90}, {-46, -90}, {-46, -74}, {-46, -74}}, color = {255, 0, 0}));
        connect(port_turbo_charger, pipe2.heatPort) annotation(
          Line(points = {{0, 98}, {0, 98}, {0, 22}, {0, 22}}, color = {191, 0, 0}));
        connect(firstOrder.y, volumeFlow.volumeFlow) annotation(
          Line(points = {{-72, -66}, {-56, -66}, {-56, -64}, {-56, -64}}, color = {0, 0, 127}));
        connect(volume_flow_lowtemp, firstOrder.u) annotation(
          Line(points = {{-106, -64}, {-86, -64}, {-86, -66}, {-86, -66}}, color = {0, 0, 127}));
      end lowtemp_water;

      model lowtemp5
        parameter Modelica.SIunits.HeatCapacity chargeaircooler_C = 4.2 "chargeaircooler heat capacity";
        parameter Modelica.SIunits.ThermalResistance chargeaircooler_water_R = 1.6 "chargeaircooler thermal resistance for water";
        parameter Modelica.SIunits.HeatCapacity motorgenerator_C = 4.2 "motorgenerator heat capacity";
        parameter Modelica.SIunits.ThermalResistance motorgenerator_water_R = 1.6 "motorgenerator thermal resistance for water";
        parameter Modelica.SIunits.HeatCapacity turbo_charger_C = 4.2 "turbo_charger heat capacity";
        parameter Modelica.SIunits.ThermalResistance turbo_charger_water_R = 1.6 "turbo_charger thermal resistance for water";
        TRAMI_L3_HEV.Thermal.thermal_parts.heated_block charge_air_cooler(c = chargeaircooler_C, r = chargeaircooler_water_R) annotation(
          Placement(visible = true, transformation(origin = {-70, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.heated_block turbo_charger(c = turbo_charger_C, r = turbo_charger_water_R) annotation(
          Placement(visible = true, transformation(origin = {0, 62}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput motor_generator_T annotation(
          Placement(visible = true, transformation(origin = {-112, 42}, extent = {{-12, -12}, {12, 12}}, rotation = 0), iconTransformation(origin = {14, 120}, extent = {{-12, -12}, {12, 12}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput charge_air_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput turbo_charger_Q annotation(
          Placement(visible = true, transformation(origin = {6, 106}, extent = {{-12, -12}, {12, 12}}, rotation = -90), iconTransformation(origin = {-108, 68}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput RAD annotation(
          Placement(visible = true, transformation(origin = {42, 104}, extent = {{-12, -12}, {12, 12}}, rotation = -90), iconTransformation(origin = {110, -32}, extent = {{-12, -12}, {12, 12}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {73, 105}, extent = {{-11, -11}, {11, 11}}, rotation = -90), iconTransformation(origin = {109, -87}, extent = {{-11, -11}, {11, 11}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput charge_air_T annotation(
          Placement(visible = true, transformation(origin = {-108, -4}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, -50}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput motor_generator_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 30}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-38, 116}, extent = {{10, -10}, {-10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput turbo_charger_T annotation(
          Placement(visible = true, transformation(origin = {-8, 104}, extent = {{10, 10}, {-10, -10}}, rotation = -90), iconTransformation(origin = {-110, 30}, extent = {{10, 10}, {-10, -10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput charge_air_radiator_Q annotation(
          Placement(visible = true, transformation(origin = {106, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput charge_air_radiator_T annotation(
          Placement(visible = true, transformation(origin = {104, 28}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {110, 50}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput volume_flow_lowtemp annotation(
          Placement(visible = true, transformation(origin = {-107, -31}, extent = {{-9, -9}, {9, 9}}, rotation = 0), iconTransformation(origin = {-109, -99}, extent = {{-9, -9}, {9, 9}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.radiator radiator(RAD_tableName = "tab2") annotation(
          Placement(visible = true, transformation(origin = {68, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.lowtempwater_t lowtempwater_te annotation(
          Placement(visible = true, transformation(origin = {5, 4}, extent = {{-15, -23}, {15, 23}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.Thermal_TinQout MG_IF(r = motorgenerator_water_R) annotation(
          Placement(visible = true, transformation(origin = {-68, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(charge_air_Q, charge_air_cooler.Q) annotation(
          Line(points = {{-110, 10}, {-96, 10}, {-96, 9}, {-81, 9}}, color = {0, 0, 127}));
        connect(turbo_charger_Q, turbo_charger.Q) annotation(
          Line(points = {{6, 106}, {6, 74}}, color = {0, 0, 127}));
        connect(charge_air_cooler.K, charge_air_T) annotation(
          Line(points = {{-80, -4}, {-104, -4}, {-104, -4}, {-108, -4}}, color = {0, 0, 127}));
        connect(turbo_charger.K, turbo_charger_T) annotation(
          Line(points = {{-8, 74}, {-8, 74}, {-8, 104}, {-8, 104}}, color = {0, 0, 127}));
        connect(RAD, radiator.RAD) annotation(
          Line(points = {{42, 104}, {42, 104}, {42, 36}, {64, 36}, {64, 12}, {64, 12}}, color = {0, 0, 127}));
        connect(VSP, radiator.VSP) annotation(
          Line(points = {{74, 106}, {72, 106}, {72, 12}, {72, 12}}, color = {0, 0, 127}));
        connect(charge_air_radiator_T, radiator.Temperature) annotation(
          Line(points = {{104, 28}, {88, 28}, {88, 6}, {78, 6}, {78, 6}}, color = {0, 0, 127}));
        connect(radiator.heatFlow, charge_air_radiator_Q) annotation(
          Line(points = {{78, -2}, {100, -2}, {100, -2}, {106, -2}}, color = {0, 0, 127}));
        connect(lowtempwater_te.lowpump_m3ps, volume_flow_lowtemp) annotation(
          Line(points = {{-14, 26}, {-16, 26}, {-16, -32}, {-106, -32}, {-106, -30}}, color = {0, 0, 127}));
        connect(charge_air_cooler.port_b, lowtempwater_te.chargeair_w) annotation(
          Line(points = {{-60, 4}, {-26, 4}, {-26, 12}, {-26, 12}}, color = {191, 0, 0}));
        connect(turbo_charger.port_b, lowtempwater_te.turbo_w) annotation(
          Line(points = {{0, 52}, {0, 52}, {0, 44}, {-26, 44}, {-26, 28}, {-26, 28}}, color = {191, 0, 0}));
        connect(lowtempwater_te.lowrad_w, radiator.port_b) annotation(
          Line(points = {{34, 8}, {44, 8}, {44, 2}, {58, 2}, {58, 2}}, color = {191, 0, 0}));
        connect(MG_IF.port_b, lowtempwater_te.mg_w) annotation(
          Line(points = {{-58, 36}, {6, 36}, {6, 34}, {6, 34}}, color = {191, 0, 0}));
        connect(motor_generator_T, MG_IF.Tin) annotation(
          Line(points = {{-112, 42}, {-92, 42}, {-92, 40}, {-80, 40}, {-80, 40}}, color = {0, 0, 127}));
        connect(motor_generator_Q, MG_IF.Qout) annotation(
          Line(points = {{-110, 30}, {-88, 30}, {-88, 32}, {-78, 32}, {-78, 32}}, color = {0, 0, 127}));
      end lowtemp5;

      model hightemp_water2
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_engine annotation(
          Placement(visible = true, transformation(origin = {-102, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-102, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_engine2 annotation(
          Placement(visible = true, transformation(origin = {-106, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-106, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe engine(T0 = Tempinit, V_flow(fixed = true, start = 0), V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-52, -26}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_radiator annotation(
          Placement(visible = true, transformation(origin = {100, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe engine2(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-12, -6}, extent = {{10, 10}, {-10, -10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe radiator(T0 = Tempinit, V_flow(start = 0), V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {68, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_flow_variable branch_flow_variable annotation(
          Placement(visible = true, transformation(origin = {6, 24}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe at_cooler(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {38, 72}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_at_cooler annotation(
          Placement(visible = true, transformation(origin = {38, 98}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-10, 104}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.volume_initial volume_initial annotation(
          Placement(visible = true, transformation(origin = {-52, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_flow_variable branch_flow_variable1 annotation(
          Placement(visible = true, transformation(origin = {4, 76}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe ptc(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {68, 80}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe hvac(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {80, 52}, extent = {{10, -10}, {-10, 10}}, rotation = 90)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_ptc annotation(
          Placement(visible = true, transformation(origin = {70, 108}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {70, 108}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_hvac annotation(
          Placement(visible = true, transformation(origin = {112, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {112, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput hightemp_valve2 annotation(
          Placement(visible = true, transformation(origin = {-106, 100}, extent = {{-12, -12}, {12, 12}}, rotation = 0), iconTransformation(origin = {-106, 100}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput hightemp_valve1 annotation(
          Placement(visible = true, transformation(origin = {-106, 74}, extent = {{-12, -12}, {12, 12}}, rotation = 0), iconTransformation(origin = {-106, 74}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput hightemp_wp annotation(
          Placement(visible = true, transformation(origin = {104, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {104, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.volumeflow_block volumeflow_block annotation(
          Placement(visible = true, transformation(origin = {34, 24}, extent = {{-10, -10}, {10, 10}}, rotation = 180)));
      equation
        connect(port_engine, engine.heatPort) annotation(
          Line(points = {{-102, -60}, {-82, -60}, {-82, -26}, {-62, -26}}, color = {191, 0, 0}));
        connect(port_engine2, engine2.heatPort) annotation(
          Line(points = {{-106, -6}, {-22, -6}}, color = {191, 0, 0}));
        connect(radiator.heatPort, port_radiator) annotation(
          Line(points = {{78, -40}, {100, -40}}, color = {191, 0, 0}));
        connect(port_at_cooler, at_cooler.heatPort) annotation(
          Line(points = {{38, 98}, {38, 82}}, color = {191, 0, 0}));
        connect(volume_initial.flowPort_in, engine.flowPort_b) annotation(
          Line(points = {{-52, 18}, {-52, -16}}, color = {255, 0, 0}));
        connect(engine2.flowPort_b, radiator.flowPort_a) annotation(
          Line(points = {{-12, -16}, {68, -16}, {68, -30}}, color = {255, 0, 0}));
        connect(engine.flowPort_a, radiator.flowPort_b) annotation(
          Line(points = {{-52, -36}, {-52, -36}, {-52, -88}, {68, -88}, {68, -50}, {68, -50}}, color = {255, 0, 0}));
        connect(branch_flow_variable1.flowPort_out2, at_cooler.flowPort_a) annotation(
          Line(points = {{14, 72}, {26, 72}, {26, 72}, {28, 72}}, color = {255, 0, 0}));
        connect(branch_flow_variable1.flowPort_out1, ptc.flowPort_a) annotation(
          Line(points = {{14, 80}, {58, 80}}, color = {255, 0, 0}));
        connect(ptc.flowPort_b, hvac.flowPort_a) annotation(
          Line(points = {{78, 80}, {80, 80}, {80, 62}, {80, 62}}, color = {255, 0, 0}));
        connect(port_ptc, ptc.heatPort) annotation(
          Line(points = {{70, 108}, {68, 108}, {68, 90}, {68, 90}}, color = {191, 0, 0}));
        connect(hvac.heatPort, port_hvac) annotation(
          Line(points = {{90, 52}, {112, 52}, {112, 50}, {112, 50}}, color = {191, 0, 0}));
        connect(hightemp_valve2, branch_flow_variable1.volume_rate) annotation(
          Line(points = {{-106, 100}, {-28, 100}, {-28, 84}, {-6, 84}, {-6, 86}}, color = {0, 0, 127}));
        connect(volumeflow_block.flowPort_in, hvac.flowPort_b) annotation(
          Line(points = {{44, 24}, {80, 24}, {80, 42}}, color = {255, 0, 0}));
        connect(at_cooler.flowPort_b, volumeflow_block.flowPort_in) annotation(
          Line(points = {{48, 72}, {54, 72}, {54, 24}, {44, 24}, {44, 24}}, color = {255, 0, 0}));
        connect(hightemp_wp, volumeflow_block.volume) annotation(
          Line(points = {{104, 0}, {40, 0}, {40, 14}, {40, 14}}, color = {0, 0, 127}));
        connect(branch_flow_variable.flowPort_in, volumeflow_block.flowPort_out) annotation(
          Line(points = {{16, 24}, {24, 24}}, color = {255, 0, 0}));
        connect(branch_flow_variable.flowPort_out2, engine2.flowPort_a) annotation(
          Line(points = {{-4, 20}, {-12, 20}, {-12, 4}, {-12, 4}}, color = {255, 0, 0}));
        connect(hightemp_valve1, branch_flow_variable.volume_rate) annotation(
          Line(points = {{-106, 74}, {-24, 74}, {-24, 48}, {20, 48}, {20, 32}, {16, 32}, {16, 34}}, color = {0, 0, 127}));
        connect(branch_flow_variable.flowPort_out1, branch_flow_variable1.flowPort_in) annotation(
          Line(points = {{-4, 28}, {-30, 28}, {-30, 76}, {-6, 76}, {-6, 76}}, color = {255, 0, 0}));
        connect(volume_initial.flowPort_out, branch_flow_variable1.flowPort_in) annotation(
          Line(points = {{-52, 38}, {-52, 38}, {-52, 76}, {-6, 76}, {-6, 76}}, color = {255, 0, 0}));
      end hightemp_water2;

      model hightemp4
        parameter Modelica.SIunits.HeatCapacity ptc_C = 4.2 "ptc heat capacity";
        parameter Modelica.SIunits.ThermalResistance ptc_water_R = 1.6 "ptc thermal resistance for water";
        parameter Modelica.SIunits.HeatCapacity engine1_C = 4.2 "engine1 heat capacity";
        parameter Modelica.SIunits.ThermalResistance engine1_water_R = 1.6 "engine1 thermal resistance for water";
        parameter Modelica.SIunits.HeatCapacity engine2_C = 4.2 "engine2 heat capacity";
        parameter Modelica.SIunits.ThermalResistance engine2_water_R = 1.6 "engine2 thermal resistance for water";
        TRAMI_L3_HEV.Thermal.thermal_parts.heated_block ptc(c = ptc_C, r = ptc_water_R) annotation(
          Placement(visible = true, transformation(origin = {22, 68}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput engine_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -36}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput hightemp_valve1_rate annotation(
          Placement(visible = true, transformation(origin = {-116, 24}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput hightemp_valve2_rate annotation(
          Placement(visible = true, transformation(origin = {-116, 66}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput at_cooler_Q annotation(
          Placement(visible = true, transformation(origin = {4, 114}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {-40, 110}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput ptc_Q annotation(
          Placement(visible = true, transformation(origin = {28, 114}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {60, 110}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput hvac_Q annotation(
          Placement(visible = true, transformation(origin = {104, 90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {110, 50}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.radiator radiator annotation(
          Placement(visible = true, transformation(origin = {70, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput radiator_T annotation(
          Placement(visible = true, transformation(origin = {104, -86}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {110, -10}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput hightemp_wp annotation(
          Placement(visible = true, transformation(origin = {106, 54}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {100, 110}, extent = {{10, -10}, {-10, 10}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealInput RAD annotation(
          Placement(visible = true, transformation(origin = {104, -24}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {110, -60}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {104, -44}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput engine_T annotation(
          Placement(visible = true, transformation(origin = {-122, -56}, extent = {{8, -8}, {-8, 8}}, rotation = 0), iconTransformation(origin = {-108, -60}, extent = {{8, -8}, {-8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput engine2_T annotation(
          Placement(visible = true, transformation(origin = {-122, -12}, extent = {{8, -8}, {-8, 8}}, rotation = 0), iconTransformation(origin = {-108, 20}, extent = {{8, -8}, {-8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput at_cooler_T annotation(
          Placement(visible = true, transformation(origin = {-10, 110}, extent = {{8, -8}, {-8, 8}}, rotation = -90), iconTransformation(origin = {-10, 108}, extent = {{8, -8}, {-8, 8}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput ptc_T annotation(
          Placement(visible = true, transformation(origin = {16, 110}, extent = {{8, -8}, {-8, 8}}, rotation = -90), iconTransformation(origin = {30, 108}, extent = {{8, -8}, {-8, 8}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput hvac_T annotation(
          Placement(visible = true, transformation(origin = {106, 76}, extent = {{-8, -8}, {8, 8}}, rotation = 0), iconTransformation(origin = {108, 80}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput radiator_Q annotation(
          Placement(visible = true, transformation(origin = {106, -100}, extent = {{-8, -8}, {8, 8}}, rotation = 0), iconTransformation(origin = {108, 20}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput coolant_temp annotation(
          Placement(visible = true, transformation(origin = {-112, -78}, extent = {{8, -8}, {-8, 8}}, rotation = 0), iconTransformation(origin = {-70, 108}, extent = {{8, -8}, {-8, 8}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.hightempwater_t hightempwater_te annotation(
          Placement(visible = true, transformation(origin = {6, -21}, extent = {{-18, -26}, {18, 26}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput engine2_Q annotation(
          Placement(visible = true, transformation(origin = {-118, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.Thermal_QinTout IF_OilCooler annotation(
          Placement(visible = true, transformation(origin = {0, 68}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.Thermal_QinTout IF_Eng1 annotation(
          Placement(visible = true, transformation(origin = {-78, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.Thermal_QinTout IF_Eng2 annotation(
          Placement(visible = true, transformation(origin = {-78, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.Thermal_QinTout IF_HVAC annotation(
          Placement(visible = true, transformation(origin = {64, 80}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      equation
        connect(ptc_Q, ptc.Q) annotation(
          Line(points = {{28, 114}, {28, 114}, {28, 80}, {28, 80}}, color = {0, 0, 127}));
        connect(radiator_T, radiator.Temperature) annotation(
          Line(points = {{104, -86}, {80, -86}}, color = {0, 0, 127}));
        connect(RAD, radiator.RAD) annotation(
          Line(points = {{104, -24}, {66, -24}, {66, -80}}, color = {0, 0, 127}));
        connect(VSP, radiator.VSP) annotation(
          Line(points = {{104, -44}, {74, -44}, {74, -81}}, color = {0, 0, 127}));
        connect(ptc.K, ptc_T) annotation(
          Line(points = {{14, 80}, {16, 80}, {16, 110}, {16, 110}}, color = {0, 0, 127}));
        connect(radiator.heatFlow, radiator_Q) annotation(
          Line(points = {{80, -94}, {88, -94}, {88, -100}, {106, -100}, {106, -100}}, color = {0, 0, 127}));
        connect(ptc.port_b, hightempwater_te.ptc_w) annotation(
          Line(points = {{22, 58}, {26, 58}, {26, 12}, {26, 12}}, color = {191, 0, 0}));
        connect(hightempwater_te.radiatorh_w, radiator.port_b) annotation(
          Line(points = {{42, -42}, {50, -42}, {50, -90}, {60, -90}, {60, -90}}, color = {191, 0, 0}));
        connect(hightemp_wp, hightempwater_te.pump_m3ps) annotation(
          Line(points = {{106, 54}, {-26, 54}, {-26, 2}, {-16, 2}, {-16, 4}}, color = {0, 0, 127}));
        connect(hightemp_valve2_rate, hightempwater_te.Valve_B) annotation(
          Line(points = {{-116, 66}, {-38, 66}, {-38, -28}, {-16, -28}, {-16, -28}}, color = {0, 0, 127}));
        connect(hightemp_valve1_rate, hightempwater_te.Valve_A) annotation(
          Line(points = {{-116, 24}, {-22, 24}, {-22, -16}, {-18, -16}, {-18, -18}, {-16, -18}}, color = {0, 0, 127}));
        connect(hightempwater_te.Temp_Engine, coolant_temp) annotation(
          Line(points = {{26, -8}, {32, -8}, {32, -78}, {-112, -78}, {-112, -78}}, color = {0, 0, 127}));
        connect(at_cooler_Q, IF_OilCooler.Qin) annotation(
          Line(points = {{4, 114}, {4, 114}, {4, 80}, {4, 80}}, color = {0, 0, 127}));
        connect(IF_OilCooler.Tout, at_cooler_T) annotation(
          Line(points = {{-4, 80}, {-4, 80}, {-4, 90}, {-10, 90}, {-10, 110}, {-10, 110}}, color = {0, 0, 127}));
        connect(IF_OilCooler.port_b, hightempwater_te.atcooler_w) annotation(
          Line(points = {{0, 58}, {0, 58}, {0, 14}, {0, 14}}, color = {191, 0, 0}));
        connect(engine_Q, IF_Eng1.Qin) annotation(
          Line(points = {{-120, -36}, {-92, -36}, {-92, -36}, {-90, -36}}, color = {0, 0, 127}));
        connect(IF_Eng1.port_b, hightempwater_te.eng1_w) annotation(
          Line(points = {{-68, -40}, {-48, -40}, {-48, -16}, {-30, -16}, {-30, -16}}, color = {191, 0, 0}));
        connect(IF_Eng1.Tout, engine_T) annotation(
          Line(points = {{-88, -44}, {-96, -44}, {-96, -56}, {-122, -56}, {-122, -56}}, color = {0, 0, 127}));
        connect(engine2_Q, IF_Eng2.Qin) annotation(
          Line(points = {{-118, 6}, {-92, 6}, {-92, 6}, {-90, 6}}, color = {0, 0, 127}));
        connect(IF_Eng2.port_b, hightempwater_te.eng2_w) annotation(
          Line(points = {{-68, 2}, {-48, 2}, {-48, 6}, {-30, 6}, {-30, 6}}, color = {191, 0, 0}));
        connect(IF_Eng2.Tout, engine2_T) annotation(
          Line(points = {{-88, -2}, {-96, -2}, {-96, -12}, {-122, -12}, {-122, -12}}, color = {0, 0, 127}));
        connect(IF_HVAC.Qin, hvac_Q) annotation(
          Line(points = {{76, 84}, {84, 84}, {84, 90}, {104, 90}, {104, 90}}, color = {0, 0, 127}));
        connect(IF_HVAC.Tout, hvac_T) annotation(
          Line(points = {{76, 76}, {102, 76}, {102, 76}, {106, 76}}, color = {0, 0, 127}));
        connect(IF_HVAC.port_b, hightempwater_te.hvac_w) annotation(
          Line(points = {{54, 80}, {42, 80}, {42, -16}, {42, -16}}, color = {191, 0, 0}));
      end hightemp4;

      model batttemp_water
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_chiller annotation(
          Placement(visible = true, transformation(origin = {0, -98}, extent = {{-10, 10}, {10, -10}}, rotation = 0), iconTransformation(origin = {0, -98}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_dcdc annotation(
          Placement(visible = true, transformation(origin = {-104, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-104, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe chiller(T0 = Tempinit, V_flow(fixed = true, start = 0), V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {0, -78}, extent = {{-10, 10}, {10, -10}}, rotation = 180)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_batt_radiator annotation(
          Placement(visible = true, transformation(origin = {102, -22}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {102, -22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe dcdc(T0 = Tempinit, V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-70, 26}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe highvoltage_radiator(T0 = Tempinit, V_flow(start = 0), V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {70, -22}, extent = {{10, -10}, {-10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_flow_variable branch_flow_variable annotation(
          Placement(visible = true, transformation(origin = {-69, -59}, extent = {{-5, -5}, {5, 5}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_flow_variable branch_flow_variable1 annotation(
          Placement(visible = true, transformation(origin = {22, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_valve2 annotation(
          Placement(visible = true, transformation(origin = {-106, 78}, extent = {{-12, -12}, {12, 12}}, rotation = 0), iconTransformation(origin = {-106, 78}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_valve1 annotation(
          Placement(visible = true, transformation(origin = {-120, -76}, extent = {{-12, -12}, {12, 12}}, rotation = 0), iconTransformation(origin = {-120, -76}, extent = {{-12, -12}, {12, 12}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_wp2 annotation(
          Placement(visible = true, transformation(origin = {-126, -24}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-126, -24}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.volumeflow_block volumeflow_block annotation(
          Placement(visible = true, transformation(origin = {-70, -18}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_flow branch_flow annotation(
          Placement(visible = true, transformation(origin = {50, -50}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe Libatt(T0 = Tempinit, V_flow(fixed = true, start = 0), V_flowLaminar = 10000, V_flowNominal = 20000, dpLaminar = 0, dpNominal = 0, h_g = 0, m = Volumemass, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-26, -78}, extent = {{-10, 10}, {10, -10}}, rotation = 180)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port_libatt annotation(
          Placement(visible = true, transformation(origin = {-26, -98}, extent = {{-10, 10}, {10, -10}}, rotation = 0), iconTransformation(origin = {-26, -98}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_wp1 annotation(
          Placement(visible = true, transformation(origin = {30, -104}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {30, -104}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.volumeflow_block volumeflow_block1 annotation(
          Placement(visible = true, transformation(origin = {28, -76}, extent = {{-6, -6}, {6, 6}}, rotation = 180)));
      equation
        connect(port_dcdc, dcdc.heatPort) annotation(
          Line(points = {{-104, 26}, {-80, 26}}, color = {191, 0, 0}));
        connect(highvoltage_radiator.heatPort, port_batt_radiator) annotation(
          Line(points = {{80, -22}, {102, -22}}, color = {191, 0, 0}));
        connect(batttemp_valve1, branch_flow_variable.volume_rate) annotation(
          Line(points = {{-120, -76}, {-73.5, -76}, {-73.5, -64}}, color = {0, 0, 127}));
        connect(batttemp_wp2, volumeflow_block.volume) annotation(
          Line(points = {{-126, -24}, {-80, -24}, {-80, -23}}, color = {0, 0, 127}));
        connect(branch_flow.flowPort_in, highvoltage_radiator.flowPort_b) annotation(
          Line(points = {{60, -50}, {70, -50}, {70, -32}}, color = {255, 0, 0}));
        connect(chiller.heatPort, port_chiller) annotation(
          Line(points = {{0, -88}, {0, -98}}, color = {191, 0, 0}));
        connect(Libatt.flowPort_a, chiller.flowPort_b) annotation(
          Line(points = {{-16, -78}, {-10, -78}}, color = {255, 0, 0}));
        connect(Libatt.heatPort, port_libatt) annotation(
          Line(points = {{-26, -88}, {-26, -98}}, color = {191, 0, 0}));
        connect(volumeflow_block.flowPort_in, branch_flow_variable.flowPort_out1) annotation(
          Line(points = {{-70, -28}, {-70, -44}, {-71, -44}, {-71, -54}}, color = {255, 0, 0}));
        connect(dcdc.flowPort_a, volumeflow_block.flowPort_out) annotation(
          Line(points = {{-70, 16}, {-70, 16}, {-70, -8}, {-70, -8}}, color = {255, 0, 0}));
        connect(branch_flow.flowPort_out1, volumeflow_block.flowPort_in) annotation(
          Line(points = {{40, -46}, {-70, -46}, {-70, -28}, {-70, -28}}, color = {255, 0, 0}));
        connect(branch_flow_variable1.flowPort_out1, highvoltage_radiator.flowPort_a) annotation(
          Line(points = {{32, 56}, {70, 56}, {70, -12}}, color = {255, 0, 0}));
        connect(branch_flow_variable1.flowPort_out2, branch_flow.flowPort_in) annotation(
          Line(points = {{32, 48}, {64, 48}, {64, -50}, {60, -50}}, color = {255, 0, 0}));
        connect(dcdc.flowPort_b, branch_flow_variable1.flowPort_in) annotation(
          Line(points = {{-70, 36}, {-70, 36}, {-70, 52}, {12, 52}, {12, 52}}, color = {255, 0, 0}));
        connect(batttemp_valve2, branch_flow_variable1.volume_rate) annotation(
          Line(points = {{-106, 78}, {-18, 78}, {-18, 62}, {12, 62}, {12, 62}}, color = {0, 0, 127}));
        connect(branch_flow_variable.flowPort_in, Libatt.flowPort_b) annotation(
          Line(points = {{-68, -64}, {-70, -64}, {-70, -78}, {-36, -78}, {-36, -78}}, color = {255, 0, 0}));
        connect(branch_flow.flowPort_out2, volumeflow_block1.flowPort_in) annotation(
          Line(points = {{40, -54}, {36, -54}, {36, -76}, {34, -76}, {34, -76}}, color = {255, 0, 0}));
        connect(branch_flow_variable.flowPort_out2, volumeflow_block1.flowPort_in) annotation(
          Line(points = {{-66, -54}, {-66, -54}, {-66, -50}, {36, -50}, {36, -76}, {34, -76}, {34, -76}}, color = {255, 0, 0}));
        connect(chiller.flowPort_a, volumeflow_block1.flowPort_out) annotation(
          Line(points = {{10, -78}, {16, -78}, {16, -76}, {22, -76}, {22, -76}, {22, -76}}, color = {255, 0, 0}));
        connect(batttemp_wp1, volumeflow_block1.volume) annotation(
          Line(points = {{30, -104}, {32, -104}, {32, -82}, {32, -82}}, color = {0, 0, 127}));
      end batttemp_water;

      model batttemp4
        parameter Modelica.SIunits.HeatCapacity libatt_C = 4.2 "libatt heat capacity";
        parameter Modelica.SIunits.ThermalResistance libatt_water_R = 1.6 "libatt thermal resistance for water";
        parameter Modelica.SIunits.HeatCapacity dcdc_C = 4.2 "dcdc heat capacity";
        parameter Modelica.SIunits.ThermalResistance dcdc_water_R = 1.6 "dcdcthermal resistance for water";
        thermal_parts.heated_block dcdc(c = dcdc_C, r = dcdc_water_R) annotation(
          Placement(visible = true, transformation(origin = {-62, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.heated_block Libatt(c = libatt_C, r = libatt_water_R) annotation(
          Placement(visible = true, transformation(origin = {-28, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.radiator highvoltage_radiator(RAD_tableName = "tab3") annotation(
          Placement(visible = true, transformation(origin = {60, -4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput dcdc_Q annotation(
          Placement(visible = true, transformation(origin = {-104, 12}, extent = {{-8, -8}, {8, 8}}, rotation = 0), iconTransformation(origin = {-104, 12}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Libatt_Q annotation(
          Placement(visible = true, transformation(origin = {-34, -100}, extent = {{-8, -8}, {8, 8}}, rotation = 90), iconTransformation(origin = {-52, -100}, extent = {{-8, -8}, {8, 8}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealInput chiller_Q annotation(
          Placement(visible = true, transformation(origin = {4, -100}, extent = {{-8, -8}, {8, 8}}, rotation = 90), iconTransformation(origin = {108, 10}, extent = {{-8, -8}, {8, 8}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput highvoltage_rad_T annotation(
          Placement(visible = true, transformation(origin = {104, 0}, extent = {{8, -8}, {-8, 8}}, rotation = 0), iconTransformation(origin = {108, 68}, extent = {{8, -8}, {-8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_valve2_rate annotation(
          Placement(visible = true, transformation(origin = {-106, 52}, extent = {{-8, -8}, {8, 8}}, rotation = 0), iconTransformation(origin = {-106, 52}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_wp2 annotation(
          Placement(visible = true, transformation(origin = {-106, -26}, extent = {{-8, -8}, {8, 8}}, rotation = 0), iconTransformation(origin = {-106, -26}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_valve1_rate annotation(
          Placement(visible = true, transformation(origin = {-104, -68}, extent = {{-8, -8}, {8, 8}}, rotation = 0), iconTransformation(origin = {-104, -68}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batttemp_wp1 annotation(
          Placement(visible = true, transformation(origin = {50, -100}, extent = {{-8, -8}, {8, 8}}, rotation = 90), iconTransformation(origin = {50, -100}, extent = {{-8, -8}, {8, 8}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {104, 42}, extent = {{8, -8}, {-8, 8}}, rotation = 0), iconTransformation(origin = {108, -88}, extent = {{8, -8}, {-8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput RAD annotation(
          Placement(visible = true, transformation(origin = {104, 84}, extent = {{8, -8}, {-8, 8}}, rotation = 0), iconTransformation(origin = {108, -40}, extent = {{8, -8}, {-8, 8}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput chiller_T annotation(
          Placement(visible = true, transformation(origin = {17, -101}, extent = {{-5, -5}, {5, 5}}, rotation = -90), iconTransformation(origin = {105, 35}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Libatt_T annotation(
          Placement(visible = true, transformation(origin = {-21, -101}, extent = {{-5, -5}, {5, 5}}, rotation = -90), iconTransformation(origin = {-21, -101}, extent = {{-5, -5}, {5, 5}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput dcdc_T annotation(
          Placement(visible = true, transformation(origin = {-103, -1}, extent = {{5, -5}, {-5, 5}}, rotation = 0), iconTransformation(origin = {-103, -1}, extent = {{5, -5}, {-5, 5}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput highvoltage_rad_Q annotation(
          Placement(visible = true, transformation(origin = {103, -9}, extent = {{-5, -5}, {5, 5}}, rotation = 0), iconTransformation(origin = {105, 95}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {-60, 34}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput batt_coolant_temp annotation(
          Placement(visible = true, transformation(origin = {-103, 35}, extent = {{5, -5}, {-5, 5}}, rotation = 0), iconTransformation(origin = {-103, 35}, extent = {{5, -5}, {-5, 5}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.battemp_t battemp_t_1 annotation(
          Placement(visible = true, transformation(origin = {2, 2}, extent = {{-10, -15}, {10, 15}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.Thermal_QinTout Chiller_IF annotation(
          Placement(visible = true, transformation(origin = {12, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      equation
        connect(dcdc_Q, dcdc.Q) annotation(
          Line(points = {{-104, 12}, {-74, 12}}, color = {0, 0, 127}));
        connect(Libatt_Q, Libatt.Q) annotation(
          Line(points = {{-34, -100}, {-34, -72}}, color = {0, 0, 127}));
        connect(highvoltage_radiator.Temperature, highvoltage_rad_T) annotation(
          Line(points = {{70, 0}, {102, 0}, {102, 0}, {104, 0}}, color = {0, 0, 127}));
        connect(VSP, highvoltage_radiator.VSP) annotation(
          Line(points = {{104, 42}, {64, 42}, {64, 6}, {64, 6}}, color = {0, 0, 127}));
        connect(RAD, highvoltage_radiator.RAD) annotation(
          Line(points = {{104, 84}, {56, 84}, {56, 6}, {56, 6}}, color = {0, 0, 127}));
        connect(Libatt.K, Libatt_T) annotation(
          Line(points = {{-20, -70}, {-20, -70}, {-20, -100}, {-20, -100}}, color = {0, 0, 127}));
        connect(dcdc_T, dcdc.K) annotation(
          Line(points = {{-103, -1}, {-72, -1}, {-72, -2}}, color = {0, 0, 127}));
        connect(highvoltage_radiator.heatFlow, highvoltage_rad_Q) annotation(
          Line(points = {{70, -8}, {100, -8}, {100, -8}, {104, -8}}, color = {0, 0, 127}));
        connect(batt_coolant_temp, temperatureSensor.T) annotation(
          Line(points = {{-102, 36}, {-70, 36}, {-70, 34}, {-70, 34}}, color = {0, 0, 127}));
        connect(battemp_t_1.dcdcinv_w, dcdc.port_b) annotation(
          Line(points = {{-18, 10}, {-52, 10}, {-52, 6}, {-52, 6}}, color = {191, 0, 0}));
        connect(temperatureSensor.port, battemp_t_1.dcdcinv_w) annotation(
          Line(points = {{-50, 34}, {-18, 34}, {-18, 10}, {-18, 10}}, color = {191, 0, 0}));
        connect(batttemp_wp2, battemp_t_1.bbpump_m3ps) annotation(
          Line(points = {{-106, -26}, {-16, -26}, {-16, 12}, {-10, 12}, {-10, 10}}, color = {0, 0, 127}));
        connect(batttemp_valve1_rate, battemp_t_1.BValve_A) annotation(
          Line(points = {{-104, -68}, {-40, -68}, {-40, 4}, {-10, 4}, {-10, 4}}, color = {0, 0, 127}));
        connect(batttemp_valve2_rate, battemp_t_1.BValve_B) annotation(
          Line(points = {{-106, 52}, {-14, 52}, {-14, -2}, {-10, -2}, {-10, -2}}, color = {0, 0, 127}));
        connect(battemp_t_1.bapump_m3ps, batttemp_wp1) annotation(
          Line(points = {{20, 0}, {30, 0}, {30, -98}, {50, -98}, {50, -100}}, color = {0, 0, 127}));
        connect(battemp_t_1.brad_w, highvoltage_radiator.port_b) annotation(
          Line(points = {{22, 4}, {42, 4}, {42, -4}, {50, -4}, {50, -4}}, color = {191, 0, 0}));
        connect(battemp_t_1.libatt_w, Libatt.port_b) annotation(
          Line(points = {{0, -18}, {-2, -18}, {-2, -44}, {-28, -44}, {-28, -50}, {-28, -50}, {-28, -50}}, color = {191, 0, 0}));
        connect(battemp_t_1.chiller_w, Chiller_IF.port_b) annotation(
          Line(points = {{4, -18}, {4, -18}, {4, -38}, {12, -38}, {12, -50}, {12, -50}}, color = {191, 0, 0}));
        connect(chiller_Q, Chiller_IF.Qin) annotation(
          Line(points = {{4, -100}, {4, -100}, {4, -78}, {8, -78}, {8, -72}, {8, -72}}, color = {0, 0, 127}));
        connect(Chiller_IF.Tout, chiller_T) annotation(
          Line(points = {{16, -70}, {16, -70}, {16, -100}, {18, -100}}, color = {0, 0, 127}));
      end batttemp4;

      model thermal_system_whole
        parameter Modelica.SIunits.HeatCapacity ENGINE_C = 6000 "Engine heat capacity";
        parameter Modelica.SIunits.HeatCapacity LAUNCH_C = 4300 "LAUNCH heat capacity";
        parameter Modelica.SIunits.HeatCapacity VARIATOR_C = 17000 "VARIATOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity CASE_C = 29000 "CASE heat capacity";
        parameter Modelica.SIunits.HeatCapacity MG_C = 2000 "MG heat capacity";
        parameter Modelica.SIunits.HeatCapacity OIL_C = 9400 "OIL heat capacity";
        parameter Modelica.SIunits.HeatCapacity ATCOOLER_C = 100 "ATCOOLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity PTC_C = 10 "PTC heat capacity";
        parameter Modelica.SIunits.HeatCapacity HVAC_C = 1 "HVAC heat capacity";
        parameter Modelica.SIunits.HeatCapacity CABIN_C = 6000 "CABIN heat capacity";
        parameter Modelica.SIunits.HeatCapacity GLASS_C = 30000 "GLASS heat capacity";
        parameter Modelica.SIunits.HeatCapacity DOOR_C = 50000 "DOOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity RADIATOR_C = 15 "RADIATOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity CHARGEAIRCOOLER_C = 15 "CHARGE AIR COOLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity TURBO_CHARGER_C = 10 "TURBO CHARGER heat capacity";
        parameter Modelica.SIunits.HeatCapacity LOW_RADIATOR_C = 1.0 "LOW RADIATOR  heat capacity";
        parameter Modelica.SIunits.HeatCapacity condenser_C = 1.0 "condenser heat capacity";
        parameter Modelica.SIunits.HeatCapacity EL_AC_C = 5.0 "e-AC heat capacity";
        parameter Modelica.SIunits.HeatCapacity CHILLER_C = 5.0 "CHILLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity LIBATT_C = 1000 "Li batt heat capacity";
        parameter Modelica.SIunits.HeatCapacity DCDC_C = 500 "DCDC heat capacity";
        parameter Modelica.SIunits.HeatCapacity BAT_RADIATOR_C = 1.0 "BAT RADIATOR  heat capacity";
        parameter Modelica.SIunits.ThermalResistance LAUNCH_ENGINE_R = 100 "LAUNCH thermal resistance for ENGINE";
        parameter Modelica.SIunits.ThermalResistance CASE_ENGINE_R = 0.015 "CASE thermal resistance for ENGINE";
        parameter Modelica.SIunits.ThermalResistance CASE_LAUNCH_R = 100 "CASE thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance CASE_VAR_R = 100 "CASE thermal resistance for VARIATOR";
        parameter Modelica.SIunits.ThermalResistance CASE_MG_R = 100 "CASE thermal resistance for MG";
        parameter Modelica.SIunits.ThermalResistance CASE_AIR_R = 0.1 "CASE thermal resistance for AIR";
        parameter Modelica.SIunits.ThermalResistance OIL_LAUNCH_R = 0.0001 "OIL thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance OIL_VAR_R = 0.073 "OIL thermal resistance for VARIATOR";
        parameter Modelica.SIunits.ThermalResistance OIL_CASE_R = 0.0044 "OIL thermal resistance for CASE";
        parameter Modelica.SIunits.ThermalResistance OIL_MG_R = 0.05 "OIL thermal resistance for MG";
        parameter Modelica.SIunits.ThermalResistance AT_COOLER_OIL_R = 0.001 "ATCOOLER thermal resistance for OIL";
        parameter Modelica.SIunits.ThermalResistance ENGINE1_WATER_R = 0.01 "ENGINE1 thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance ENGINE2_WATER_R = 0.01 "ENGINE2 thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance ATCOOLER_WATER_R = 0.01 "AT COOLER thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance PTC_WATER_R = 0.01 "PTC thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance HVAC_WATER_R = 0.01 "HVAC thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance HVAC_CABIN_R = 0.1 "HVAC thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance GLASS_CABIN_R = 10 "GLASS thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance DOOR_CABIN_R = 10 "DOOR thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance LOW_RADIATOR_R = 0.01 "low thermal resistance for rad";
        parameter Modelica.SIunits.ThermalResistance BAT_RADIATOR_R = 0.01 "bat thermal resistance for rad";
        parameter Modelica.SIunits.ThermalResistance MG_WATER_R = 0.01 "MG thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance CHARGEAIRCOOLER_WATER_R = 0.01 "CHARGEAIRCOOLER thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance TURBO_WATER_R = 0.01 "TURBO thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance condenser_HVAC_R = 0.1 "condenser thermal resistance for HVAC";
        parameter Modelica.SIunits.ThermalResistance condenser_HIGHRAD_R = 0.01 "KONDENDOR thermal resistance for HIGHRAD";
        parameter Modelica.SIunits.ThermalResistance AC_HVAC_R = 0.1 "AC thermal resistance for HVAC";
        parameter Modelica.SIunits.ThermalResistance AC_CHILLER_R = 0.1 "AC thermal resistance for CHILLER";
        parameter Modelica.SIunits.ThermalResistance CHILLER_condenser_R = 0.1 "CHILLER thermal resistance for condenser";
        parameter Modelica.SIunits.ThermalResistance CHILLER_WATER_R = 0.01 "CHIller thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance LIBATT_WATER_R = 0.01 "LIBATT thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance DCDC_WATER_R = 0.01 "DCDC thermal resistance for water";
        TRAMI_L3_HEV.Thermal.thermal_circuits.batttemp4 batttemp_thermal(dcdc_C = DCDC_C, dcdc_water_R = DCDC_WATER_R, libatt_C = LIBATT_C, libatt_water_R = LIBATT_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-43, -249}, extent = {{-31, -31}, {31, 31}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.lowtemp5 lowtemp_thermal(chargeaircooler_C = CHARGEAIRCOOLER_C, chargeaircooler_water_R = CHARGEAIRCOOLER_WATER_R, motorgenerator_C = MG_C, motorgenerator_water_R = MG_WATER_R, turbo_charger_C = TURBO_CHARGER_C, turbo_charger_water_R = TURBO_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-43, -75}, extent = {{-37, -37}, {37, 37}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput AIR_TEMP annotation(
          Placement(visible = true, transformation(origin = {245, 359}, extent = {{9, -9}, {-9, 9}}, rotation = 0), iconTransformation(origin = {-219, -599}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.hightemp4 hightemp4_1(engine1_C = ENGINE_C * 0.5, engine1_water_R = ENGINE1_WATER_R, engine2_C = ENGINE_C * 0.5, engine2_water_R = ENGINE2_WATER_R, ptc_C = PTC_C, ptc_water_R = PTC_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-40, 70}, extent = {{-44, -44}, {44, 44}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.hvac hvac(hvac_C = HVAC_C, hvac_water_R = HVAC_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {176, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.cabin cabin_1(cabin_C = CABIN_C, hvac_cabin_R = HVAC_CABIN_R) annotation(
          Placement(visible = true, transformation(origin = {175, 59}, extent = {{-17, -17}, {17, 17}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.thermal_heat_block door(c = DOOR_C, r = DOOR_CABIN_R) annotation(
          Placement(visible = true, transformation(origin = {176, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.thermal_heat_block glass(c = GLASS_C, r = GLASS_CABIN_R) annotation(
          Placement(visible = true, transformation(origin = {176, 94}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.condenser_comp condenser_comp(chiller_condenser_R = CHILLER_condenser_R, condenser_C = condenser_C, condenser_highrad_R = condenser_HIGHRAD_R, condenser_hvac_R = condenser_HVAC_R) annotation(
          Placement(visible = true, transformation(origin = {176, -104}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.chiller_comp chiller_comp(ac_chiller_R = AC_CHILLER_R, chiller_C = CHILLER_C, chiller_water_R = CHILLER_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {176, -156}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.el_ac_comp el_ac_comp(ac_hvac_R = AC_HVAC_R, el_ac_C = EL_AC_C) annotation(
          Placement(visible = true, transformation(origin = {176, -204}, extent = {{-22, -22}, {22, 22}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.engine_comp engine_comp(c = ENGINE_C, engine1_water_R = ENGINE1_WATER_R, engine2_water_R = ENGINE2_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-220, 286}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.at_cooler_comp at_cooler_comp(at_cooler_C = ATCOOLER_C, at_cooler_oil_R = AT_COOLER_OIL_R, at_cooler_water_R = ATCOOLER_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-211, 327}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.MG_comp mG_comp(c = MG_C) annotation(
          Placement(visible = true, transformation(origin = {-220, 4}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.case_comp case_comp(case_C = CASE_C, case_air_R = CASE_AIR_R, case_engine_R = CASE_ENGINE_R, case_launch_R = CASE_LAUNCH_R, case_mg_R = CASE_MG_R, case_var_R = CASE_VAR_R, oil_case_R = OIL_CASE_R) annotation(
          Placement(visible = true, transformation(origin = {-220, 228}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.launch_comp launch_comp(launch_C = LAUNCH_C, launch_engine_R = LAUNCH_ENGINE_R) annotation(
          Placement(visible = true, transformation(origin = {-218, 172}, extent = {{-18, -18}, {18, 18}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.oil_comp oil_comp(oil_C = OIL_C, oil_launch_R = OIL_LAUNCH_R, oil_mg_R = OIL_MG_R, oil_variator_R = OIL_VAR_R) annotation(
          Placement(visible = true, transformation(origin = {-220, 66}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput PTC_Q annotation(
          Placement(visible = true, transformation(origin = {-14, 220}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, 600}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PTC_T annotation(
          Placement(visible = true, transformation(origin = {-28, 186}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 586}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_VALVE1 annotation(
          Placement(visible = true, transformation(origin = {-102, 196}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_VALVE2 annotation(
          Placement(visible = true, transformation(origin = {-88, 166}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {201, -277}, extent = {{9, -9}, {-9, 9}}, rotation = 0), iconTransformation(origin = {-221, -541}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput RADFAN annotation(
          Placement(visible = true, transformation(origin = {201, -261}, extent = {{9, -9}, {-9, 9}}, rotation = 0), iconTransformation(origin = {-224, 418}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_WP annotation(
          Placement(visible = true, transformation(origin = {4, 180}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, 240}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_WP1 annotation(
          Placement(visible = true, transformation(origin = {-16, -330}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, 360}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput LIBAT_T annotation(
          Placement(visible = true, transformation(origin = {-50, -326}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {208, 190}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput LIBAT_Q annotation(
          Placement(visible = true, transformation(origin = {-60, -386}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, -480}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_VALVE1 annotation(
          Placement(visible = true, transformation(origin = {-98, -322}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-220, 0}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_WP2 annotation(
          Placement(visible = true, transformation(origin = {-130, -328}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, 180}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput DCDC_T annotation(
          Placement(visible = true, transformation(origin = {-150, -322}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {210, 388}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput DCDC_Q annotation(
          Placement(visible = true, transformation(origin = {-184, -322}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, -418}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_VALVE2 annotation(
          Placement(visible = true, transformation(origin = {-232, -320}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, 122}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput LTEMP_WP annotation(
          Placement(visible = true, transformation(origin = {-252, -174}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 298}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput CHARGEAIR_Q annotation(
          Placement(visible = true, transformation(origin = {-230, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 482}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGEAIR_T annotation(
          Placement(visible = true, transformation(origin = {-176, -96}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -330}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput CHARGER_Q annotation(
          Placement(visible = true, transformation(origin = {-228, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 542}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGER_T annotation(
          Placement(visible = true, transformation(origin = {-194, -64}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -196}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput LAUNCH_Q annotation(
          Placement(visible = true, transformation(origin = {-318, 174}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VAR_Q annotation(
          Placement(visible = true, transformation(origin = {-324, 112}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -240}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGINE_Q annotation(
          Placement(visible = true, transformation(origin = {-280, 274}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -300}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput MG_Q annotation(
          Placement(visible = true, transformation(origin = {-328, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -360}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput coolant_temp annotation(
          Placement(visible = true, transformation(origin = {-70, 244}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 484}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput MG_T annotation(
          Placement(visible = true, transformation(origin = {-314, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, 292}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput batt_coolantemp annotation(
          Placement(visible = true, transformation(origin = {-210, -330}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {210, 80}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput AC_Q annotation(
          Placement(visible = true, transformation(origin = {252, -204}, extent = {{20, -20}, {-20, 20}}, rotation = 0), iconTransformation(origin = {-222, -120}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput cabin_T annotation(
          Placement(visible = true, transformation(origin = {216, 62}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -62}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.radiator_comp radiator_comp(bat_rad_R = BAT_RADIATOR_R, bat_radiator_C = BAT_RADIATOR_C, low_rad_R = LOW_RADIATOR_R, low_radiator_C = LOW_RADIATOR_C, radiator_C = RADIATOR_C) annotation(
          Placement(visible = true, transformation(origin = {174, -54}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.vat_comp vat_comp annotation(
          Placement(visible = true, transformation(origin = {-220, 124}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput oil_temp annotation(
          Placement(visible = true, transformation(origin = {-302, 50}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {211, -571}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      equation
        connect(hightemp4_1.hvac_T, hvac.from_hightempthermal_T) annotation(
          Line(points = {{8, 105}, {108, 105}, {108, 10}, {154, 10}}, color = {0, 0, 127}));
        connect(hightemp4_1.hvac_Q, hvac.to_hightempthermal_Q) annotation(
          Line(points = {{8, 92}, {103, 92}, {103, 5}, {155, 5}}, color = {0, 0, 127}));
        connect(door.K_in, AIR_TEMP) annotation(
          Line(points = {{185, 126}, {226, 126}, {226, 359}, {245, 359}}, color = {0, 0, 127}));
        connect(glass.K_in, AIR_TEMP) annotation(
          Line(points = {{185, 100}, {226, 100}, {226, 359}, {245, 359}}, color = {0, 0, 127}));
        connect(door.K_out, cabin_1.from_door_T) annotation(
          Line(points = {{166, 113}, {143, 113}, {143, 64}, {156, 64}, {156, 65}}, color = {0, 0, 127}));
        connect(cabin_1.to_door_Q, door.Q_in) annotation(
          Line(points = {{157, 61}, {157, 60.375}, {137, 60.375}, {137, 125.75}, {165, 125.75}, {165, 125}}, color = {0, 0, 127}));
        connect(hvac.from_cabin_Q, cabin_1.to_hvac_Q) annotation(
          Line(points = {{154, 20}, {138, 20}, {138, 45}, {157, 45}}, color = {0, 0, 127}));
        connect(cabin_1.from_hvac_T, hvac.to_cabin_T) annotation(
          Line(points = {{156, 49}, {126, 49}, {126, 15}, {155, 15}}, color = {0, 0, 127}));
        connect(batttemp_thermal.highvoltage_rad_Q, condenser_comp.from_hig_rad) annotation(
          Line(points = {{-10, -220}, {27.5, -220}, {27.5, -104}, {154, -104}}, color = {0, 0, 127}));
        connect(condenser_comp.to_highvrad_T, batttemp_thermal.highvoltage_rad_T) annotation(
          Line(points = {{155, -109}, {30.5, -109}, {30.5, -228}, {-10, -228}}, color = {0, 0, 127}));
        connect(hvac.from_condenser_Q, condenser_comp.to_hvac_Q) annotation(
          Line(points = {{154, -14}, {74, -14}, {74, -98}, {141, -98}, {141, -98.5}, {155, -98.5}, {155, -99}}, color = {0, 0, 127}));
        connect(condenser_comp.from_hvac_T, hvac.to_condenser_T) annotation(
          Line(points = {{154, -94}, {78, -94}, {78, -19}, {155, -19}}, color = {0, 0, 127}));
        connect(condenser_comp.from_chiller_T, chiller_comp.to_condenser_T) annotation(
          Line(points = {{154, -118}, {66, -118}, {66, -142}, {155, -142}, {155, -141}}, color = {0, 0, 127}));
        connect(condenser_comp.to_chiller_Q, chiller_comp.from_condenser_Q) annotation(
          Line(points = {{155, -123}, {70, -123}, {70, -136}, {154, -136}}, color = {0, 0, 127}));
        connect(chiller_comp.to_batrad_Q, batttemp_thermal.chiller_Q) annotation(
          Line(points = {{155, -159}, {40.5, -159}, {40.5, -246}, {-10, -246}}, color = {0, 0, 127}));
        connect(batttemp_thermal.chiller_T, chiller_comp.from_batrad_T) annotation(
          Line(points = {{-10, -238}, {37, -238}, {37, -154}, {154, -154}}, color = {0, 0, 127}));
        connect(hvac.to_ac_T, el_ac_comp.from_hvac_T) annotation(
          Line(points = {{155, -7}, {52, -7}, {52, -219}, {152, -219}}, color = {0, 0, 127}));
        connect(hvac.from_ac_Q, el_ac_comp.to_hvac_Q) annotation(
          Line(points = {{154, -2}, {50, -2}, {50, -225}, {153, -225}}, color = {0, 0, 127}));
        connect(chiller_comp.from_ac_T, el_ac_comp.to_chiller_T) annotation(
          Line(points = {{154, -170}, {78, -170}, {78, -188}, {153, -188}}, color = {0, 0, 127}));
        connect(chiller_comp.to_ac_Q, el_ac_comp.from_chiller_Q) annotation(
          Line(points = {{155, -174}, {80, -174}, {80, -183}, {152, -183}}, color = {0, 0, 127}));
        connect(hightemp4_1.engine_T, engine_comp.from_hightempthermal_T) annotation(
          Line(points = {{-88, 44}, {-124, 44}, {-124, 296}, {-198, 296}}, color = {0, 0, 127}));
        connect(at_cooler_comp.to_hightempthermal_Q, hightemp4_1.at_cooler_Q) annotation(
          Line(points = {{-199, 333}, {-58, 333}, {-58, 118}}, color = {0, 0, 127}));
        connect(at_cooler_comp.from_hightempthermal_T, hightemp4_1.at_cooler_T) annotation(
          Line(points = {{-199, 337}, {-44, 337}, {-44, 118}}, color = {0, 0, 127}));
        connect(PTC_Q, hightemp4_1.ptc_Q) annotation(
          Line(points = {{-14, 220}, {-14, 118}}, color = {0, 0, 127}));
        connect(hightemp4_1.ptc_T, PTC_T) annotation(
          Line(points = {{-27, 118}, {-27, 174}, {-28, 174}, {-28, 186}}, color = {0, 0, 127}));
        connect(HTEMP_VALVE1, hightemp4_1.hightemp_valve1_rate) annotation(
          Line(points = {{-102, 196}, {-102, 96}, {-88, 96}}, color = {0, 0, 127}));
        connect(hightemp4_1.hightemp_wp, HTEMP_WP) annotation(
          Line(points = {{4, 118}, {4, 180}}, color = {0, 0, 127}));
        connect(BTEMP_WP1, batttemp_thermal.batttemp_wp1) annotation(
          Line(points = {{-16, -330}, {-16, -301}, {-27.5, -301}, {-27.5, -280}}, color = {0, 0, 127}));
        connect(batttemp_thermal.Libatt_T, LIBAT_T) annotation(
          Line(points = {{-50, -280}, {-50, -326}}, color = {0, 0, 127}));
        connect(batttemp_thermal.batttemp_valve1_rate, BTEMP_VALVE1) annotation(
          Line(points = {{-75, -270}, {-98, -270}, {-98, -322}}, color = {0, 0, 127}));
        connect(batttemp_thermal.batttemp_wp2, BTEMP_WP2) annotation(
          Line(points = {{-76, -257}, {-130, -257}, {-130, -328}}, color = {0, 0, 127}));
        connect(batttemp_thermal.dcdc_Q, DCDC_Q) annotation(
          Line(points = {{-75, -245}, {-184, -245}, {-184, -322}}, color = {0, 0, 127}));
        connect(batttemp_thermal.dcdc_T, DCDC_T) annotation(
          Line(points = {{-75, -249}, {-150, -249}, {-150, -322}}, color = {0, 0, 127}));
        connect(BTEMP_VALVE2, batttemp_thermal.batttemp_valve2_rate) annotation(
          Line(points = {{-232, -320}, {-232, -233}, {-76, -233}}, color = {0, 0, 127}));
        connect(LTEMP_WP, lowtemp_thermal.volume_flow_lowtemp) annotation(
          Line(points = {{-252, -174}, {-192.5, -174}, {-192.5, -112}, {-83, -112}}, color = {0, 0, 127}));
        connect(CHARGEAIR_Q, lowtemp_thermal.charge_air_Q) annotation(
          Line(points = {{-230, -80}, {-175, -80}, {-175, -79}, {-84, -79}}, color = {0, 0, 127}));
        connect(CHARGEAIR_T, lowtemp_thermal.charge_air_T) annotation(
          Line(points = {{-176, -96}, {-84, -96}, {-84, -93.5}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.turbo_charger_Q, CHARGER_Q) annotation(
          Line(points = {{-83, -50}, {-228, -50}}, color = {0, 0, 127}));
        connect(CHARGER_T, lowtemp_thermal.turbo_charger_T) annotation(
          Line(points = {{-194, -64}, {-84, -64}}, color = {0, 0, 127}));
        connect(launch_comp.from_launchloss_Q, LAUNCH_Q) annotation(
          Line(points = {{-238, 175}, {-276.5, 175}, {-276.5, 174}, {-318, 174}}, color = {0, 0, 127}));
        connect(ENGINE_Q, engine_comp.from_engineloss) annotation(
          Line(points = {{-280, 274}, {-242, 274}}, color = {0, 0, 127}));
        connect(MG_Q, mG_comp.from_mg_loss_Q) annotation(
          Line(points = {{-328, 20}, {-297, 20}, {-297, 4}, {-242, 4}}, color = {0, 0, 127}));
        connect(coolant_temp, hightemp4_1.coolant_temp) annotation(
          Line(points = {{-70, 244}, {-70, 118}, {-71, 118}}, color = {0, 0, 127}));
        connect(MG_T, mG_comp.to_mg_loss_T) annotation(
          Line(points = {{-314, 0}, {-241, 0}, {-241, -1}}, color = {0, 0, 127}));
        connect(batttemp_thermal.batt_coolant_temp, batt_coolantemp) annotation(
          Line(points = {{-75, -238}, {-210, -238}, {-210, -330}}, color = {0, 0, 127}));
        connect(AC_Q, el_ac_comp.from_AC_Q) annotation(
          Line(points = {{252, -204}, {200, -204}}, color = {0, 0, 127}));
        connect(radiator_comp.to_lowrad_T, lowtemp_thermal.charge_air_radiator_T) annotation(
          Line(points = {{153, -51}, {32, -51}, {32, -56}, {-2, -56}, {-2, -56.5}}, color = {0, 0, 127}));
        connect(radiator_comp.from_low_rad, lowtemp_thermal.charge_air_radiator_Q) annotation(
          Line(points = {{152, -47}, {27.5, -47}, {27.5, -42}, {-2, -42}}, color = {0, 0, 127}));
        connect(radiator_comp.to_battrad_T, condenser_comp.from_lowrad_T) annotation(
          Line(points = {{153, -73}, {110, -73}, {110, -84}, {154, -84}}, color = {0, 0, 127}));
        connect(radiator_comp.from_batrad_Q, condenser_comp.to_lowrad_Q) annotation(
          Line(points = {{152, -68}, {98, -68}, {98, -89}, {155, -89}}, color = {0, 0, 127}));
        connect(radiator_comp.from_hightemp_Q, hightemp4_1.radiator_Q) annotation(
          Line(points = {{152, -36}, {90, -36}, {90, 79}, {8, 79}}, color = {0, 0, 127}));
        connect(hightemp4_1.radiator_T, radiator_comp.to_hightemp_T) annotation(
          Line(points = {{8, 66}, {82, 66}, {82, -40}, {153, -40}, {153, -41}}, color = {0, 0, 127}));
        connect(VAR_Q, vat_comp.from_var_loss_Q) annotation(
          Line(points = {{-324, 112}, {-242, 112}}, color = {0, 0, 127}));
        connect(oil_temp, oil_comp.oil_temp) annotation(
          Line(points = {{-302, 50}, {-292, 50}, {-292, 47}, {-241, 47}}, color = {0, 0, 127}));
        connect(cabin_1.cabin_T, cabin_T) annotation(
          Line(points = {{193, 62}, {216, 62}}, color = {0, 0, 127}));
        connect(glass.K_out, cabin_1.from_glass_T) annotation(
          Line(points = {{166, 88}, {150, 88}, {150, 74}, {156, 74}, {156, 74}}, color = {0, 0, 127}));
        connect(glass.Q_in, cabin_1.to_glass_Q) annotation(
          Line(points = {{166, 100}, {148, 100}, {148, 70}, {158, 70}, {158, 70}}, color = {0, 0, 127}));
        connect(mG_comp.from_lowtempthermal_Q, lowtemp_thermal.motor_generator_Q) annotation(
          Line(points = {{-198, -16}, {-57, -16}, {-57, -32}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.motor_generator_T, mG_comp.to_lowtempthermal_T) annotation(
          Line(points = {{-38, -31}, {-38, -8}, {-199, -8}, {-199, -9}}, color = {0, 0, 127}));
        connect(engine_comp.from_hightempthermal2_T, hightemp4_1.engine2_T) annotation(
          Line(points = {{-198, 306}, {-114, 306}, {-114, 79}, {-88, 79}}, color = {0, 0, 127}));
        connect(engine_comp.to_hightempthermal2_Q, hightemp4_1.engine2_Q) annotation(
          Line(points = {{-198, 302}, {-118, 302}, {-118, 61}, {-88, 61}}, color = {0, 0, 127}));
        connect(engine_comp.to_hightempthermal_Q, hightemp4_1.engine_Q) annotation(
          Line(points = {{-198, 290}, {-130, 290}, {-130, 26}, {-88, 26}}, color = {0, 0, 127}));
        connect(HTEMP_VALVE2, hightemp4_1.hightemp_valve2_rate) annotation(
          Line(points = {{-88, 166}, {-90, 166}, {-90, 114}, {-88, 114}}, color = {0, 0, 127}));
        connect(LIBAT_Q, batttemp_thermal.Libatt_Q) annotation(
          Line(points = {{-60, -386}, {-60, -280}}, color = {0, 0, 127}));
        connect(case_comp.from_airtemp, AIR_TEMP) annotation(
          Line(points = {{-242, 242}, {-306, 242}, {-306, 360}, {246, 360}}, color = {0, 0, 127}));
        connect(radiator_comp.from_air_T, AIR_TEMP) annotation(
          Line(points = {{196, -50}, {226, -50}, {226, 360}, {246, 360}, {246, 360}}, color = {0, 0, 127}));
        connect(batttemp_thermal.VSP, VSP) annotation(
          Line(points = {{-10, -276}, {194, -276}, {194, -277}, {201, -277}}, color = {0, 0, 127}));
        connect(batttemp_thermal.RAD, RADFAN) annotation(
          Line(points = {{-10, -262}, {192, -262}, {192, -261}, {201, -261}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.VSP, VSP) annotation(
          Line(points = {{-2, -108}, {4, -108}, {4, -276}, {202, -276}, {202, -276}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.RAD, RADFAN) annotation(
          Line(points = {{-2, -86}, {8, -86}, {8, -262}, {202, -262}, {202, -260}}, color = {0, 0, 127}));
        connect(hightemp4_1.VSP, VSP) annotation(
          Line(points = {{8, 26}, {18, 26}, {18, -276}, {202, -276}}, color = {0, 0, 127}));
        connect(hightemp4_1.RAD, RADFAN) annotation(
          Line(points = {{8, 44}, {24, 44}, {24, -262}, {202, -262}, {202, -260}}, color = {0, 0, 127}));
        connect(oil_comp.from_case_Q, case_comp.to_oil_Q) annotation(
          Line(points = {{-198, 68}, {-178, 68}, {-178, 226}, {-199, 226}}, color = {0, 0, 127}));
        connect(at_cooler_comp.to_oil_Q, oil_comp.from_oilcooler_Q) annotation(
          Line(points = {{-200, 318}, {-148, 318}, {-148, 58}, {-198, 58}, {-198, 58}}, color = {0, 0, 127}));
        connect(oil_comp.to_MG_Q, mG_comp.from_oil_Q) annotation(
          Line(points = {{-198, 46}, {-194, 46}, {-194, 24}, {-198, 24}}, color = {0, 0, 127}));
        connect(oil_comp.to_launch_Q, launch_comp.from_oil_Q) annotation(
          Line(points = {{-198, 74}, {-184, 74}, {-184, 162}, {-198, 162}, {-198, 162}}, color = {0, 0, 127}));
        connect(case_comp.to_MG_Q, mG_comp.from_case_Q) annotation(
          Line(points = {{-199, 234}, {-162, 234}, {-162, 8}, {-198, 8}}, color = {0, 0, 127}));
        connect(oil_comp.to_ratio_Q, vat_comp.from_oil_Q) annotation(
          Line(points = {{-198, 82}, {-192, 82}, {-192, 110}, {-198, 110}, {-198, 110}}, color = {0, 0, 127}));
        connect(oil_comp.to_oilcooler_Toil, at_cooler_comp.from_oil_T) annotation(
          Line(points = {{-198, 54}, {-144, 54}, {-144, 322}, {-198, 322}, {-198, 322}}, color = {0, 0, 127}));
        connect(mG_comp.to_oil_Tmg, oil_comp.from_mG_T) annotation(
          Line(points = {{-199, 19}, {-192, 19}, {-192, 50}, {-198, 50}, {-198, 52}}, color = {0, 0, 127}));
        connect(mG_comp.to_case_Tmg, case_comp.from_mG_T) annotation(
          Line(points = {{-199, 3}, {-158, 3}, {-158, 238}, {-198, 238}}, color = {0, 0, 127}));
        connect(vat_comp.to_oil_Tvat, oil_comp.from_ratio_T) annotation(
          Line(points = {{-198, 106}, {-194, 106}, {-194, 86}, {-198, 86}, {-198, 86}}, color = {0, 0, 127}));
        connect(oil_comp.from_launch_T, launch_comp.to_oil_Tlaunch) annotation(
          Line(points = {{-198, 78}, {-188, 78}, {-188, 156}, {-200, 156}, {-200, 156}}, color = {0, 0, 127}));
        connect(engine_comp.to_case_TempEng, case_comp.from_engine_T) annotation(
          Line(points = {{-198, 268}, {-194, 268}, {-194, 247}, {-198, 247}}, color = {0, 0, 127}));
        connect(case_comp.to_engine_Q, engine_comp.from_case_Q) annotation(
          Line(points = {{-199, 243}, {-192, 243}, {-192, 272}, {-198, 272}}, color = {0, 0, 127}));
        connect(oil_comp.to_case_Toil, case_comp.from_oil_T) annotation(
          Line(points = {{-198, 64}, {-174, 64}, {-174, 230}, {-198, 230}}, color = {0, 0, 127}));
        connect(engine_comp.to_launch_TempEng, launch_comp.from_engine_T) annotation(
          Line(points = {{-198, 280}, {-170, 280}, {-170, 174}, {-198, 174}, {-198, 174}}, color = {0, 0, 127}));
        connect(launch_comp.to_engine_Q, engine_comp.from_launch_Q) annotation(
          Line(points = {{-200, 170}, {-166, 170}, {-166, 284}, {-198, 284}, {-198, 284}}, color = {0, 0, 127}));
        connect(case_comp.to_launch_Q, launch_comp.from_case_Q) annotation(
          Line(points = {{-199, 210}, {-194, 210}, {-194, 190}, {-198, 190}}, color = {0, 0, 127}));
        connect(launch_comp.to_case_Tlaunch, case_comp.from_launch_T) annotation(
          Line(points = {{-200, 184}, {-192, 184}, {-192, 214}, {-198, 214}}, color = {0, 0, 127}));
        connect(case_comp.to_ratio_Q, vat_comp.from_case_Q) annotation(
          Line(points = {{-198, 218}, {-140, 218}, {-140, 142}, {-198, 142}, {-198, 142}}, color = {0, 0, 127}));
        connect(vat_comp.to_case_Tvat, case_comp.from_ratio_T) annotation(
          Line(points = {{-198, 136}, {-136, 136}, {-136, 222}, {-198, 222}, {-198, 222}}, color = {0, 0, 127}));
      protected
        annotation(
          Icon(coordinateSystem(extent = {{-200, -600}, {200, 600}}, initialScale = 0.1), graphics = {Text(origin = {-76, 536}, extent = {{-118, 54}, {264, -1128}}, textString = "%name"), Rectangle(origin = {-2, -3}, extent = {{-198, 603}, {198, -603}})}),
          Diagram(coordinateSystem(extent = {{-200, -600}, {200, 600}})));
      end thermal_system_whole;

      model cabin
        parameter Modelica.SIunits.HeatCapacity cabin_C = 2000;
        parameter Modelica.SIunits.ThermalResistance hvac_cabin_R = 1.6 "HVAC thermal resistance for cabin";
        Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = cabin_C, T(fixed = true, start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {92, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hvac_T annotation(
          Placement(visible = true, transformation(origin = {-112, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_hvac_Q annotation(
          Placement(visible = true, transformation(origin = {-110, -90}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-208, -166}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_door_T annotation(
          Placement(visible = true, transformation(origin = {-116, -10}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 76}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_glass_T annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 176}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature annotation(
          Placement(visible = true, transformation(origin = {-62, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor annotation(
          Placement(visible = true, transformation(origin = {-18, -10}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_door_Q annotation(
          Placement(visible = true, transformation(origin = {-110, -38}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 28}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature1 annotation(
          Placement(visible = true, transformation(origin = {-60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor1 annotation(
          Placement(visible = true, transformation(origin = {-20, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_glass_Q annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, 126}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput cabin_T annotation(
          Placement(visible = true, transformation(origin = {206, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(
          Placement(visible = true, transformation(origin = {160, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sensors.HeatFlowSensor heatFlowSensor3 annotation(
          Placement(visible = true, transformation(origin = {-18, -66}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature prescribedTemperature3 annotation(
          Placement(visible = true, transformation(origin = {-62, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor thermalResistor(R = hvac_cabin_R) annotation(
          Placement(visible = true, transformation(origin = {32, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor dummy(R = 0.01) annotation(
          Placement(visible = true, transformation(origin = {32, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Components.ThermalResistor dummy2(R = 0.01) annotation(
          Placement(visible = true, transformation(origin = {32, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(from_door_T, prescribedTemperature.T) annotation(
          Line(points = {{-116, -10}, {-74, -10}}, color = {0, 0, 127}));
        connect(from_door_T, prescribedTemperature.T) annotation(
          Line(points = {{-116, -10}, {-74, -10}}, color = {0, 0, 127}));
        connect(to_door_Q, heatFlowSensor.Q_flow) annotation(
          Line(points = {{-110, -38}, {-18, -38}, {-18, -20}}, color = {0, 0, 127}));
        connect(from_glass_T, prescribedTemperature1.T) annotation(
          Line(points = {{-120, 40}, {-72, 40}, {-72, 40}, {-72, 40}}, color = {0, 0, 127}));
        connect(to_glass_Q, heatFlowSensor1.Q_flow) annotation(
          Line(points = {{-110, 20}, {-20, 20}, {-20, 30}}, color = {0, 0, 127}));
        connect(prescribedTemperature1.port, heatFlowSensor1.port_b) annotation(
          Line(points = {{-50, 40}, {-32, 40}, {-32, 40}, {-30, 40}}, color = {191, 0, 0}));
        connect(prescribedTemperature.port, heatFlowSensor.port_b) annotation(
          Line(points = {{-52, -10}, {-28, -10}, {-28, -10}, {-28, -10}}, color = {191, 0, 0}));
        connect(temperatureSensor.T, cabin_T) annotation(
          Line(points = {{170, 22}, {198, 22}, {198, 20}, {206, 20}}, color = {0, 0, 127}));
        connect(heatCapacitor.port, temperatureSensor.port) annotation(
          Line(points = {{92, 80}, {92, 80}, {92, 22}, {150, 22}, {150, 22}}, color = {191, 0, 0}));
        connect(heatFlowSensor3.port_a, thermalResistor.port_a) annotation(
          Line(points = {{-8, -66}, {22, -66}, {22, -66}, {22, -66}}, color = {191, 0, 0}));
        connect(prescribedTemperature3.port, heatFlowSensor3.port_b) annotation(
          Line(points = {{-52, -66}, {-30, -66}, {-30, -66}, {-28, -66}}, color = {191, 0, 0}));
        connect(thermalResistor.port_b, heatCapacitor.port) annotation(
          Line(points = {{42, -66}, {92, -66}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        connect(from_hvac_T, prescribedTemperature3.T) annotation(
          Line(points = {{-112, -66}, {-74, -66}, {-74, -66}, {-74, -66}}, color = {0, 0, 127}));
        connect(to_hvac_Q, heatFlowSensor3.Q_flow) annotation(
          Line(points = {{-110, -90}, {-18, -90}, {-18, -76}, {-18, -76}}, color = {0, 0, 127}));
        connect(heatFlowSensor1.port_a, dummy.port_a) annotation(
          Line(points = {{-10, 40}, {22, 40}, {22, 40}, {22, 40}}, color = {191, 0, 0}));
        connect(dummy.port_b, heatCapacitor.port) annotation(
          Line(points = {{42, 40}, {92, 40}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        connect(heatFlowSensor.port_a, dummy2.port_a) annotation(
          Line(points = {{-8, -10}, {20, -10}, {20, -10}, {22, -10}}, color = {191, 0, 0}));
        connect(dummy2.port_b, heatCapacitor.port) annotation(
          Line(points = {{42, -10}, {92, -10}, {92, 80}, {92, 80}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Text(origin = {-139, 157}, extent = {{-53, 35}, {329, -349}}, textString = "%name"), Rectangle(origin = {-104, 100}, extent = {{-96, 100}, {304, -300}})}, coordinateSystem(extent = {{-200, -200}, {200, 200}}, initialScale = 0.1)),
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}})));
      end cabin;

      model thermal_control
        TRAMI_L3_HEV.Thermal.thermal_parts.ptc_cont_Q ptc_cont_Q annotation(
          Placement(visible = true, transformation(origin = {1, 173}, extent = {{-13, -13}, {13, 13}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PTC_Q annotation(
          Placement(visible = true, transformation(origin = {204, 200}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 270}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ptctemp annotation(
          Placement(visible = true, transformation(origin = {-202, 182}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-212, 300}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput coolanttemp annotation(
          Placement(visible = true, transformation(origin = {-202, 168}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-210, 250}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.BooleanInput ac_onoff annotation(
          Placement(visible = true, transformation(origin = {-204, 150}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-210, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable2D Charger_Q(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/param/pnt/charger_Q.txt", tableName = "tab1", tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {0, 128}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGtrq annotation(
          Placement(visible = true, transformation(origin = {-204, 134}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-210, -150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput EngREV annotation(
          Placement(visible = true, transformation(origin = {-204, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-210, -210}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGER_Q annotation(
          Placement(visible = true, transformation(origin = {204, 180}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 230}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable2D Charger_aircoolar_Q(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/param/pnt/charger_air_cooler_Q.txt", tableName = "tab1", tableOnFile = true) annotation(
          Placement(visible = true, transformation(origin = {0, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGE_AIRCOOLER_Q annotation(
          Placement(visible = true, transformation(origin = {204, 160}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 190}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.rad_wp radiator_control(controlFile = currDir + "/param/cnt/coolant_RAD.txt", powerFile = currDir + "/param/pnt/RAD_W.txt") annotation(
          Placement(visible = true, transformation(origin = {-2, 68}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput RADFAN_Q annotation(
          Placement(visible = true, transformation(origin = {204, 140}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 148}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput RADFAN_W annotation(
          Placement(visible = true, transformation(origin = {204, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.rad_wp wp1 annotation(
          Placement(visible = true, transformation(origin = {-2, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.rad_wp wp2(controlTable = "tab2", powerTable = "tab2") annotation(
          Placement(visible = true, transformation(origin = {-2, -4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.rad_wp wp3(controlTable = "tab3", powerTable = "tab3") annotation(
          Placement(visible = true, transformation(origin = {-2, -36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.rad_wp wp4(controlTable = "tab4", powerTable = "tab4") annotation(
          Placement(visible = true, transformation(origin = {-2, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput dcdc_t annotation(
          Placement(visible = true, transformation(origin = {-206, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-212, 202}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput mg_t annotation(
          Placement(visible = true, transformation(origin = {-206, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-212, 148}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput batt_t annotation(
          Placement(visible = true, transformation(origin = {-206, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-212, 84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP1_Q annotation(
          Placement(visible = true, transformation(origin = {204, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP1_W annotation(
          Placement(visible = true, transformation(origin = {204, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP2_Q annotation(
          Placement(visible = true, transformation(origin = {204, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP2_W annotation(
          Placement(visible = true, transformation(origin = {204, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP3_Q annotation(
          Placement(visible = true, transformation(origin = {204, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP3_W annotation(
          Placement(visible = true, transformation(origin = {204, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP4_W annotation(
          Placement(visible = true, transformation(origin = {204, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput WP4_Q annotation(
          Placement(visible = true, transformation(origin = {204, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_sw_cont valve1(OFFrate = 0.01, ONrate = 0.95, hysLOW = 333.15) annotation(
          Placement(visible = true, transformation(origin = {-28, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput VALVE1_RATE annotation(
          Placement(visible = true, transformation(origin = {204, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput VALVE2_RATE annotation(
          Placement(visible = true, transformation(origin = {204, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -130}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput VALVE3_RATE annotation(
          Placement(visible = true, transformation(origin = {204, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput VALVE4_RATE annotation(
          Placement(visible = true, transformation(origin = {204, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -170}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_sw_cont valve2(OFFrate = 0.01, ONrate = 0.99) annotation(
          Placement(visible = true, transformation(origin = {-54, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_sw_cont valve3(OFFrate = 0.01, ONrate = 0.99, hysLOW = 333.15) annotation(
          Placement(visible = true, transformation(origin = {-78, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_sw_cont valve4(OFFrate = 0.01, ONrate = 0.99, hysHIGH = 363.15, hysLOW = 358.15) annotation(
          Placement(visible = true, transformation(origin = {-102, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput cabin_temp annotation(
          Placement(visible = true, transformation(origin = {-204, -192}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-212, -32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.ac_control ac_control annotation(
          Placement(visible = true, transformation(origin = {2, -196}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput AC_Q annotation(
          Placement(visible = true, transformation(origin = {204, -180}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -230}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput AC_W annotation(
          Placement(visible = true, transformation(origin = {202, -218}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -248}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ac_set_t annotation(
          Placement(visible = true, transformation(origin = {-204, -152}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-208, -268}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput bat_cool_t annotation(
          Placement(visible = true, transformation(origin = {-204, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-213, 27}, extent = {{-9, 9}, {9, -9}}, rotation = 0)));
        Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold(samplePeriod = 0.01, ySample(start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {-60, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold1(samplePeriod = 0.01, ySample(start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {-98, -98}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold2(samplePeriod = 0.01, ySample(start = 293.15)) annotation(
          Placement(visible = true, transformation(origin = {-136, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(ptctemp, ptc_cont_Q.ptc_temp_in) annotation(
          Line(points = {{-202, 182}, {-14, 182}}, color = {0, 0, 127}));
        connect(coolanttemp, ptc_cont_Q.coolant_temp_in) annotation(
          Line(points = {{-202, 168}, {-52, 168}, {-52, 179}, {-13, 179}}, color = {0, 0, 127}));
        connect(ac_onoff, ptc_cont_Q.AC_Onoff) annotation(
          Line(points = {{-204, 150}, {-38, 150}, {-38, 163}, {-25.5, 163}, {-25.5, 161}, {-13, 161}}, color = {255, 0, 255}));
        connect(ENGtrq, Charger_Q.u1) annotation(
          Line(points = {{-204, 134}, {-12, 134}}, color = {0, 0, 127}));
        connect(EngREV, Charger_Q.u2) annotation(
          Line(points = {{-204, 120}, {-14, 120}, {-14, 123}, {-12, 123}, {-12, 122}}, color = {0, 0, 127}));
        connect(ENGtrq, Charger_aircoolar_Q.u1) annotation(
          Line(points = {{-204, 134}, {-54, 134}, {-54, 106}, {-12, 106}}, color = {0, 0, 127}));
        connect(EngREV, Charger_aircoolar_Q.u2) annotation(
          Line(points = {{-204, 120}, {-60, 120}, {-60, 94}, {-12, 94}}, color = {0, 0, 127}));
        connect(coolanttemp, radiator_control.coolant_temp) annotation(
          Line(points = {{-202, 168}, {-90, 168}, {-90, 72}, {-12, 72}, {-12, 72}}, color = {0, 0, 127}));
        connect(dcdc_t, wp1.coolant_temp) annotation(
          Line(points = {{-206, 34}, {-12, 34}}, color = {0, 0, 127}));
        connect(mg_t, wp2.coolant_temp) annotation(
          Line(points = {{-206, 0}, {-12, 0}}, color = {0, 0, 127}));
        connect(batt_t, wp4.coolant_temp) annotation(
          Line(points = {{-206, -40}, {-109, -40}, {-109, -66}, {-12, -66}}, color = {0, 0, 127}));
        connect(ptc_cont_Q.PTC_Q, PTC_Q) annotation(
          Line(points = {{16, 174}, {42, 174}, {42, 200}, {204, 200}, {204, 200}}, color = {0, 0, 127}));
        connect(Charger_Q.y, CHARGER_Q) annotation(
          Line(points = {{12, 128}, {48, 128}, {48, 180}, {204, 180}, {204, 180}}, color = {0, 0, 127}));
        connect(Charger_aircoolar_Q.y, CHARGE_AIRCOOLER_Q) annotation(
          Line(points = {{12, 100}, {60, 100}, {60, 160}, {204, 160}, {204, 160}}, color = {0, 0, 127}));
        connect(radiator_control.y, RADFAN_Q) annotation(
          Line(points = {{8, 72}, {70, 72}, {70, 140}, {204, 140}, {204, 140}}, color = {0, 0, 127}));
        connect(radiator_control.power, RADFAN_W) annotation(
          Line(points = {{8, 66}, {80, 66}, {80, 120}, {204, 120}, {204, 120}}, color = {0, 0, 127}));
        connect(wp1.y, WP1_Q) annotation(
          Line(points = {{8, 34}, {90, 34}, {90, 100}, {204, 100}, {204, 100}}, color = {0, 0, 127}));
        connect(wp1.power, WP1_W) annotation(
          Line(points = {{8, 28}, {100, 28}, {100, 80}, {204, 80}, {204, 80}}, color = {0, 0, 127}));
        connect(wp2.y, WP2_Q) annotation(
          Line(points = {{8, 0}, {108, 0}, {108, 60}, {198, 60}, {198, 60}, {204, 60}}, color = {0, 0, 127}));
        connect(wp2.power, WP2_W) annotation(
          Line(points = {{8, -6}, {118, -6}, {118, 40}, {198, 40}, {198, 40}, {204, 40}}, color = {0, 0, 127}));
        connect(wp3.y, WP3_Q) annotation(
          Line(points = {{8, -32}, {128, -32}, {128, 20}, {196, 20}, {196, 20}, {204, 20}}, color = {0, 0, 127}));
        connect(wp3.power, WP3_W) annotation(
          Line(points = {{8, -38}, {140, -38}, {140, 0}, {204, 0}, {204, 0}}, color = {0, 0, 127}));
        connect(wp4.y, WP4_Q) annotation(
          Line(points = {{8, -66}, {150, -66}, {150, -20}, {204, -20}, {204, -20}}, color = {0, 0, 127}));
        connect(wp4.power, WP4_W) annotation(
          Line(points = {{8, -72}, {160, -72}, {160, -40}, {198, -40}, {198, -40}, {204, -40}}, color = {0, 0, 127}));
        connect(valve1.valve_rate, VALVE1_RATE) annotation(
          Line(points = {{-17, -86}, {168, -86}, {168, -60}, {204, -60}}, color = {0, 0, 127}));
        connect(valve2.valve_rate, VALVE2_RATE) annotation(
          Line(points = {{-44, -100}, {172, -100}, {172, -80}, {204, -80}, {204, -80}}, color = {0, 0, 127}));
        connect(valve3.valve_rate, VALVE3_RATE) annotation(
          Line(points = {{-67, -120}, {180, -120}, {180, -100}, {204, -100}}, color = {0, 0, 127}));
        connect(valve4.valve_rate, VALVE4_RATE) annotation(
          Line(points = {{-92, -140}, {186, -140}, {186, -118}, {204, -118}, {204, -120}}, color = {0, 0, 127}));
        connect(cabin_temp, ac_control.cabin_temp) annotation(
          Line(points = {{-204, -192}, {-13, -192}}, color = {0, 0, 127}));
        connect(ac_control.y, AC_Q) annotation(
          Line(points = {{16, -194}, {178, -194}, {178, -180}, {204, -180}}, color = {0, 0, 127}));
        connect(ac_control.power, AC_W) annotation(
          Line(points = {{16, -202}, {96, -202}, {96, -218}, {202, -218}}, color = {0, 0, 127}));
        connect(ac_set_t, ac_control.ac_set_temp) annotation(
          Line(points = {{-204, -152}, {-54, -152}, {-54, -184}, {-14, -184}, {-14, -184}}, color = {0, 0, 127}));
        connect(ac_onoff, ac_control.AC_OnOff) annotation(
          Line(points = {{-204, 150}, {-174, 150}, {-174, -198}, {-14, -198}, {-14, -198}}, color = {255, 0, 255}));
        connect(bat_cool_t, valve1.switch_temp) annotation(
          Line(points = {{-204, -80}, {-74, -80}, {-74, -86}, {-40, -86}, {-40, -86}, {-38, -86}}, color = {0, 0, 127}));
        connect(bat_cool_t, valve3.switch_temp) annotation(
          Line(points = {{-204, -80}, {-116, -80}, {-116, -120}, {-88, -120}, {-88, -120}}, color = {0, 0, 127}));
        connect(zeroOrderHold.y, wp3.coolant_temp) annotation(
          Line(points = {{-48, -30}, {-14, -30}, {-14, -32}, {-12, -32}}, color = {0, 0, 127}));
        connect(coolanttemp, zeroOrderHold.u) annotation(
          Line(points = {{-202, 168}, {-100, 168}, {-100, -30}, {-72, -30}, {-72, -30}}, color = {0, 0, 127}));
        connect(zeroOrderHold2.y, valve4.switch_temp) annotation(
          Line(points = {{-124, -140}, {-116, -140}, {-116, -138}, {-112, -138}, {-112, -140}}, color = {0, 0, 127}));
        connect(zeroOrderHold1.y, valve2.switch_temp) annotation(
          Line(points = {{-86, -98}, {-64, -98}, {-64, -100}, {-64, -100}}, color = {0, 0, 127}));
        connect(coolanttemp, zeroOrderHold1.u) annotation(
          Line(points = {{-202, 168}, {-130, 168}, {-130, -100}, {-110, -100}, {-110, -98}}, color = {0, 0, 127}));
        connect(coolanttemp, zeroOrderHold2.u) annotation(
          Line(points = {{-202, 168}, {-162, 168}, {-162, -140}, {-146, -140}, {-146, -140}, {-148, -140}}, color = {0, 0, 127}));
        annotation(
          Icon(coordinateSystem(extent = {{-200, -300}, {200, 300}}, initialScale = 0.1), graphics = {Rectangle(origin = {2, -1}, extent = {{-200, 301}, {188, -289}}), Text(origin = {-1, 10}, extent = {{-107, 44}, {107, -44}}, textString = "%name")}),
          Diagram(coordinateSystem(extent = {{-200, -300}, {200, 300}})));
      end thermal_control;

      model thermal
        Modelica.Blocks.Interfaces.RealInput ENGTrq annotation(
          Placement(visible = true, transformation(origin = {-120, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.BooleanInput ACONOFF annotation(
          Placement(visible = true, transformation(origin = {-120, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGrev annotation(
          Placement(visible = true, transformation(origin = {-120, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput AC_SET_TEMP annotation(
          Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput LAUNCH_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VARIATOR_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Engine_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput MG_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput DCDC_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput LIBAT_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -160}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {-120, -200}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput AIR_TEMP annotation(
          Placement(visible = true, transformation(origin = {-120, -240}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -240}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput OIL_TEMP annotation(
          Placement(visible = true, transformation(origin = {308, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {112, -82}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.thermal_control thermal_cont annotation(
          Placement(visible = true, transformation(origin = {19, 125.5}, extent = {{-51, -76.5}, {51, 76.5}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.thermal_system_whole thermal_plant(CABIN_C = 5000, CASE_C = 30000, CASE_ENGINE_R = 0.01, CHARGEAIRCOOLER_C = 10, ENGINE_C = 5000, LAUNCH_C = 5000, MG_C = 1000, OIL_C = 10000, OIL_CASE_R = 0.01, OIL_VAR_R = 0.1, RADIATOR_C = 10, VARIATOR_C = 15000) annotation(
          Placement(visible = true, transformation(origin = {179.333, 94}, extent = {{-33.3333, -100}, {33.3333, 100}}, rotation = 0)));
      equation
        connect(thermal_plant.PTC_Q, thermal_cont.PTC_Q) annotation(
          Line(points = {{143, 194}, {70, 194}}, color = {0, 0, 127}));
        connect(thermal_cont.CHARGER_Q, thermal_plant.CHARGER_Q) annotation(
          Line(points = {{70, 184}, {142, 184}}, color = {0, 0, 127}));
        connect(thermal_cont.CHARGE_AIRCOOLER_Q, thermal_plant.CHARGEAIR_Q) annotation(
          Line(points = {{70, 174}, {142, 174}}, color = {0, 0, 127}));
        connect(thermal_cont.RADFAN_Q, thermal_plant.RADFAN) annotation(
          Line(points = {{70, 164}, {142, 164}}, color = {0, 0, 127}));
        connect(thermal_cont.WP1_Q, thermal_plant.BTEMP_WP1) annotation(
          Line(points = {{70, 144}, {78, 144}, {78, 154}, {142, 154}, {142, 154}}, color = {0, 0, 127}));
        connect(thermal_cont.WP2_Q, thermal_plant.LTEMP_WP) annotation(
          Line(points = {{70, 134}, {80, 134}, {80, 144}, {142, 144}}, color = {0, 0, 127}));
        connect(thermal_cont.WP3_Q, thermal_plant.HTEMP_WP) annotation(
          Line(points = {{70, 122}, {82, 122}, {82, 134}, {142, 134}}, color = {0, 0, 127}));
        connect(thermal_cont.WP4_Q, thermal_plant.BTEMP_WP2) annotation(
          Line(points = {{70, 112}, {90, 112}, {90, 124}, {142, 124}}, color = {0, 0, 127}));
        connect(thermal_cont.VALVE1_RATE, thermal_plant.BTEMP_VALVE2) annotation(
          Line(points = {{70, 98}, {96, 98}, {96, 114}, {142, 114}}, color = {0, 0, 127}));
        connect(thermal_cont.VALVE2_RATE, thermal_plant.HTEMP_VALVE2) annotation(
          Line(points = {{70, 92}, {100, 92}, {100, 104}, {142, 104}}, color = {0, 0, 127}));
        connect(thermal_cont.VALVE3_RATE, thermal_plant.BTEMP_VALVE1) annotation(
          Line(points = {{70, 88}, {104, 88}, {104, 94}, {143, 94}}, color = {0, 0, 127}));
        connect(thermal_cont.VALVE4_RATE, thermal_plant.HTEMP_VALVE1) annotation(
          Line(points = {{70, 82}, {108, 82}, {108, 84}, {143, 84}}, color = {0, 0, 127}));
        connect(thermal_cont.AC_Q, thermal_plant.AC_Q) annotation(
          Line(points = {{70, 66}, {74, 66}, {74, 74}, {142, 74}}, color = {0, 0, 127}));
        connect(LAUNCH_Q, thermal_plant.LAUNCH_Q) annotation(
          Line(points = {{-120, 40}, {86, 40}, {86, 64}, {142, 64}}, color = {0, 0, 127}));
        connect(VARIATOR_Q, thermal_plant.VAR_Q) annotation(
          Line(points = {{-120, 0}, {90, 0}, {90, 58}, {142, 58}, {142, 54}}, color = {0, 0, 127}));
        connect(Engine_Q, thermal_plant.ENGINE_Q) annotation(
          Line(points = {{-120, -40}, {96, -40}, {96, 44}, {142, 44}}, color = {0, 0, 127}));
        connect(MG_Q, thermal_plant.MG_Q) annotation(
          Line(points = {{-120, -80}, {100, -80}, {100, 34}, {142, 34}}, color = {0, 0, 127}));
        connect(DCDC_Q, thermal_plant.DCDC_Q) annotation(
          Line(points = {{-120, -120}, {104, -120}, {104, 24}, {142, 24}}, color = {0, 0, 127}));
        connect(LIBAT_Q, thermal_plant.LIBAT_Q) annotation(
          Line(points = {{-120, -160}, {112, -160}, {112, 14}, {142, 14}}, color = {0, 0, 127}));
        connect(VSP, thermal_plant.VSP) annotation(
          Line(points = {{-120, -200}, {118, -200}, {118, 4}, {142, 4}}, color = {0, 0, 127}));
        connect(AIR_TEMP, thermal_plant.AIR_TEMP) annotation(
          Line(points = {{-120, -240}, {124, -240}, {124, -6}, {143, -6}}, color = {0, 0, 127}));
        connect(thermal_plant.PTC_T, thermal_cont.ptctemp) annotation(
          Line(points = {{214, 192}, {226, 192}, {226, 222}, {-42, 222}, {-42, 200}, {-36, 200}, {-36, 202}}, color = {0, 0, 127}));
        connect(thermal_plant.coolant_temp, thermal_cont.coolanttemp) annotation(
          Line(points = {{214, 175}, {232, 175}, {232, 230}, {-48, 230}, {-48, 190}, {-34, 190}}, color = {0, 0, 127}));
        connect(thermal_plant.DCDC_T, thermal_cont.dcdc_t) annotation(
          Line(points = {{214, 159}, {236, 159}, {236, 236}, {-52, 236}, {-52, 178}, {-36, 178}}, color = {0, 0, 127}));
        connect(thermal_plant.MG_T, thermal_cont.mg_t) annotation(
          Line(points = {{214, 143}, {240, 143}, {240, 240}, {-56, 240}, {-56, 162}, {-36, 162}, {-36, 164}}, color = {0, 0, 127}));
        connect(thermal_plant.LIBAT_T, thermal_cont.batt_t) annotation(
          Line(points = {{214, 126}, {244, 126}, {244, 244}, {-62, 244}, {-62, 148}, {-36, 148}, {-36, 146}}, color = {0, 0, 127}));
        connect(thermal_plant.batt_coolantemp, thermal_cont.bat_cool_t) annotation(
          Line(points = {{214, 107}, {248, 107}, {248, 248}, {-66, 248}, {-66, 132}, {-36, 132}}, color = {0, 0, 127}));
        connect(thermal_plant.cabin_T, thermal_cont.cabin_temp) annotation(
          Line(points = {{214, 84}, {250, 84}, {250, 252}, {-70, 252}, {-70, 118}, {-36, 118}}, color = {0, 0, 127}));
        connect(thermal_plant.oil_temp, OIL_TEMP) annotation(
          Line(points = {{214, -1}, {263, -1}, {263, 2}, {308, 2}}, color = {0, 0, 127}));
        connect(ACONOFF, thermal_cont.ac_onoff) annotation(
          Line(points = {{-120, 200}, {-74, 200}, {-74, 102}, {-34, 102}, {-34, 102}}, color = {255, 0, 255}));
        connect(ENGTrq, thermal_cont.ENGtrq) annotation(
          Line(points = {{-120, 160}, {-78, 160}, {-78, 88}, {-34, 88}, {-34, 88}}, color = {0, 0, 127}));
        connect(ENGrev, thermal_cont.EngREV) annotation(
          Line(points = {{-120, 120}, {-82, 120}, {-82, 72}, {-34, 72}, {-34, 72}}, color = {0, 0, 127}));
        connect(AC_SET_TEMP, thermal_cont.ac_set_t) annotation(
          Line(points = {{-120, 80}, {-92, 80}, {-92, 58}, {-34, 58}, {-34, 58}}, color = {0, 0, 127}));
        annotation(
          Diagram(coordinateSystem(extent = {{-100, -240}, {100, 200}})),
          Icon(coordinateSystem(extent = {{-100, -240}, {100, 200}}, initialScale = 0.1), graphics = {Rectangle(origin = {1, -21}, extent = {{-99, 219}, {99, -219}}), Text(origin = {-11, 1}, extent = {{-81, 189}, {107, -237}}, textString = "%name")}));
      end thermal;

      model hightempwater_t
        Modelica.Thermal.FluidHeatFlow.Components.Pipe engine(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-94, 26}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe ATcooler(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {76, 40}, extent = {{-10, 10}, {10, -10}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.water_pump_t water_pump1 annotation(
          Placement(visible = true, transformation(origin = {28, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe engine2(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-52, 46}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Thermal.FluidHeatFlow.Sensors.TemperatureSensor temperatureSensor1(medium = Modelica.Thermal.FluidHeatFlow.Media.Water()) annotation(
          Placement(visible = true, transformation(origin = {150, 116}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_t valve_A annotation(
          Placement(visible = true, transformation(origin = {-16, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe radiator(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 3.5, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-52, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_t valve_B annotation(
          Placement(visible = true, transformation(origin = {42, 88}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe PTC(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {126, 92}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe Hvac(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {154, 26}, extent = {{-10, 10}, {10, -10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput Valve_A annotation(
          Placement(visible = true, transformation(origin = {-168, -44}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Temp_Engine annotation(
          Placement(visible = true, transformation(origin = {194, 116}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Valve_B annotation(
          Placement(visible = true, transformation(origin = {-168, -84}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput pump_m3ps annotation(
          Placement(visible = true, transformation(origin = {-188, 72}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a eng1_w annotation(
          Placement(visible = true, transformation(origin = {-202, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-202, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a ptc_w annotation(
          Placement(visible = true, transformation(origin = {112, 196}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {112, 196}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a hvac_w annotation(
          Placement(visible = true, transformation(origin = {198, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {198, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a atcooler_w annotation(
          Placement(visible = true, transformation(origin = {-32, 198}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-32, 198}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a radiatorh_w annotation(
          Placement(visible = true, transformation(origin = {198, -122}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {198, -122}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a eng2_w annotation(
          Placement(visible = true, transformation(origin = {-204, 154}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-204, 154}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {-60, 88}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe1(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {14, 88}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe2(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {64, 0}, extent = {{10, 10}, {-10, -10}}, rotation = 0)));
      equation
        connect(temperatureSensor1.flowPort, engine.flowPort_b) annotation(
          Line(points = {{140, 116}, {-94, 116}, {-94, 36}}, color = {255, 0, 0}));
        connect(valve_B.flowPort_b, ATcooler.flowPort_a) annotation(
          Line(points = {{52, 84}, {76, 84}, {76, 50}}, color = {255, 0, 0}));
        connect(valve_B.PORT_OUT, PTC.flowPort_a) annotation(
          Line(points = {{52, 92}, {116, 92}}, color = {255, 0, 0}));
        connect(engine2.flowPort_b, radiator.flowPort_b) annotation(
          Line(points = {{-52, 36}, {-52, 4}}, color = {255, 0, 0}));
        connect(valve_A.PORT_OUT, engine2.flowPort_a) annotation(
          Line(points = {{-20, 32}, {-20, 80}, {-52, 80}, {-52, 56}}, color = {255, 0, 0}));
        connect(PTC.flowPort_b, Hvac.flowPort_a) annotation(
          Line(points = {{136, 92}, {154, 92}, {154, 36}}, color = {255, 0, 0}));
        connect(water_pump1.flowPort_b, valve_A.PORT_IN) annotation(
          Line(points = {{18, 0}, {-16, 0}, {-16, 12}}, color = {255, 0, 0}));
        connect(Valve_A, valve_A.u) annotation(
          Line(points = {{-168, -44}, {-24, -44}, {-24, 10}}, color = {0, 0, 127}));
        connect(temperatureSensor1.y, Temp_Engine) annotation(
          Line(points = {{161, 116}, {194, 116}}, color = {0, 0, 127}));
        connect(Valve_B, valve_B.u) annotation(
          Line(points = {{-168, -84}, {0, -84}, {0, 96}, {30, 96}}, color = {0, 0, 127}));
        connect(radiator.flowPort_a, engine.flowPort_a) annotation(
          Line(points = {{-52, -16}, {-52, -30}, {-94, -30}, {-94, 16}}, color = {255, 0, 0}));
        connect(pump_m3ps, water_pump1.pump_m3ps) annotation(
          Line(points = {{-188, 72}, {50, 72}, {50, 6}, {40, 6}}, color = {0, 0, 127}));
        connect(eng1_w, engine.heatPort) annotation(
          Line(points = {{-202, 26}, {-104, 26}, {-104, 26}, {-104, 26}}, color = {191, 0, 0}));
        connect(ptc_w, PTC.heatPort) annotation(
          Line(points = {{112, 196}, {126, 196}, {126, 102}, {126, 102}}, color = {191, 0, 0}));
        connect(Hvac.heatPort, hvac_w) annotation(
          Line(points = {{164, 26}, {198, 26}, {198, 28}, {198, 28}}, color = {191, 0, 0}));
        connect(atcooler_w, ATcooler.heatPort) annotation(
          Line(points = {{-32, 198}, {-34, 198}, {-34, 148}, {104, 148}, {104, 40}, {86, 40}, {86, 40}}, color = {191, 0, 0}));
        connect(radiator.heatPort, radiatorh_w) annotation(
          Line(points = {{-42, -6}, {10, -6}, {10, -122}, {198, -122}, {198, -122}}, color = {191, 0, 0}));
        connect(eng2_w, engine2.heatPort) annotation(
          Line(points = {{-204, 154}, {-112, 154}, {-112, 46}, {-62, 46}, {-62, 46}}, color = {191, 0, 0}));
        connect(pipe.flowPort_a, engine.flowPort_b) annotation(
          Line(points = {{-70, 88}, {-94, 88}, {-94, 36}, {-94, 36}}, color = {255, 0, 0}));
        connect(valve_A.flowPort_b, pipe1.flowPort_a) annotation(
          Line(points = {{-12, 32}, {-12, 32}, {-12, 88}, {4, 88}, {4, 88}}, color = {255, 0, 0}));
        connect(pipe.flowPort_b, pipe1.flowPort_a) annotation(
          Line(points = {{-50, 88}, {4, 88}, {4, 88}, {4, 88}}, color = {255, 0, 0}));
        connect(pipe1.flowPort_b, valve_B.PORT_IN) annotation(
          Line(points = {{24, 88}, {32, 88}, {32, 88}, {32, 88}}, color = {255, 0, 0}));
        connect(pipe2.flowPort_a, ATcooler.flowPort_b) annotation(
          Line(points = {{74, 0}, {76, 0}, {76, 30}}, color = {255, 0, 0}));
        connect(pipe2.flowPort_a, Hvac.flowPort_b) annotation(
          Line(points = {{74, 0}, {154, 0}, {154, 16}}, color = {255, 0, 0}));
        connect(pipe2.flowPort_b, water_pump1.flowPort_a) annotation(
          Line(points = {{54, 0}, {38, 0}}, color = {255, 0, 0}));
        annotation(
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}}, preserveAspectRatio = false)),
          experiment(StartTime = 0, StopTime = 200, Tolerance = 1e-6, Interval = 0.1),
          Icon(coordinateSystem(extent = {{-100, -150}, {100, 150}}, preserveAspectRatio = false)));
      end hightempwater_t;

      model lowtempwater_t
        Modelica.Thermal.FluidHeatFlow.Components.Pipe chargeaipipe(T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1e3, dpNominal(displayUnit = "Pa") = 2e3, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-96, 54}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.water_pump_t water_pump1 annotation(
          Placement(visible = true, transformation(origin = {30, -32}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe turbopipe(T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1e3, dpNominal(displayUnit = "Pa") = 2e3, h_g = 0, m = 0.5, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-44, 92}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe lowradiatorpipe(T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1e3, dpNominal(displayUnit = "Pa") = 2e3, h_g = 0, m = 2, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {140, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe mgpipe(T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1e3, dpNominal(displayUnit = "Pa") = 2e3, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {4, 132}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput lowpump_m3ps annotation(
          Placement(visible = true, transformation(origin = {-196, -102}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a chargeair_w annotation(
          Placement(visible = true, transformation(origin = {-200, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-200, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a mg_w annotation(
          Placement(visible = true, transformation(origin = {6, 200}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {6, 200}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a lowrad_w annotation(
          Placement(visible = true, transformation(origin = {198, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {198, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a turbo_w annotation(
          Placement(visible = true, transformation(origin = {-204, 154}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-204, 154}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_t branch_t annotation(
          Placement(visible = true, transformation(origin = {-64, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe1(T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1e3, dpNominal(displayUnit = "Pa") = 2e3, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {-26, -32}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      equation
        connect(chargeair_w, chargeaipipe.heatPort) annotation(
          Line(points = {{-200, 54}, {-106, 54}}, color = {191, 0, 0}));
        connect(mg_w, mgpipe.heatPort) annotation(
          Line(points = {{6, 200}, {4, 200}, {4, 142}}, color = {191, 0, 0}));
        connect(turbo_w, turbopipe.heatPort) annotation(
          Line(points = {{-204, 154}, {-112, 154}, {-112, 92}, {-54, 92}}, color = {191, 0, 0}));
        connect(lowradiatorpipe.heatPort, lowrad_w) annotation(
          Line(points = {{150, 10}, {198, 10}, {198, 28}, {198, 28}}, color = {191, 0, 0}));
        connect(water_pump1.flowPort_a, lowradiatorpipe.flowPort_a) annotation(
          Line(points = {{40, -32}, {140, -32}, {140, 0}, {140, 0}}, color = {255, 0, 0}));
        connect(lowpump_m3ps, water_pump1.pump_m3ps) annotation(
          Line(points = {{-196, -102}, {52, -102}, {52, -26}, {42, -26}, {42, -26}}, color = {0, 0, 127}));
        connect(chargeaipipe.flowPort_a, branch_t.PORT_OUT) annotation(
          Line(points = {{-96, 44}, {-96, 32}, {-68, 32}, {-68, 16}}, color = {255, 0, 0}));
        connect(turbopipe.flowPort_b, branch_t.flowPort_b) annotation(
          Line(points = {{-44, 82}, {-44, 82}, {-44, 34}, {-60, 34}, {-60, 16}, {-60, 16}}, color = {255, 0, 0}));
        connect(chargeaipipe.flowPort_b, mgpipe.flowPort_a) annotation(
          Line(points = {{-96, 64}, {-96, 132}, {-6, 132}}, color = {255, 0, 0}));
        connect(mgpipe.flowPort_b, lowradiatorpipe.flowPort_b) annotation(
          Line(points = {{14, 132}, {140, 132}, {140, 20}, {140, 20}}, color = {255, 0, 0}));
        connect(turbopipe.flowPort_a, lowradiatorpipe.flowPort_b) annotation(
          Line(points = {{-44, 102}, {140, 102}, {140, 20}, {140, 20}}, color = {255, 0, 0}));
        connect(water_pump1.flowPort_b, pipe1.flowPort_b) annotation(
          Line(points = {{20, -32}, {-18, -32}, {-18, -32}, {-16, -32}}, color = {255, 0, 0}));
        connect(pipe1.flowPort_a, branch_t.PORT_IN) annotation(
          Line(points = {{-36, -32}, {-64, -32}, {-64, -4}, {-64, -4}}, color = {255, 0, 0}));
        annotation(
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}}, preserveAspectRatio = false)),
          experiment(StartTime = 0, StopTime = 200, Tolerance = 1e-6, Interval = 0.1),
          Icon(coordinateSystem(extent = {{-100, -150}, {100, 150}}, preserveAspectRatio = false)));
      end lowtempwater_t;

      model battemp_t
        Modelica.Thermal.FluidHeatFlow.Components.Pipe dcdcinvpipe(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 3, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-78, 98}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.water_pump_t water_pump1 annotation(
          Placement(visible = true, transformation(origin = {40, -78}, extent = {{10, -10}, {-10, 10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe chillerpipe(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.5, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {12, -98}, extent = {{-10, 10}, {10, -10}}, rotation = 180)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_t valve_A annotation(
          Placement(visible = true, transformation(origin = {-48, -76}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe libattpipe(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 5, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {-30, -98}, extent = {{-10, 10}, {10, -10}}, rotation = 180)));
        TRAMI_L3_HEV.Thermal.thermal_parts.valve_t valve_B annotation(
          Placement(visible = true, transformation(origin = {40, 118}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe bradpipe(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = true) annotation(
          Placement(visible = true, transformation(origin = {154, 26}, extent = {{-10, 10}, {10, -10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput BValve_A annotation(
          Placement(visible = true, transformation(origin = {-206, -64}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput BValve_B annotation(
          Placement(visible = true, transformation(origin = {-208, 126}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput bapump_m3ps annotation(
          Placement(visible = true, transformation(origin = {194, -18}, extent = {{-20, -20}, {20, 20}}, rotation = 180), iconTransformation(origin = {174, -28}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a libatt_w annotation(
          Placement(visible = true, transformation(origin = {-28, -202}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-28, -202}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a brad_w annotation(
          Placement(visible = true, transformation(origin = {198, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {198, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a chiller_w annotation(
          Placement(visible = true, transformation(origin = {14, -202}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {14, -202}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a dcdcinv_w annotation(
          Placement(visible = true, transformation(origin = {-204, 76}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-204, 76}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.water_pump_t water_pump_t annotation(
          Placement(visible = true, transformation(origin = {-78, 62}, extent = {{10, -10}, {-10, 10}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.branch_t branch_t annotation(
          Placement(visible = true, transformation(origin = {64, 2}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput bbpump_m3ps annotation(
          Placement(visible = true, transformation(origin = {-216, 12}, extent = {{20, -20}, {-20, 20}}, rotation = 180), iconTransformation(origin = {-122, 86}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe1(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {100, 2}, extent = {{10, 10}, {-10, -10}}, rotation = 0)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {-80, 30}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
        Modelica.Thermal.FluidHeatFlow.Components.Pipe pipe2(T(fixed = true), T0 = Tempinit, T0fixed = true, V_flowLaminar = 1e3, V_flowNominal = 2e3, dpLaminar(displayUnit = "Pa") = 1000, dpNominal(displayUnit = "Pa") = 2000, h_g = 0, m = 0.1, medium = Modelica.Thermal.FluidHeatFlow.Media.Water(), useHeatPort = false) annotation(
          Placement(visible = true, transformation(origin = {40, -42}, extent = {{10, -10}, {-10, 10}}, rotation = 90)));
      equation
        connect(bradpipe.heatPort, brad_w) annotation(
          Line(points = {{164, 26}, {198, 26}, {198, 28}, {198, 28}}, color = {191, 0, 0}));
        connect(dcdcinvpipe.flowPort_b, valve_B.PORT_IN) annotation(
          Line(points = {{-78, 108}, {-78, 118}, {30, 118}}, color = {255, 0, 0}));
        connect(valve_B.PORT_OUT, bradpipe.flowPort_a) annotation(
          Line(points = {{50, 122}, {154, 122}, {154, 36}}, color = {255, 0, 0}));
        connect(libattpipe.flowPort_a, chillerpipe.flowPort_b) annotation(
          Line(points = {{-20, -98}, {2, -98}}, color = {255, 0, 0}));
        connect(libattpipe.flowPort_b, valve_A.PORT_IN) annotation(
          Line(points = {{-40, -98}, {-48, -98}, {-48, -86}}, color = {255, 0, 0}));
        connect(water_pump1.flowPort_b, chillerpipe.flowPort_a) annotation(
          Line(points = {{40, -88}, {31, -88}, {31, -98}, {22, -98}}, color = {255, 0, 0}));
        connect(dcdcinvpipe.flowPort_a, water_pump_t.flowPort_b) annotation(
          Line(points = {{-78, 88}, {-78, 72}}, color = {255, 0, 0}));
        connect(chiller_w, chillerpipe.heatPort) annotation(
          Line(points = {{14, -202}, {14, -147}, {12, -147}, {12, -108}}, color = {191, 0, 0}));
        connect(dcdcinv_w, dcdcinvpipe.heatPort) annotation(
          Line(points = {{-204, 76}, {-146, 76}, {-146, 98}, {-88, 98}}, color = {191, 0, 0}));
        connect(water_pump1.pump_m3ps, bapump_m3ps) annotation(
          Line(points = {{34, -66}, {34, -16}, {194, -16}, {194, -18}}, color = {0, 0, 127}));
        connect(BValve_A, valve_A.u) annotation(
          Line(points = {{-206, -64}, {-132, -64}, {-132, -88}, {-56, -88}}, color = {0, 0, 127}));
        connect(BValve_B, valve_B.u) annotation(
          Line(points = {{-208, 126}, {28, 126}}, color = {0, 0, 127}));
        connect(bbpump_m3ps, water_pump_t.pump_m3ps) annotation(
          Line(points = {{-216, 12}, {-72, 12}, {-72, 50}}, color = {0, 0, 127}));
        connect(libattpipe.heatPort, libatt_w) annotation(
          Line(points = {{-30, -108}, {-30, -108}, {-30, -202}, {-28, -202}}, color = {191, 0, 0}));
        connect(pipe1.flowPort_a, bradpipe.flowPort_b) annotation(
          Line(points = {{110, 2}, {154, 2}, {154, 16}, {154, 16}}, color = {255, 0, 0}));
        connect(valve_B.flowPort_b, pipe1.flowPort_a) annotation(
          Line(points = {{50, 114}, {126, 114}, {126, 2}, {110, 2}}, color = {255, 0, 0}));
        connect(pipe1.flowPort_b, branch_t.PORT_IN) annotation(
          Line(points = {{90, 2}, {74, 2}, {74, 2}, {74, 2}}, color = {255, 0, 0}));
        connect(branch_t.PORT_OUT, pipe.flowPort_a) annotation(
          Line(points = {{54, 6}, {-80, 6}, {-80, 20}, {-80, 20}}, color = {255, 0, 0}));
        connect(valve_A.PORT_OUT, pipe.flowPort_a) annotation(
          Line(points = {{-52, -66}, {-52, -66}, {-52, -38}, {-80, -38}, {-80, 20}, {-80, 20}}, color = {255, 0, 0}));
        connect(pipe.flowPort_b, water_pump_t.flowPort_a) annotation(
          Line(points = {{-80, 40}, {-80, 40}, {-80, 52}, {-78, 52}, {-78, 52}}, color = {255, 0, 0}));
        connect(valve_A.flowPort_b, pipe2.flowPort_a) annotation(
          Line(points = {{-44, -66}, {-44, -66}, {-44, -24}, {40, -24}, {40, -32}, {40, -32}}, color = {255, 0, 0}));
        connect(branch_t.flowPort_b, pipe2.flowPort_a) annotation(
          Line(points = {{54, -2}, {40, -2}, {40, -32}, {40, -32}}, color = {255, 0, 0}));
        connect(pipe2.flowPort_b, water_pump1.flowPort_a) annotation(
          Line(points = {{40, -52}, {40, -52}, {40, -68}, {40, -68}}, color = {255, 0, 0}));
        annotation(
          Diagram(coordinateSystem(extent = {{-200, -200}, {200, 200}}, preserveAspectRatio = false)),
          experiment(StartTime = 0, StopTime = 200, Tolerance = 1e-6, Interval = 0.1),
          Icon(coordinateSystem(extent = {{-100, -150}, {100, 150}}, preserveAspectRatio = false)));
      end battemp_t;

      model TRAMI_thermal
        parameter Modelica.SIunits.HeatCapacity TRAMI_LAUNCH_C = 4300 "LAUNCH heat capacity";
        parameter Modelica.SIunits.HeatCapacity TRAMI_VARIATOR_C = 17000 "VARIATOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity TRAMI_CASE_C = 29000 "CASE heat capacity";
        parameter Modelica.SIunits.HeatCapacity TRAMI_MG_C = 2000 "MG heat capacity";
        parameter Modelica.SIunits.HeatCapacity TRAMI_OIL_C = 9400 "OIL heat capacity";
        parameter Modelica.SIunits.ThermalResistance TRAMI_LAUNCH_ENGINE_R = 100 "LAUNCH thermal resistance for ENGINE";
        parameter Modelica.SIunits.ThermalResistance TRAMI_CASE_ENGINE_R = 0.015 "CASE thermal resistance for ENGINE";
        parameter Modelica.SIunits.ThermalResistance TRAMI_CASE_LAUNCH_R = 100 "CASE thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance TRAMI_CASE_VAR_R = 100 "CASE thermal resistance for VARIATOR";
        parameter Modelica.SIunits.ThermalResistance TRAMI_CASE_MG_R = 100 "CASE thermal resistance for MG";
        parameter Modelica.SIunits.ThermalResistance TRAMI_CASE_AIR_R = 0.1 "CASE thermal resistance for AIR";
        parameter Modelica.SIunits.ThermalResistance TRAMI_OIL_LAUNCH_R = 0.0001 "OIL thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance TRAMI_OIL_VAR_R = 0.073 "OIL thermal resistance for VARIATOR";
        parameter Modelica.SIunits.ThermalResistance TRAMI_OIL_CASE_R = 0.0044 "OIL thermal resistance for CASE";
        parameter Modelica.SIunits.ThermalResistance TRAMI_OIL_MG_R = 0.05 "OIL thermal resistance for MG";
        parameter Modelica.SIunits.ThermalResistance TRAMI_MG_WATER_R = 0.01 "MG thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance TRAMI_ENGINECASE_R = 100000 "enginecase thermal resistance for CVT";
        parameter Modelica.SIunits.ThermalResistance TRAMI_ENGINESHAFT_LAUNCH_R = 100000 "engineshaft thermal resistance for CVT";
        Modelica.Blocks.Interfaces.RealInput AIR_TEMP annotation(
          Placement(visible = true, transformation(origin = {95, 355}, extent = {{9, -9}, {-9, 9}}, rotation = 90), iconTransformation(origin = {-219, -179}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.MG_comp mG_comp(c = TRAMI_MG_C) annotation(
          Placement(visible = true, transformation(origin = {140, 130}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.case_comp case_comp(case_C = TRAMI_CASE_C, case_air_R = TRAMI_CASE_AIR_R, case_engine_R = TRAMI_CASE_ENGINE_R, case_enginecase_R = TRAMI_ENGINECASE_R, case_launch_R = TRAMI_CASE_LAUNCH_R, case_mg_R = TRAMI_CASE_MG_R, case_var_R = TRAMI_CASE_VAR_R, oil_case_R = TRAMI_OIL_CASE_R) annotation(
          Placement(visible = true, transformation(origin = {51, 233}, extent = {{-37, -37}, {37, 37}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.launch_comp launch_comp(engineshaft_launch_R = TRAMI_ENGINESHAFT_LAUNCH_R, launch_C = TRAMI_LAUNCH_C, launch_engine_R = TRAMI_LAUNCH_ENGINE_R) annotation(
          Placement(visible = true, transformation(origin = {-147, 249}, extent = {{-35, -35}, {35, 35}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.oil_comp oil_comp(oil_C = TRAMI_OIL_C, oil_launch_R = TRAMI_OIL_LAUNCH_R, oil_mg_R = TRAMI_OIL_MG_R, oil_variator_R = TRAMI_OIL_VAR_R) annotation(
          Placement(visible = true, transformation(origin = {10.385, -48.0043}, extent = {{-54.0043, -48.0038}, {54.0043, 60.0048}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealInput LAUNCH_Q annotation(
          Placement(visible = true, transformation(origin = {-174, 408}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-224, 118}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VAR_Q annotation(
          Placement(visible = true, transformation(origin = {-46, 334}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput MG_Q annotation(
          Placement(visible = true, transformation(origin = {172, 276}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput MG_T annotation(
          Placement(visible = true, transformation(origin = {150, 296}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.vat_comp vat_comp(variator_C = TRAMI_VARIATOR_C) annotation(
          Placement(visible = true, transformation(origin = {-34, 238}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput oil_temp annotation(
          Placement(visible = true, transformation(origin = {52, -140}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {211, -107}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_Lowtempthermal_Q annotation(
          Placement(visible = true, transformation(origin = {130, 356}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-218, 342}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_Lowtempthermal_T annotation(
          Placement(visible = true, transformation(origin = {116, 380}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {208, -542}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engine_T annotation(
          Placement(visible = true, transformation(origin = {82, 454}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-216, 556}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_enginecase_T annotation(
          Placement(visible = true, transformation(origin = {54, 482}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, -300}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engineshaft_T annotation(
          Placement(visible = true, transformation(origin = {-144, 556}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-218, -380}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_transcase_T annotation(
          Placement(visible = true, transformation(origin = {26, 528}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, -484}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_engine_launch_T annotation(
          Placement(visible = true, transformation(origin = {-124, 490}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, 440}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oilcooler_Q annotation(
          Placement(visible = true, transformation(origin = {-36, -188}, extent = {{-20, -20}, {20, 20}}, rotation = 90), iconTransformation(origin = {-222, 642}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oilcooler_T annotation(
          Placement(visible = true, transformation(origin = {-20, -154}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {208, -328}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_engine_Q annotation(
          Placement(visible = true, transformation(origin = {70, 420}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {208, -402}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_enginecase_Q annotation(
          Placement(visible = true, transformation(origin = {42, 444}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 318}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_engineshaft_Q annotation(
          Placement(visible = true, transformation(origin = {-152, 494}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {206, 234}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_transcase_Q annotation(
          Placement(visible = true, transformation(origin = {20, 430}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {204, 380}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_engine_launch_Q annotation(
          Placement(visible = true, transformation(origin = {-130, 456}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {206, -470}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput launch_T annotation(
          Placement(visible = true, transformation(origin = {-186, 480}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 552}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput variator_T annotation(
          Placement(visible = true, transformation(origin = {-62, 416}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 464}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {-12, 488}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, -582}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_hyd_Q annotation(
          Placement(visible = true, transformation(origin = {14, -212}, extent = {{-20, -20}, {20, 20}}, rotation = 90), iconTransformation(origin = {-224, 222}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      equation
        connect(launch_comp.from_launchloss_Q, LAUNCH_Q) annotation(
          Line(points = {{-164.5, 288}, {-164.5, 300}, {-174, 300}, {-174, 408}}, color = {0, 0, 127}));
        connect(MG_Q, mG_comp.from_mg_loss_Q) annotation(
          Line(points = {{172, 276}, {172, 214}, {156, 214}, {156, 152}}, color = {0, 0, 127}));
        connect(MG_T, mG_comp.to_mg_loss_T) annotation(
          Line(points = {{150, 296}, {151, 296}, {151, 151}}, color = {0, 0, 127}));
        connect(VAR_Q, vat_comp.from_var_loss_Q) annotation(
          Line(points = {{-46, 334}, {-45, 334}, {-45, 260}, {-46, 260}}, color = {0, 0, 127}));
        connect(oil_temp, oil_comp.oil_temp) annotation(
          Line(points = {{52, -140}, {52, -105}}, color = {0, 0, 127}));
        connect(case_comp.from_airtemp, AIR_TEMP) annotation(
          Line(points = {{88, 274}, {88, 314.5}, {95, 314.5}, {95, 355}}, color = {0, 0, 127}));
        connect(oil_comp.from_case_Q, case_comp.to_oil_Q) annotation(
          Line(points = {{7, 11}, {7, 159}, {47, 159}, {47, 194}}, color = {0, 0, 127}));
        connect(oil_comp.to_MG_Q, mG_comp.from_oil_Q) annotation(
          Line(points = {{52, 9}, {52, 50}, {160, 50}, {160, 108}}, color = {0, 0, 127}));
        connect(oil_comp.to_launch_Q, launch_comp.from_oil_Q) annotation(
          Line(points = {{-41, 9}, {-41, 104}, {-168, 104}, {-168, 210.5}}, color = {0, 0, 127}));
        connect(case_comp.to_MG_Q, mG_comp.from_case_Q) annotation(
          Line(points = {{60, 194}, {60, 78}, {130, 78}, {130, 108}}, color = {0, 0, 127}));
        connect(oil_comp.to_ratio_Q, vat_comp.from_oil_Q) annotation(
          Line(points = {{-10, 9}, {-10, 131}, {-48, 131}, {-48, 216}}, color = {0, 0, 127}));
        connect(mG_comp.to_oil_Tmg, oil_comp.from_mG_T) annotation(
          Line(points = {{155, 109}, {155, 56}, {40, 56}, {40, 11}}, color = {0, 0, 127}));
        connect(mG_comp.to_case_Tmg, case_comp.from_mG_T) annotation(
          Line(points = {{125, 109}, {125.5, 109}, {125.5, 89}, {66, 89}, {66, 192}}, color = {0, 0, 127}));
        connect(vat_comp.to_oil_Tvat, oil_comp.from_ratio_T) annotation(
          Line(points = {{-53, 217}, {-52, 217}, {-52, 123}, {-21, 123}, {-21, 11}, {-22, 11}}, color = {0, 0, 127}));
        connect(oil_comp.from_launch_T, launch_comp.to_oil_Tlaunch) annotation(
          Line(points = {{-53, 11}, {-53, 91.5}, {-180, 91.5}, {-180, 212}}, color = {0, 0, 127}));
        connect(oil_comp.to_case_Toil, case_comp.from_oil_T) annotation(
          Line(points = {{18, 9}, {18, 126}, {53, 126}, {53, 192}}, color = {0, 0, 127}));
        connect(case_comp.to_launch_Q, launch_comp.from_case_Q) annotation(
          Line(points = {{35, 194}, {35, 182}, {-112, 182}, {-112, 210.5}}, color = {0, 0, 127}));
        connect(launch_comp.to_case_Tlaunch, case_comp.from_launch_T) annotation(
          Line(points = {{-124, 212}, {-124, 179}, {41, 179}, {41, 192}}, color = {0, 0, 127}));
        connect(case_comp.to_ratio_Q, vat_comp.from_case_Q) annotation(
          Line(points = {{22, 194}, {22, 188}, {-16, 188}, {-16, 216}}, color = {0, 0, 127}));
        connect(vat_comp.to_case_Tvat, case_comp.from_ratio_T) annotation(
          Line(points = {{-21, 217}, {-21, 184}, {28, 184}, {28, 192}}, color = {0, 0, 127}));
        connect(from_Lowtempthermal_Q, mG_comp.from_lowtempthermal_Q) annotation(
          Line(points = {{130, 356}, {130, 356}, {130, 230}, {134, 230}, {134, 152}, {132, 152}}, color = {0, 0, 127}));
        connect(to_Lowtempthermal_T, mG_comp.to_lowtempthermal_T) annotation(
          Line(points = {{116, 380}, {116, 202}, {126, 202}, {126, 152}}, color = {0, 0, 127}));
        connect(from_engine_T, case_comp.from_engine_T) annotation(
          Line(points = {{82, 454}, {82, 357}, {75, 357}, {75, 274}}, color = {0, 0, 127}));
        connect(case_comp.from_enginecase_T, from_enginecase_T) annotation(
          Line(points = {{53, 274}, {53, 378}, {54, 378}, {54, 482}}, color = {0, 0, 127}));
        connect(from_transcase_T, case_comp.from_transcase_T) annotation(
          Line(points = {{26, 528}, {26, 401}, {35, 401}, {35, 274}}, color = {0, 0, 127}));
        connect(from_engine_launch_T, launch_comp.from_engine_T) annotation(
          Line(points = {{-124, 490}, {-124, 322}, {-122.5, 322}, {-122.5, 287.5}}, color = {0, 0, 127}));
        connect(from_engineshaft_T, launch_comp.from_engineshaft_T) annotation(
          Line(points = {{-144, 556}, {-144, 418}, {-143.5, 418}, {-143.5, 287.5}}, color = {0, 0, 127}));
        connect(oil_comp.from_oilcooler_Q, from_oilcooler_Q) annotation(
          Line(points = {{-36, -108}, {-36, -188}}, color = {0, 0, 127}));
        connect(oil_comp.to_oilcooler_Toil, to_oilcooler_T) annotation(
          Line(points = {{-20, -106}, {-20, -154}}, color = {0, 0, 127}));
        connect(to_engine_Q, case_comp.to_engine_Q) annotation(
          Line(points = {{70, 420}, {70, 335}, {69, 335}, {69, 271}}, color = {0, 0, 127}));
        connect(to_enginecase_Q, case_comp.to_enginecase_Q) annotation(
          Line(points = {{42, 444}, {42, 360}, {44, 360}, {44, 272}}, color = {0, 0, 127}));
        connect(to_transcase_Q, case_comp.to_transcase_Q) annotation(
          Line(points = {{20, 430}, {20, 351}, {29, 351}, {29, 272}}, color = {0, 0, 127}));
        connect(to_engine_launch_Q, launch_comp.to_engine_Q) annotation(
          Line(points = {{-130, 456}, {-130, 371}, {-132, 371}, {-132, 286}}, color = {0, 0, 127}));
        connect(to_engineshaft_Q, launch_comp.to_enigineshaft_Q) annotation(
          Line(points = {{-152, 494}, {-152, 286}}, color = {0, 0, 127}));
        connect(launch_T, launch_comp.to_launchloss_T) annotation(
          Line(points = {{-186, 480}, {-186, 480}, {-186, 294}, {-170, 294}, {-170, 286}, {-172, 286}}, color = {0, 0, 127}));
        connect(variator_T, vat_comp.to_var_loss_T) annotation(
          Line(points = {{-62, 416}, {-62, 416}, {-62, 296}, {-52, 296}, {-52, 258}, {-50, 258}}, color = {0, 0, 127}));
        connect(VSP, case_comp.VSP) annotation(
          Line(points = {{-12, 488}, {-12, 488}, {-12, 350}, {14, 350}, {14, 274}, {14, 274}}, color = {0, 0, 127}));
        connect(from_hyd_Q, oil_comp.from_hyd_Q) annotation(
          Line(points = {{14, -212}, {14, -108}}, color = {0, 0, 127}));
      protected
        annotation(
          Icon(coordinateSystem(extent = {{-200, -650}, {200, 650}}), graphics = {Text(origin = {-118, 974}, extent = {{-22, -784}, {264, -1128}}, textString = "%name"), Rectangle(origin = {-2, -3}, extent = {{-198, 647}, {196, -631}})}),
          Diagram(coordinateSystem(extent = {{-200, -650}, {200, 650}})));
      end TRAMI_thermal;

      model thermal_meti
        parameter Modelica.SIunits.HeatCapacity METI_ENGINE_C = 6000 "Engine heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_MG_C = 2000 "MG heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_ATCOOLER_C = 100 "ATCOOLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_PTC_C = 10 "PTC heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_HVAC_C = 1 "HVAC heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_CABIN_C = 6000 "CABIN heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_GLASS_C = 30000 "GLASS heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_DOOR_C = 50000 "DOOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_RADIATOR_C = 15 "RADIATOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_CHARGEAIRCOOLER_C = 15 "CHARGE AIR COOLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_TURBO_CHARGER_C = 10 "TURBO CHARGER heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_LOW_RADIATOR_C = 1.0 "LOW RADIATOR  heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_condenser_C = 1.0 "condenser heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_EL_AC_C = 5.0 "e-AC heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_CHILLER_C = 5.0 "CHILLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_LIBATT_C = 1000 "Li batt heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_DCDC_C = 500 "DCDC heat capacity";
        parameter Modelica.SIunits.HeatCapacity METI_BAT_RADIATOR_C = 1.0 "BAT RADIATOR  heat capacity";
        parameter Modelica.SIunits.ThermalResistance METI_AT_COOLER_OIL_R = 0.001 "ATCOOLER thermal resistance for OIL";
        parameter Modelica.SIunits.ThermalResistance METI_ENGINE1_WATER_R = 0.01 "ENGINE1 thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance METI_ENGINE2_WATER_R = 0.01 "ENGINE2 thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance METI_ATCOOLER_WATER_R = 0.01 "AT COOLER thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance METI_PTC_WATER_R = 0.01 "PTC thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance METI_HVAC_WATER_R = 0.01 "HVAC thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance METI_HVAC_CABIN_R = 0.1 "HVAC thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance METI_GLASS_CABIN_R = 10 "GLASS thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance METI_DOOR_CABIN_R = 10 "DOOR thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance METI_LOW_RADIATOR_R = 0.01 "low thermal resistance for rad";
        parameter Modelica.SIunits.ThermalResistance METI_BAT_RADIATOR_R = 0.01 "bat thermal resistance for rad";
        parameter Modelica.SIunits.ThermalResistance METI_MG_WATER_R = 0.01 "MG thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance METI_CHARGEAIRCOOLER_WATER_R = 0.01 "CHARGEAIRCOOLER thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance METI_TURBO_WATER_R = 0.01 "TURBO thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance METI_condenser_HVAC_R = 0.1 "condenser thermal resistance for HVAC";
        parameter Modelica.SIunits.ThermalResistance METI_condenser_HIGHRAD_R = 0.01 "KONDENDOR thermal resistance for HIGHRAD";
        parameter Modelica.SIunits.ThermalResistance METI_AC_HVAC_R = 0.1 "AC thermal resistance for HVAC";
        parameter Modelica.SIunits.ThermalResistance METI_AC_CHILLER_R = 0.1 "AC thermal resistance for CHILLER";
        parameter Modelica.SIunits.ThermalResistance METI_CHILLER_condenser_R = 0.1 "CHILLER thermal resistance for condenser";
        parameter Modelica.SIunits.ThermalResistance METI_CHILLER_WATER_R = 0.01 "CHIller thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance METI_LIBATT_WATER_R = 0.01 "LIBATT thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance METI_DCDC_WATER_R = 0.01 "DCDC thermal resistance for water";
        TRAMI_L3_HEV.Thermal.thermal_circuits.batttemp4 batttemp_thermal(dcdc_C = METI_DCDC_C, dcdc_water_R = METI_DCDC_WATER_R, libatt_C = METI_LIBATT_C, libatt_water_R = METI_LIBATT_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-43, -249}, extent = {{-31, -31}, {31, 31}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.lowtemp5 lowtemp_thermal(chargeaircooler_C = METI_CHARGEAIRCOOLER_C, chargeaircooler_water_R = METI_CHARGEAIRCOOLER_WATER_R, motorgenerator_C = METI_MG_C, motorgenerator_water_R = METI_MG_WATER_R, turbo_charger_C = METI_TURBO_CHARGER_C, turbo_charger_water_R = METI_TURBO_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-43, -75}, extent = {{-37, -37}, {37, 37}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput AIR_TEMP annotation(
          Placement(visible = true, transformation(origin = {245, 359}, extent = {{9, -9}, {-9, 9}}, rotation = 0), iconTransformation(origin = {-217, -423}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.hightemp4 hightemp4_1(engine1_C = METI_ENGINE_C * 0.5, engine1_water_R = METI_ENGINE1_WATER_R, engine2_C = METI_ENGINE_C * 0.5, engine2_water_R = METI_ENGINE2_WATER_R, ptc_C = METI_PTC_C, ptc_water_R = METI_PTC_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-40, 70}, extent = {{-44, -44}, {44, 44}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.hvac hvac(hvac_C = METI_HVAC_C, hvac_water_R = METI_HVAC_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {176, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.cabin cabin_1(cabin_C = METI_CABIN_C, hvac_cabin_R = METI_HVAC_CABIN_R) annotation(
          Placement(visible = true, transformation(origin = {175, 59}, extent = {{-17, -17}, {17, 17}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.thermal_heat_block door(c = METI_DOOR_C, r = METI_DOOR_CABIN_R) annotation(
          Placement(visible = true, transformation(origin = {176, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.thermal_heat_block glass(c = METI_GLASS_C, r = METI_GLASS_CABIN_R) annotation(
          Placement(visible = true, transformation(origin = {176, 94}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.condenser_comp condenser_comp(chiller_condenser_R = METI_CHILLER_condenser_R, condenser_C = METI_condenser_C, condenser_highrad_R = METI_condenser_HIGHRAD_R, condenser_hvac_R = METI_condenser_HVAC_R) annotation(
          Placement(visible = true, transformation(origin = {176, -104}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.chiller_comp chiller_comp(ac_chiller_R = METI_AC_CHILLER_R, chiller_C = METI_CHILLER_C, chiller_water_R = METI_CHILLER_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {176, -156}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.el_ac_comp el_ac_comp(ac_hvac_R = METI_AC_HVAC_R, el_ac_C = METI_EL_AC_C) annotation(
          Placement(visible = true, transformation(origin = {176, -204}, extent = {{-22, -22}, {22, 22}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.engine_comp engine_comp(c = METI_ENGINE_C, engine1_water_R = METI_ENGINE1_WATER_R, engine2_water_R = METI_ENGINE2_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-134, 330}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        TRAMI_L3_HEV.Thermal.thermal_parts.at_cooler_comp at_cooler_comp(at_cooler_C = METI_ATCOOLER_C, at_cooler_oil_R = METI_AT_COOLER_OIL_R, at_cooler_water_R = METI_ATCOOLER_WATER_R) annotation(
          Placement(visible = true, transformation(origin = {-71, 495}, extent = {{-29, -29}, {29, 29}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput PTC_Q annotation(
          Placement(visible = true, transformation(origin = {-14, 220}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, 600}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PTC_T annotation(
          Placement(visible = true, transformation(origin = {-28, 186}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 586}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_VALVE1 annotation(
          Placement(visible = true, transformation(origin = {-102, 196}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_VALVE2 annotation(
          Placement(visible = true, transformation(origin = {-88, 166}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {201, -277}, extent = {{9, -9}, {-9, 9}}, rotation = 0), iconTransformation(origin = {-219, -365}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput RADFAN annotation(
          Placement(visible = true, transformation(origin = {201, -261}, extent = {{9, -9}, {-9, 9}}, rotation = 0), iconTransformation(origin = {-224, 418}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_WP annotation(
          Placement(visible = true, transformation(origin = {4, 180}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-222, 240}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_WP1 annotation(
          Placement(visible = true, transformation(origin = {-16, -330}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, 360}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput LIBAT_T annotation(
          Placement(visible = true, transformation(origin = {-50, -326}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {208, 190}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput LIBAT_Q annotation(
          Placement(visible = true, transformation(origin = {-60, -386}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-220, -304}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_VALVE1 annotation(
          Placement(visible = true, transformation(origin = {-98, -322}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-220, 0}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_WP2 annotation(
          Placement(visible = true, transformation(origin = {-130, -328}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, 180}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput DCDC_T annotation(
          Placement(visible = true, transformation(origin = {-150, -322}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {210, 388}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput DCDC_Q annotation(
          Placement(visible = true, transformation(origin = {-184, -322}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-220, -242}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_VALVE2 annotation(
          Placement(visible = true, transformation(origin = {-232, -320}, extent = {{20, -20}, {-20, 20}}, rotation = -90), iconTransformation(origin = {-222, 122}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput LTEMP_WP annotation(
          Placement(visible = true, transformation(origin = {-252, -174}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 298}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput CHARGEAIR_Q annotation(
          Placement(visible = true, transformation(origin = {-230, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 482}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGEAIR_T annotation(
          Placement(visible = true, transformation(origin = {-176, -96}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -330}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput CHARGER_Q annotation(
          Placement(visible = true, transformation(origin = {-228, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 542}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGER_T annotation(
          Placement(visible = true, transformation(origin = {-194, -64}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -196}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGINE_Q annotation(
          Placement(visible = true, transformation(origin = {-146, 392}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-220, -178}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput coolant_temp annotation(
          Placement(visible = true, transformation(origin = {-70, 244}, extent = {{-10, -10}, {10, 10}}, rotation = 90), iconTransformation(origin = {210, 484}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput batt_coolantemp annotation(
          Placement(visible = true, transformation(origin = {-210, -330}, extent = {{10, -10}, {-10, 10}}, rotation = 90), iconTransformation(origin = {210, 80}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput AC_Q annotation(
          Placement(visible = true, transformation(origin = {252, -204}, extent = {{20, -20}, {-20, 20}}, rotation = 0), iconTransformation(origin = {-222, -120}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput cabin_T annotation(
          Placement(visible = true, transformation(origin = {216, 62}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -62}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_parts.radiator_comp radiator_comp(bat_rad_R = METI_BAT_RADIATOR_R, bat_radiator_C = METI_BAT_RADIATOR_C, low_rad_R = METI_LOW_RADIATOR_R, low_radiator_C = METI_LOW_RADIATOR_C, radiator_C = METI_RADIATOR_C) annotation(
          Placement(visible = true, transformation(origin = {174, -54}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_oil_T annotation(
          Placement(visible = true, transformation(origin = {-206, 420}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-218, -480}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_mg_T annotation(
          Placement(visible = true, transformation(origin = {-208, 14}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -672}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_case_engine_Q annotation(
          Placement(visible = true, transformation(origin = {-210, 260}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -542}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput from_launch_Q annotation(
          Placement(visible = true, transformation(origin = {-212, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-224, -600}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_oil_Q annotation(
          Placement(visible = true, transformation(origin = {-208, 454}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {208, -448}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_mg_Q annotation(
          Placement(visible = true, transformation(origin = {-204, -12}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {214, -678}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_case_engine_T annotation(
          Placement(visible = true, transformation(origin = {-204, 292}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {210, -522}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput to_launch_T annotation(
          Placement(visible = true, transformation(origin = {-202, 234}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {216, -592}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(hightemp4_1.hvac_T, hvac.from_hightempthermal_T) annotation(
          Line(points = {{8, 105}, {108, 105}, {108, 10}, {154, 10}}, color = {0, 0, 127}));
        connect(hightemp4_1.hvac_Q, hvac.to_hightempthermal_Q) annotation(
          Line(points = {{8, 92}, {103, 92}, {103, 5}, {155, 5}}, color = {0, 0, 127}));
        connect(door.K_in, AIR_TEMP) annotation(
          Line(points = {{185, 126}, {226, 126}, {226, 359}, {245, 359}}, color = {0, 0, 127}));
        connect(glass.K_in, AIR_TEMP) annotation(
          Line(points = {{185, 100}, {226, 100}, {226, 359}, {245, 359}}, color = {0, 0, 127}));
        connect(door.K_out, cabin_1.from_door_T) annotation(
          Line(points = {{166, 113}, {143, 113}, {143, 64}, {156, 64}, {156, 65}}, color = {0, 0, 127}));
        connect(cabin_1.to_door_Q, door.Q_in) annotation(
          Line(points = {{157, 61}, {157, 60.375}, {137, 60.375}, {137, 125.75}, {165, 125.75}, {165, 125}}, color = {0, 0, 127}));
        connect(hvac.from_cabin_Q, cabin_1.to_hvac_Q) annotation(
          Line(points = {{154, 20}, {138, 20}, {138, 45}, {157, 45}}, color = {0, 0, 127}));
        connect(cabin_1.from_hvac_T, hvac.to_cabin_T) annotation(
          Line(points = {{156, 49}, {126, 49}, {126, 15}, {155, 15}}, color = {0, 0, 127}));
        connect(batttemp_thermal.highvoltage_rad_Q, condenser_comp.from_hig_rad) annotation(
          Line(points = {{-10, -220}, {27.5, -220}, {27.5, -104}, {154, -104}}, color = {0, 0, 127}));
        connect(condenser_comp.to_highvrad_T, batttemp_thermal.highvoltage_rad_T) annotation(
          Line(points = {{155, -109}, {30.5, -109}, {30.5, -228}, {-10, -228}}, color = {0, 0, 127}));
        connect(hvac.from_condenser_Q, condenser_comp.to_hvac_Q) annotation(
          Line(points = {{154, -14}, {74, -14}, {74, -98}, {141, -98}, {141, -98.5}, {155, -98.5}, {155, -99}}, color = {0, 0, 127}));
        connect(condenser_comp.from_hvac_T, hvac.to_condenser_T) annotation(
          Line(points = {{154, -94}, {78, -94}, {78, -19}, {155, -19}}, color = {0, 0, 127}));
        connect(condenser_comp.from_chiller_T, chiller_comp.to_condenser_T) annotation(
          Line(points = {{154, -118}, {66, -118}, {66, -142}, {155, -142}, {155, -141}}, color = {0, 0, 127}));
        connect(condenser_comp.to_chiller_Q, chiller_comp.from_condenser_Q) annotation(
          Line(points = {{155, -123}, {70, -123}, {70, -136}, {154, -136}}, color = {0, 0, 127}));
        connect(chiller_comp.to_batrad_Q, batttemp_thermal.chiller_Q) annotation(
          Line(points = {{155, -159}, {40.5, -159}, {40.5, -246}, {-10, -246}}, color = {0, 0, 127}));
        connect(batttemp_thermal.chiller_T, chiller_comp.from_batrad_T) annotation(
          Line(points = {{-10, -238}, {37, -238}, {37, -154}, {154, -154}}, color = {0, 0, 127}));
        connect(hvac.to_ac_T, el_ac_comp.from_hvac_T) annotation(
          Line(points = {{155, -7}, {52, -7}, {52, -219}, {152, -219}}, color = {0, 0, 127}));
        connect(hvac.from_ac_Q, el_ac_comp.to_hvac_Q) annotation(
          Line(points = {{154, -2}, {50, -2}, {50, -225}, {153, -225}}, color = {0, 0, 127}));
        connect(chiller_comp.from_ac_T, el_ac_comp.to_chiller_T) annotation(
          Line(points = {{154, -170}, {78, -170}, {78, -188}, {153, -188}}, color = {0, 0, 127}));
        connect(chiller_comp.to_ac_Q, el_ac_comp.from_chiller_Q) annotation(
          Line(points = {{155, -174}, {80, -174}, {80, -183}, {152, -183}}, color = {0, 0, 127}));
        connect(hightemp4_1.engine_T, engine_comp.from_hightempthermal_T) annotation(
          Line(points = {{-88, 44}, {-124, 44}, {-124, 308}}, color = {0, 0, 127}));
        connect(at_cooler_comp.to_hightempthermal_Q, hightemp4_1.at_cooler_Q) annotation(
          Line(points = {{-55, 465}, {-58, 465}, {-58, 118}}, color = {0, 0, 127}));
        connect(at_cooler_comp.from_hightempthermal_T, hightemp4_1.at_cooler_T) annotation(
          Line(points = {{-45, 463}, {-44, 463}, {-44, 118}}, color = {0, 0, 127}));
        connect(PTC_Q, hightemp4_1.ptc_Q) annotation(
          Line(points = {{-14, 220}, {-14, 118}}, color = {0, 0, 127}));
        connect(hightemp4_1.ptc_T, PTC_T) annotation(
          Line(points = {{-27, 118}, {-27, 174}, {-28, 174}, {-28, 186}}, color = {0, 0, 127}));
        connect(HTEMP_VALVE1, hightemp4_1.hightemp_valve1_rate) annotation(
          Line(points = {{-102, 196}, {-102, 96}, {-88, 96}}, color = {0, 0, 127}));
        connect(hightemp4_1.hightemp_wp, HTEMP_WP) annotation(
          Line(points = {{4, 118}, {4, 180}}, color = {0, 0, 127}));
        connect(BTEMP_WP1, batttemp_thermal.batttemp_wp1) annotation(
          Line(points = {{-16, -330}, {-16, -301}, {-27.5, -301}, {-27.5, -280}}, color = {0, 0, 127}));
        connect(batttemp_thermal.Libatt_T, LIBAT_T) annotation(
          Line(points = {{-50, -280}, {-50, -326}}, color = {0, 0, 127}));
        connect(batttemp_thermal.batttemp_valve1_rate, BTEMP_VALVE1) annotation(
          Line(points = {{-75, -270}, {-98, -270}, {-98, -322}}, color = {0, 0, 127}));
        connect(batttemp_thermal.batttemp_wp2, BTEMP_WP2) annotation(
          Line(points = {{-76, -257}, {-130, -257}, {-130, -328}}, color = {0, 0, 127}));
        connect(batttemp_thermal.dcdc_Q, DCDC_Q) annotation(
          Line(points = {{-75, -245}, {-184, -245}, {-184, -322}}, color = {0, 0, 127}));
        connect(batttemp_thermal.dcdc_T, DCDC_T) annotation(
          Line(points = {{-75, -249}, {-150, -249}, {-150, -322}}, color = {0, 0, 127}));
        connect(BTEMP_VALVE2, batttemp_thermal.batttemp_valve2_rate) annotation(
          Line(points = {{-232, -320}, {-232, -233}, {-76, -233}}, color = {0, 0, 127}));
        connect(LTEMP_WP, lowtemp_thermal.volume_flow_lowtemp) annotation(
          Line(points = {{-252, -174}, {-192.5, -174}, {-192.5, -112}, {-83, -112}}, color = {0, 0, 127}));
        connect(CHARGEAIR_Q, lowtemp_thermal.charge_air_Q) annotation(
          Line(points = {{-230, -80}, {-175, -80}, {-175, -79}, {-84, -79}}, color = {0, 0, 127}));
        connect(CHARGEAIR_T, lowtemp_thermal.charge_air_T) annotation(
          Line(points = {{-176, -96}, {-84, -96}, {-84, -93.5}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.turbo_charger_Q, CHARGER_Q) annotation(
          Line(points = {{-83, -50}, {-228, -50}}, color = {0, 0, 127}));
        connect(CHARGER_T, lowtemp_thermal.turbo_charger_T) annotation(
          Line(points = {{-194, -64}, {-84, -64}}, color = {0, 0, 127}));
        connect(ENGINE_Q, engine_comp.from_engineloss) annotation(
          Line(points = {{-146, 392}, {-146, 352}}, color = {0, 0, 127}));
        connect(coolant_temp, hightemp4_1.coolant_temp) annotation(
          Line(points = {{-70, 244}, {-70, 118}, {-71, 118}}, color = {0, 0, 127}));
        connect(batttemp_thermal.batt_coolant_temp, batt_coolantemp) annotation(
          Line(points = {{-75, -238}, {-210, -238}, {-210, -330}}, color = {0, 0, 127}));
        connect(AC_Q, el_ac_comp.from_AC_Q) annotation(
          Line(points = {{252, -204}, {200, -204}}, color = {0, 0, 127}));
        connect(radiator_comp.to_lowrad_T, lowtemp_thermal.charge_air_radiator_T) annotation(
          Line(points = {{153, -51}, {32, -51}, {32, -56}, {-2, -56}, {-2, -56.5}}, color = {0, 0, 127}));
        connect(radiator_comp.from_low_rad, lowtemp_thermal.charge_air_radiator_Q) annotation(
          Line(points = {{152, -47}, {27.5, -47}, {27.5, -42}, {-2, -42}}, color = {0, 0, 127}));
        connect(radiator_comp.to_battrad_T, condenser_comp.from_lowrad_T) annotation(
          Line(points = {{153, -73}, {110, -73}, {110, -84}, {154, -84}}, color = {0, 0, 127}));
        connect(radiator_comp.from_batrad_Q, condenser_comp.to_lowrad_Q) annotation(
          Line(points = {{152, -68}, {98, -68}, {98, -89}, {155, -89}}, color = {0, 0, 127}));
        connect(radiator_comp.from_hightemp_Q, hightemp4_1.radiator_Q) annotation(
          Line(points = {{152, -36}, {90, -36}, {90, 79}, {8, 79}}, color = {0, 0, 127}));
        connect(hightemp4_1.radiator_T, radiator_comp.to_hightemp_T) annotation(
          Line(points = {{8, 66}, {82, 66}, {82, -40}, {153, -40}, {153, -41}}, color = {0, 0, 127}));
        connect(cabin_1.cabin_T, cabin_T) annotation(
          Line(points = {{193, 62}, {216, 62}}, color = {0, 0, 127}));
        connect(glass.K_out, cabin_1.from_glass_T) annotation(
          Line(points = {{166, 88}, {150, 88}, {150, 74}, {156, 74}, {156, 74}}, color = {0, 0, 127}));
        connect(glass.Q_in, cabin_1.to_glass_Q) annotation(
          Line(points = {{166, 100}, {148, 100}, {148, 70}, {158, 70}, {158, 70}}, color = {0, 0, 127}));
        connect(engine_comp.from_hightempthermal2_T, hightemp4_1.engine2_T) annotation(
          Line(points = {{-114, 308}, {-114, 79}, {-88, 79}}, color = {0, 0, 127}));
        connect(engine_comp.to_hightempthermal2_Q, hightemp4_1.engine2_Q) annotation(
          Line(points = {{-119, 309}, {-118, 309}, {-118, 61}, {-88, 61}}, color = {0, 0, 127}));
        connect(engine_comp.to_hightempthermal_Q, hightemp4_1.engine_Q) annotation(
          Line(points = {{-129, 309}, {-130, 309}, {-130, 26}, {-88, 26}}, color = {0, 0, 127}));
        connect(HTEMP_VALVE2, hightemp4_1.hightemp_valve2_rate) annotation(
          Line(points = {{-88, 166}, {-90, 166}, {-90, 114}, {-88, 114}}, color = {0, 0, 127}));
        connect(LIBAT_Q, batttemp_thermal.Libatt_Q) annotation(
          Line(points = {{-60, -386}, {-60, -280}}, color = {0, 0, 127}));
        connect(radiator_comp.from_air_T, AIR_TEMP) annotation(
          Line(points = {{196, -50}, {226, -50}, {226, 360}, {246, 360}, {246, 360}}, color = {0, 0, 127}));
        connect(batttemp_thermal.VSP, VSP) annotation(
          Line(points = {{-10, -276}, {194, -276}, {194, -277}, {201, -277}}, color = {0, 0, 127}));
        connect(batttemp_thermal.RAD, RADFAN) annotation(
          Line(points = {{-10, -262}, {192, -262}, {192, -261}, {201, -261}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.VSP, VSP) annotation(
          Line(points = {{-2, -108}, {4, -108}, {4, -276}, {202, -276}, {202, -276}}, color = {0, 0, 127}));
        connect(lowtemp_thermal.RAD, RADFAN) annotation(
          Line(points = {{-2, -86}, {8, -86}, {8, -262}, {202, -262}, {202, -260}}, color = {0, 0, 127}));
        connect(hightemp4_1.VSP, VSP) annotation(
          Line(points = {{8, 26}, {18, 26}, {18, -276}, {202, -276}}, color = {0, 0, 127}));
        connect(hightemp4_1.RAD, RADFAN) annotation(
          Line(points = {{8, 44}, {24, 44}, {24, -262}, {202, -262}, {202, -260}}, color = {0, 0, 127}));
        connect(from_mg_T, lowtemp_thermal.motor_generator_T) annotation(
          Line(points = {{-208, 14}, {-38, 14}, {-38, -30}}, color = {0, 0, 127}));
        connect(from_oil_T, at_cooler_comp.from_oil_T) annotation(
          Line(points = {{-206, 420}, {-86, 420}, {-86, 464}}, color = {0, 0, 127}));
        connect(engine_comp.from_case_Q, from_case_engine_Q) annotation(
          Line(points = {{-148, 308}, {-148, 308}, {-148, 258}, {-210, 258}, {-210, 260}}, color = {0, 0, 127}));
        connect(from_launch_Q, engine_comp.from_launch_Q) annotation(
          Line(points = {{-212, 200}, {-136, 200}, {-136, 308}}, color = {0, 0, 127}));
        connect(to_mg_Q, lowtemp_thermal.motor_generator_Q) annotation(
          Line(points = {{-204, -12}, {-58, -12}, {-58, -32}, {-58, -32}}, color = {0, 0, 127}));
        connect(to_launch_T, engine_comp.to_launch_TempEng) annotation(
          Line(points = {{-202, 234}, {-140, 234}, {-140, 310}, {-140, 310}}, color = {0, 0, 127}));
        connect(to_case_engine_T, engine_comp.to_case_TempEng) annotation(
          Line(points = {{-204, 292}, {-152, 292}, {-152, 310}, {-152, 310}}, color = {0, 0, 127}));
        connect(to_oil_Q, at_cooler_comp.to_oil_Q) annotation(
          Line(points = {{-208, 454}, {-98, 454}, {-98, 464}, {-98, 464}}, color = {0, 0, 127}));
      protected
        annotation(
          Icon(coordinateSystem(extent = {{-200, -700}, {200, 600}}), graphics = {Text(origin = {-76, 538}, extent = {{-118, 54}, {264, -1128}}, textString = "%name"), Rectangle(origin = {-2, -3}, extent = {{-198, 603}, {194, -687}})}),
          Diagram(coordinateSystem(extent = {{-200, -700}, {200, 600}})));
      end thermal_meti;

      model thermal_plant_base
        parameter Modelica.SIunits.HeatCapacity ENGINE_C = 6000 "Engine heat capacity";
        parameter Modelica.SIunits.HeatCapacity LAUNCH_C = 4300 "LAUNCH heat capacity";
        parameter Modelica.SIunits.HeatCapacity VARIATOR_C = 17000 "VARIATOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity CASE_C = 29000 "CASE heat capacity";
        parameter Modelica.SIunits.HeatCapacity MG_C = 2000 "MG heat capacity";
        parameter Modelica.SIunits.HeatCapacity OIL_C = 9400 "OIL heat capacity";
        parameter Modelica.SIunits.HeatCapacity ATCOOLER_C = 100 "ATCOOLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity PTC_C = 10 "PTC heat capacity";
        parameter Modelica.SIunits.HeatCapacity HVAC_C = 1 "HVAC heat capacity";
        parameter Modelica.SIunits.HeatCapacity CABIN_C = 6000 "CABIN heat capacity";
        parameter Modelica.SIunits.HeatCapacity GLASS_C = 30000 "GLASS heat capacity";
        parameter Modelica.SIunits.HeatCapacity DOOR_C = 50000 "DOOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity RADIATOR_C = 15 "RADIATOR heat capacity";
        parameter Modelica.SIunits.HeatCapacity CHARGEAIRCOOLER_C = 15 "CHARGE AIR COOLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity TURBO_CHARGER_C = 10 "TURBO CHARGER heat capacity";
        parameter Modelica.SIunits.HeatCapacity LOW_RADIATOR_C = 1.0 "LOW RADIATOR  heat capacity";
        parameter Modelica.SIunits.HeatCapacity condenser_C = 1.0 "condenser heat capacity";
        parameter Modelica.SIunits.HeatCapacity EL_AC_C = 5.0 "e-AC heat capacity";
        parameter Modelica.SIunits.HeatCapacity CHILLER_C = 5.0 "CHILLER heat capacity";
        parameter Modelica.SIunits.HeatCapacity LIBATT_C = 1000 "Li batt heat capacity";
        parameter Modelica.SIunits.HeatCapacity DCDC_C = 500 "DCDC heat capacity";
        parameter Modelica.SIunits.HeatCapacity BAT_RADIATOR_C = 1.0 "BAT RADIATOR  heat capacity";
        parameter Modelica.SIunits.ThermalResistance LAUNCH_ENGINE_R = 100 "LAUNCH thermal resistance for ENGINE";
        parameter Modelica.SIunits.ThermalResistance CASE_ENGINE_R = 0.015 "CASE thermal resistance for ENGINE";
        parameter Modelica.SIunits.ThermalResistance CASE_LAUNCH_R = 100 "CASE thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance CASE_VAR_R = 100 "CASE thermal resistance for VARIATOR";
        parameter Modelica.SIunits.ThermalResistance CASE_MG_R = 100 "CASE thermal resistance for MG";
        parameter Modelica.SIunits.ThermalResistance CASE_AIR_R = 0.1 "CASE thermal resistance for AIR";
        parameter Modelica.SIunits.ThermalResistance OIL_LAUNCH_R = 0.0001 "OIL thermal resistance for launch";
        parameter Modelica.SIunits.ThermalResistance OIL_VAR_R = 0.073 "OIL thermal resistance for VARIATOR";
        parameter Modelica.SIunits.ThermalResistance OIL_CASE_R = 0.0044 "OIL thermal resistance for CASE";
        parameter Modelica.SIunits.ThermalResistance OIL_MG_R = 0.05 "OIL thermal resistance for MG";
        parameter Modelica.SIunits.ThermalResistance AT_COOLER_OIL_R = 0.001 "ATCOOLER thermal resistance for OIL";
        parameter Modelica.SIunits.ThermalResistance ENGINE1_WATER_R = 0.01 "ENGINE1 thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance ENGINE2_WATER_R = 0.01 "ENGINE2 thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance ATCOOLER_WATER_R = 0.01 "AT COOLER thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance PTC_WATER_R = 0.01 "PTC thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance HVAC_WATER_R = 0.01 "HVAC thermal resistance for WATER";
        parameter Modelica.SIunits.ThermalResistance HVAC_CABIN_R = 0.1 "HVAC thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance GLASS_CABIN_R = 10 "GLASS thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance DOOR_CABIN_R = 10 "DOOR thermal resistance for CABIN";
        parameter Modelica.SIunits.ThermalResistance LOW_RADIATOR_R = 0.01 "low thermal resistance for rad";
        parameter Modelica.SIunits.ThermalResistance BAT_RADIATOR_R = 0.01 "bat thermal resistance for rad";
        parameter Modelica.SIunits.ThermalResistance MG_WATER_R = 0.01 "MG thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance CHARGEAIRCOOLER_WATER_R = 0.01 "CHARGEAIRCOOLER thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance TURBO_WATER_R = 0.01 "TURBO thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance condenser_HVAC_R = 0.1 "condenser thermal resistance for HVAC";
        parameter Modelica.SIunits.ThermalResistance condenser_HIGHRAD_R = 0.01 "KONDENDOR thermal resistance for HIGHRAD";
        parameter Modelica.SIunits.ThermalResistance AC_HVAC_R = 0.1 "AC thermal resistance for HVAC";
        parameter Modelica.SIunits.ThermalResistance AC_CHILLER_R = 0.1 "AC thermal resistance for CHILLER";
        parameter Modelica.SIunits.ThermalResistance CHILLER_condenser_R = 0.1 "CHILLER thermal resistance for condenser";
        parameter Modelica.SIunits.ThermalResistance CHILLER_WATER_R = 0.01 "CHIller thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance LIBATT_WATER_R = 0.01 "LIBATT thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance DCDC_WATER_R = 0.01 "DCDC thermal resistance for water";
        parameter Modelica.SIunits.ThermalResistance ENGINECASE_R = 100000 "enginecase thermal resistance for CVT";
        parameter Modelica.SIunits.ThermalResistance ENGINESHAFT_LAUNCH_R = 100000 "engineshaft thermal resistance for CVT";
        Modelica.Blocks.Interfaces.RealInput AIR_TEMP annotation(
          Placement(visible = true, transformation(origin = {-259, 205}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-219, -599}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput PTC_Q annotation(
          Placement(visible = true, transformation(origin = {-198, 572}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-220, 676}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PTC_T annotation(
          Placement(visible = true, transformation(origin = {58, 566}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 586}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_VALVE1 annotation(
          Placement(visible = true, transformation(origin = {-242, 338}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-220, 16}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_VALVE2 annotation(
          Placement(visible = true, transformation(origin = {-208, 380}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 136}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {-325, 227}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-221, -541}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput RADFAN annotation(
          Placement(visible = true, transformation(origin = {-207, 507}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-224, 494}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HTEMP_WP annotation(
          Placement(visible = true, transformation(origin = {-206, 444}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 316}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_WP1 annotation(
          Placement(visible = true, transformation(origin = {-234, 486}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 436}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput LIBAT_T annotation(
          Placement(visible = true, transformation(origin = {50, 426}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {208, 190}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput LIBAT_Q annotation(
          Placement(visible = true, transformation(origin = {-206, 252}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -480}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_VALVE1 annotation(
          Placement(visible = true, transformation(origin = {-222, 358}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-220, 76}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_WP2 annotation(
          Placement(visible = true, transformation(origin = {-222, 422}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 256}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput DCDC_T annotation(
          Placement(visible = true, transformation(origin = {56, 496}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 388}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput DCDC_Q annotation(
          Placement(visible = true, transformation(origin = {-236, 272}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -418}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput BTEMP_VALVE2 annotation(
          Placement(visible = true, transformation(origin = {-242, 402}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 198}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput LTEMP_WP annotation(
          Placement(visible = true, transformation(origin = {-242, 464}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 374}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput CHARGEAIR_Q annotation(
          Placement(visible = true, transformation(origin = {-264, 530}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 558}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGEAIR_T annotation(
          Placement(visible = true, transformation(origin = {62, 242}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -330}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput CHARGER_Q annotation(
          Placement(visible = true, transformation(origin = {-232, 550}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, 618}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput CHARGER_T annotation(
          Placement(visible = true, transformation(origin = {64, 290}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -196}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput LAUNCH_Q annotation(
          Placement(visible = true, transformation(origin = {16, -64}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -112}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VAR_Q annotation(
          Placement(visible = true, transformation(origin = {2, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -172}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGINE_Q annotation(
          Placement(visible = true, transformation(origin = {-222, 296}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -300}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput MG_Q annotation(
          Placement(visible = true, transformation(origin = {0, -108}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -360}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput coolant_temp annotation(
          Placement(visible = true, transformation(origin = {56, 530}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 484}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput MG_T annotation(
          Placement(visible = true, transformation(origin = {218, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 292}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput batt_coolantemp annotation(
          Placement(visible = true, transformation(origin = {48, 386}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 80}, extent = {{10, -10}, {-10, 10}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealInput AC_Q annotation(
          Placement(visible = true, transformation(origin = {-206, 316}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -44}, extent = {{20, -20}, {-20, 20}}, rotation = 180)));
        Modelica.Blocks.Interfaces.RealOutput cabin_T annotation(
          Placement(visible = true, transformation(origin = {52, 336}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -62}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput oil_temp annotation(
          Placement(visible = true, transformation(origin = {218, -116}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {211, -571}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.thermal_meti thermal_meti_model(METI_AC_CHILLER_R = AC_CHILLER_R, METI_AC_HVAC_R = AC_HVAC_R, METI_ATCOOLER_C = ATCOOLER_C, METI_ATCOOLER_WATER_R = ATCOOLER_WATER_R, METI_AT_COOLER_OIL_R = AT_COOLER_OIL_R, METI_BAT_RADIATOR_C = BAT_RADIATOR_C, METI_BAT_RADIATOR_R = BAT_RADIATOR_R, METI_CABIN_C = CABIN_C, METI_CHARGEAIRCOOLER_C = CHARGEAIRCOOLER_C, METI_CHARGEAIRCOOLER_WATER_R = CHARGEAIRCOOLER_WATER_R, METI_CHILLER_C = CHILLER_C, METI_CHILLER_WATER_R = CHILLER_WATER_R, METI_CHILLER_condenser_R = CHILLER_condenser_R, METI_DCDC_C = DCDC_C, METI_DCDC_WATER_R = DCDC_WATER_R, METI_DOOR_C = DOOR_C, METI_DOOR_CABIN_R = DOOR_CABIN_R, METI_EL_AC_C = EL_AC_C, METI_ENGINE1_WATER_R = ENGINE1_WATER_R, METI_ENGINE2_WATER_R = ENGINE2_WATER_R, METI_ENGINE_C = ENGINE_C, METI_GLASS_C = GLASS_C, METI_GLASS_CABIN_R = GLASS_CABIN_R, METI_HVAC_C = HVAC_C, METI_HVAC_CABIN_R = HVAC_CABIN_R, METI_HVAC_WATER_R = HVAC_WATER_R, METI_LIBATT_C = LIBATT_C, METI_LIBATT_WATER_R = LIBATT_WATER_R, METI_LOW_RADIATOR_C = LOW_RADIATOR_C, METI_LOW_RADIATOR_R = LOW_RADIATOR_R, METI_MG_C = MG_C, METI_MG_WATER_R = MG_WATER_R, METI_PTC_C = PTC_C, METI_PTC_WATER_R = PTC_WATER_R, METI_RADIATOR_C = RADIATOR_C, METI_TURBO_CHARGER_C = TURBO_CHARGER_C, METI_TURBO_WATER_R = TURBO_WATER_R, METI_condenser_C = condenser_C, METI_condenser_HIGHRAD_R = condenser_HIGHRAD_R, METI_condenser_HVAC_R = condenser_HVAC_R) annotation(
          Placement(visible = true, transformation(origin = {-71, 371}, extent = {{-71, -248.5}, {71, 213}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.TRAMI_thermal trami_thermal_model(TRAMI_CASE_AIR_R = CASE_AIR_R, TRAMI_CASE_C = CASE_C, TRAMI_CASE_ENGINE_R = CASE_ENGINE_R, TRAMI_CASE_LAUNCH_R = CASE_LAUNCH_R, TRAMI_CASE_MG_R = CASE_MG_R, TRAMI_CASE_VAR_R = CASE_VAR_R, TRAMI_ENGINECASE_R = ENGINECASE_R, TRAMI_ENGINESHAFT_LAUNCH_R = ENGINESHAFT_LAUNCH_R, TRAMI_LAUNCH_C = LAUNCH_C, TRAMI_LAUNCH_ENGINE_R = LAUNCH_ENGINE_R, TRAMI_MG_C = MG_C, TRAMI_MG_WATER_R = MG_WATER_R, TRAMI_OIL_C = OIL_C, TRAMI_OIL_CASE_R = OIL_CASE_R, TRAMI_OIL_LAUNCH_R = OIL_LAUNCH_R, TRAMI_OIL_MG_R = OIL_MG_R, TRAMI_OIL_VAR_R = OIL_VAR_R, TRAMI_VARIATOR_C = VARIATOR_C) annotation(
          Placement(visible = true, transformation(origin = {130, -90}, extent = {{-46, -138}, {46, 138}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGINECASE_T annotation(
          Placement(visible = true, transformation(origin = {4, -152}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-222, -658}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput TRANS_T annotation(
          Placement(visible = true, transformation(origin = {0, -196}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-224, -778}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGINSHAFT_T annotation(
          Placement(visible = true, transformation(origin = {2, -174}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-220, -720}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HYD_Q annotation(
          Placement(visible = true, transformation(origin = {-10, -42}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-224, -234}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      equation
        connect(thermal_meti_model.to_oil_Q, trami_thermal_model.from_oilcooler_Q) annotation(
          Line(points = {{2, 200}, {58, 200}, {58, 46}, {79, 46}}, color = {0, 0, 127}));
        connect(thermal_meti_model.to_case_engine_T, trami_thermal_model.from_engine_T) annotation(
          Line(points = {{4, 172}, {46, 172}, {46, 28}, {80, 28}}, color = {0, 0, 127}));
        connect(thermal_meti_model.to_launch_T, trami_thermal_model.from_engine_launch_T) annotation(
          Line(points = {{6, 148}, {38, 148}, {38, 4}, {79, 4}, {79, 3}}, color = {0, 0, 127}));
        connect(thermal_meti_model.to_mg_Q, trami_thermal_model.from_Lowtempthermal_Q) annotation(
          Line(points = {{4, 118}, {30, 118}, {30, -17}, {80, -17}}, color = {0, 0, 127}));
        connect(thermal_meti_model.PTC_T, PTC_T) annotation(
          Line(points = {{4, 566}, {52, 566}, {52, 566}, {58, 566}}, color = {0, 0, 127}));
        connect(thermal_meti_model.coolant_temp, coolant_temp) annotation(
          Line(points = {{4, 530}, {56, 530}}, color = {0, 0, 127}));
        connect(thermal_meti_model.DCDC_T, DCDC_T) annotation(
          Line(points = {{4, 496}, {56, 496}}, color = {0, 0, 127}));
        connect(thermal_meti_model.LIBAT_T, LIBAT_T) annotation(
          Line(points = {{2, 426}, {50, 426}}, color = {0, 0, 127}));
        connect(thermal_meti_model.batt_coolantemp, batt_coolantemp) annotation(
          Line(points = {{4, 386}, {48, 386}}, color = {0, 0, 127}));
        connect(thermal_meti_model.cabin_T, cabin_T) annotation(
          Line(points = {{4, 336}, {48, 336}, {48, 336}, {52, 336}}, color = {0, 0, 127}));
        connect(thermal_meti_model.CHARGER_T, CHARGER_T) annotation(
          Line(points = {{4, 288}, {56, 288}, {56, 290}, {64, 290}}, color = {0, 0, 127}));
        connect(thermal_meti_model.CHARGEAIR_T, CHARGEAIR_T) annotation(
          Line(points = {{4, 242}, {52, 242}, {52, 242}, {62, 242}}, color = {0, 0, 127}));
        connect(trami_thermal_model.oil_temp, oil_temp) annotation(
          Line(points = {{179, -113}, {197, -113}, {197, -116}, {218, -116}}, color = {0, 0, 127}));
        connect(trami_thermal_model.MG_T, MG_T) annotation(
          Line(points = {{178, -60}, {218, -60}}, color = {0, 0, 127}));
        connect(PTC_Q, thermal_meti_model.PTC_Q) annotation(
          Line(points = {{-198, 572}, {-150, 572}}, color = {0, 0, 127}));
        connect(thermal_meti_model.CHARGER_Q, CHARGER_Q) annotation(
          Line(points = {{-150, 550}, {-232, 550}}, color = {0, 0, 127}));
        connect(thermal_meti_model.CHARGEAIR_Q, CHARGEAIR_Q) annotation(
          Line(points = {{-150, 530}, {-264, 530}}, color = {0, 0, 127}));
        connect(RADFAN, thermal_meti_model.RADFAN) annotation(
          Line(points = {{-206, 508}, {-152, 508}, {-152, 506}, {-150, 506}}, color = {0, 0, 127}));
        connect(BTEMP_WP1, thermal_meti_model.BTEMP_WP1) annotation(
          Line(points = {{-234, 486}, {-150, 486}}, color = {0, 0, 127}));
        connect(LTEMP_WP, thermal_meti_model.LTEMP_WP) annotation(
          Line(points = {{-242, 464}, {-154, 464}, {-154, 464}, {-150, 464}}, color = {0, 0, 127}));
        connect(thermal_meti_model.HTEMP_WP, HTEMP_WP) annotation(
          Line(points = {{-150, 444}, {-206, 444}}, color = {0, 0, 127}));
        connect(BTEMP_WP2, thermal_meti_model.BTEMP_WP2) annotation(
          Line(points = {{-222, 422}, {-150, 422}}, color = {0, 0, 127}));
        connect(BTEMP_VALVE2, thermal_meti_model.BTEMP_VALVE2) annotation(
          Line(points = {{-242, 402}, {-158, 402}, {-158, 402}, {-150, 402}}, color = {0, 0, 127}));
        connect(HTEMP_VALVE2, thermal_meti_model.HTEMP_VALVE2) annotation(
          Line(points = {{-208, 380}, {-150, 380}}, color = {0, 0, 127}));
        connect(BTEMP_VALVE1, thermal_meti_model.BTEMP_VALVE1) annotation(
          Line(points = {{-222, 358}, {-150, 358}}, color = {0, 0, 127}));
        connect(HTEMP_VALVE1, thermal_meti_model.HTEMP_VALVE1) annotation(
          Line(points = {{-242, 338}, {-154, 338}, {-154, 336}, {-150, 336}}, color = {0, 0, 127}));
        connect(AC_Q, thermal_meti_model.AC_Q) annotation(
          Line(points = {{-206, 316}, {-150, 316}}, color = {0, 0, 127}));
        connect(ENGINE_Q, thermal_meti_model.ENGINE_Q) annotation(
          Line(points = {{-222, 296}, {-150, 296}}, color = {0, 0, 127}));
        connect(DCDC_Q, thermal_meti_model.DCDC_Q) annotation(
          Line(points = {{-236, 272}, {-150, 272}}, color = {0, 0, 127}));
        connect(LIBAT_Q, thermal_meti_model.LIBAT_Q) annotation(
          Line(points = {{-206, 252}, {-154, 252}, {-154, 250}, {-150, 250}}, color = {0, 0, 127}));
        connect(VSP, thermal_meti_model.VSP) annotation(
          Line(points = {{-325, 227}, {-184, 227}, {-184, 228}, {-148, 228}}, color = {0, 0, 127}));
        connect(AIR_TEMP, thermal_meti_model.AIR_TEMP) annotation(
          Line(points = {{-259, 205}, {-152, 205}, {-152, 208}, {-148, 208}}, color = {0, 0, 127}));
        connect(LAUNCH_Q, trami_thermal_model.LAUNCH_Q) annotation(
          Line(points = {{16, -64}, {46, -64}, {46, -65}, {78, -65}}, color = {0, 0, 127}));
        connect(VAR_Q, trami_thermal_model.VAR_Q) annotation(
          Line(points = {{2, -86}, {79, -86}}, color = {0, 0, 127}));
        connect(trami_thermal_model.to_oilcooler_T, thermal_meti_model.from_oil_T) annotation(
          Line(points = {{178, -160}, {226, -160}, {226, -340}, {-228, -340}, {-228, 186}, {-148, 186}, {-148, 188}}, color = {0, 0, 127}));
        connect(MG_Q, trami_thermal_model.MG_Q) annotation(
          Line(points = {{0, -108}, {38.5, -108}, {38.5, -107}, {79, -107}}, color = {0, 0, 127}));
        connect(thermal_meti_model.from_launch_Q, trami_thermal_model.to_engine_launch_Q) annotation(
          Line(points = {{-150, 146}, {-196, 146}, {-196, -308}, {204, -308}, {204, -190}, {177, -190}}, color = {0, 0, 127}));
        connect(thermal_meti_model.from_mg_T, trami_thermal_model.to_Lowtempthermal_T) annotation(
          Line(points = {{-150, 120}, {-182, 120}, {-182, -286}, {178, -286}, {178, -205}}, color = {0, 0, 127}));
        connect(AIR_TEMP, trami_thermal_model.AIR_TEMP) annotation(
          Line(points = {{-258, 206}, {-238, 206}, {-238, -128}, {80, -128}}, color = {0, 0, 127}));
        connect(ENGINECASE_T, trami_thermal_model.from_enginecase_T) annotation(
          Line(points = {{4, -152}, {41.5, -152}, {41.5, -154}, {79, -154}}, color = {0, 0, 127}));
        connect(ENGINSHAFT_T, trami_thermal_model.from_engineshaft_T) annotation(
          Line(points = {{2, -174}, {40, -174}, {40, -171}, {80, -171}}, color = {0, 0, 127}));
        connect(TRANS_T, trami_thermal_model.from_transcase_T) annotation(
          Line(points = {{0, -196}, {40, -196}, {40, -193}, {79, -193}}, color = {0, 0, 127}));
        connect(trami_thermal_model.to_engine_Q, thermal_meti_model.from_case_engine_Q) annotation(
          Line(points = {{178, -175}, {212, -175}, {212, -322}, {-210, -322}, {-210, 164}, {-150, 164}, {-150, 166}}, color = {0, 0, 127}));
        connect(VSP, trami_thermal_model.VSP) annotation(
          Line(points = {{-324, 228}, {-296, 228}, {-296, -214}, {79, -214}}, color = {0, 0, 127}));
        connect(HYD_Q, trami_thermal_model.from_hyd_Q) annotation(
          Line(points = {{-10, -42}, {78, -42}}, color = {0, 0, 127}));
      protected
        annotation(
          Icon(coordinateSystem(extent = {{-200, -800}, {200, 700}}), graphics = {Text(origin = {-76, 536}, extent = {{-114, -58}, {264, -1128}}, textString = "%name"), Rectangle(origin = {-2, -3}, extent = {{-194, 701}, {196, -803}})}),
          Diagram(coordinateSystem(extent = {{-200, -800}, {200, 700}})));
      end thermal_plant_base;

      model thermal_common
        Modelica.Blocks.Interfaces.RealInput ENGTrq annotation(
          Placement(visible = true, transformation(origin = {-120, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.BooleanInput ACONOFF annotation(
          Placement(visible = true, transformation(origin = {-120, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENGrev annotation(
          Placement(visible = true, transformation(origin = {-120, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput AC_SET_TEMP annotation(
          Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput LAUNCH_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VARIATOR_Q annotation(
          Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Engine_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -58}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -76}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput MG_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -98}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -116}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput DCDC_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -138}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -156}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput LIBAT_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -178}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -196}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput VSP annotation(
          Placement(visible = true, transformation(origin = {-120, -218}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -236}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput AIR_TEMP annotation(
          Placement(visible = true, transformation(origin = {-120, -258}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -276}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput OIL_TEMP annotation(
          Placement(visible = true, transformation(origin = {216, 32}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {112, -82}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.thermal_control thermal_cont annotation(
          Placement(visible = true, transformation(origin = {19, 125.5}, extent = {{-51, -76.5}, {51, 76.5}}, rotation = 0)));
        TRAMI_L3_HEV.Thermal.thermal_circuits.thermal_plant_base thermal_common_plant(AT_COOLER_OIL_R = 0.001, CABIN_C = 5000, CASE_AIR_R = 0.1, CASE_C = 30000, CASE_ENGINE_R = 0.01, CASE_MG_R = 100, CHARGEAIRCOOLER_C = 10, ENGINECASE_R = 10000, ENGINESHAFT_LAUNCH_R = 10000, ENGINE_C = 5000, LAUNCH_C = 5000, LAUNCH_ENGINE_R = 100, MG_C = 1000, OIL_C = 10000, OIL_CASE_R = 0.01, OIL_MG_R = 0.05, OIL_VAR_R = 0.1, RADIATOR_C = 10, VARIATOR_C = 1500) annotation(
          Placement(visible = true, transformation(origin = {152, 90}, extent = {{-20, -80}, {20, 70}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENG_CASE annotation(
          Placement(visible = true, transformation(origin = {-120, -298}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -316}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ENG_CRANK annotation(
          Placement(visible = true, transformation(origin = {-120, -338}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -356}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput TRANS_AIR annotation(
          Placement(visible = true, transformation(origin = {-120, -378}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -396}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput HYD_Q annotation(
          Placement(visible = true, transformation(origin = {-120, -28}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -38}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      equation
        connect(ACONOFF, thermal_cont.ac_onoff) annotation(
          Line(points = {{-120, 200}, {-74, 200}, {-74, 102}, {-34, 102}, {-34, 102}}, color = {255, 0, 255}));
        connect(ENGTrq, thermal_cont.ENGtrq) annotation(
          Line(points = {{-120, 160}, {-78, 160}, {-78, 88}, {-34, 88}, {-34, 88}}, color = {0, 0, 127}));
        connect(ENGrev, thermal_cont.EngREV) annotation(
          Line(points = {{-120, 120}, {-82, 120}, {-82, 72}, {-34, 72}, {-34, 72}}, color = {0, 0, 127}));
        connect(AC_SET_TEMP, thermal_cont.ac_set_t) annotation(
          Line(points = {{-120, 80}, {-92, 80}, {-92, 58}, {-34, 58}, {-34, 58}}, color = {0, 0, 127}));
        connect(thermal_common_plant.PTC_Q, thermal_cont.PTC_Q) annotation(
          Line(points = {{130, 158}, {122, 158}, {122, 194}, {70, 194}}, color = {0, 0, 127}));
        connect(thermal_common_plant.CHARGER_Q, thermal_cont.CHARGER_Q) annotation(
          Line(points = {{130, 152}, {120, 152}, {120, 184}, {70, 184}}, color = {0, 0, 127}));
        connect(thermal_common_plant.CHARGEAIR_Q, thermal_cont.CHARGE_AIRCOOLER_Q) annotation(
          Line(points = {{130, 146}, {116, 146}, {116, 174}, {70, 174}}, color = {0, 0, 127}));
        connect(thermal_common_plant.RADFAN, thermal_cont.RADFAN_Q) annotation(
          Line(points = {{130, 139}, {112, 139}, {112, 164}, {70, 164}}, color = {0, 0, 127}));
        connect(thermal_common_plant.BTEMP_WP1, thermal_cont.WP1_Q) annotation(
          Line(points = {{130, 134}, {108, 134}, {108, 144}, {70, 144}}, color = {0, 0, 127}));
        connect(thermal_common_plant.LTEMP_WP, thermal_cont.WP2_Q) annotation(
          Line(points = {{130, 127}, {104, 127}, {104, 134}, {70, 134}}, color = {0, 0, 127}));
        connect(thermal_common_plant.HTEMP_WP, thermal_cont.WP3_Q) annotation(
          Line(points = {{130, 122}, {70, 122}}, color = {0, 0, 127}));
        connect(thermal_common_plant.BTEMP_WP2, thermal_cont.WP4_Q) annotation(
          Line(points = {{130, 116}, {70, 116}, {70, 112}}, color = {0, 0, 127}));
        connect(thermal_common_plant.BTEMP_VALVE2, thermal_cont.VALVE1_RATE) annotation(
          Line(points = {{130, 110}, {76, 110}, {76, 98}, {70, 98}}, color = {0, 0, 127}));
        connect(thermal_common_plant.HTEMP_VALVE2, thermal_cont.VALVE2_RATE) annotation(
          Line(points = {{130, 104}, {78, 104}, {78, 92}, {70, 92}}, color = {0, 0, 127}));
        connect(thermal_common_plant.BTEMP_VALVE1, thermal_cont.VALVE3_RATE) annotation(
          Line(points = {{130, 98}, {80, 98}, {80, 88}, {70, 88}}, color = {0, 0, 127}));
        connect(thermal_common_plant.HTEMP_VALVE1, thermal_cont.VALVE4_RATE) annotation(
          Line(points = {{130, 92}, {82, 92}, {82, 82}, {70, 82}}, color = {0, 0, 127}));
        connect(thermal_common_plant.AC_Q, thermal_cont.AC_Q) annotation(
          Line(points = {{130, 86}, {84, 86}, {84, 68}, {72, 68}, {72, 66}, {70, 66}}, color = {0, 0, 127}));
        connect(LAUNCH_Q, thermal_common_plant.LAUNCH_Q) annotation(
          Line(points = {{-120, 40}, {86, 40}, {86, 79}, {130, 79}}, color = {0, 0, 127}));
        connect(VARIATOR_Q, thermal_common_plant.VAR_Q) annotation(
          Line(points = {{-120, 0}, {88, 0}, {88, 73}, {130, 73}}, color = {0, 0, 127}));
        connect(Engine_Q, thermal_common_plant.ENGINE_Q) annotation(
          Line(points = {{-120, -58}, {92, -58}, {92, 60}, {130, 60}}, color = {0, 0, 127}));
        connect(MG_Q, thermal_common_plant.MG_Q) annotation(
          Line(points = {{-120, -98}, {94, -98}, {94, 54}, {130, 54}}, color = {0, 0, 127}));
        connect(DCDC_Q, thermal_common_plant.DCDC_Q) annotation(
          Line(points = {{-120, -138}, {96, -138}, {96, 50}, {130, 50}, {130, 48}}, color = {0, 0, 127}));
        connect(LIBAT_Q, thermal_common_plant.LIBAT_Q) annotation(
          Line(points = {{-120, -178}, {98, -178}, {98, 42}, {130, 42}}, color = {0, 0, 127}));
        connect(VSP, thermal_common_plant.VSP) annotation(
          Line(points = {{-120, -218}, {100, -218}, {100, 36}, {130, 36}}, color = {0, 0, 127}));
        connect(AIR_TEMP, thermal_common_plant.AIR_TEMP) annotation(
          Line(points = {{-120, -258}, {102, -258}, {102, 30}, {130, 30}}, color = {0, 0, 127}));
        connect(ENG_CASE, thermal_common_plant.ENGINECASE_T) annotation(
          Line(points = {{-120, -298}, {106, -298}, {106, 24}, {130, 24}}, color = {0, 0, 127}));
        connect(ENG_CRANK, thermal_common_plant.ENGINSHAFT_T) annotation(
          Line(points = {{-120, -338}, {110, -338}, {110, 18}, {130, 18}}, color = {0, 0, 127}));
        connect(TRANS_AIR, thermal_common_plant.TRANS_T) annotation(
          Line(points = {{-120, -378}, {114, -378}, {114, 12}, {130, 12}}, color = {0, 0, 127}));
        connect(thermal_common_plant.oil_temp, OIL_TEMP) annotation(
          Line(points = {{173, 33}, {195, 33}, {195, 32}, {216, 32}}, color = {0, 0, 127}));
        connect(thermal_common_plant.PTC_T, thermal_cont.ptctemp) annotation(
          Line(points = {{173, 149}, {178, 149}, {178, 212}, {-40, 212}, {-40, 202}, {-36, 202}}, color = {0, 0, 127}));
        connect(thermal_common_plant.coolant_temp, thermal_cont.coolanttemp) annotation(
          Line(points = {{173, 138}, {184, 138}, {184, 220}, {-46, 220}, {-46, 190}, {-34, 190}}, color = {0, 0, 127}));
        connect(thermal_common_plant.DCDC_T, thermal_cont.dcdc_t) annotation(
          Line(points = {{173, 129}, {190, 129}, {190, 228}, {-50, 228}, {-50, 176}, {-36, 176}, {-36, 178}}, color = {0, 0, 127}));
        connect(thermal_common_plant.MG_T, thermal_cont.mg_t) annotation(
          Line(points = {{173, 119}, {194, 119}, {194, 232}, {-56, 232}, {-56, 164}, {-36, 164}}, color = {0, 0, 127}));
        connect(thermal_common_plant.LIBAT_T, thermal_cont.batt_t) annotation(
          Line(points = {{173, 109}, {202, 109}, {202, 240}, {-58, 240}, {-58, 144}, {-36, 144}, {-36, 146}}, color = {0, 0, 127}));
        connect(thermal_common_plant.batt_coolantemp, thermal_cont.bat_cool_t) annotation(
          Line(points = {{173, 98}, {208, 98}, {208, 244}, {-60, 244}, {-60, 132}, {-36, 132}}, color = {0, 0, 127}));
        connect(thermal_common_plant.cabin_T, thermal_cont.cabin_temp) annotation(
          Line(points = {{173, 84}, {212, 84}, {212, 248}, {-64, 248}, {-64, 118}, {-36, 118}}, color = {0, 0, 127}));
        connect(HYD_Q, thermal_common_plant.HYD_Q) annotation(
          Line(points = {{-120, -28}, {90, -28}, {90, 68}, {130, 68}, {130, 66}}, color = {0, 0, 127}));
        annotation(
          Diagram(coordinateSystem(extent = {{-100, -400}, {100, 200}})),
          Icon(coordinateSystem(extent = {{-100, -400}, {100, 200}}), graphics = {Rectangle(origin = {1, -21}, extent = {{-99, 219}, {99, -377}}), Text(origin = {-11, 1}, extent = {{-81, 189}, {107, -237}}, textString = "%name")}));
      end thermal_common;
    end thermal_circuits;
  equation

  protected
    annotation(
      uses(Modelica(version = "3.2.3")),
      Diagram);
  end Thermal;

  package TransMission
    package Mechanics
      model TransMission
        parameter Real Oil_Viscosity_Breakpoint[:];
        Modelica.Blocks.Interfaces.RealInput f_synchro_n[8] annotation(
          Placement(visible = true, transformation(origin = {-120, 70}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput tau_clutch_cap[2] annotation(
          Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 260}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput trq_FW_PNT_in_Nm annotation(
          Placement(visible = true, transformation(origin = {-120, -4}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_DS_PNT_out_radps annotation(
          Placement(visible = true, transformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_ENG_PNT_radps annotation(
          Placement(visible = true, transformation(origin = {110, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput tau_DS_PNT_out_Nm annotation(
          Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_GB_PNT_W annotation(
          Placement(visible = true, transformation(origin = {110, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -160}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_synchro_dif_radps[10] annotation(
          Placement(visible = true, transformation(origin = {110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ToutOil annotation(
          Placement(visible = true, transformation(origin = {-120, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput p_line_Pa annotation(
          Placement(visible = true, transformation(origin = {-120, -94}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_gearbox_input_radps annotation(
          Placement(visible = true, transformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 260}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_gearbox_output_radps annotation(
          Placement(visible = true, transformation(origin = {110, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 200}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput I_actuator_A annotation(
          Placement(visible = true, transformation(origin = {-120, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput I_EOP_A annotation(
          Placement(visible = true, transformation(origin = {-120, -146}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -220}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput V_BT_PNT_Lo_V annotation(
          Placement(visible = true, transformation(origin = {-120, -172}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -280}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_HYD_W annotation(
          Placement(visible = true, transformation(origin = {110, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -220}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_SD_PNT_W annotation(
          Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.OilPump oilPump(Oil_Pump_Loss_Table_Filename = "OP.txt", Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {-6, -64}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Vehicle.Flywheel Flywheel(Jfw = 0.4) annotation(
          Placement(visible = true, transformation(origin = {-70, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Electrics.Actuator_eLoss actuator annotation(
          Placement(visible = true, transformation(origin = {-34, -124}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Electrics.EOP_eLoss eOP annotation(
          Placement(visible = true, transformation(origin = {-34, -150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.DCT_DS dct_ds(Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {34, 1.1}, extent = {{-26, -30.9}, {26, 30.9}}, rotation = 0)));
        Modelica.Blocks.Math.Add3 add3 annotation(
          Placement(visible = true, transformation(origin = {80, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Tc_K0 annotation(
          Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-18, 302}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput Tm_tgt annotation(
          Placement(visible = true, transformation(origin = {40, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {46, 302}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput Vm annotation(
          Placement(visible = true, transformation(origin = {12, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 90), iconTransformation(origin = {-40, -320}, extent = {{-20, -20}, {20, 20}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealOutput Im annotation(
          Placement(visible = true, transformation(origin = {70, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {40, -310}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput w_starting_device_input_radps annotation(
          Placement(visible = true, transformation(origin = {110, -150}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -280}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput mg_loss annotation(
          Placement(visible = true, transformation(origin = {52, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {22, -310}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput inv_loss annotation(
          Placement(visible = true, transformation(origin = {34, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {4, -310}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      equation
        connect(add3.y, Qf_HYD_W) annotation(
          Line(points = {{91, -110}, {110, -110}}, color = {0, 0, 127}));
        connect(oilPump.PHI_TM_PNT_OP_W, add3.u1) annotation(
          Line(points = {{6, -72}, {56, -72}, {56, -102}, {68, -102}}, color = {0, 0, 127}));
        connect(dct_ds.Qf_GB_PNT_W, Qf_GB_PNT_W) annotation(
          Line(points = {{61, -18}, {84, -18}, {84, -70}, {110, -70}}, color = {0, 0, 127}));
        connect(dct_ds.Qf_SD_PNT_W, Qf_SD_PNT_W) annotation(
          Line(points = {{61, -10}, {90, -10}, {90, -30}, {110, -30}}, color = {0, 0, 127}));
        connect(eOP.PHI_TM_PNT_EOP_W, add3.u3) annotation(
          Line(points = {{-23, -150}, {61.5, -150}, {61.5, -118}, {68, -118}}, color = {0, 0, 127}));
        connect(actuator.PHI_TM_PNT_Actuator_W, add3.u2) annotation(
          Line(points = {{-23, -124}, {57.5, -124}, {57.5, -110}, {68, -110}}, color = {0, 0, 127}));
        connect(dct_ds.tau_DS_PNT_out_Nm, tau_DS_PNT_out_Nm) annotation(
          Line(points = {{61, -3}, {80, -3}, {80, 0}, {110, 0}}, color = {0, 0, 127}));
        connect(dct_ds.w_synchro_dif_radps, w_synchro_dif_radps) annotation(
          Line(points = {{61, 13}, {94, 13}, {94, 50}, {110, 50}}, color = {0, 0, 127}, thickness = 0.5));
        connect(dct_ds.w_gearbox_output_radps, w_gearbox_output_radps) annotation(
          Line(points = {{61, 20}, {88, 20}, {88, 70}, {110, 70}}, color = {0, 0, 127}));
        connect(dct_ds.w_gearbox_input_radps, w_gearbox_input_radps) annotation(
          Line(points = {{61, 28}, {76, 28}, {76, 90}, {110, 90}}, color = {0, 0, 127}));
        connect(p_line_Pa, dct_ds.p_line_Pa) annotation(
          Line(points = {{-120, -94}, {-30, -94}, {-30, -18}, {5, -18}}, color = {0, 0, 127}));
        connect(ToutOil, dct_ds.ToutOil) annotation(
          Line(points = {{-120, -66}, {-34, -66}, {-34, -10}, {5, -10}}, color = {0, 0, 127}));
        connect(w_DS_PNT_out_radps, dct_ds.w_DS_PNT_out_radps) annotation(
          Line(points = {{-120, -40}, {-36, -40}, {-36, -3}, {5, -3}}, color = {0, 0, 127}));
        connect(p_line_Pa, oilPump.p_Line_Pa) annotation(
          Line(points = {{-120, -94}, {-26, -94}, {-26, -68}, {-17, -68}}, color = {0, 0, 127}));
        connect(Flywheel.w_TM_PNT_FW_radps, dct_ds.w_TM_PNT_FW_radps) annotation(
          Line(points = {{-58, 4}, {-24.5, 4}, {-24.5, 5}, {5, 5}}, color = {0, 0, 127}));
        connect(dct_ds.trq_TM_PNT_FW_Nm, Flywheel.trq_TM_PNT_FW_Nm) annotation(
          Line(points = {{61, 5}, {72, 5}, {72, -44}, {-48, -44}, {-48, -4}, {-58, -4}}, color = {0, 0, 127}));
        connect(oilPump.trq_DCT_PNT_Nm1, dct_ds.trq_DCT_PNT_Nm1) annotation(
          Line(points = {{-16, -62}, {-26, -62}, {-26, -26}, {5, -26}}, color = {0, 0, 127}));
        connect(dct_ds.w_DCT_PNT_radps1, oilPump.w_DCT_PNT_radps1) annotation(
          Line(points = {{61, -26}, {68, -26}, {68, -48}, {-24, -48}, {-24, -56}, {-18, -56}}, color = {0, 0, 127}));
        connect(nu_oil_m2ps, dct_ds.nu_oil_m2ps) annotation(
          Line(points = {{-120, 40}, {-40, 40}, {-40, 13}, {5, 13}}, color = {0, 0, 127}));
        connect(tau_clutch_cap, dct_ds.tau_clutch_cap) annotation(
          Line(points = {{-120, 70}, {-20, 70}, {-20, 29}, {5, 29}, {5, 28}}, color = {0, 0, 127}, thickness = 0.5));
        connect(f_synchro_n, dct_ds.f_synchro_n) annotation(
          Line(points = {{-120, 100}, {-30, 100}, {-30, 21}, {5, 21}}, color = {0, 0, 127}, thickness = 0.5));
        connect(nu_oil_m2ps, oilPump.nu_oil_m2ps) annotation(
          Line(points = {{-120, 40}, {-40, 40}, {-40, -72}, {-17, -72}}, color = {0, 0, 127}));
        connect(Flywheel.w_ENG_PNT_radps, w_ENG_PNT_radps) annotation(
          Line(points = {{-81, 4}, {-88, 4}, {-88, 46}, {82, 46}, {82, 28}, {110, 28}}, color = {0, 0, 127}));
        connect(trq_FW_PNT_in_Nm, Flywheel.trq_ENG_PNT_in_Nm) annotation(
          Line(points = {{-120, -4}, {-82, -4}}, color = {0, 0, 127}));
        connect(V_BT_PNT_Lo_V, actuator.V_BT_PNT_Lo_V) annotation(
          Line(points = {{-120, -172}, {-52, -172}, {-52, -128}, {-46, -128}}, color = {0, 0, 127}));
        connect(I_actuator_A, actuator.I_actuator_A) annotation(
          Line(points = {{-120, -120}, {-46, -120}}, color = {0, 0, 127}));
        connect(V_BT_PNT_Lo_V, eOP.V_BT_PNT_Lo_V) annotation(
          Line(points = {{-120, -172}, {-52, -172}, {-52, -154}, {-46, -154}}, color = {0, 0, 127}));
        connect(I_EOP_A, eOP.I_EOP_A) annotation(
          Line(points = {{-120, -146}, {-46, -146}}, color = {0, 0, 127}));
        connect(dct_ds.Tc_K0, Tc_K0) annotation(
          Line(points = {{13, 36}, {13, 86}, {0, 86}, {0, 120}}, color = {0, 0, 127}));
        connect(dct_ds.Tm_tgt, Tm_tgt) annotation(
          Line(points = {{21, 36}, {18, 36}, {18, 86}, {40, 86}, {40, 120}}, color = {0, 0, 127}));
        connect(Vm, dct_ds.Vm) annotation(
          Line(points = {{12, -180}, {12, -107}, {13, -107}, {13, -34}}, color = {0, 0, 127}));
        connect(dct_ds.Im, Im) annotation(
          Line(points = {{38, -32}, {38, -142}, {70, -142}, {70, -170}}, color = {0, 0, 127}));
        connect(dct_ds.w_starting_device_input_radps, w_starting_device_input_radps) annotation(
          Line(points = {{61, -34}, {64, -34}, {64, -150}, {110, -150}}, color = {0, 0, 127}));
        connect(dct_ds.mloss, mg_loss) annotation(
          Line(points = {{32, -32}, {32, -32}, {32, -146}, {54, -146}, {54, -170}, {52, -170}}, color = {0, 0, 127}));
        connect(dct_ds.iloss, inv_loss) annotation(
          Line(points = {{24, -32}, {26, -32}, {26, -156}, {34, -156}, {34, -170}, {34, -170}}, color = {0, 0, 127}));
        annotation(
          Diagram(coordinateSystem(extent = {{-100, -160}, {100, 100}}, initialScale = 0.1)),
          __OpenModelica_commandLineOptions = "",
          Icon(coordinateSystem(extent = {{-100, -300}, {100, 280}}, initialScale = 0.1), graphics = {Rectangle(origin = {0, -10}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 290}, {100, -290}}), Text(origin = {-4, -62}, lineColor = {0, 0, 255}, extent = {{-140, 26}, {140, -26}}, textString = "%name")}));
      end TransMission;

      model DCT_DS
        parameter Real Oil_Viscosity_Breakpoint[:];
        Modelica.Blocks.Interfaces.RealInput f_synchro_n[8] annotation(
          Placement(visible = true, transformation(origin = {-218, 98}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 102}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput tau_clutch_cap[2] annotation(
          Placement(visible = true, transformation(origin = {-218, 68}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_TM_PNT_FW_radps annotation(
          Placement(visible = true, transformation(origin = {-218, -2}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_DS_PNT_out_radps annotation(
          Placement(visible = true, transformation(origin = {-218, -42}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput trq_TM_PNT_FW_Nm annotation(
          Placement(visible = true, transformation(origin = {210, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput tau_DS_PNT_out_Nm annotation(
          Placement(visible = true, transformation(origin = {210, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_synchro_dif_radps[10] annotation(
          Placement(visible = true, transformation(origin = {210, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ToutOil annotation(
          Placement(visible = true, transformation(origin = {-218, -82}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput p_line_Pa annotation(
          Placement(visible = true, transformation(origin = {-218, -118}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
          Placement(visible = true, transformation(origin = {-218, 38}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_GB_PNT_W annotation(
          Placement(visible = true, transformation(origin = {210, -108}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_gearbox_input_radps annotation(
          Placement(visible = true, transformation(origin = {210, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_gearbox_output_radps annotation(
          Placement(visible = true, transformation(origin = {210, 72}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput trq_DCT_PNT_Nm1 annotation(
          Placement(visible = true, transformation(origin = {-218, -152}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-222, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_DCT_PNT_radps1 annotation(
          Placement(visible = true, transformation(origin = {210, -128}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_SD_PNT_W annotation(
          Placement(visible = true, transformation(origin = {210, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.DriveShaft driveShaft(Ids = 0.01, c = 1e4, d = 1e3) annotation(
          Placement(visible = true, transformation(origin = {146, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.DCT_PNT dCT_PNT(Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {58, -6}, extent = {{-20, -36}, {20, 30}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.ClutchSig clutchSig annotation(
          Placement(visible = true, transformation(origin = {-160, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.Vehicle.Flywheel RotorInertia(Jfw = 0.001) annotation(
          Placement(visible = true, transformation(origin = {-20, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Add add annotation(
          Placement(visible = true, transformation(origin = {-60, -18}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.HEVElectricElements.MotorGenerator motorGenerator annotation(
          Placement(visible = true, transformation(origin = {-106, -38}, extent = {{-18, -12}, {16, 12}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Tm_tgt annotation(
          Placement(visible = true, transformation(origin = {-100, 182}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-100, 182}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput Tc_K0 annotation(
          Placement(visible = true, transformation(origin = {-160, 182}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-160, 182}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput Vm annotation(
          Placement(visible = true, transformation(origin = {-160, -182}, extent = {{-20, -20}, {20, 20}}, rotation = 90), iconTransformation(origin = {-160, -182}, extent = {{-20, -20}, {20, 20}}, rotation = 90)));
        Modelica.Blocks.Interfaces.RealOutput Im annotation(
          Placement(visible = true, transformation(origin = {-6, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {28, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput w_starting_device_input_radps annotation(
          Placement(visible = true, transformation(origin = {212, -154}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput mloss annotation(
          Placement(visible = true, transformation(origin = {-38, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {-22, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput iloss annotation(
          Placement(visible = true, transformation(origin = {-66, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {-70, -170}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      equation
        connect(f_synchro_n, dCT_PNT.f_synchro_n) annotation(
          Line(points = {{-218, 98}, {58, 98}, {58, 26}}, color = {0, 0, 127}, thickness = 0.5));
        connect(tau_clutch_cap, dCT_PNT.tau_clutch_cap) annotation(
          Line(points = {{-218, 68}, {50, 68}, {50, 26}}, color = {0, 0, 127}, thickness = 0.5));
        connect(dCT_PNT.w_TM_PNT_DCT_radps, driveShaft.w_TM_PNT_DCT_radps) annotation(
          Line(points = {{80, -2}, {135, -2}}, color = {0, 0, 127}));
        connect(dCT_PNT.trq_TM_PNT_DCT_Nm, driveShaft.trq_TM_PNT_DCT_Nm) annotation(
          Line(points = {{79, -10}, {134, -10}}, color = {0, 0, 127}));
        connect(ToutOil, dCT_PNT.ToutOil) annotation(
          Line(points = {{-218, -82}, {0, -82}, {0, -42}, {36, -42}}, color = {0, 0, 127}));
        connect(nu_oil_m2ps, dCT_PNT.nu_oil_m2ps) annotation(
          Line(points = {{-218, 38}, {0, 38}, {0, -34}, {36, -34}}, color = {0, 0, 127}));
        connect(p_line_Pa, dCT_PNT.p_line_Pa) annotation(
          Line(points = {{-218, -118}, {10, -118}, {10, 18}, {36, 18}}, color = {0, 0, 127}));
        connect(dCT_PNT.Qf_GB_PNT_W, Qf_GB_PNT_W) annotation(
          Line(points = {{79, -38}, {134, -38}, {134, -108}, {210, -108}}, color = {0, 0, 127}));
        connect(dCT_PNT.Qf_SD_PNT_W, Qf_SD_PNT_W) annotation(
          Line(points = {{79, -30}, {142, -30}, {142, -78}, {210, -78}}, color = {0, 0, 127}));
        connect(dCT_PNT.w_synchro_dif_radps, w_synchro_dif_radps) annotation(
          Line(points = {{79, 18}, {120, 18}, {120, 52}, {210, 52}}, color = {0, 0, 127}, thickness = 0.5));
        connect(trq_DCT_PNT_Nm1, dCT_PNT.trq_TM_PNT_DCT_Nm1) annotation(
          Line(points = {{-218, -152}, {18, -152}, {18, -24}, {36, -24}}, color = {0, 0, 127}));
        connect(dCT_PNT.w_TM_PNT_DCT_radps1, w_DCT_PNT_radps1) annotation(
          Line(points = {{37, -16}, {26, -16}, {26, -128}, {210, -128}}, color = {0, 0, 127}));
        connect(driveShaft.w_TM_PNT_DCT_radps, w_gearbox_output_radps) annotation(
          Line(points = {{135, -2}, {112, -2}, {112, 72}, {210, 72}}, color = {0, 0, 127}));
        connect(driveShaft.tau_DS_PNT_out_Nm, tau_DS_PNT_out_Nm) annotation(
          Line(points = {{157, -10}, {210, -10}}, color = {0, 0, 127}));
        connect(w_DS_PNT_out_radps, driveShaft.w_DS_PNT_out_radps) annotation(
          Line(points = {{-218, -42}, {-194, -42}, {-194, 44}, {180, 44}, {180, -1}, {160, -1}, {160, -1.5}, {158, -1.5}, {158, -2}}, color = {0, 0, 127}));
        connect(w_TM_PNT_FW_radps, clutchSig.w1) annotation(
          Line(points = {{-218, -2}, {-172, -2}}, color = {0, 0, 127}));
        connect(trq_TM_PNT_FW_Nm, clutchSig.T1) annotation(
          Line(points = {{210, 30}, {-182, 30}, {-182, -10}, {-171, -10}}, color = {0, 0, 127}));
        connect(RotorInertia.w_ENG_PNT_radps, clutchSig.w2) annotation(
          Line(points = {{-31, -2}, {-148, -2}}, color = {0, 0, 127}));
        connect(RotorInertia.w_TM_PNT_FW_radps, dCT_PNT.w_TM_PNT_FW_radps) annotation(
          Line(points = {{-9, -2}, {36, -2}}, color = {0, 0, 127}));
        connect(dCT_PNT.trq_TM_PNT_FW_Nm, RotorInertia.trq_TM_PNT_FW_Nm) annotation(
          Line(points = {{37, -10}, {-8, -10}}, color = {0, 0, 127}));
        connect(clutchSig.T2, add.u1) annotation(
          Line(points = {{-149, -10}, {-72, -10}, {-72, -12}}, color = {0, 0, 127}));
        connect(add.y, RotorInertia.trq_ENG_PNT_in_Nm) annotation(
          Line(points = {{-49, -18}, {-40, -18}, {-40, -10}, {-32, -10}}, color = {0, 0, 127}));
        connect(motorGenerator.MotorTrq, add.u2) annotation(
          Line(points = {{-89, -32}, {-82, -32}, {-82, -24}, {-72, -24}}, color = {0, 0, 127}));
        connect(RotorInertia.w_ENG_PNT_radps, motorGenerator.MotorW) annotation(
          Line(points = {{-30, -2}, {-138, -2}, {-138, -38}, {-124, -38}, {-124, -38}}, color = {0, 0, 127}));
        connect(clutchSig.Tc, Tc_K0) annotation(
          Line(points = {{-160, 6}, {-160, 182}}, color = {0, 0, 127}));
        connect(motorGenerator.TargetTrq, Tm_tgt) annotation(
          Line(points = {{-124, -30}, {-130, -30}, {-130, 140}, {-100, 140}, {-100, 182}, {-100, 182}}, color = {0, 0, 127}));
        connect(Vm, motorGenerator.HiBatVol) annotation(
          Line(points = {{-160, -182}, {-160, -182}, {-160, -44}, {-124, -44}, {-124, -44}}, color = {0, 0, 127}));
        connect(motorGenerator.MotorCur, Im) annotation(
          Line(points = {{-88, -36}, {-6, -36}, {-6, -170}}, color = {0, 0, 127}));
        connect(RotorInertia.w_TM_PNT_FW_radps, w_starting_device_input_radps) annotation(
          Line(points = {{-8, -2}, {22, -2}, {22, -154}, {212, -154}, {212, -154}}, color = {0, 0, 127}));
        connect(w_gearbox_input_radps, RotorInertia.w_ENG_PNT_radps) annotation(
          Line(points = {{210, 92}, {-44, 92}, {-44, -2}, {-30, -2}}, arrowSize = 0.25));
        connect(motorGenerator.MotorLoss, mloss) annotation(
          Line(points = {{-88, -40}, {-38, -40}, {-38, -170}, {-38, -170}}, color = {0, 0, 127}));
        connect(motorGenerator.InverterLoss, iloss) annotation(
          Line(points = {{-88, -44}, {-64, -44}, {-64, -170}, {-66, -170}}, color = {0, 0, 127}));
        annotation(
          Diagram(coordinateSystem(extent = {{-200, -160}, {200, 160}}, preserveAspectRatio = false)),
          __OpenModelica_commandLineOptions = "",
          Icon(coordinateSystem(extent = {{-200, -160}, {200, 160}}, preserveAspectRatio = false, initialScale = 0.1), graphics = {Rectangle(origin = {0, -10}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-200, 170}, {200, -150}}), Text(origin = {-2, -90}, lineColor = {0, 0, 255}, extent = {{-140, 26}, {140, -26}}, textString = "%name")}));
      end DCT_DS;

      model DCT_PNT
        constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
        parameter Real Oil_Viscosity_Breakpoint[:];
        constant Real BRG_DummyLoad = 1000;
        Modelica.Mechanics.Rotational.Components.Inertia inertia_out(J = 0.01, phi(start = 0), w(start = 0)) annotation(
          Placement(visible = true, transformation(origin = {590, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Inertia inertia_odd(J = 0.01, phi(fixed = true, start = 0), w(fixed = true, start = 0)) annotation(
          Placement(visible = true, transformation(origin = {-40, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Inertia inertia_eve(J = 0.01, phi(fixed = true, start = 0), w(fixed = true, start = 0)) annotation(
          Placement(visible = true, transformation(origin = {-38, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Inertia inertia_in(J = 0.01, phi(start = 0), w(start = 0)) annotation(
          Placement(visible = true, transformation(origin = {-370, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Routing.DeMultiplex2 deMultiplex21(n1 = 1, n2 = 1) annotation(
          Placement(visible = true, transformation(origin = {-480, 110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Routing.DeMultiplex2 deMultiplex22(n1 = 5, n2 = 3) annotation(
          Placement(visible = true, transformation(origin = {-90, 244}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Routing.DeMultiplex5 deMultiplex51(n1 = 1, n2 = 1, n3 = 1, n4 = 1, n5 = 1) annotation(
          Placement(visible = true, transformation(origin = {-50, 250}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput f_synchro_n[8] annotation(
          Placement(visible = true, transformation(origin = {-160, 244}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {0, 320}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput tau_clutch_cap[2] annotation(
          Placement(visible = true, transformation(origin = {-520, 110}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-80, 320}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput p_line_Pa annotation(
          Placement(visible = true, transformation(origin = {-620, 90}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 240}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_TM_PNT_FW_radps annotation(
          Placement(visible = true, transformation(origin = {-688, 30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput trq_TM_PNT_DCT_Nm1 annotation(
          Placement(visible = true, transformation(origin = {-684, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
          Placement(visible = true, transformation(origin = {-620, 130}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -280}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_TM_PNT_DCT_radps annotation(
          Placement(visible = true, transformation(origin = {740, 4}, extent = {{20, -20}, {-20, 20}}, rotation = 0), iconTransformation(origin = {220, 40}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput ToutOil annotation(
          Placement(visible = true, transformation(origin = {-620, 170}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -360}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput trq_TM_PNT_DCT_Nm annotation(
          Placement(visible = true, transformation(origin = {730, -56}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput trq_TM_PNT_FW_Nm annotation(
          Placement(visible = true, transformation(origin = {-678, -30}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_TM_PNT_DCT_radps1 annotation(
          Placement(visible = true, transformation(origin = {-674, -120}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-210, -100}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_synchro_dif_radps[10] annotation(
          Placement(visible = true, transformation(origin = {590, 310}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 240}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Nonlinear.Limiter limiter1(limitsAtInit = true, uMax = 500, uMin = 0) annotation(
          Placement(visible = true, transformation(origin = {-400, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Nonlinear.Limiter limiter2(limitsAtInit = true, uMax = 500, uMin = 0) annotation(
          Placement(visible = true, transformation(origin = {-400, 130}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Routing.Multiplex5 multiplex51 annotation(
          Placement(visible = true, transformation(origin = {470, 330}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor1 annotation(
          Placement(visible = true, transformation(origin = {-370, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor2 annotation(
          Placement(visible = true, transformation(origin = {590, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Upper3(BRG_Friction_Filename = "N12.txt", Gear_Friction_Filename = "G1.txt", Gear_K_Filename = "G1K.txt", Gear_Ratio = 63 / 18, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG1.txt", SynchronizerLoss_Filename = "S1.txt") annotation(
          Placement(visible = true, transformation(origin = {250, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Upper7(BRG_Friction_Filename = "N5.txt", Gear_Friction_Filename = "G7.txt", Gear_K_Filename = "G7K.txt", Gear_Ratio = 1 / 1, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG7.txt", SynchronizerLoss_Filename = "S7.txt") annotation(
          Placement(visible = true, transformation(origin = {370, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Upper8(BRG_Friction_Filename = "N11.txt", Gear_Friction_Filename = "G4.txt", Gear_K_Filename = "G4K.txt", Gear_Ratio = 51 / 50, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG4.txt", SynchronizerLoss_Filename = "S4.txt") annotation(
          Placement(visible = true, transformation(origin = {130, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Upper6(BRG_Friction_Filename = "N2.txt", Gear_Friction_Filename = "Grev.txt", Gear_K_Filename = "GrevK.txt", Gear_Ratio = -63 / 22, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SGrev.txt", SynchronizerLoss_Filename = "Srev.txt") annotation(
          Placement(visible = true, transformation(origin = {10, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Lower4(BRG_Friction_Filename = "N10.txt", Gear_Friction_Filename = "G2.txt", Gear_K_Filename = "G2K.txt", Gear_Ratio = 61 / 22, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG2.txt", SynchronizerLoss_Filename = "S2.txt") annotation(
          Placement(visible = true, transformation(origin = {10, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Lower2(BRG_Friction_Filename = "N3.txt", Gear_Friction_Filename = "G6.txt", Gear_K_Filename = "G6K.txt", Gear_Ratio = 42 / 50, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG6.txt", SynchronizerLoss_Filename = "S6.txt") annotation(
          Placement(visible = true, transformation(origin = {130, -118}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Lower5(BRG_Friction_Filename = "N4.txt", Gear_Friction_Filename = "G5.txt", Gear_K_Filename = "G5K.txt", Gear_Ratio = 45 / 44, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG5.txt", SynchronizerLoss_Filename = "S5.txt") annotation(
          Placement(visible = true, transformation(origin = {370, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Gear_Synchro_Set_Lower gear_Synchro_Set_Lower1(BRG_Friction_Filename = "N13.txt", Gear_Friction_Filename = "G3.txt", Gear_K_Filename = "G3K.txt", Gear_Ratio = 50 / 27, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "SG3.txt", SynchronizerLoss_Filename = "S3.txt") annotation(
          Placement(visible = true, transformation(origin = {250, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Gear_wLoss gear_wLoss9(Gear_Friction_Filename = "G9.txt", Gear_K_Filename = "G9K.txt", Gear_Ratio = 75 / 20, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {470, 140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Gear_wLoss gear_wLoss10(Gear_Friction_Filename = "G10.txt", Gear_K_Filename = "G10K.txt", Gear_Ratio = 75 / 26, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {468, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Calc.Brg_Load_Distribution_T1T2 brg_Load_Distribution_T1T2(Y_1 = 1.594, Y_2 = 1.597, a_T1 = -73.806, a_T2 = -73.806, alpha_3 = 0.893617021, alpha_6 = 0.264989, alpha_7 = 0.553191489, alpha_9 = 0.125, b_T1 = 9809.4, b_T2 = 9809.4, beta_3 = -1, beta_6 = -1, beta_7 = -1, beta_9 = -1, gamma_3 = -0.269636831, gamma_6 = -0.23746, gamma_7 = -0.180364665, gamma_9 = 0.140865476, omega = 2.03437654) annotation(
          Placement(visible = true, transformation(origin = {480, 240}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Calc.Brg_Load_Distribution_T3T4 brg_Load_Distribution_T3T4(Y_3 = 1.711, Y_4 = 1.599, a_T3 = -79.911, a_T4 = -79.911, alpha_1 = 0.638297872, alpha_10 = 0.127659574, alpha_2 = 0.541666667, alpha_4 = 0.255319149, alpha_5 = 0.9375, b_T3 = 8598.2, b_T4 = 8598.2, beta_1 = -1, beta_10 = -1, beta_2 = -1, beta_4 = -1, beta_5 = -1, gamma_1 = -0.205775476, gamma_10 = 0.111123305, gamma_2 = -0.164059361, gamma_4 = -0.233416958, gamma_5 = -0.166101351, omega = 2.083375126) annotation(
          Placement(visible = true, transformation(origin = {490, -82}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Calc.Brg_Load_Distribution_T5T6 brg_Load_Distribution_T5T6(Y_5 = 1.418, Y_6 = 1.418, a_T5 = -52.914, a_T6 = -52.914, alpha_10 = 0.838709677, alpha_9 = 0.838709677, b_T5 = 5114.9, b_T6 = 5114.9, beta_10 = 1, beta_9 = 1, gamma_10 = -0.683819505, gamma_9 = -0.684085714, omega = 0.763564773) annotation(
          Placement(visible = true, transformation(origin = {480, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Calc.Brg_Load_Distribution_A1A2 brg_Load_Distribution_A1A2(Y_1 = 0.76, Y_2 = 0.76, a_A1 = 0, a_A2 = 0, alpha_1 = 0.558139535, alpha_2 = 0.465116279, alpha_3 = 0.837209302, alpha_4 = 0.139534884, alpha_5 = 0.906976744, alpha_6 = 0.112772, alpha_7 = 0.465116279, b_A1 = 0, b_A2 = 0, beta_1 = 1, beta_2 = 1, beta_3 = 1, beta_4 = 1, beta_5 = 1, beta_6 = 1, beta_7 = 1, gamma_1 = 0.154943084, gamma_2 = 0.168677923, gamma_3 = 0.085141139, gamma_4 = 0.124730302, gamma_5 = 0.166398492, gamma_6 = 0.242434, gamma_7 = 0.182717692, omega = 1.401868869) annotation(
          Placement(visible = true, transformation(origin = {-90, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder2(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {520, 244}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder3(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {508, 238}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder4(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {520, 230}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder5(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {524, -90}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder6(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {524, -78}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder7(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {512, -84}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Gear_wLoss gear_wLoss11(Gear_Friction_Filename = "G11.txt", Gear_K_Filename = "G11K.txt", Gear_Ratio = 1, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {-562, -144}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const29(k = BRG_DummyLoad) annotation(
          Placement(visible = true, transformation(origin = {-610, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle1(BRG_Friction_Filename = "N1.txt") annotation(
          Placement(visible = true, transformation(origin = {-580, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.OilSeal oilSeal1(OilSeal_friction_filename = "OS.txt") annotation(
          Placement(visible = true, transformation(origin = {-550, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.SealRing sealRing1(SealRing_friction_filename = "SR.txt") annotation(
          Placement(visible = true, transformation(origin = {-480, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.SealRing sealRing2(SealRing_friction_filename = "SR.txt") annotation(
          Placement(visible = true, transformation(origin = {-450, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Stirring2D stirringIP1(Stirring_Resistance_Filename = "IP1.txt") annotation(
          Placement(visible = true, transformation(origin = {-410, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_ThrustNeedle bRG_ThrustNeedle1(BRG_Friction_Filename = "SN1.txt") annotation(
          Placement(visible = true, transformation(origin = {-410, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const30(k = BRG_DummyLoad) annotation(
          Placement(visible = true, transformation(origin = {-450, -50}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Stirring3D Stirring3DCL2(Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "CL2.txt") annotation(
          Placement(visible = true, transformation(origin = {-280, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_ThrustNeedle bRG_ThrustNeedle2(BRG_Friction_Filename = "SN2.txt") annotation(
          Placement(visible = true, transformation(origin = {-280, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const32(k = BRG_DummyLoad) annotation(
          Placement(visible = true, transformation(origin = {-320, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_ThrustNeedle bRG_ThrustNeedle3(BRG_Friction_Filename = "SN3.txt") annotation(
          Placement(visible = true, transformation(origin = {-230, -74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Stirring3D Stirring3DCL1(Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, Stirring_Resistance_Filename = "CL1.txt") annotation(
          Placement(visible = true, transformation(origin = {-230, -34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const20(k = BRG_DummyLoad) annotation(
          Placement(visible = true, transformation(origin = {-274, -54}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle8(BRG_Friction_Filename = "N8.txt") annotation(
          Placement(visible = true, transformation(origin = {-180, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const6(k = BRG_DummyLoad) annotation(
          Placement(visible = true, transformation(origin = {-210, 100}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle9(BRG_Friction_Filename = "N9.txt") annotation(
          Placement(visible = true, transformation(origin = {-140, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle6(BRG_Friction_Filename = "N6.txt") annotation(
          Placement(visible = true, transformation(origin = {-150, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Angular bRG_Angular1(BRG_Friction_Filename = "A1.txt") annotation(
          Placement(visible = true, transformation(origin = {-70, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const27(k = BRG_DummyLoad) annotation(
          Placement(visible = true, transformation(origin = {-180, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Taper bRG_Taper1(BRG_Friction_Filename = "T1.txt") annotation(
          Placement(visible = true, transformation(origin = {-10, 180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Taper bRG_Taper2(BRG_Friction_Filename = "T2.txt") annotation(
          Placement(visible = true, transformation(origin = {518, 180}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Angular bRG_Angular2(BRG_Friction_Filename = "A2.txt") annotation(
          Placement(visible = true, transformation(origin = {370, 70}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Taper bRG_Taper3(BRG_Friction_Filename = "T3.txt") annotation(
          Placement(visible = true, transformation(origin = {-10, -190}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Taper bRG_Taper4(BRG_Friction_Filename = "T4.txt") annotation(
          Placement(visible = true, transformation(origin = {520, -190}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Taper bRG_Taper5(BRG_Friction_Filename = "T5.txt") annotation(
          Placement(visible = true, transformation(origin = {540, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_Taper bRG_Taper6(BRG_Friction_Filename = "T6.txt") annotation(
          Placement(visible = true, transformation(origin = {630, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.OilSeal oilSeal2(OilSeal_friction_filename = "OS.txt") annotation(
          Placement(visible = true, transformation(origin = {500, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.OilSeal oilSeal3(OilSeal_friction_filename = "OS.txt") annotation(
          Placement(visible = true, transformation(origin = {670, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Stirring2D stirringDF(Stirring_Resistance_Filename = "DF1.txt") annotation(
          Placement(visible = true, transformation(origin = {540, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle7(BRG_Friction_Filename = "N7.txt") annotation(
          Placement(visible = true, transformation(origin = {-110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Clutch clutch2 annotation(
          Placement(visible = true, transformation(origin = {-280, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Clutch clutch1 annotation(
          Placement(visible = true, transformation(origin = {-210, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression1(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-610, -14}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression2(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-528, -160}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression3(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-450, -76}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression4(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-320, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression5(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-220, 54}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression6(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-180, -120}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression7(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-26, -140}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression8(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-40, -196}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression9(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {434, -140}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression10(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {544, -210}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression11(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-34, 140}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression12(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {-40, 174}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression13(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {370, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression14(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {440, 140}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression15(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {540, 160}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression16(y = nu_oil_m2ps) annotation(
          Placement(visible = true, transformation(origin = {500, 10}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression17(y = ToutOil - 273.15) annotation(
          Placement(visible = true, transformation(origin = {-106, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression18(y = ToutOil - 273.15) annotation(
          Placement(visible = true, transformation(origin = {460, 260}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression19(y = ToutOil - 273.15) annotation(
          Placement(visible = true, transformation(origin = {474, -60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression20(y = ToutOil - 273.15) annotation(
          Placement(visible = true, transformation(origin = {464, 102}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Sources.RealExpression realExpression21(y = firstOrder_p_line_Pa.y) annotation(
          Placement(visible = true, transformation(origin = {-514, 26}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Routing.Multiplex5 multiplex52 annotation(
          Placement(visible = true, transformation(origin = {470, 304}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const(k = 0) annotation(
          Placement(visible = true, transformation(origin = {438, 350}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Routing.Multiplex2 multiplex21(n1 = 5, n2 = 5) annotation(
          Placement(visible = true, transformation(origin = {510, 310}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.TorqueToAngleAdaptor torqueToAngleAdaptor1(use_a = false, use_w = true) annotation(
          Placement(visible = true, transformation(origin = {-630, -150}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Routing.DeMultiplex3 deMultiplex31(n1 = 1, n2 = 1, n3 = 1) annotation(
          Placement(visible = true, transformation(origin = {-50, 220}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {508, 250}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder8(T = 0.05, k = 1, y(fixed = true)) annotation(
          Placement(visible = true, transformation(origin = {512, -72}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder_p_line_Pa(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-568, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_SD_PNT_W annotation(
          Placement(visible = true, transformation(origin = {-170, -240}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -240}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Qf_GB_PNT_W annotation(
          Placement(visible = true, transformation(origin = {684, -258}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, -320}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.AngleToTorqueAdaptor angleToTorqueAdaptor1(use_a = false, use_w = false) annotation(
          Placement(visible = true, transformation(origin = {-632, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.Integrator integrator1(initType = Modelica.Blocks.Types.Init.InitialState, k = 1, y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-654, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.AngleToTorqueAdaptor angleToTorqueAdaptor2(use_a = false, use_w = false) annotation(
          Placement(visible = true, transformation(origin = {650, -20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.Integrator integrator2(initType = Modelica.Blocks.Types.Init.InitialState, k = 1, y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {682, 4}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain1(k = -1) annotation(
          Placement(visible = true, transformation(origin = {-650, -180}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain2(k = -1) annotation(
          Placement(visible = true, transformation(origin = {-652, -30}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain3(k = -1) annotation(
          Placement(visible = true, transformation(origin = {688, -56}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum_GB_W3(nu = 20) annotation(
          Placement(visible = true, transformation(origin = {610, -220}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum_GB1(nu = 7) annotation(
          Placement(visible = true, transformation(origin = {-370, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum_GB_W2(nu = 5) annotation(
          Placement(visible = true, transformation(origin = {-60, -222}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum_SD_W(nu = 6) annotation(
          Placement(visible = true, transformation(origin = {-220, -168}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed annotation(
          Placement(visible = true, transformation(origin = {-428, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed1 annotation(
          Placement(visible = true, transformation(origin = {518, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed2 annotation(
          Placement(visible = true, transformation(origin = {-580, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed3 annotation(
          Placement(visible = true, transformation(origin = {-150, -126}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed4 annotation(
          Placement(visible = true, transformation(origin = {-110, -126}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed5 annotation(
          Placement(visible = true, transformation(origin = {540, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed6 annotation(
          Placement(visible = true, transformation(origin = {630, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed7 annotation(
          Placement(visible = true, transformation(origin = {-10, 160}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed8 annotation(
          Placement(visible = true, transformation(origin = {518, 160}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed9 annotation(
          Placement(visible = true, transformation(origin = {-10, -210}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed10 annotation(
          Placement(visible = true, transformation(origin = {520, -210}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed11 annotation(
          Placement(visible = true, transformation(origin = {-70, -120}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed12 annotation(
          Placement(visible = true, transformation(origin = {370, 50}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed13 annotation(
          Placement(visible = true, transformation(origin = {-480, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed14 annotation(
          Placement(visible = true, transformation(origin = {-450, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed15 annotation(
          Placement(visible = true, transformation(origin = {-550, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed16 annotation(
          Placement(visible = true, transformation(origin = {500, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed17 annotation(
          Placement(visible = true, transformation(origin = {670, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed18 annotation(
          Placement(visible = true, transformation(origin = {-430, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Add3 add3 annotation(
          Placement(visible = true, transformation(origin = {654, -258}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Sources.Constant const1(k = 0) annotation(
          Placement(visible = true, transformation(origin = {-98, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(bRG_RadialNeedle7.flange_b, bRG_Angular1.flange_a) annotation(
          Line(points = {{-98, -100}, {-80, -100}}));
        connect(const27.y, bRG_RadialNeedle7.Fr) annotation(
          Line(points = {{-174, -80}, {-108, -80}, {-108, -88}}, color = {0, 255, 0}));
        connect(const27.y, bRG_RadialNeedle7.Fth) annotation(
          Line(points = {{-174, -80}, {-128, -80}, {-128, -94}, {-120, -94}}, color = {0, 255, 0}));
        connect(realExpression6.y, bRG_RadialNeedle7.nu_oil_m2ps) annotation(
          Line(points = {{-174, -120}, {-128, -120}, {-128, -106}, {-120, -106}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle6.flange_b, bRG_RadialNeedle7.flange_a) annotation(
          Line(points = {{-140, -100}, {-118, -100}}));
        connect(realExpression6.y, bRG_RadialNeedle6.nu_oil_m2ps) annotation(
          Line(points = {{-174, -120}, {-168, -120}, {-168, -106}, {-162, -106}, {-162, -106}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle6.flange_a, clutch1.flange_b) annotation(
          Line(points = {{-160, -100}, {-200, -100}, {-200, -100}, {-200, -100}}));
        connect(const27.y, bRG_RadialNeedle6.Fth) annotation(
          Line(points = {{-173.4, -80}, {-167.4, -80}, {-167.4, -92}, {-161.4, -92}, {-161.4, -92}}, color = {0, 255, 0}));
        connect(const27.y, bRG_RadialNeedle6.Fr) annotation(
          Line(points = {{-173.4, -80}, {-151.4, -80}, {-151.4, -88}, {-151.4, -88}}, color = {0, 255, 0}));
        connect(trq_TM_PNT_DCT_Nm1, gain1.u) annotation(
          Line(points = {{-684, -180}, {-658, -180}, {-658, -180}, {-658, -180}}, color = {0, 0, 127}));
        connect(gain1.y, torqueToAngleAdaptor1.tau) annotation(
          Line(points = {{-643.4, -180}, {-639.4, -180}, {-639.4, -158}, {-633, -158}}, color = {0, 0, 127}));
        connect(torqueToAngleAdaptor1.flange, gear_wLoss11.flange_b) annotation(
          Line(points = {{-628, -150}, {-572, -150}}));
        connect(torqueToAngleAdaptor1.w, w_TM_PNT_DCT_radps1) annotation(
          Line(points = {{-633, -145}, {-641, -145}, {-641, -121}, {-673, -121}}, color = {0, 0, 127}));
        connect(realExpression2.y, gear_wLoss11.nu_oil_m2ps) annotation(
          Line(points = {{-521.4, -160}, {-515.4, -160}, {-515.4, -144}, {-549.4, -144}, {-549.4, -144}}, color = {0, 255, 0}));
        connect(oilSeal1.flange_b, gear_wLoss11.flange_a) annotation(
          Line(points = {{-540, 0}, {-520, 0}, {-520, -138}, {-552, -138}}));
        connect(bRG_RadialNeedle1.flange_b, oilSeal1.flange_a) annotation(
          Line(points = {{-572, 0}, {-562, 0}}));
        connect(const29.y, bRG_RadialNeedle1.Fr) annotation(
          Line(points = {{-605.4, 20}, {-582, 20}, {-582, 12}}, color = {0, 255, 0}));
        connect(const29.y, bRG_RadialNeedle1.Fth) annotation(
          Line(points = {{-605.4, 20}, {-599.4, 20}, {-599.4, 6}, {-594, 6}}, color = {0, 255, 0}));
        connect(realExpression1.y, bRG_RadialNeedle1.nu_oil_m2ps) annotation(
          Line(points = {{-604, -14}, {-600, -14}, {-600, -6}, {-594, -6}}, color = {0, 255, 0}));
        connect(angleToTorqueAdaptor1.flange, bRG_RadialNeedle1.flange_a) annotation(
          Line(points = {{-630, 0}, {-592, 0}}));
        connect(multiplex51.u3[1], gear_Synchro_Set_Lower2.w_synchro_dif_radps) annotation(
          Line(points = {{458, 330}, {150, 330}, {150, -112}, {141, -112}}, color = {0, 255, 0}));
        connect(f_synchro_n, deMultiplex22.u) annotation(
          Line(points = {{-158, 244}, {-100, 244}}, color = {0, 255, 0}));
        connect(gain3.y, trq_TM_PNT_DCT_Nm) annotation(
          Line(points = {{694, -56}, {722, -56}, {722, -56}, {730, -56}}, color = {0, 0, 127}));
        connect(angleToTorqueAdaptor2.tau, gain3.u) annotation(
          Line(points = {{653, -28}, {664, -28}, {664, -56}, {680, -56}}, color = {0, 0, 127}));
        connect(gain2.u, angleToTorqueAdaptor1.tau) annotation(
          Line(points = {{-644, -30}, {-640, -30}, {-640, -8}, {-634, -8}, {-634, -8}}, color = {0, 0, 127}));
        connect(trq_TM_PNT_FW_Nm, gain2.y) annotation(
          Line(points = {{-678, -30}, {-658, -30}, {-658, -30}, {-658, -30}}, color = {0, 0, 127}));
        connect(integrator2.y, angleToTorqueAdaptor2.phi) annotation(
          Line(points = {{676, 4}, {664, 4}, {664, -12}, {653, -12}}, color = {0, 0, 127}));
        connect(w_TM_PNT_DCT_radps, integrator2.u) annotation(
          Line(points = {{740, 4}, {690, 4}, {690, 4}, {690, 4}}, color = {0, 0, 127}));
        connect(angleToTorqueAdaptor2.flange, inertia_out.flange_b) annotation(
          Line(points = {{648, -20}, {608, -20}, {608, 40}, {600, 40}}));
        connect(integrator1.y, angleToTorqueAdaptor1.phi) annotation(
          Line(points = {{-648, 30}, {-642, 30}, {-642, 8}, {-636, 8}, {-636, 8}}, color = {0, 0, 127}));
        connect(w_TM_PNT_FW_radps, integrator1.u) annotation(
          Line(points = {{-688, 30}, {-662, 30}, {-662, 30}, {-662, 30}}, color = {0, 0, 127}));
        connect(deMultiplex22.y2, deMultiplex31.u) annotation(
          Line(points = {{-77, 238}, {-70, 238}, {-70, 220}, {-62, 220}}, color = {0, 255, 0}, thickness = 0.25));
        connect(deMultiplex22.y1, deMultiplex51.u) annotation(
          Line(points = {{-77, 250}, {-62, 250}}, color = {0, 255, 0}));
        connect(deMultiplex51.y1[1], gear_Synchro_Set_Upper8.f_synchro_n) annotation(
          Line(points = {{-39, 258}, {130, 258}, {130, 132}}, color = {0, 255, 0}));
        connect(deMultiplex51.y2[1], gear_Synchro_Set_Lower1.f_synchro_n) annotation(
          Line(points = {{-39, 254}, {300, 254}, {300, -90}, {250, -90}, {250, -108}}, color = {0, 255, 0}));
        connect(deMultiplex51.y3[1], gear_Synchro_Set_Lower2.f_synchro_n) annotation(
          Line(points = {{-39, 250}, {180, 250}, {180, -90}, {130, -90}, {130, -106}}, color = {0, 255, 0}));
        connect(deMultiplex51.y4[1], gear_Synchro_Set_Upper3.f_synchro_n) annotation(
          Line(points = {{-39, 246}, {250, 246}, {250, 132}}, color = {0, 255, 0}));
        connect(deMultiplex51.y5[1], gear_Synchro_Set_Lower4.f_synchro_n) annotation(
          Line(points = {{-39, 242}, {60, 242}, {60, -90}, {10, -90}, {10, -108}}, color = {0, 255, 0}));
        connect(deMultiplex31.y3[1], gear_Synchro_Set_Upper7.f_synchro_n) annotation(
          Line(points = {{-37, 213}, {370, 213}, {370, 132}}, color = {0, 255, 0}));
        connect(deMultiplex31.y2[1], gear_Synchro_Set_Upper6.f_synchro_n) annotation(
          Line(points = {{-37, 220}, {10, 220}, {10, 132}}, color = {0, 255, 0}));
        connect(deMultiplex31.y1[1], gear_Synchro_Set_Lower5.f_synchro_n) annotation(
          Line(points = {{-37, 227}, {420, 227}, {420, -88}, {370, -88}, {370, -108}}, color = {0, 255, 0}));
        connect(bRG_ThrustNeedle1.flange_b, sealRing2.flange_b) annotation(
          Line(points = {{-400, -70}, {-390, -70}, {-390, 0}, {-440, 0}, {-440, 0}}));
        connect(realExpression3.y, bRG_ThrustNeedle1.nu_oil_m2ps) annotation(
          Line(points = {{-444, -76}, {-422, -76}, {-422, -76}, {-422, -76}}, color = {0, 255, 0}));
        connect(const30.y, bRG_ThrustNeedle1.Fth) annotation(
          Line(points = {{-443.4, -50}, {-429.4, -50}, {-429.4, -62}, {-421.4, -62}, {-421.4, -62}, {-421.4, -62}, {-421.4, -62}}, color = {0, 255, 0}));
        connect(const30.y, bRG_ThrustNeedle1.Fr) annotation(
          Line(points = {{-443.4, -50}, {-412.4, -50}, {-412.4, -54}, {-412.4, -54}, {-412.4, -58}}, color = {0, 255, 0}));
        connect(stirringIP1.flange_b, sealRing2.flange_b) annotation(
          Line(points = {{-400, -30}, {-390, -30}, {-390, 0}, {-440, 0}}));
        connect(realExpression3.y, stirringIP1.nu_oil_m2ps) annotation(
          Line(points = {{-444, -76}, {-436, -76}, {-436, -22}, {-422, -22}}, color = {0, 255, 0}));
        connect(p_line_Pa, firstOrder_p_line_Pa.u) annotation(
          Line(points = {{-620, 90}, {-580, 90}, {-580, 90}, {-580, 90}}, color = {0, 255, 0}));
        connect(firstOrder8.y, bRG_Taper3.Fr) annotation(
          Line(points = {{516, -70}, {536, -70}, {536, -162}, {-12, -162}, {-12, -178}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T3T4.Fr_T3, firstOrder8.u) annotation(
          Line(points = {{501, -73}, {504, -73}, {504, -70}, {507, -70}}, color = {0, 255, 0}));
        connect(realExpression19.y, brg_Load_Distribution_T3T4.Toil) annotation(
          Line(points = {{480, -60}, {490, -60}, {490, -70}, {490, -70}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T3T4.Fth_T3, firstOrder7.u) annotation(
          Line(points = {{501, -85}, {503, -85}, {503, -85}, {505, -85}, {505, -85}, {506, -85}, {506, -85}, {507, -85}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T3T4.Fr_T4, firstOrder6.u) annotation(
          Line(points = {{501, -79}, {509, -79}, {509, -79}, {517, -79}, {517, -79}, {518, -79}, {518, -79}, {519, -79}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T3T4.Fth_T4, firstOrder5.u) annotation(
          Line(points = {{501, -91}, {509, -91}, {509, -91}, {517, -91}, {517, -91}, {518, -91}, {518, -91}, {519, -91}}, color = {0, 255, 0}));
        connect(gear_wLoss10.Gear_Load, brg_Load_Distribution_T3T4.G10) annotation(
          Line(points = {{479, -140}, {490, -140}, {490, -120}, {460, -120}, {460, -92}, {478, -92}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower5.Gear_Load, brg_Load_Distribution_T3T4.G5) annotation(
          Line(points = {{382, -120}, {440, -120}, {440, -87}, {478, -87}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower1.Gear_Load, brg_Load_Distribution_T3T4.G1) annotation(
          Line(points = {{262, -120}, {320, -120}, {320, -82}, {478, -82}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower2.Gear_Load, brg_Load_Distribution_T3T4.G2) annotation(
          Line(points = {{141, -118}, {200, -118}, {200, -77}, {478, -77}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower4.Gear_Load, brg_Load_Distribution_T3T4.G4) annotation(
          Line(points = {{21, -120}, {80, -120}, {80, -72}, {478, -72}}, color = {0, 255, 0}));
        connect(firstOrder1.y, bRG_Taper1.Fr) annotation(
          Line(points = {{512, 250}, {530, 250}, {530, 204}, {-12, 204}, {-12, 192}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T1T2.Fr_T1, firstOrder1.u) annotation(
          Line(points = {{491, 249}, {502, 249}}, color = {0, 255, 0}));
        connect(realExpression18.y, brg_Load_Distribution_T1T2.Toil) annotation(
          Line(points = {{466, 260}, {480, 260}, {480, 252}, {480, 252}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Upper6.Gear_Load, brg_Load_Distribution_T1T2.G6) annotation(
          Line(points = {{21, 120}, {40, 120}, {40, 248}, {468, 248}, {468, 249}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Upper3.Gear_Load, brg_Load_Distribution_T1T2.G3) annotation(
          Line(points = {{261, 120}, {280, 120}, {280, 243}, {468, 243}}, color = {0, 255, 0}));
        connect(gear_wLoss9.Gear_Load, brg_Load_Distribution_T1T2.G9) annotation(
          Line(points = {{482, 140}, {490, 140}, {490, 160}, {460, 160}, {460, 231}, {468, 231}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T1T2.Fth_T2, firstOrder4.u) annotation(
          Line(points = {{491, 231}, {503, 231}, {503, 233}, {516, 233}, {516, 230}, {515, 230}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T1T2.Fth_T1, firstOrder3.u) annotation(
          Line(points = {{491, 237}, {497, 237}, {497, 239}, {503, 239}, {503, 239}, {504, 239}, {504, 237}, {503, 237}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T1T2.Fr_T2, firstOrder2.u) annotation(
          Line(points = {{491, 243}, {502, 243}, {502, 245}, {513, 245}, {513, 245}, {515, 245}, {515, 243}, {515, 243}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T5T6.Fr_T5, bRG_Taper5.Fr) annotation(
          Line(points = {{492, 90}, {538, 90}, {538, 52}, {538, 52}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T5T6.Fr_T6, bRG_Taper6.Fr) annotation(
          Line(points = {{492, 84}, {632, 84}, {632, 52}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T5T6.Fth_T5, bRG_Taper5.Fth) annotation(
          Line(points = {{492, 78}, {522, 78}, {522, 48}, {528, 48}, {528, 48}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_T5T6.Fth_T6, bRG_Taper6.Fth) annotation(
          Line(points = {{492, 72}, {650, 72}, {650, 48}, {642, 48}}, color = {0, 255, 0}));
        connect(realExpression20.y, brg_Load_Distribution_T5T6.Toil) annotation(
          Line(points = {{470, 102}, {480, 102}, {480, 92}}, color = {0, 255, 0}));
        connect(gear_wLoss9.Gear_Load, brg_Load_Distribution_T5T6.G9) annotation(
          Line(points = {{482, 140}, {490, 140}, {490, 120}, {450, 120}, {450, 90}, {468, 90}}, color = {0, 255, 0}));
        connect(gear_wLoss10.Gear_Load, brg_Load_Distribution_T5T6.G10) annotation(
          Line(points = {{479, -140}, {490, -140}, {490, -120}, {460, -120}, {460, 86}, {468, 86}, {468, 85}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_A1A2.Fr_A1, bRG_Angular1.Fr) annotation(
          Line(points = {{-78, -10}, {-2, -10}, {-2, -72}, {-72, -72}, {-72, -88}, {-72, -88}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_A1A2.Fr_A2, bRG_Angular2.Fr) annotation(
          Line(points = {{-78, -16}, {392, -16}, {392, 88}, {372, 88}, {372, 82}, {372, 82}}, color = {0, 255, 0}));
        connect(brg_Load_Distribution_A1A2.Fth_A2, bRG_Angular2.Fth) annotation(
          Line(points = {{-78, -28}, {396, -28}, {396, 78}, {382, 78}, {382, 78}}, color = {0, 255, 0}));
        connect(realExpression17.y, brg_Load_Distribution_A1A2.Toil) annotation(
          Line(points = {{-100, 0}, {-90, 0}, {-90, -8}, {-90, -8}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower1.Gear_Load, brg_Load_Distribution_A1A2.G1) annotation(
          Line(points = {{262, -120}, {320, -120}, {320, -50}, {-116, -50}, {-116, -11}, {-102, -11}, {-102, -10}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower4.Gear_Load, brg_Load_Distribution_A1A2.G4) annotation(
          Line(points = {{21, -120}, {80, -120}, {80, -48}, {-108, -48}, {-108, -30}, {-102, -30}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Upper3.Gear_Load, brg_Load_Distribution_A1A2.G3) annotation(
          Line(points = {{261, 120}, {280, 120}, {280, -44}, {-112, -44}, {-112, -20}, {-102, -20}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower5.Gear_Load, brg_Load_Distribution_A1A2.G5) annotation(
          Line(points = {{382, -120}, {410, -120}, {410, -46}, {-114, -46}, {-114, -14.5}, {-102, -14.5}, {-102, -15}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Upper6.Gear_Load, brg_Load_Distribution_A1A2.G6) annotation(
          Line(points = {{21, 120}, {40, 120}, {40, -38}, {-90, -38}, {-90, -32}}, color = {0, 255, 0}));
        connect(gear_Synchro_Set_Lower2.Gear_Load, brg_Load_Distribution_A1A2.G2) annotation(
          Line(points = {{141, -118}, {200, -118}, {200, -40}, {-95, -40}, {-95, -32}}, color = {0, 255, 0}));
        connect(limiter2.y, clutch2.tau_clutch_cap) annotation(
          Line(points = {{-388, 130}, {-280, 130}, {-280, 82}, {-280, 82}}, color = {0, 255, 0}));
        connect(limiter1.y, clutch1.tau_clutch_cap) annotation(
          Line(points = {{-388, 90}, {-210, 90}, {-210, -88}, {-210, -88}}, color = {0, 255, 0}));
        connect(w_synchro_dif_radps, multiplex21.y) annotation(
          Line(points = {{590, 310}, {520, 310}, {520, 310}, {522, 310}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex21.u2, multiplex52.y) annotation(
          Line(points = {{500, 304}, {482, 304}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex21.u1, multiplex51.y) annotation(
          Line(points = {{500, 316}, {490, 316}, {490, 330}, {482, 330}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex52.u5[1], gear_Synchro_Set_Upper8.w_synchro_dif_radps) annotation(
          Line(points = {{458, 294}, {148, 294}, {148, 126}, {142, 126}, {142, 126}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex52.u4[1], const.y) annotation(
          Line(points = {{458, 300}, {450, 300}, {450, 350}, {445, 350}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex51.u1[1], const.y) annotation(
          Line(points = {{458, 340}, {451.5, 340}, {451.5, 350}, {445, 350}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex52.u3[1], gear_Synchro_Set_Upper7.w_synchro_dif_radps) annotation(
          Line(points = {{458, 304}, {390, 304}, {390, 126}, {382, 126}, {382, 126}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex52.u2[1], gear_Synchro_Set_Upper6.w_synchro_dif_radps) annotation(
          Line(points = {{458, 310}, {28, 310}, {28, 126}, {22, 126}, {22, 126}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex52.u1[1], gear_Synchro_Set_Lower5.w_synchro_dif_radps) annotation(
          Line(points = {{458, 314}, {404, 314}, {404, -114}, {382, -114}, {382, -114}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex51.u5[1], gear_Synchro_Set_Lower4.w_synchro_dif_radps) annotation(
          Line(points = {{458, 320}, {30, 320}, {30, -114}, {22, -114}, {22, -114}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex51.u4[1], gear_Synchro_Set_Upper3.w_synchro_dif_radps) annotation(
          Line(points = {{458, 326}, {268, 326}, {268, 126}, {262, 126}, {262, 126}}, color = {0, 255, 0}, thickness = 0.25));
        connect(multiplex51.u2[1], gear_Synchro_Set_Lower1.w_synchro_dif_radps) annotation(
          Line(points = {{458, 336}, {270, 336}, {270, -114}, {262, -114}, {262, -114}}, color = {0, 255, 0}, thickness = 0.25));
        connect(deMultiplex21.y1[1], limiter2.u) annotation(
          Line(points = {{-467, 116}, {-453, 116}, {-453, 130}, {-415, 130}}, color = {0, 255, 0}, thickness = 0.25));
        connect(deMultiplex21.y2[1], limiter1.u) annotation(
          Line(points = {{-467, 104}, {-453, 104}, {-453, 90}, {-415, 90}}, color = {0, 255, 0}, thickness = 0.25));
        connect(tau_clutch_cap, deMultiplex21.u) annotation(
          Line(points = {{-520, 110}, {-490, 110}}, color = {0, 255, 0}, thickness = 0.25));
        connect(realExpression21.y, sealRing2.p_line_Pa) annotation(
          Line(points = {{-508, 26}, {-470, 26}, {-470, 8}, {-462, 8}, {-462, 8}}, color = {0, 255, 0}));
        connect(realExpression21.y, sealRing1.p_line_Pa) annotation(
          Line(points = {{-508, 26}, {-500, 26}, {-500, 8}, {-492, 8}, {-492, 8}}, color = {0, 255, 0}));
        connect(realExpression16.y, bRG_Taper6.nu_oil_m2ps) annotation(
          Line(points = {{507, 10}, {648, 10}, {648, 34}, {642, 34}}, color = {0, 255, 0}));
        connect(realExpression16.y, stirringDF.nu_oil_m2ps) annotation(
          Line(points = {{507, 10}, {522, 10}, {522, -22}, {528, -22}}, color = {0, 255, 0}));
        connect(realExpression16.y, bRG_Taper5.nu_oil_m2ps) annotation(
          Line(points = {{507, 10}, {522, 10}, {522, 34}, {528, 34}}, color = {0, 255, 0}));
        connect(realExpression15.y, bRG_Taper2.nu_oil_m2ps) annotation(
          Line(points = {{546, 160}, {552, 160}, {552, 174}, {530, 174}, {530, 174}}, color = {0, 255, 0}));
        connect(realExpression14.y, gear_wLoss9.nu_oil_m2ps) annotation(
          Line(points = {{446, 140}, {458, 140}, {458, 140}, {458, 140}}, color = {0, 255, 0}));
        connect(realExpression13.y, bRG_Angular2.nu_oil_m2ps) annotation(
          Line(points = {{377, 30}, {388, 30}, {388, 64}, {382, 64}}, color = {0, 255, 0}));
        connect(realExpression12.y, bRG_Taper1.nu_oil_m2ps) annotation(
          Line(points = {{-34, 174}, {-24, 174}, {-24, 174}, {-22, 174}}, color = {0, 255, 0}));
        connect(realExpression11.y, gear_Synchro_Set_Upper8.nu_oil_m2ps) annotation(
          Line(points = {{-28, 140}, {106, 140}, {106, 120}, {118, 120}, {118, 120}}, color = {0, 255, 0}));
        connect(realExpression11.y, gear_Synchro_Set_Upper3.nu_oil_m2ps) annotation(
          Line(points = {{-28, 140}, {226, 140}, {226, 120}, {238, 120}, {238, 120}}, color = {0, 255, 0}));
        connect(realExpression11.y, gear_Synchro_Set_Upper7.nu_oil_m2ps) annotation(
          Line(points = {{-28, 140}, {346, 140}, {346, 120}, {358, 120}, {358, 120}}, color = {0, 255, 0}));
        connect(realExpression11.y, gear_Synchro_Set_Upper6.nu_oil_m2ps) annotation(
          Line(points = {{-28, 140}, {-14, 140}, {-14, 120}, {-2, 120}, {-2, 120}}, color = {0, 255, 0}));
        connect(realExpression10.y, bRG_Taper4.nu_oil_m2ps) annotation(
          Line(points = {{550, -210}, {556, -210}, {556, -196}, {532, -196}}, color = {0, 255, 0}));
        connect(realExpression9.y, gear_wLoss10.nu_oil_m2ps) annotation(
          Line(points = {{440, -140}, {456, -140}}, color = {0, 255, 0}));
        connect(realExpression8.y, bRG_Taper3.nu_oil_m2ps) annotation(
          Line(points = {{-34, -196}, {-24, -196}, {-24, -196}, {-22, -196}}, color = {0, 255, 0}));
        connect(realExpression7.y, gear_Synchro_Set_Lower1.nu_oil_m2ps) annotation(
          Line(points = {{-20, -140}, {230, -140}, {230, -120}, {238, -120}, {238, -120}}, color = {0, 255, 0}));
        connect(realExpression7.y, gear_Synchro_Set_Lower5.nu_oil_m2ps) annotation(
          Line(points = {{-20, -140}, {350, -140}, {350, -120}, {358, -120}, {358, -120}}, color = {0, 255, 0}));
        connect(realExpression7.y, gear_Synchro_Set_Lower4.nu_oil_m2ps) annotation(
          Line(points = {{-20, -140}, {-10, -140}, {-10, -120}, {-2, -120}, {-2, -120}}, color = {0, 255, 0}));
        connect(realExpression7.y, gear_Synchro_Set_Lower2.nu_oil_m2ps) annotation(
          Line(points = {{-20, -140}, {110, -140}, {110, -118}, {118, -118}}, color = {0, 255, 0}));
        connect(realExpression6.y, bRG_Angular1.nu_oil_m2ps) annotation(
          Line(points = {{-174, -120}, {-88, -120}, {-88, -106}, {-82, -106}, {-82, -106}}, color = {0, 255, 0}));
        connect(realExpression5.y, bRG_RadialNeedle8.nu_oil_m2ps) annotation(
          Line(points = {{-214, 54}, {-200, 54}, {-200, 64}, {-192, 64}}, color = {0, 255, 0}));
        connect(realExpression5.y, bRG_RadialNeedle9.nu_oil_m2ps) annotation(
          Line(points = {{-214, 54}, {-160, 54}, {-160, 64}, {-152, 64}, {-152, 64}}, color = {0, 255, 0}));
        connect(realExpression4.y, Stirring3DCL1.nu_oil_m2ps) annotation(
          Line(points = {{-314, -20}, {-254, -20}, {-254, -26}, {-242, -26}, {-242, -26}}, color = {0, 255, 0}));
        connect(realExpression4.y, bRG_ThrustNeedle3.nu_oil_m2ps) annotation(
          Line(points = {{-314, -20}, {-254, -20}, {-254, -80}, {-242, -80}, {-242, -80}}, color = {0, 255, 0}));
        connect(realExpression4.y, bRG_ThrustNeedle2.nu_oil_m2ps) annotation(
          Line(points = {{-314, -20}, {-306, -20}, {-306, -6}, {-292, -6}, {-292, -6}}, color = {0, 255, 0}));
        connect(realExpression4.y, Stirring3DCL2.nu_oil_m2ps) annotation(
          Line(points = {{-314, -20}, {-306, -20}, {-306, 48}, {-292, 48}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle9.support, clutch1.flange_b) annotation(
          Line(points = {{-140, 60}, {-140, 60}, {-140, 40}, {-180, 40}, {-180, -34}, {-192, -34}, {-192, -100}, {-200, -100}, {-200, -100}}));
        connect(bRG_ThrustNeedle3.flange_b, clutch1.flange_b) annotation(
          Line(points = {{-220, -74}, {-192, -74}, {-192, -100}, {-200, -100}, {-200, -100}}));
        connect(Stirring3DCL1.flange_b, clutch1.flange_b) annotation(
          Line(points = {{-220, -34}, {-192, -34}, {-192, -100}, {-200, -100}, {-200, -100}}));
        connect(bRG_RadialNeedle8.support, clutch1.flange_b) annotation(
          Line(points = {{-180, 60}, {-180, -34}, {-192, -34}, {-192, -100}, {-200, -100}}));
        connect(Stirring3DCL1.flange_a, inertia_in.flange_b) annotation(
          Line(points = {{-242, -34}, {-340, -34}, {-340, 0}, {-362, 0}}));
        connect(clutch1.flange_a, inertia_in.flange_b) annotation(
          Line(points = {{-220, -100}, {-340, -100}, {-340, 0}, {-360, 0}, {-360, 0}}));
        connect(bRG_ThrustNeedle3.flange_a, clutch2.flange_b) annotation(
          Line(points = {{-240, -74}, {-260, -74}, {-260, 70}, {-270, 70}, {-270, 70}}));
        connect(Stirring3DCL2.flange_b, clutch2.flange_b) annotation(
          Line(points = {{-270, 40}, {-260, 40}, {-260, 70}, {-270, 70}}));
        connect(bRG_ThrustNeedle2.flange_b, clutch2.flange_b) annotation(
          Line(points = {{-270, 0}, {-260, 0}, {-260, 70}, {-270, 70}}));
        connect(bRG_ThrustNeedle2.flange_a, clutch2.flange_a) annotation(
          Line(points = {{-290, 0}, {-340, 0}, {-340, 70}, {-290, 70}, {-290, 70}}));
        connect(Stirring3DCL2.flange_a, clutch2.flange_a) annotation(
          Line(points = {{-290, 40}, {-340, 40}, {-340, 70}, {-290, 70}}));
        connect(clutch2.flange_a, inertia_in.flange_b) annotation(
          Line(points = {{-290, 70}, {-340, 70}, {-340, 0}, {-360, 0}, {-360, 0}}));
        connect(bRG_RadialNeedle8.flange_a, clutch2.flange_b) annotation(
          Line(points = {{-190, 70}, {-270, 70}}));
        connect(sealRing1.flange_b, sealRing2.flange_a) annotation(
          Line(points = {{-470, 0}, {-460, 0}, {-460, 0}, {-460, 0}}));
        connect(const6.y, bRG_RadialNeedle9.Fth) annotation(
          Line(points = {{-203.4, 100}, {-159.4, 100}, {-159.4, 78}, {-151.4, 78}, {-151.4, 78}}, color = {0, 255, 0}));
        connect(const6.y, bRG_RadialNeedle9.Fr) annotation(
          Line(points = {{-203.4, 100}, {-141.4, 100}, {-141.4, 82}, {-141.4, 82}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle8.flange_b, bRG_RadialNeedle9.flange_a) annotation(
          Line(points = {{-170, 70}, {-150, 70}}));
        connect(bRG_RadialNeedle9.flange_b, inertia_odd.flange_a) annotation(
          Line(points = {{-132, 70}, {-50, 70}}));
        connect(const6.y, bRG_RadialNeedle8.Fr) annotation(
          Line(points = {{-203.4, 100}, {-182, 100}, {-182, 82}}, color = {0, 255, 0}));
        connect(const6.y, bRG_RadialNeedle8.Fth) annotation(
          Line(points = {{-203.4, 100}, {-197.4, 100}, {-197.4, 78}, {-192, 78}}, color = {0, 255, 0}));
        connect(const20.y, bRG_ThrustNeedle3.Fr) annotation(
          Line(points = {{-267.4, -54}, {-231.4, -54}, {-231.4, -62}}, color = {0, 255, 0}));
        connect(const32.y, bRG_ThrustNeedle2.Fr) annotation(
          Line(points = {{-313.4, 20}, {-281.4, 20}, {-281.4, 12}, {-281.4, 12}}, color = {0, 255, 0}));
        connect(const32.y, bRG_ThrustNeedle2.Fth) annotation(
          Line(points = {{-313.4, 20}, {-299.4, 20}, {-299.4, 8}, {-291.4, 8}, {-291.4, 8}}, color = {0, 255, 0}));
        connect(sealRing2.flange_b, inertia_in.flange_a) annotation(
          Line(points = {{-440, 0}, {-380, 0}}));
        connect(inertia_in.flange_a, speedSensor1.flange) annotation(
          Line(points = {{-382, 0}, {-382, 0}, {-382, 20}, {-382, 20}}));
        connect(sealRing1.flange_a, oilSeal1.flange_b) annotation(
          Line(points = {{-490, 0}, {-540, 0}, {-540, 0}, {-540, 0}}));
        connect(firstOrder3.y, bRG_Taper1.Fth) annotation(
          Line(points = {{512, 238}, {528, 238}, {528, 206}, {-30, 206}, {-30, 188}, {-22, 188}}, color = {0, 255, 0}));
        connect(bRG_Taper1.flange_b, gear_wLoss9.flange_a) annotation(
          Line(points = {{0, 180}, {450, 180}, {450, 146}, {460, 146}}));
        connect(firstOrder5.y, bRG_Taper4.Fth) annotation(
          Line(points = {{528, -90}, {542, -90}, {542, -182}, {532, -182}}, color = {0, 255, 0}));
        connect(firstOrder6.y, bRG_Taper4.Fr) annotation(
          Line(points = {{528, -78}, {540, -78}, {540, -170}, {522, -170}, {522, -178}}, color = {0, 255, 0}));
        connect(bRG_Taper4.flange_b, gear_wLoss10.flange_a) annotation(
          Line(points = {{510, -190}, {450, -190}, {450, -134}, {458, -134}}));
        connect(gear_Synchro_Set_Lower5.flange_b, gear_wLoss10.flange_a) annotation(
          Line(points = {{380, -126}, {390, -126}, {390, -190}, {450, -190}, {450, -134}, {458, -134}}));
        connect(gear_Synchro_Set_Lower1.flange_b, gear_wLoss10.flange_a) annotation(
          Line(points = {{260, -126}, {270, -126}, {270, -190}, {450, -190}, {450, -134}, {458, -134}}));
        connect(gear_Synchro_Set_Lower2.flange_b, gear_wLoss10.flange_a) annotation(
          Line(points = {{140, -124}, {150, -124}, {150, -190}, {450, -190}, {450, -134}, {458, -134}}));
        connect(firstOrder7.y, bRG_Taper3.Fth) annotation(
          Line(points = {{516, -84}, {534, -84}, {534, -160}, {-28, -160}, {-28, -182}, {-22, -182}}, color = {0, 255, 0}));
        connect(bRG_Taper3.flange_b, gear_wLoss10.flange_a) annotation(
          Line(points = {{0, -190}, {450, -190}, {450, -134}, {458, -134}}));
        connect(gear_Synchro_Set_Lower4.flange_b, gear_wLoss10.flange_a) annotation(
          Line(points = {{20, -126}, {30, -126}, {30, -190}, {450, -190}, {450, -134}, {458, -134}}));
        connect(stirringDF.flange_b, inertia_out.flange_a) annotation(
          Line(points = {{550, -30}, {560, -30}, {560, 40}, {580, 40}}));
        connect(bRG_Taper6.flange_a, oilSeal3.flange_b) annotation(
          Line(points = {{642, 40}, {660, 40}}));
        connect(inertia_out.flange_b, bRG_Taper6.flange_b) annotation(
          Line(points = {{600, 40}, {620, 40}}));
        connect(bRG_Taper5.flange_b, inertia_out.flange_a) annotation(
          Line(points = {{550, 40}, {580, 40}, {580, 40}, {580, 40}}));
        connect(oilSeal2.flange_b, bRG_Taper5.flange_a) annotation(
          Line(points = {{510, 40}, {530, 40}, {530, 40}, {530, 40}}));
        connect(firstOrder4.y, bRG_Taper2.Fth) annotation(
          Line(points = {{524, 230}, {536, 230}, {536, 188}, {530, 188}, {530, 188}}, color = {0, 255, 0}));
        connect(firstOrder2.y, bRG_Taper2.Fr) annotation(
          Line(points = {{524, 244}, {534, 244}, {534, 198}, {520, 198}, {520, 192}, {520, 192}}, color = {0, 255, 0}));
        connect(bRG_Taper2.flange_b, gear_wLoss9.flange_a) annotation(
          Line(points = {{508, 180}, {450, 180}, {450, 146}, {460, 146}}));
        connect(gear_wLoss10.flange_b, inertia_out.flange_a) annotation(
          Line(points = {{478, -146}, {560, -146}, {560, 40}, {580, 40}}));
        connect(gear_wLoss9.flange_b, inertia_out.flange_a) annotation(
          Line(points = {{480, 134}, {560, 134}, {560, 40}, {580, 40}}));
        connect(inertia_out.flange_a, speedSensor2.flange) annotation(
          Line(points = {{580, 40}, {580, 40}, {580, 40}, {580, 40}, {580, 60}, {581, 60}, {581, 60}, {580, 60}}));
        connect(gear_Synchro_Set_Upper8.flange_b, gear_wLoss9.flange_a) annotation(
          Line(points = {{140, 114}, {170, 114}, {170, 180}, {450, 180}, {450, 146}, {460, 146}}));
        connect(gear_Synchro_Set_Upper6.flange_b, gear_wLoss9.flange_a) annotation(
          Line(points = {{20, 114}, {50, 114}, {50, 180}, {450, 180}, {450, 146}, {460, 146}}));
        connect(inertia_odd.flange_b, gear_Synchro_Set_Lower5.flange_a) annotation(
          Line(points = {{-30, 70}, {350, 70}, {350, -114}, {360, -114}}, thickness = 0.5));
        connect(inertia_odd.flange_b, gear_Synchro_Set_Lower1.flange_a) annotation(
          Line(points = {{-30, 70}, {230, 70}, {230, -114}, {240, -114}}, thickness = 0.5));
        connect(gear_Synchro_Set_Lower4.flange_a, inertia_eve.flange_b) annotation(
          Line(points = {{0, -114}, {-10, -114}, {-10, -100}, {-28, -100}}));
        connect(inertia_eve.flange_b, gear_Synchro_Set_Lower2.flange_a) annotation(
          Line(points = {{-28, -100}, {110, -100}, {110, -112}, {120, -112}}));
        connect(inertia_odd.flange_b, bRG_Angular2.flange_b) annotation(
          Line(points = {{-30, 70}, {360, 70}}, thickness = 0.5));
        connect(inertia_odd.flange_b, gear_Synchro_Set_Upper7.flange_a) annotation(
          Line(points = {{-30, 70}, {350, 70}, {350, 126}, {360, 126}}, thickness = 0.5));
        connect(gear_Synchro_Set_Upper3.flange_a, inertia_odd.flange_b) annotation(
          Line(points = {{240, 126}, {230, 126}, {230, 70}, {-30, 70}}, thickness = 0.5));
        connect(inertia_eve.flange_b, gear_Synchro_Set_Upper8.flange_a) annotation(
          Line(points = {{-28, -100}, {110, -100}, {110, 126}, {120, 126}}));
        connect(inertia_eve.flange_b, gear_Synchro_Set_Upper6.flange_a) annotation(
          Line(points = {{-28, -100}, {-10, -100}, {-10, 126}, {0, 126}}));
        connect(gear_Synchro_Set_Upper3.flange_b, gear_wLoss9.flange_a) annotation(
          Line(points = {{260, 114}, {300, 114}, {300, 180}, {450, 180}, {450, 146}, {460, 146}}));
        connect(gear_Synchro_Set_Upper7.flange_b, gear_wLoss9.flange_a) annotation(
          Line(points = {{380, 114}, {410, 114}, {410, 180}, {450, 180}, {450, 146}, {460, 146}}));
        connect(bRG_Angular1.flange_b, inertia_eve.flange_a) annotation(
          Line(points = {{-60, -100}, {-48, -100}, {-48, -100}, {-48, -100}}));
/* -------------------------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------------------------- */
        connect(oilSeal2.PHI_W, multiSum_GB_W3.u[1]) annotation(
          Line(points = {{512, 32}, {516, 32}, {516, 0}, {580, 0}, {580, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(oilSeal3.PHI_W, multiSum_GB_W3.u[2]) annotation(
          Line(points = {{660, 32}, {654, 32}, {654, 0}, {580, 0}, {580, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_Taper4.PHI_W, multiSum_GB_W3.u[3]) annotation(
          Line(points = {{510, -198}, {500, -198}, {500, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_Taper3.PHI_W, multiSum_GB_W3.u[4]) annotation(
          Line(points = {{2, -198}, {500, -198}, {500, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_Taper5.PHI_W, multiSum_GB_W3.u[5]) annotation(
          Line(points = {{552, 32}, {556, 32}, {556, 0}, {580, 0}, {580, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_Taper6.PHI_W, multiSum_GB_W3.u[6]) annotation(
          Line(points = {{620, 32}, {614, 32}, {614, 0}, {580, 0}, {580, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_Taper2.PHI_W, multiSum_GB_W3.u[7]) annotation(
          Line(points = {{508, 172}, {500, 172}, {500, 112}, {440, 112}, {440, 0}, {580, 0}, {580, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_Taper1.PHI_W, multiSum_GB_W3.u[8]) annotation(
          Line(points = {{2, 172}, {70, 172}, {70, 90}, {440, 90}, {440, 0}, {580, 0}, {580, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(bRG_RadialNeedle1.PHI_W, multiSum_GB1.u[1]) annotation(
          Line(points = {{-568, -8}, {-566, -8}, {-566, -110}, {-380, -110}}, color = {191, 0, 0}));
        connect(oilSeal1.PHI_W, multiSum_GB1.u[2]) annotation(
          Line(points = {{-538, -8}, {-528, -8}, {-528, -110}, {-380, -110}, {-380, -110}}, color = {191, 0, 0}));
        connect(stirringIP1.PHI_W, multiSum_GB1.u[3]) annotation(
          Line(points = {{-399, -38}, {-394, -38}, {-394, -110}, {-380, -110}}, color = {191, 0, 0}));
        connect(bRG_RadialNeedle7.PHI_W, multiSum_GB_W2.u[1]) annotation(
          Line(points = {{-98, -108}, {-92, -108}, {-92, -222}, {-70, -222}}, color = {191, 0, 0}));
        connect(bRG_RadialNeedle6.PHI_W, multiSum_GB_W2.u[2]) annotation(
          Line(points = {{-138, -108}, {-134, -108}, {-134, -222}, {-70, -222}}, color = {191, 0, 0}));
        connect(bRG_RadialNeedle8.PHI_W, multiSum_GB_W2.u[3]) annotation(
          Line(points = {{-168, 62}, {-164, 62}, {-164, 46}, {-134, 46}, {-134, -222}, {-70, -222}, {-70, -222}}, color = {191, 0, 0}));
        connect(bRG_RadialNeedle9.PHI_W, multiSum_GB_W2.u[4]) annotation(
          Line(points = {{-128, 62}, {-122, 62}, {-122, 46}, {-134, 46}, {-134, -222}, {-70, -222}, {-70, -222}}, color = {191, 0, 0}));
        connect(multiSum_GB1.u[4], gear_wLoss11.PHI_W) annotation(
          Line(points = {{-380, -110}, {-506, -110}, {-506, -168}, {-580, -168}, {-580, -154}, {-572, -154}, {-572, -154}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[9], gear_wLoss9.PHI_W) annotation(
          Line(points = {{600, -220}, {580, -220}, {580, 0}, {440, 0}, {440, 112}, {486, 112}, {486, 130}, {482, 130}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[10], gear_wLoss10.PHI_W) annotation(
          Line(points = {{600, -220}, {500, -220}, {500, -198}, {488, -198}, {488, -150}, {479, -150}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[11], gear_Synchro_Set_Lower5.PHI_W) annotation(
          Line(points = {{600, -220}, {500, -220}, {500, -198}, {386, -198}, {386, -130}, {382, -130}, {382, -130}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[12], gear_Synchro_Set_Lower1.PHI_W) annotation(
          Line(points = {{600, -220}, {500, -220}, {500, -198}, {266, -198}, {266, -130}, {262, -130}, {262, -130}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[13], gear_Synchro_Set_Lower2.PHI_W) annotation(
          Line(points = {{600, -220}, {500, -220}, {500, -198}, {146, -198}, {146, -128}, {141, -128}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[14], gear_Synchro_Set_Lower4.PHI_W) annotation(
          Line(points = {{600, -220}, {500, -220}, {500, -198}, {26, -198}, {26, -130}, {22, -130}, {22, -130}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[15], gear_Synchro_Set_Upper7.PHI_W) annotation(
          Line(points = {{600, -220}, {580, -220}, {580, 0}, {440, 0}, {440, 90}, {384, 90}, {384, 110}, {382, 110}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[16], gear_Synchro_Set_Upper3.PHI_W) annotation(
          Line(points = {{600, -220}, {580, -220}, {580, 0}, {440, 0}, {440, 90}, {266, 90}, {266, 110}, {262, 110}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[17], gear_Synchro_Set_Upper8.PHI_W) annotation(
          Line(points = {{600, -220}, {580, -220}, {580, 0}, {440, 0}, {440, 90}, {144, 90}, {144, 110}, {142, 110}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[18], gear_Synchro_Set_Upper6.PHI_W) annotation(
          Line(points = {{600, -220}, {580, -220}, {580, 0}, {440, 0}, {440, 90}, {26, 90}, {26, 110}, {22, 110}}, color = {191, 0, 0}));
        connect(multiSum_SD_W.u[1], clutch2.PHI_W) annotation(
          Line(points = {{-230, -168}, {-264, -168}, {-264, 60}, {-268, 60}, {-268, 60}, {-268, 60}}, color = {191, 0, 0}));
        connect(multiSum_SD_W.u[2], clutch1.PHI_W) annotation(
          Line(points = {{-230, -168}, {-264, -168}, {-264, -124}, {-194, -124}, {-194, -110}, {-198, -110}, {-198, -110}}, color = {191, 0, 0}));
        connect(fixed.flange, stirringIP1.support) annotation(
          Line(points = {{-428, -30}, {-420, -30}, {-420, -30}, {-420, -30}}));
        connect(fixed1.flange, stirringDF.support) annotation(
          Line(points = {{518, -30}, {530, -30}, {530, -30}, {530, -30}}));
        connect(bRG_RadialNeedle1.support, fixed2.flange) annotation(
          Line(points = {{-580, -10}, {-580, -10}, {-580, -20}, {-580, -20}}));
        connect(bRG_RadialNeedle6.support, fixed3.flange) annotation(
          Line(points = {{-150, -110}, {-150, -110}, {-150, -126}, {-150, -126}}));
        connect(bRG_RadialNeedle7.support, fixed4.flange) annotation(
          Line(points = {{-110, -110}, {-110, -110}, {-110, -126}, {-110, -126}}));
        connect(bRG_Taper5.support, fixed5.flange) annotation(
          Line(points = {{540, 30}, {540, 30}, {540, 20}, {540, 20}}));
        connect(bRG_Taper6.support, fixed6.flange) annotation(
          Line(points = {{630, 30}, {630, 30}, {630, 20}, {630, 20}}));
        connect(bRG_Taper1.support, fixed7.flange) annotation(
          Line(points = {{-10, 170}, {-10, 170}, {-10, 160}, {-10, 160}}));
        connect(bRG_Taper2.support, fixed8.flange) annotation(
          Line(points = {{518, 170}, {518, 170}, {518, 160}, {518, 160}}));
        connect(bRG_Taper3.support, fixed9.flange) annotation(
          Line(points = {{-10, -200}, {-10, -200}, {-10, -210}, {-10, -210}}));
        connect(bRG_Taper4.support, fixed10.flange) annotation(
          Line(points = {{520, -200}, {520, -200}, {520, -210}, {520, -210}}));
        connect(bRG_Angular1.support, fixed11.flange) annotation(
          Line(points = {{-70, -110}, {-70, -110}, {-70, -120}, {-70, -120}}));
        connect(bRG_Angular2.support, fixed12.flange) annotation(
          Line(points = {{370, 60}, {370, 60}, {370, 50}, {370, 50}}));
        connect(multiSum_GB_W2.u[5], bRG_Angular1.PHI_W) annotation(
          Line(points = {{-70, -222}, {-92, -222}, {-92, -132}, {-54, -132}, {-54, -108}, {-58, -108}, {-58, -108}}, color = {191, 0, 0}));
        connect(bRG_Angular2.PHI_W, multiSum_GB_W3.u[19]) annotation(
          Line(points = {{360, 62}, {354, 62}, {354, 90}, {440, 90}, {440, 0}, {580, 0}, {580, -220}, {600, -220}, {600, -220}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.u[20], stirringDF.PHI_W) annotation(
          Line(points = {{600, -220}, {580, -220}, {580, -38}, {552, -38}, {552, -38}}, color = {191, 0, 0}));
        connect(sealRing1.PHI_W, multiSum_GB1.u[5]) annotation(
          Line(points = {{-468, -8}, {-464, -8}, {-464, -110}, {-380, -110}, {-380, -110}}, color = {191, 0, 0}));
        connect(sealRing2.PHI_W, multiSum_GB1.u[6]) annotation(
          Line(points = {{-438, -8}, {-394, -8}, {-394, -110}, {-380, -110}, {-380, -110}}, color = {191, 0, 0}));
        connect(sealRing1.support, fixed13.flange) annotation(
          Line(points = {{-480, -10}, {-480, -10}, {-480, -20}, {-480, -20}}));
        connect(sealRing2.support, fixed14.flange) annotation(
          Line(points = {{-450, -10}, {-450, -10}, {-450, -20}, {-450, -20}}));
        connect(oilSeal1.support, fixed15.flange) annotation(
          Line(points = {{-550, -10}, {-550, -10}, {-550, -20}, {-550, -20}}));
        connect(oilSeal2.support, fixed16.flange) annotation(
          Line(points = {{500, 30}, {500, 30}, {500, 20}, {500, 20}}));
        connect(oilSeal3.support, fixed17.flange) annotation(
          Line(points = {{670, 30}, {670, 30}, {670, 20}, {670, 20}}));
        connect(Stirring3DCL2.PHI_W, multiSum_SD_W.u[3]) annotation(
          Line(points = {{-269, 32}, {-264, 32}, {-264, -168}, {-230, -168}}, color = {191, 0, 0}));
        connect(Stirring3DCL1.PHI_W, multiSum_SD_W.u[4]) annotation(
          Line(points = {{-218, -42}, {-194, -42}, {-194, -124}, {-264, -124}, {-264, -168}, {-230, -168}, {-230, -168}}, color = {191, 0, 0}));
        connect(multiSum_SD_W.u[5], bRG_ThrustNeedle2.PHI_W) annotation(
          Line(points = {{-230, -168}, {-264, -168}, {-264, -8}, {-268, -8}, {-268, -8}}, color = {191, 0, 0}));
        connect(multiSum_SD_W.u[6], bRG_ThrustNeedle3.PHI_W) annotation(
          Line(points = {{-230, -168}, {-264, -168}, {-264, -124}, {-194, -124}, {-194, -82}, {-218, -82}, {-218, -82}}, color = {191, 0, 0}));
        connect(bRG_ThrustNeedle1.PHI_W, multiSum_GB1.u[7]) annotation(
          Line(points = {{-398, -78}, {-394, -78}, {-394, -110}, {-380, -110}, {-380, -110}}, color = {191, 0, 0}));
        connect(fixed18.flange, bRG_ThrustNeedle1.flange_a) annotation(
          Line(points = {{-430, -70}, {-420, -70}}));
        connect(multiSum_SD_W.y, Qf_SD_PNT_W) annotation(
          Line(points = {{-208, -168}, {-200, -168}, {-200, -240}, {-170, -240}, {-170, -240}}, color = {191, 0, 0}));
        connect(multiSum_GB1.y, add3.u3) annotation(
          Line(points = {{-358, -110}, {-348, -110}, {-348, -268}, {642, -268}, {642, -266}}, color = {191, 0, 0}));
        connect(multiSum_GB_W2.y, add3.u2) annotation(
          Line(points = {{-48, -222}, {-40, -222}, {-40, -258}, {642, -258}, {642, -258}}, color = {191, 0, 0}));
        connect(multiSum_GB_W3.y, add3.u1) annotation(
          Line(points = {{622, -220}, {630, -220}, {630, -250}, {642, -250}, {642, -250}}, color = {191, 0, 0}));
        connect(add3.y, Qf_GB_PNT_W) annotation(
          Line(points = {{666, -258}, {676, -258}, {676, -258}, {684, -258}}, color = {191, 0, 0}));
        connect(gear_Synchro_Set_Upper8.Gear_Load, brg_Load_Distribution_T1T2.G7) annotation(
          Line(points = {{142, 120}, {156.5, 120}, {156.5, 238}, {468, 238}}, color = {255, 0, 0}, thickness = 0.75));
        connect(brg_Load_Distribution_A1A2.G7, gear_Synchro_Set_Upper8.Gear_Load) annotation(
          Line(points = {{-102, -24}, {-109.5, -24}, {-109.5, -42}, {156, -42}, {156, 120}, {142, 120}}, color = {255, 0, 0}, thickness = 0.75));
        connect(brg_Load_Distribution_A1A2.Fth_A1, bRG_ThrustNeedle3.Fth) annotation(
          Line(points = {{-78, -22}, {-68, -22}, {-68, -56}, {-250, -56}, {-250, -66}, {-242, -66}}, color = {255, 0, 0}, thickness = 0.75));
        connect(const1.y, bRG_Angular1.Fth) annotation(
          Line(points = {{-92, -80}, {-88, -80}, {-88, -92}, {-82, -92}}, color = {255, 0, 0}, thickness = 0.75));
        annotation(
          experiment(StartTime = 0, StopTime = 88, Tolerance = 1e-06, Interval = 0.005),
          Diagram(coordinateSystem(extent = {{-700, -360}, {700, 300}}, initialScale = 0.1)),
          __OpenModelica_commandLineOptions = "",
          Icon(graphics = {Rectangle(origin = {0, 2}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 98}, {100, -102}}), Text(origin = {-19, -392}, lineColor = {0, 0, 255}, extent = {{-95, 24}, {105, -16}}, textString = "%name"), Text(origin = {-164, 368}, extent = {{-18, 2}, {82, -28}}, textString = "Clutch"), Text(origin = {32, 368}, extent = {{-18, 2}, {82, -28}}, textString = "Synchro"), Text(origin = {240, 274}, extent = {{-40, 12}, {42, -28}}, textString = "w_diff"), Line(origin = {-40, 60}, points = {{0, 20}, {0, -20}}), Line(origin = {-30, 60}, points = {{0, 20}, {0, -20}}), Line(origin = {-55, 0}, points = {{15, 60}, {-15, 60}, {-15, -60}, {15, -60}}), Line(origin = {-40, -60}, points = {{0, 20}, {0, -20}}), Line(origin = {-25.5789, -62.9474}, points = {{0, 20}, {0, -20}}), Line(origin = {-85, 0}, points = {{-15, 0}, {15, 0}, {15, 0}}), Line(origin = {45, 4}, points = {{-55, 0}, {55, 0}}), Line(origin = {0, 38}, points = {{-8, 0}, {8, 0}}), Line(origin = {0, -30}, points = {{-8, 0}, {8, 0}}), Line(origin = {0, 4}, points = {{0, 34}, {0, -34}}), Line(origin = {0, 40}, points = {{-8, 0}, {8, 0}}), Line(origin = {15, 60}, points = {{-45, 0}, {45, 0}}), Line(origin = {0, 80}, points = {{-8, 0}, {8, 0}, {8, 0}}), Line(origin = {0, 60}, points = {{0, -20}, {0, 20}}), Line(origin = {50, 84}, points = {{-8, 0}, {8, 0}, {8, 0}}), Line(origin = {50, 60}, points = {{0, -24}, {0, 24}}), Line(origin = {50, 36}, points = {{-8, 0}, {8, 0}}), Line(origin = {50, 8}, points = {{0, 26}, {0, -34}}), Line(origin = {50, 34}, points = {{-8, 0}, {8, 0}}), Line(origin = {50, -26}, points = {{-8, 0}, {8, 0}}), Line(origin = {50, -92}, points = {{-8, 0}, {8, 0}}), Line(origin = {50, -52}, points = {{0, -40}, {0, 24}}), Line(origin = {15, -60}, points = {{-45, 0}, {45, 0}}), Line(origin = {50, -28}, points = {{-8, 0}, {8, 0}, {8, 0}}), Line(origin = {0, -88}, points = {{-8, 0}, {8, 0}}), Line(origin = {-0.248295, -52}, points = {{0, -36}, {0, 20}}), Line(origin = {0, -32}, points = {{-8, 0}, {8, 0}, {8, 0}}), Text(origin = {-274, -230}, extent = {{-18, 2}, {82, -28}}, textString = "Oil_V"), Text(origin = {-276, 298}, extent = {{-18, 2}, {82, -28}}, textString = "Line_P"), Text(origin = {208, -284}, extent = {{-18, 2}, {82, -28}}, textString = "QfGB"), Text(origin = {-274, -310}, extent = {{-18, 2}, {82, -28}}, textString = "Oil_T"), Text(origin = {208, -202}, extent = {{-18, 2}, {82, -28}}, textString = "QfSD"), Rectangle(origin = {0, 1}, extent = {{-200, 299}, {200, -361}}), Text(origin = {-272, -130}, extent = {{4, 10}, {82, -28}}, textString = "T"), Text(origin = {-266, -68}, extent = {{4, 10}, {82, -28}}, textString = "w"), Text(origin = {-266, -4}, extent = {{4, 10}, {82, -28}}, textString = "T"), Text(origin = {-272, 88}, extent = {{4, 10}, {82, -28}}, textString = "w"), Text(origin = {176, 86}, extent = {{4, 10}, {82, -28}}, textString = "w"), Text(origin = {176, -8}, extent = {{4, 10}, {82, -28}}, textString = "T")}, coordinateSystem(extent = {{-200, -360}, {200, 300}}, initialScale = 0.1)));
      end DCT_PNT;

      model OilPump
        parameter String Oil_Pump_Loss_Table_Filename = "OP.txt";
        parameter Real Oil_Viscosity_Breakpoint[:];
        Modelica.Blocks.Math.Gain radps2rpm(k = 60 / (2 * Modelica.Constants.pi)) annotation(
          Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PHI_TM_PNT_OP_W annotation(
          Placement(visible = true, transformation(origin = {20, -110}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Product lossPower annotation(
          Placement(visible = true, transformation(origin = {80, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
          Placement(visible = true, transformation(origin = {-110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Utilities.CombiTable3D combiTable3D(filename = Oil_Pump_Loss_Table_Filename, z_ax = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {34, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        /* Table Input Angular Velocity unit [rpm]驍ｵ��ｲ��ｽ��ｽ��ｽOil Pressure unit [kPa] Oil Viscosity unit [mm^2/s]驍ｵ��ｲ��ｽ��ｽ��ｽ*/
        Modelica.Blocks.Interfaces.RealInput p_Line_Pa annotation(
          Placement(visible = true, transformation(origin = {-110, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Product lossTorque annotation(
          Placement(visible = true, transformation(origin = {30, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain1(k = -10) annotation(
          Placement(visible = true, transformation(origin = {-6, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_DCT_PNT_radps1 annotation(
          Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput trq_DCT_PNT_Nm1 annotation(
          Placement(visible = true, transformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, 20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Tanh tanh1 annotation(
          Placement(visible = true, transformation(origin = {30, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-36, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Gain Pa2kPa(k = 1 / 1000) annotation(
          Placement(visible = true, transformation(origin = {-74, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(Pa2kPa.y, firstOrder1.u) annotation(
          Line(points = {{-62, -40}, {-48, -40}, {-48, -40}, {-48, -40}}, color = {0, 0, 127}));
        connect(p_Line_Pa, Pa2kPa.u) annotation(
          Line(points = {{-110, -40}, {-86, -40}, {-86, -40}, {-86, -40}}, color = {0, 0, 127}));
        connect(nu_oil_m2ps, combiTable3D.u2) annotation(
          Line(points = {{-110, -80}, {-10, -80}, {-10, -48}, {22, -48}}, color = {0, 0, 127}));
        connect(firstOrder1.y, combiTable3D.u1) annotation(
          Line(points = {{-25, -40}, {22, -40}}, color = {0, 0, 127}));
        connect(tanh1.y, lossTorque.u1) annotation(
          Line(points = {{42, 58}, {50, 58}, {50, 26}, {42, 26}, {42, 26}}, color = {0, 0, 127}));
        connect(gain1.y, tanh1.u) annotation(
          Line(points = {{6, 58}, {18, 58}, {18, 58}, {18, 58}}, color = {0, 0, 127}));
        connect(w_DCT_PNT_radps1, gain1.u) annotation(
          Line(points = {{-120, 80}, {-34, 80}, {-34, 58}, {-18, 58}, {-18, 58}}, color = {0, 0, 127}));
        connect(w_DCT_PNT_radps1, radps2rpm.u) annotation(
          Line(points = {{-120, 80}, {-34, 80}, {-34, -20}, {-12, -20}, {-12, -20}}, color = {0, 0, 127}));
        connect(w_DCT_PNT_radps1, lossPower.u1) annotation(
          Line(points = {{-120, 80}, {62, 80}, {62, 26}, {68, 26}, {68, 26}}, color = {0, 0, 127}));
        connect(lossTorque.y, trq_DCT_PNT_Nm1) annotation(
          Line(points = {{20, 20}, {-102, 20}, {-102, 20}, {-110, 20}}, color = {0, 0, 127}));
        connect(radps2rpm.y, combiTable3D.u) annotation(
          Line(points = {{13, -20}, {15, -20}, {15, -32}, {19, -32}, {19, -32}, {21, -32}}, color = {0, 0, 127}));
        connect(combiTable3D.y, lossTorque.u2) annotation(
          Line(points = {{46, -40}, {54, -40}, {54, 14}, {42, 14}, {42, 14}}, color = {0, 0, 127}));
        connect(combiTable3D.y, lossPower.u2) annotation(
          Line(points = {{45, -40}, {54, -40}, {54, 14}, {68, 14}}, color = {0, 0, 127}));
        connect(lossPower.y, PHI_TM_PNT_OP_W) annotation(
          Line(points = {{91, 20}, {100, 20}, {100, -82}, {20, -82}, {20, -110}}, color = {0, 0, 127}));
        annotation(
          Icon(coordinateSystem(initialScale = 0.1), graphics = {Text(origin = {-2, 136}, lineColor = {0, 0, 255}, extent = {{-144, 24}, {144, -24}}, textString = "%name"), Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Ellipse(lineThickness = 0.75, extent = {{-60, 60}, {60, -60}}, endAngle = 360), Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 25}, {100, -25}}), Ellipse(lineColor = {255, 255, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-60, 60}, {60, -60}}, endAngle = 360), Line(origin = {-78, 11}, points = {{-15, -2}, {-9, 2}, {-3, 2}, {3, -2}, {9, -2}, {15, 2}}, thickness = 0.15), Line(origin = {78, 10}, points = {{-14, 0}, {14, 0}}, thickness = 0.15), Line(rotation = -12, points = {{0, 50}, {0, -50}}, color = {160, 160, 160}), Line(rotation = 21, points = {{0, 50}, {0, -50}}, color = {220, 220, 220}), Line(rotation = 111, points = {{0, 50}, {0, -50}}, color = {220, 220, 220}), Line(rotation = 156, points = {{0, 50}, {0, -50}}, color = {220, 220, 220}), Line(rotation = 66, points = {{0, 50}, {0, -50}}, color = {220, 220, 220}), Line(rotation = 33, points = {{0, 50}, {0, -50}}, color = {160, 160, 160}), Line(rotation = 78, points = {{0, 50}, {0, -50}}, color = {160, 160, 160}), Line(rotation = 123, points = {{0, 50}, {0, -50}}, color = {160, 160, 160}), Line(points = {{0, 50}, {0, -50}}), Line(rotation = 45, points = {{0, 50}, {0, -50}}), Line(rotation = 135, points = {{0, 50}, {0, -50}}), Line(rotation = 90, points = {{0, 50}, {0, -50}}), Ellipse(fillColor = {144, 144, 144}, fillPattern = FillPattern.Solid, extent = {{-20, 20}, {20, -20}}, endAngle = 360), Line(origin = {-78, 0}, points = {{-15, -2}, {-9, 2}, {-3, 2}, {3, -2}, {9, -2}, {15, 2}}, thickness = 0.15), Line(origin = {-78, -11}, points = {{-15, -2}, {-9, 2}, {-3, 2}, {3, -2}, {9, -2}, {15, 2}}, thickness = 0.15), Line(origin = {78, 0}, points = {{-14, 0}, {14, 0}}, thickness = 0.15), Line(origin = {78, -10}, points = {{-14, 0}, {14, 0}}, thickness = 0.15), Text(origin = {-123, -58}, extent = {{-31, 6}, {25, -12}}, textString = "Oil_V"), Text(origin = {-123, -16}, extent = {{-37, 6}, {25, -12}}, textString = "Line_P"), Text(origin = {-131, 40}, extent = {{-3, 12}, {25, -12}}, textString = "T"), Text(origin = {-131, 112}, extent = {{-3, 12}, {25, -12}}, textString = "w"), Text(origin = {105, -62}, extent = {{-3, 12}, {49, -12}}, textString = "QfOP")}),
          uses(Modelica(version = "3.2.2")));
      end OilPump;

      model DriveShaft
        parameter Modelica.SIunits.Inertia Ids = 0.01;
        parameter Modelica.SIunits.RotationalSpringConstant c = 1e4;
        parameter Modelica.SIunits.RotationalDampingConstant d = 1e3;
        Modelica.Mechanics.Rotational.Components.Inertia inertiaDS(J = Ids) annotation(
          Placement(visible = true, transformation(origin = {-30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput trq_TM_PNT_DCT_Nm annotation(
          Placement(visible = true, transformation(origin = {-120, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput w_TM_PNT_DCT_radps annotation(
          Placement(visible = true, transformation(origin = {-110, 30}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput tau_DS_PNT_out_Nm annotation(
          Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w_DS_PNT_out_radps annotation(
          Placement(visible = true, transformation(origin = {120, 30}, extent = {{20, -20}, {-20, 20}}, rotation = 0), iconTransformation(origin = {120, 40}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.SpringDamper springDamperDS(c = c, d = d, phi_rel(fixed = true, start = 0), w_rel(fixed = true, start = 0)) annotation(
          Placement(visible = true, transformation(origin = {20, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.TorqueToAngleAdaptor torqueToAngleAdaptor1(use_a = false, use_w = true) annotation(
          Placement(visible = true, transformation(origin = {-62, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.AngleToTorqueAdaptor angleToTorqueAdaptor1(use_a = false, use_w = false) annotation(
          Placement(visible = true, transformation(origin = {52, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.Integrator integrator1(initType = Modelica.Blocks.Types.Init.InitialState, k = 1, y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {80, 30}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain1(k = -1) annotation(
          Placement(visible = true, transformation(origin = {-84, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain2(k = -1) annotation(
          Placement(visible = true, transformation(origin = {82, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(gain2.y, tau_DS_PNT_out_Nm) annotation(
          Line(points = {{88, -30}, {102, -30}, {102, -30}, {110, -30}}, color = {0, 0, 127}));
        connect(angleToTorqueAdaptor1.tau, gain2.u) annotation(
          Line(points = {{56, -8}, {66, -8}, {66, -30}, {74, -30}, {74, -30}}, color = {0, 0, 127}));
        connect(gain1.y, torqueToAngleAdaptor1.tau) annotation(
          Line(points = {{-78, -30}, {-72, -30}, {-72, -8}, {-66, -8}, {-66, -8}}, color = {0, 0, 127}));
        connect(trq_TM_PNT_DCT_Nm, gain1.u) annotation(
          Line(points = {{-120, -30}, {-92, -30}, {-92, -30}, {-92, -30}}, color = {0, 0, 127}));
        connect(angleToTorqueAdaptor1.phi, integrator1.y) annotation(
          Line(points = {{56, 8}, {66, 8}, {66, 30}, {73, 30}}, color = {0, 0, 127}));
        connect(integrator1.u, w_DS_PNT_out_radps) annotation(
          Line(points = {{87, 30}, {120, 30}}, color = {0, 0, 127}));
        connect(springDamperDS.flange_b, angleToTorqueAdaptor1.flange) annotation(
          Line(points = {{30, 0}, {50, 0}, {50, 0}, {50, 0}}));
        connect(w_TM_PNT_DCT_radps, torqueToAngleAdaptor1.w) annotation(
          Line(points = {{-110, 30}, {-80, 30}, {-80, 4}, {-66, 4}, {-66, 4}}, color = {0, 0, 127}));
        connect(inertiaDS.flange_a, torqueToAngleAdaptor1.flange) annotation(
          Line(points = {{-40, 0}, {-60, 0}, {-60, 0}, {-60, 0}}));
        connect(springDamperDS.flange_a, inertiaDS.flange_b) annotation(
          Line(points = {{10, 0}, {-20, 0}}));
        annotation(
          Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {0, -127}, lineColor = {0, 0, 255}, extent = {{-120, 17}, {120, -33}}, textString = "%name"), Line(points = {{-100, 0}, {-59, 0}}), Line(points = {{59, 0}, {100, 0}}), Ellipse(origin = {-40, 0}, lineThickness = 0.75, extent = {{-24, 24}, {24, -24}}, startAngle = 90, endAngle = 270), Ellipse(origin = {-40, 0}, lineColor = {255, 255, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-24, 24}, {24, -24}}, endAngle = 360), Ellipse(origin = {40, 0}, lineThickness = 0.75, extent = {{-24, 24}, {24, -24}}, startAngle = -90, endAngle = 90), Ellipse(origin = {40, 0}, lineColor = {255, 255, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-24, 24}, {24, -24}}, endAngle = 360), Line(points = {{-40, 0}, {40, 0}}), Ellipse(origin = {-40, 0}, fillColor = {161, 161, 161}, fillPattern = FillPattern.Solid, extent = {{-6, 6}, {6, -6}}, endAngle = 360), Ellipse(origin = {40, 0}, fillColor = {161, 161, 161}, fillPattern = FillPattern.Solid, extent = {{-6, 6}, {6, -6}}, endAngle = 360), Text(origin = {-127, -1}, extent = {{-27, 23}, {27, -23}}, textString = "T"), Text(origin = {-123, 69}, extent = {{-27, 23}, {27, -23}}, textString = "w"), Text(origin = {121, 79}, extent = {{-27, 23}, {27, -23}}, textString = "w"), Text(origin = {117, -11}, extent = {{-27, 23}, {27, -23}}, textString = "T")}, coordinateSystem(initialScale = 0.1)));
      end DriveShaft;

      model Gear_Synchro_Set_Upper
        parameter Real Gear_Ratio;
        parameter String Gear_Friction_Filename;
        parameter String BRG_Friction_Filename;
        parameter String SynchronizerLoss_Filename;
        parameter Real Oil_Viscosity_Breakpoint[:];
        /*[:] = {8.6e-6, 1.1e-5, 1.7e-5, 3.1e-5, 6.5e-5}*/
        parameter String Gear_K_Filename;
        constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
        constant Real T_const = 0.001;
        Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
          Placement(visible = true, transformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
          Placement(visible = true, transformation(origin = {100, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
          Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput f_synchro_n annotation(
          Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput w_synchro_dif_radps annotation(
          Placement(visible = true, transformation(origin = {110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Gear_Load[3] annotation(
          Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle(BRG_Friction_Filename = BRG_Friction_Filename) annotation(
          Placement(visible = true, transformation(origin = {52, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Synchronizer synchronizer(Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, SynchroninzerLoss_Filename = SynchronizerLoss_Filename) annotation(
          Placement(visible = true, transformation(origin = {0, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
          Placement(visible = true, transformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Gear_wLoss gear_wLoss(Gear_Friction_Filename = Gear_Friction_Filename, Gear_K_Filename = Gear_K_Filename, Gear_Ratio = Gear_Ratio, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {-54, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum(nu = 3) annotation(
          Placement(visible = true, transformation(origin = {80, -100}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor annotation(
          Placement(visible = true, transformation(origin = {16, 32}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain(k = -1) annotation(
          Placement(visible = true, transformation(origin = {76, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(gain.y, w_synchro_dif_radps) annotation(
          Line(points = {{82, 60}, {102, 60}, {102, 60}, {110, 60}}, color = {0, 255, 0}));
        connect(relSpeedSensor.w_rel, gain.u) annotation(
          Line(points = {{16, 26}, {16, 26}, {16, 20}, {52, 20}, {52, 60}, {68, 60}, {68, 60}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle.flange_a, relSpeedSensor.flange_b) annotation(
          Line(points = {{46, 0}, {34, 0}, {34, 32}, {22, 32}, {22, 32}}));
        connect(gear_wLoss.flange_b, relSpeedSensor.flange_a) annotation(
          Line(points = {{-48, 0}, {-24, 0}, {-24, 32}, {10, 32}, {10, 32}, {10, 32}}));
        connect(multiSum.u[3], gear_wLoss.PHI_W) annotation(
          Line(points = {{74, -100}, {66, -100}, {66, -28}, {-44, -28}, {-44, -2}, {-48, -2}, {-48, -2}}, color = {191, 0, 0}, thickness = 0.25));
        connect(gear_wLoss.Gear_Load[2], bRG_RadialNeedle.Fth) annotation(
          Line(points = {{-48, 4}, {-40, 4}, {-40, 14}, {40, 14}, {40, 4}, {44, 4}, {44, 4}}, color = {0, 255, 0}, thickness = 0.25));
        connect(gear_wLoss.Gear_Load[1], bRG_RadialNeedle.Fr) annotation(
          Line(points = {{-48, 4}, {-40, 4}, {-40, 14}, {52, 14}, {52, 8}, {50, 8}}, color = {0, 255, 0}, thickness = 0.25));
        connect(gear_wLoss.Gear_Load, Gear_Load) annotation(
          Line(points = {{-48, 4}, {-40, 4}, {-40, 14}, {90, 14}, {90, 0}, {110, 0}, {110, 0}}, color = {0, 255, 0}, thickness = 0.25));
        connect(bRG_RadialNeedle.flange_b, flange_b) annotation(
          Line(points = {{58, 0}, {76, 0}, {76, -60}, {100, -60}}));
        connect(nu_oil_m2ps, bRG_RadialNeedle.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-96, 0}, {-96, -16}, {40, -16}, {40, -4}, {45, -4}}, color = {0, 255, 0}));
        connect(synchronizer.flange_b, bRG_RadialNeedle.flange_a) annotation(
          Line(points = {{6, 0}, {46, 0}}));
        connect(f_synchro_n, synchronizer.f_synchro_n) annotation(
          Line(points = {{0, 120}, {0, 7}}, color = {0, 255, 0}));
        connect(nu_oil_m2ps, synchronizer.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-96, 0}, {-96, -16}, {-20, -16}, {-20, 5}, {-7, 5}}, color = {0, 255, 0}));
        connect(nu_oil_m2ps, gear_wLoss.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-96, 0}, {-96, 4}, {-62, 4}, {-62, 4}}, color = {0, 255, 0}));
        connect(flange_a, gear_wLoss.flange_a) annotation(
          Line(points = {{-100, 60}, {-68, 60}, {-68, 8}, {-60, 8}, {-60, 8}}));
        connect(gear_wLoss.flange_b, synchronizer.flange_a) annotation(
          Line(points = {{-48, 0}, {-6, 0}}));
        connect(multiSum.y, PHI_W) annotation(
          Line(points = {{88, -100}, {102, -100}, {102, -100}, {110, -100}}, color = {191, 0, 0}));
        connect(multiSum.u[1], bRG_RadialNeedle.PHI_W) annotation(
          Line(points = {{74, -100}, {66, -100}, {66, -4}, {58, -4}}, color = {191, 0, 0}));
        connect(bRG_RadialNeedle.support, gear_wLoss.flange_b) annotation(
          Line(points = {{52, -6}, {52, -6}, {52, -20}, {-28, -20}, {-28, 0}, {-48, 0}, {-48, 0}}));
        connect(synchronizer.PHI_W, multiSum.u[2]) annotation(
          Line(points = {{6, -6}, {12, -6}, {12, -28}, {66, -28}, {66, -100}, {74, -100}}, color = {191, 0, 0}));
        annotation(
          Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {0, -134}, lineColor = {0, 0, 255}, extent = {{-140, 26}, {140, -26}}, textString = "%name"), Text(origin = {0, 40}, extent = {{-100, 40}, {100, -10}}, textString = "Gear"), Text(origin = {0, -10}, extent = {{-100, 40}, {100, -10}}, textString = "and"), Text(origin = {0, -60}, extent = {{-100, 40}, {100, -10}}, textString = "Synchro")}, coordinateSystem(initialScale = 0.1)),
          uses(Modelica(version = "3.2.2")));
      end Gear_Synchro_Set_Upper;

      model Gear_Synchro_Set_Lower
        parameter Real Gear_Ratio;
        parameter String Gear_Friction_Filename;
        parameter String BRG_Friction_Filename;
        parameter String SynchronizerLoss_Filename;
        parameter String Stirring_Resistance_Filename;
        parameter Real Oil_Viscosity_Breakpoint[:];
        parameter String Gear_K_Filename;
        constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
        Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
          Placement(visible = true, transformation(origin = {100, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
          Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput f_synchro_n annotation(
          Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealOutput w_synchro_dif_radps annotation(
          Placement(visible = true, transformation(origin = {110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput Gear_Load[3] annotation(
          Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
          Placement(visible = true, transformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.BRG_RadialNeedle bRG_RadialNeedle(BRG_Friction_Filename = BRG_Friction_Filename) annotation(
          Placement(visible = true, transformation(origin = {50, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Stirring2D stirring2D(Stirring_Resistance_Filename = Stirring_Resistance_Filename) annotation(
          Placement(visible = true, transformation(origin = {-42, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Synchronizer synchronizer1(Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint, SynchroninzerLoss_Filename = SynchronizerLoss_Filename) annotation(
          Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
          Placement(visible = true, transformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.MultiSum multiSum(nu = 4) annotation(
          Placement(visible = true, transformation(origin = {80, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        TRAMI_L3_HEV.TransMission.Mechanics.Elements.Gear_wLoss gear_wLoss(Gear_Friction_Filename = Gear_Friction_Filename, Gear_K_Filename = Gear_K_Filename, Gear_Ratio = Gear_Ratio, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
          Placement(visible = true, transformation(origin = {-50, 6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Components.Fixed fixed annotation(
          Placement(visible = true, transformation(origin = {-64, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain1(k = -1) annotation(
          Placement(visible = true, transformation(origin = {74, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
          Placement(visible = true, transformation(origin = {16, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      equation
        connect(gain1.y, w_synchro_dif_radps) annotation(
          Line(points = {{86, 60}, {104, 60}, {104, 60}, {110, 60}}, color = {0, 255, 0}));
        connect(relSpeedSensor1.w_rel, gain1.u) annotation(
          Line(points = {{16, 28}, {16, 28}, {16, 24}, {48, 24}, {48, 60}, {62, 60}, {62, 60}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle.flange_a, relSpeedSensor1.flange_b) annotation(
          Line(points = {{40, 0}, {26, 0}, {26, 40}, {26, 40}}));
        connect(gear_wLoss.flange_b, relSpeedSensor1.flange_a) annotation(
          Line(points = {{-40, 0}, {-20, 0}, {-20, 40}, {6, 40}}));
        connect(f_synchro_n, synchronizer1.f_synchro_n) annotation(
          Line(points = {{0, 120}, {0, 12}}, color = {0, 255, 0}));
        connect(nu_oil_m2ps, synchronizer1.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-94, 0}, {-94, -16}, {-16, -16}, {-16, 8}, {-12, 8}}, color = {0, 255, 0}));
        connect(synchronizer1.flange_b, bRG_RadialNeedle.flange_a) annotation(
          Line(points = {{10, 0}, {40, 0}}));
        connect(nu_oil_m2ps, stirring2D.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-94, 0}, {-94, 48}, {-54, 48}}, color = {0, 255, 0}));
        connect(nu_oil_m2ps, bRG_RadialNeedle.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-94, 0}, {-94, -16}, {28, -16}, {28, -5}, {38, -5}, {38, -6}}, color = {0, 255, 0}));
        connect(bRG_RadialNeedle.flange_b, flange_b) annotation(
          Line(points = {{60, 0}, {90, 0}, {90, -60}, {100, -60}}));
        connect(PHI_W, multiSum.y) annotation(
          Line(points = {{110, -100}, {92, -100}, {92, -100}, {92, -100}}, color = {191, 0, 0}));
        connect(multiSum.u[1], bRG_RadialNeedle.PHI_W) annotation(
          Line(points = {{70, -100}, {66, -100}, {66, -8}, {61, -8}}, color = {191, 0, 0}));
        connect(multiSum.u[2], stirring2D.PHI_W) annotation(
          Line(points = {{70, -100}, {66, -100}, {66, -28}, {-24, -28}, {-24, 32}, {-31, 32}}, color = {191, 0, 0}));
        connect(stirring2D.flange_b, synchronizer1.flange_a) annotation(
          Line(points = {{-32, 40}, {-20, 40}, {-20, 0}, {-10, 0}}));
        connect(bRG_RadialNeedle.support, synchronizer1.flange_a) annotation(
          Line(points = {{50, -10}, {50, -22}, {-20, -22}, {-20, 0}, {-10, 0}}));
        connect(gear_wLoss.flange_b, synchronizer1.flange_a) annotation(
          Line(points = {{-40, 0}, {-10, 0}}));
        connect(flange_a, gear_wLoss.flange_a) annotation(
          Line(points = {{-100, 60}, {-72, 60}, {-72, 12}, {-60, 12}, {-60, 12}}));
        connect(nu_oil_m2ps, gear_wLoss.nu_oil_m2ps) annotation(
          Line(points = {{-120, 0}, {-94, 0}, {-94, 6}, {-62, 6}, {-62, 6}}, color = {0, 255, 0}));
        connect(gear_wLoss.Gear_Load[1], bRG_RadialNeedle.Fr) annotation(
          Line(points = {{-38, 6}, {-30, 6}, {-30, 20}, {48, 20}, {48, 12}}, color = {0, 255, 0}));
        connect(gear_wLoss.Gear_Load[2], bRG_RadialNeedle.Fth) annotation(
          Line(points = {{-38, 6}, {-30, 6}, {-30, 20}, {30, 20}, {30, 8}, {38, 8}}, color = {0, 255, 0}));
        connect(gear_wLoss.Gear_Load, Gear_Load) annotation(
          Line(points = {{-38, 6}, {-30, 6}, {-30, 20}, {94, 20}, {94, 0}, {110, 0}}, color = {0, 255, 0}));
        connect(gear_wLoss.PHI_W, multiSum.u[3]) annotation(
          Line(points = {{-38, -4}, {-34, -4}, {-34, -28}, {66, -28}, {66, -100}, {70, -100}, {70, -100}}, color = {191, 0, 0}));
        connect(synchronizer1.PHI_W, multiSum.u[4]) annotation(
          Line(points = {{12, -10}, {16, -10}, {16, -28}, {66, -28}, {66, -100}, {70, -100}, {70, -100}}, color = {191, 0, 0}));
        connect(stirring2D.support, fixed.flange) annotation(
          Line(points = {{-52, 40}, {-64, 40}, {-64, 40}, {-64, 40}}));
        annotation(
          Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {0, -134}, lineColor = {0, 0, 255}, extent = {{-140, 26}, {140, -26}}, textString = "%name"), Text(origin = {0, 40}, extent = {{-100, 40}, {100, -10}}, textString = "Gear"), Text(origin = {0, -10}, extent = {{-100, 40}, {100, -10}}, textString = "and"), Text(origin = {0, -60}, extent = {{-100, 40}, {100, -10}}, textString = "Synchro")}, coordinateSystem(initialScale = 0.1)),
          uses(Modelica(version = "3.2.2")));
      end Gear_Synchro_Set_Lower;

      package Elements
        model Gear_wLoss
          parameter Real Gear_Ratio = Gear_Ratio;
          parameter String Gear_Friction_Filename = Gear_Friction_Filename;
          parameter Real Oil_Viscosity_Breakpoint[:];
          parameter String Gear_K_Filename = Gear_K_Filename;
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Components.IdealGear idealGear1(ratio = Gear_Ratio) annotation(
            Placement(visible = true, transformation(origin = {10, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-90, 30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
          Modelica.Mechanics.Rotational.Sensors.TorqueSensor torqueSensor1(tau(start = 0)) annotation(
            Placement(visible = true, transformation(origin = {-30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1 annotation(
            Placement(visible = true, transformation(origin = {-32, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          TRAMI_L3_HEV.TransMission.Mechanics.Calc.GearLoss_Calc gearLoss_Calc1(Gear_Friction_Filename = Gear_Friction_Filename, Oil_Viscosity_Breakpoint = Oil_Viscosity_Breakpoint) annotation(
            Placement(visible = true, transformation(origin = {-70, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1D combiTable1D_Kt(fileName = currDir + "/Tables/" + Gear_K_Filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {14, -48}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1D combiTable1D_Kr(fileName = currDir + "/Tables/" + Gear_K_Filename, tableName = "tab2", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {14, -66}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1D combiTable1D_Ka(fileName = currDir + "/Tables/" + Gear_K_Filename, tableName = "tab3", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {14, -86}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Routing.Multiplex3 multiplex31 annotation(
            Placement(visible = true, transformation(origin = {40, -66}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Gear_Load[3] annotation(
            Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Product product1 annotation(
            Placement(visible = true, transformation(origin = {-44, -82}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-22, -82}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Discrete.UnitDelay unitDelay(samplePeriod = 0.01) annotation(
            Placement(visible = true, transformation(origin = {-22, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        equation
          connect(torqueSensor1.tau, combiTable1D_Ka.u[1]) annotation(
            Line(points = {{-38, -10}, {-38, -10}, {-38, -40}, {0, -40}, {0, -86}, {6, -86}, {6, -86}}, color = {0, 255, 0}));
          connect(combiTable1D_Ka.y[1], multiplex31.u3[1]) annotation(
            Line(points = {{20, -86}, {26, -86}, {26, -70}, {32, -70}, {32, -70}}, color = {0, 255, 0}, thickness = 0.5));
          connect(abs1.u, product1.y) annotation(
            Line(points = {{-30, -82}, {-38, -82}, {-38, -82}, {-38, -82}}, color = {0, 255, 0}));
          connect(product1.u2, speedSensor1.w) annotation(
            Line(points = {{-52, -86}, {-90, -86}, {-90, 20}, {-90, 20}}, color = {0, 255, 0}));
          connect(product1.u1, gearLoss_Calc1.Gear_Loss) annotation(
            Line(points = {{-52, -78}, {-54, -78}, {-54, -60}, {-58, -60}, {-58, -60}}, color = {0, 255, 0}));
          connect(idealGear1.flange_b, flange_b) annotation(
            Line(points = {{20, 0}, {70, 0}, {70, -60}, {100, -60}, {100, -60}}));
          connect(Gear_Load, multiplex31.y) annotation(
            Line(points = {{110, 0}, {102, 0}, {102, -2}, {84, -2}, {84, -66}, {46, -66}}, color = {0, 255, 0}, thickness = 0.5));
          connect(combiTable1D_Kr.y[1], multiplex31.u2[1]) annotation(
            Line(points = {{20, -66}, {32, -66}, {32, -66}, {32, -66}}, color = {0, 255, 0}, thickness = 0.5));
          connect(combiTable1D_Kt.y[1], multiplex31.u1[1]) annotation(
            Line(points = {{20, -48}, {26, -48}, {26, -62}, {32, -62}, {32, -62}}, color = {0, 255, 0}, thickness = 0.5));
          connect(speedSensor1.w, gearLoss_Calc1.Gear_w) annotation(
            Line(points = {{-90, 20}, {-90, 20}, {-90, -60}, {-82, -60}, {-82, -60}}, color = {0, 255, 0}));
          connect(gearLoss_Calc1.Gear_Loss, torque1.tau) annotation(
            Line(points = {{-58, -60}, {-44, -60}, {-44, -60}, {-44, -60}}, color = {0, 255, 0}));
          connect(torque1.flange, torqueSensor1.flange_b) annotation(
            Line(points = {{-22, -60}, {-10, -60}, {-10, 0}, {-20, 0}}));
          connect(flange_a, speedSensor1.flange) annotation(
            Line(points = {{-100, 60}, {-91, 60}, {-91, 40}, {-90, 40}}));
          connect(nu_oil_m2ps, gearLoss_Calc1.nu_oil_m2ps) annotation(
            Line(points = {{-120, 0}, {-96, 0}, {-96, -66}, {-82, -66}, {-82, -66}}, color = {0, 255, 0}));
          connect(torqueSensor1.flange_b, idealGear1.flange_a) annotation(
            Line(points = {{-20, 0}, {0, 0}}));
          connect(flange_a, torqueSensor1.flange_a) annotation(
            Line(points = {{-100, 60}, {-70, 60}, {-70, 0}, {-40, 0}}));
          connect(PHI_W, abs1.y) annotation(
            Line(points = {{110, -100}, {-8, -100}, {-8, -82}, {-16, -82}, {-16, -82}}, color = {191, 0, 0}));
          connect(torqueSensor1.tau, gearLoss_Calc1.Gear_Torque) annotation(
            Line(points = {{-38, -10}, {-38, -10}, {-38, -20}, {-84, -20}, {-84, -54}, {-82, -54}, {-82, -54}}, color = {0, 255, 0}));
          connect(unitDelay.u, torqueSensor1.tau) annotation(
            Line(points = {{-30, -20}, {-38, -20}, {-38, -10}, {-38, -10}}, color = {0, 0, 127}));
          connect(unitDelay.y, combiTable1D_Kt.u[1]) annotation(
            Line(points = {{-16, -20}, {0, -20}, {0, -20}, {2, -20}, {2, -48}, {6, -48}, {6, -48}}, color = {0, 0, 127}));
          connect(combiTable1D_Kr.u[1], unitDelay.y) annotation(
            Line(points = {{6, -66}, {2, -66}, {2, -20}, {-16, -20}, {-16, -20}}, color = {0, 0, 127}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {0, -134}, lineColor = {0, 0, 255}, extent = {{-140, 26}, {140, -26}}, textString = "%name"), Text(extent = {{-100, 40}, {100, -40}}, textString = "Gear")}, coordinateSystem(initialScale = 0.1)));
        end Gear_wLoss;

        model OilSeal
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String OilSeal_friction_filename = OilSeal_friction_filename;
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {72, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {54, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-28, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds1(fileName = currDir + "/Tables/" + OilSeal_friction_filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-2, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-2, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          constant Real w_Threshold = 0.2;
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {46, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-54, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-28, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor annotation(
            Placement(visible = true, transformation(origin = {-70, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 180)));
          Modelica.Mechanics.Rotational.Interfaces.Support support annotation(
            Placement(visible = true, transformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(gain1.y, abs1.u) annotation(
            Line(points = {{-47, 4}, {-36, 4}}, color = {0, 255, 0}));
          connect(combiTable1Ds1.y[1], product3.u1) annotation(
            Line(points = {{4, 4}, {38, 4}, {38, 4}, {38, 4}}, color = {0, 255, 0}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{38.8, -3.6}, {33.8, -3.6}, {33.8, -30}, {5, -30}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable1Ds1.u) annotation(
            Line(points = {{-21.4, 4}, {-9.8, 4}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{52.6, 0}, {64.6, 0}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{78, 0}, {100, 0}}));
          connect(flange_a, flange_b) annotation(
            Line(points = {{-100, 0}, {-90, 0}, {-90, 40}, {94, 40}, {94, 0}, {100, 0}}));
          connect(abs11.y, product2.u2) annotation(
            Line(points = {{-22, -70}, {14, -70}, {14, -84}, {47, -84}}, color = {0, 255, 0}));
          connect(combiTable1Ds1.y[1], product2.u1) annotation(
            Line(points = {{4, 4}, {26, 4}, {26, -76}, {47, -76}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{61, -80}, {110, -80}}, color = {191, 0, 0}));
          connect(torque1.support, support) annotation(
            Line(points = {{72, -6}, {72, -6}, {72, -100}, {0, -100}, {0, -100}}));
          connect(flange_a, relSpeedSensor.flange_b) annotation(
            Line(points = {{-100, 0}, {-90, 0}, {-90, -80}, {-76, -80}, {-76, -80}}));
          connect(relSpeedSensor.flange_a, support) annotation(
            Line(points = {{-64, -80}, {0, -80}, {0, -100}, {0, -100}}));
          connect(relSpeedSensor.w_rel, gain1.u) annotation(
            Line(points = {{-70, -74}, {-70, -74}, {-70, 4}, {-62, 4}, {-62, 4}}, color = {0, 255, 0}));
          connect(relSpeedSensor.w_rel, combiTable1Ds2.u) annotation(
            Line(points = {{-70, -74}, {-70, -74}, {-70, -30}, {-10, -30}, {-10, -30}}, color = {0, 255, 0}));
          connect(relSpeedSensor.w_rel, abs11.u) annotation(
            Line(points = {{-70, -74}, {-70, -74}, {-70, -70}, {-36, -70}, {-36, -70}}, color = {0, 255, 0}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-100, 14}, {100, -14}}), Polygon(origin = {-10, -47}, fillColor = {100, 100, 100}, fillPattern = FillPattern.Solid, points = {{30, 7}, {30, 17}, {30, 17}, {10, 33}, {-10, 17}, {-24, 17}, {-30, 11}, {-30, -27}, {-24, -33}, {20, -33}, {20, -23}, {-20, -23}, {-20, 7}, {30, 7}}), Ellipse(origin = {0, -38}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{10, -10}, {-10, 10}}, endAngle = 360), Polygon(origin = {-10, 47}, fillColor = {100, 100, 100}, fillPattern = FillPattern.Solid, points = {{18, 33}, {-24, 33}, {-30, 27}, {-30, -11}, {-24, -17}, {-10, -17}, {10, -33}, {30, -17}, {30, -7}, {-20, -7}, {-20, 23}, {18, 23}, {18, 33}}), Ellipse(origin = {0, 38}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{10, -10}, {-10, 10}}, endAngle = 360), Text(origin = {0, -135}, lineColor = {0, 0, 255}, extent = {{-140, 25}, {140, -25}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)));
        end OilSeal;

        model SealRing
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String SealRing_friction_filename = SealRing_friction_filename;
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {72, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {60, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-34, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/" + SealRing_friction_filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-6, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-8, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          constant Real w_Threshold = 0.2;
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {46, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput p_line_Pa annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-58, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-34, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor annotation(
            Placement(visible = true, transformation(origin = {-70, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 180)));
          Modelica.Mechanics.Rotational.Interfaces.Support support annotation(
            Placement(visible = true, transformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain2(k = 1 / 1000) annotation(
            Placement(visible = true, transformation(origin = {-60, 80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        equation
          connect(p_line_Pa, gain2.u) annotation(
            Line(points = {{-120, 80}, {-68, 80}, {-68, 80}, {-68, 80}}, color = {0, 255, 0}));
          connect(gain2.y, combiTable2D1.u1) annotation(
            Line(points = {{-54, 80}, {-18, 80}, {-18, 8}, {-14, 8}, {-14, 8}}, color = {0, 255, 0}));
          connect(gain1.y, abs1.u) annotation(
            Line(points = {{-51.4, 0}, {-42.4, 0}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable2D1.u2) annotation(
            Line(points = {{-27, 0}, {-14, 0}}, color = {0, 255, 0}));
          connect(combiTable2D1.y, product3.u1) annotation(
            Line(points = {{0, 4}, {38, 4}, {38, 4}, {38, 4}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{52.6, 0}, {64.6, 0}}, color = {0, 255, 0}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{38.8, -3.6}, {33.8, -3.6}, {33.8, -29.6}, {-1.2, -29.6}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{78, 0}, {100, 0}}));
          connect(flange_a, flange_b) annotation(
            Line(points = {{-100, 0}, {-90, 0}, {-90, 40}, {94, 40}, {94, 0}, {100, 0}}));
          connect(abs11.y, product2.u2) annotation(
            Line(points = {{-28, -70}, {36, -70}, {36, -84}, {52, -84}, {52, -84}}, color = {0, 255, 0}));
          connect(combiTable2D1.y, product2.u1) annotation(
            Line(points = {{0, 4}, {20, 4}, {20, -60}, {46, -60}, {46, -76}, {52, -76}, {52, -76}}, color = {0, 255, 0}));
          connect(torque1.support, support) annotation(
            Line(points = {{72, -6}, {72, -6}, {72, -100}, {0, -100}, {0, -100}}));
          connect(relSpeedSensor.flange_a, support) annotation(
            Line(points = {{-64, -80}, {0, -80}, {0, -100}, {0, -100}}));
          connect(relSpeedSensor.flange_b, flange_a) annotation(
            Line(points = {{-76, -80}, {-90, -80}, {-90, 0}, {-100, 0}}));
          connect(relSpeedSensor.w_rel, gain1.u) annotation(
            Line(points = {{-70, -74}, {-70, -74}, {-70, 0}, {-66, 0}, {-66, 0}}, color = {0, 255, 0}));
          connect(relSpeedSensor.w_rel, combiTable1Ds2.u) annotation(
            Line(points = {{-70, -74}, {-70, -74}, {-70, -30}, {-16, -30}, {-16, -30}}, color = {0, 255, 0}));
          connect(relSpeedSensor.w_rel, abs11.u) annotation(
            Line(points = {{-70, -74}, {-70, -74}, {-70, -70}, {-42, -70}, {-42, -70}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{66, -80}, {104, -80}, {104, -80}, {110, -80}}, color = {191, 0, 0}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-100, 14}, {100, -14}}), Polygon(origin = {0, 48}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, points = {{-50, -32}, {50, -32}, {20, 32}, {-20, 32}, {-50, -32}}), Polygon(origin = {0, -48}, rotation = 180, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, points = {{-50, -32}, {50, -32}, {20, 32}, {-20, 32}, {-50, -32}}), Text(origin = {-135, 108}, extent = {{-65, 12}, {35, -18}}, textString = "Oil_Pressure"), Text(origin = {0, -135}, lineColor = {0, 0, 255}, extent = {{-140, 25}, {140, -25}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)),
            Diagram,
            __OpenModelica_commandLineOptions = "");
        end SealRing;

        model Stirring2D
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String Stirring_Resistance_Filename;
          constant Real w_Threshold = 0.2;
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {72, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {62, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-20, 8}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/" + Stirring_Resistance_Filename, smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {12, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {10, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {46, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-48, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-20, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Support support annotation(
            Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor annotation(
            Placement(visible = true, transformation(origin = {-72, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        equation
          connect(combiTable2D1.y, product3.u1) annotation(
            Line(points = {{19, 4}, {38, 4}}, color = {0, 255, 0}));
          connect(abs1.u, gain1.y) annotation(
            Line(points = {{-27, 8}, {-36, 8}, {-36, 0}, {-41, 0}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable2D1.u1) annotation(
            Line(points = {{-13, 8}, {5, 8}}, color = {0, 255, 0}));
          connect(nu_oil_m2ps, combiTable2D1.u2) annotation(
            Line(points = {{-120, 80}, {0, 80}, {0, 0}, {5, 0}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{52.6, 0}, {64.6, 0}}, color = {0, 255, 0}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{38.8, -3.6}, {33.8, -3.6}, {33.8, -30}, {17, -30}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{78, 0}, {100, 0}}));
          connect(combiTable2D1.y, product2.u1) annotation(
            Line(points = {{19, 4}, {26, 4}, {26, -76}, {55, -76}}, color = {0, 255, 0}));
          connect(abs11.y, product2.u2) annotation(
            Line(points = {{-13, -70}, {16, -70}, {16, -84}, {55, -84}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{68, -80}, {110, -80}}, color = {191, 0, 0}));
          connect(torque1.support, support) annotation(
            Line(points = {{72, -6}, {72, -6}, {72, -16}, {-90, -16}, {-90, 0}, {-100, 0}, {-100, 0}}));
          connect(flange_b, relSpeedSensor.flange_b) annotation(
            Line(points = {{100, 0}, {90, 0}, {90, 30}, {-66, 30}, {-66, 30}}));
          connect(relSpeedSensor.w_rel, gain1.u) annotation(
            Line(points = {{-72, 24}, {-72, 24}, {-72, 0}, {-56, 0}, {-56, 0}}, color = {0, 255, 0}));
          connect(relSpeedSensor.w_rel, combiTable1Ds2.u) annotation(
            Line(points = {{-72, 24}, {-72, 24}, {-72, -30}, {2, -30}, {2, -30}}, color = {0, 255, 0}));
          connect(relSpeedSensor.w_rel, abs11.u) annotation(
            Line(points = {{-72, 24}, {-72, 24}, {-72, -70}, {-28, -70}, {-28, -70}}, color = {0, 255, 0}));
          connect(relSpeedSensor.flange_a, support) annotation(
            Line(points = {{-78, 30}, {-90, 30}, {-90, 0}, {-100, 0}}));
          annotation(
            Icon(coordinateSystem(initialScale = 0.1), graphics = {Rectangle(origin = {-40, 0}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-20, 100}, {20, -100}}), Rectangle(origin = {60, 0}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-20, 100}, {20, -100}}), Line(origin = {95, 0}, points = {{-15, 0}, {5, 0}}), Line(origin = {9.56132, 60.3825}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {9.68952, 20.3504}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {9.56132, -19.6175}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {9.56132, -59.6175}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {-0.438684, 90.3825}, points = {{-10, -10}, {10, 10}}), Line(origin = {19.5613, -89.6175}, points = {{-10, -10}, {10, 10}, {10, 10}}), Text(origin = {-135, 118}, extent = {{-65, 12}, {35, -18}}, textString = "nu_oil_m2ps"), Text(origin = {0, -135}, lineColor = {0, 0, 255}, extent = {{-140, 25}, {140, -25}}, textString = "%name")}),
            Diagram,
            __OpenModelica_commandLineOptions = "");
        end Stirring2D;

        model Stirring3D
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String Stirring_Resistance_Filename = Stirring_Resistance_Filename;
          parameter Real Oil_Viscosity_Breakpoint[:];
          constant Real w_Threshold = 0.2;
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {72, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-78, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {66, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-32, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          TRAMI_L3_HEV.TransMission.Utilities.CombiTable3D combiTable3D1(filename = Stirring_Resistance_Filename, z_ax = Oil_Viscosity_Breakpoint) annotation(
            Placement(visible = true, transformation(origin = {2, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-2, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {52, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-48, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-2, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-32, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain2(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-58, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(combiTable3D1.y, product3.u1) annotation(
            Line(points = {{8, 4}, {44, 4}, {44, 4}, {44, 4}}, color = {0, 255, 0}));
          connect(combiTable1Ds2.u, relSpeedSensor1.w_rel) annotation(
            Line(points = {{-10, -30}, {-48, -30}, {-48, 34}, {-48, 34}}, color = {0, 255, 0}));
          connect(gain2.y, abs1.u) annotation(
            Line(points = {{-52, 0}, {-40, 0}, {-40, 0}, {-40, 0}}, color = {0, 255, 0}));
          connect(speedSensor1.w, gain2.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, 0}, {-66, 0}}, color = {0, 255, 0}));
          connect(gain1.y, combiTable3D1.u1) annotation(
            Line(points = {{-26, 20}, {-22, 20}, {-22, 4}, {-6, 4}, {-6, 4}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, gain1.u) annotation(
            Line(points = {{-48, 33.4}, {-48, 33.4}, {-48, 19.4}, {-40, 19.4}, {-40, 19.4}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, abs11.u) annotation(
            Line(points = {{-48, 33.4}, {-48, 33.4}, {-48, -70.6}, {-10, -70.6}, {-10, -70.6}}, color = {0, 255, 0}));
          connect(flange_a, relSpeedSensor1.flange_a) annotation(
            Line(points = {{-100, 0}, {-90, 0}, {-90, 40}, {-54, 40}}));
          connect(relSpeedSensor1.flange_b, flange_b) annotation(
            Line(points = {{-42, 40}, {90, 40}, {90, 0}, {100, 0}}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{44.8, -3.6}, {39.8, -3.6}, {39.8, -29.6}, {4.8, -29.6}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{59, 0}, {64.6, 0}}, color = {0, 255, 0}));
          connect(nu_oil_m2ps, combiTable3D1.u2) annotation(
            Line(points = {{-120, 80}, {-18, 80}, {-18, -2}, {-5, -2}, {-5, -1}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable3D1.u) annotation(
            Line(points = {{-25.4, 0}, {-15.4, 0}, {-15.4, 8}, {-5.4, 8}, {-5.4, 8}}, color = {0, 255, 0}));
          connect(torque1.support, flange_a) annotation(
            Line(points = {{72, -6}, {72, -12}, {-90, -12}, {-90, 0}, {-100, 0}}));
          connect(speedSensor1.flange, flange_a) annotation(
            Line(points = {{-84, 0}, {-100, 0}}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{78, 0}, {100, 0}}));
          connect(product2.u2, abs11.y) annotation(
            Line(points = {{58, -84}, {20, -84}, {20, -70}, {4, -70}, {4, -70}}, color = {0, 255, 0}));
          connect(combiTable3D1.y, product2.u1) annotation(
            Line(points = {{8, 4}, {30, 4}, {30, -76}, {58, -76}, {58, -76}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{72, -80}, {104, -80}, {104, -80}, {110, -80}}, color = {191, 0, 0}));
          annotation(
            Icon(coordinateSystem(initialScale = 0.1), graphics = {Rectangle(origin = {-50, 0}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-20, 100}, {20, -100}}), Rectangle(origin = {50, 0}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-20, 100}, {20, -100}}), Line(origin = {95, 0}, points = {{-25, 0}, {5, 0}}), Line(origin = {-0.43868, 60.3825}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {-0.31048, 20.3504}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {-0.43868, -19.6175}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {-0.43868, -59.6175}, points = {{-20, -20}, {20, 20}, {20, 20}}), Line(origin = {-10.4387, 90.3825}, points = {{-10, -10}, {10, 10}}), Line(origin = {9.5613, -89.6175}, points = {{-10, -10}, {10, 10}, {10, 10}}), Text(origin = {-135, 118}, extent = {{-65, 12}, {35, -18}}, textString = "nu_oil_m2ps"), Line(origin = {-80, 0}, points = {{-20, 0}, {10, 0}}), Text(origin = {0, -140}, lineColor = {0, 0, 255}, extent = {{-120, 30}, {120, -30}}, textString = "%name")}),
            Diagram,
            __OpenModelica_commandLineOptions = "");
        end Stirring3D;

        model BRG_RadialNeedle
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String BRG_Friction_Filename;
          constant Real w_Threshold = 0.2;
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {80, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {60, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-54, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-54, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {60, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, 8}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs2 annotation(
            Placement(visible = true, transformation(origin = {-80, 80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fr annotation(
            Placement(visible = true, transformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D2(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab2", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, -16}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fth annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Add add1 annotation(
            Placement(visible = true, transformation(origin = {10, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Support support annotation(
            Placement(visible = true, transformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-78, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-14, -46}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-100, -40}, extent = {{6, 6}, {-6, -6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs3 annotation(
            Placement(visible = true, transformation(origin = {-28, 80}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(add1.y, product3.u1) annotation(
            Line(points = {{16, 4}, {52, 4}, {52, 4}, {52, 4}}, color = {0, 255, 0}));
          connect(abs2.y, combiTable2D2.u2) annotation(
            Line(points = {{-74, 80}, {-38, 80}, {-38, 70}, {-32, 70}, {-32, -20}, {-22, -20}, {-22, -20}}, color = {0, 255, 0}));
          connect(abs3.y, combiTable2D2.u1) annotation(
            Line(points = {{-28, 74}, {-28, -12}, {-21, -12}}, color = {0, 255, 0}));
          connect(Fr, abs3.u) annotation(
            Line(points = {{-20, 120}, {-20, 120}, {-20, 94}, {-28, 94}, {-28, 88}, {-28, 88}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.flange_a, support) annotation(
            Line(points = {{-94, -40}, {-86, -40}, {-86, -56}, {0, -56}, {0, -100}, {0, -100}}));
          connect(flange_a, relSpeedSensor1.flange_b) annotation(
            Line(points = {{-120, 0}, {-110, 0}, {-110, -40}, {-106, -40}, {-106, -40}}));
          connect(relSpeedSensor1.w_rel, abs11.u) annotation(
            Line(points = {{-100, -34}, {-100, -34}, {-100, -28}, {-80, -28}, {-80, -46}, {-22, -46}, {-22, -46}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, gain1.u) annotation(
            Line(points = {{-100, -34}, {-100, -34}, {-100, 0}, {-86, 0}, {-86, 0}}, color = {0, 255, 0}));
          connect(combiTable2D2.y, add1.u2) annotation(
            Line(points = {{-7, -16}, {-2, -16}, {-2, 0}, {2, 0}}, color = {0, 255, 0}));
          connect(nu_oil_m2ps, combiTable2D1.u1) annotation(
            Line(points = {{-120, -60}, {-36, -60}, {-36, 12}, {-21, 12}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable2D1.u2) annotation(
            Line(points = {{-48, 4}, {-21, 4}}, color = {0, 255, 0}));
          connect(combiTable2D1.y, add1.u1) annotation(
            Line(points = {{-7, 8}, {2, 8}}, color = {0, 255, 0}));
          connect(gain1.y, combiTable1Ds2.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, -30}, {-62, -30}, {-62, -30}}, color = {0, 255, 0}));
          connect(gain1.y, abs1.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, 4}, {-62, 4}, {-62, 4}}, color = {0, 255, 0}));
          connect(flange_a, flange_b) annotation(
            Line(points = {{-120, 0}, {-110, 0}, {-110, 40}, {94, 40}, {94, 0}, {100, 0}}));
          connect(torque1.support, support) annotation(
            Line(points = {{80, -6}, {80, -6}, {80, -86}, {0, -86}, {0, -100}, {0, -100}}));
          connect(Fth, abs2.u) annotation(
            Line(points = {{-120, 80}, {-88, 80}, {-88, 80}, {-88, 80}}, color = {0, 255, 0}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{52, -4}, {48, -4}, {48, -30}, {-48, -30}, {-48, -30}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{67, 0}, {73, 0}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{86, 0}, {100, 0}}));
          connect(add1.y, product2.u1) annotation(
            Line(points = {{16, 4}, {32, 4}, {32, -66}, {52, -66}, {52, -66}}, color = {0, 255, 0}));
          connect(abs11.y, product2.u2) annotation(
            Line(points = {{-8, -46}, {20, -46}, {20, -74}, {52, -74}, {52, -74}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{66, -70}, {90, -70}, {90, -80}, {110, -80}, {110, -80}}, color = {191, 0, 0}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-100, 14}, {100, -14}}), Rectangle(origin = {-1, -26}, lineColor = {80, 80, 80}, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-51, 10}, {51, -10}}), Polygon(origin = {1, -38}, fillColor = {220, 220, 220}, fillPattern = FillPattern.Solid, points = {{-71, 12}, {-53, 12}, {-53, 2}, {49, 2}, {49, 12}, {69, 12}, {69, -6}, {63, -12}, {-65, -12}, {-71, -6}, {-71, 12}}), Polygon(origin = {-1, 38}, rotation = 180, fillColor = {220, 220, 220}, fillPattern = FillPattern.Solid, points = {{-71, 12}, {-53, 12}, {-53, 2}, {49, 2}, {49, 12}, {69, 12}, {69, -6}, {63, -12}, {-65, -12}, {-71, -6}, {-71, 12}}), Rectangle(origin = {1, 26}, lineColor = {80, 80, 80}, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-51, 10}, {51, -10}}), Text(origin = {25, 138}, extent = {{-25, 12}, {35, -18}}, textString = "Fr"), Text(origin = {-135, 128}, extent = {{-25, 12}, {35, -18}}, textString = "Fth"), Text(origin = {-135, -22}, extent = {{-65, 12}, {35, -18}}, textString = "nu_oil_m2ps"), Line(origin = {0, -74}, points = {{0, 24}, {0, -24}}), Text(origin = {0, -140}, lineColor = {0, 0, 255}, extent = {{-120, 20}, {120, -20}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)));
        end BRG_RadialNeedle;

        model BRG_Angular
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String BRG_Friction_Filename;
          constant Real w_Threshold = 0.2;
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {80, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {60, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-54, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-54, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {60, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, 8}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs2 annotation(
            Placement(visible = true, transformation(origin = {-80, 80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fr annotation(
            Placement(visible = true, transformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D2(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab2", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, -16}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fth annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Add add1 annotation(
            Placement(visible = true, transformation(origin = {10, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Support support annotation(
            Placement(visible = true, transformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-78, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-14, -46}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-100, -40}, extent = {{6, 6}, {-6, -6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs3 annotation(
            Placement(visible = true, transformation(origin = {-28, 80}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(add1.y, product3.u1) annotation(
            Line(points = {{16, 4}, {52, 4}, {52, 4}, {52, 4}}, color = {0, 255, 0}));
          connect(abs2.y, combiTable2D2.u2) annotation(
            Line(points = {{-74, 80}, {-38, 80}, {-38, 70}, {-32, 70}, {-32, -20}, {-22, -20}, {-22, -20}}, color = {0, 255, 0}));
          connect(abs3.y, combiTable2D2.u1) annotation(
            Line(points = {{-28, 74}, {-28, -12}, {-21, -12}}, color = {0, 255, 0}));
          connect(Fr, abs3.u) annotation(
            Line(points = {{-20, 120}, {-20, 120}, {-20, 94}, {-28, 94}, {-28, 88}, {-28, 88}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.flange_a, support) annotation(
            Line(points = {{-94, -40}, {-86, -40}, {-86, -56}, {0, -56}, {0, -100}, {0, -100}}));
          connect(flange_a, relSpeedSensor1.flange_b) annotation(
            Line(points = {{-120, 0}, {-110, 0}, {-110, -40}, {-106, -40}, {-106, -40}}));
          connect(relSpeedSensor1.w_rel, abs11.u) annotation(
            Line(points = {{-100, -34}, {-100, -34}, {-100, -28}, {-80, -28}, {-80, -46}, {-22, -46}, {-22, -46}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, gain1.u) annotation(
            Line(points = {{-100, -34}, {-100, -34}, {-100, 0}, {-86, 0}, {-86, 0}}, color = {0, 255, 0}));
          connect(combiTable2D2.y, add1.u2) annotation(
            Line(points = {{-7, -16}, {-2, -16}, {-2, 0}, {2, 0}}, color = {0, 255, 0}));
          connect(nu_oil_m2ps, combiTable2D1.u1) annotation(
            Line(points = {{-120, -60}, {-36, -60}, {-36, 12}, {-21, 12}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable2D1.u2) annotation(
            Line(points = {{-48, 4}, {-21, 4}}, color = {0, 255, 0}));
          connect(combiTable2D1.y, add1.u1) annotation(
            Line(points = {{-7, 8}, {2, 8}}, color = {0, 255, 0}));
          connect(gain1.y, combiTable1Ds2.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, -30}, {-62, -30}, {-62, -30}}, color = {0, 255, 0}));
          connect(gain1.y, abs1.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, 4}, {-62, 4}, {-62, 4}}, color = {0, 255, 0}));
          connect(flange_a, flange_b) annotation(
            Line(points = {{-120, 0}, {-110, 0}, {-110, 40}, {94, 40}, {94, 0}, {100, 0}}));
          connect(torque1.support, support) annotation(
            Line(points = {{80, -6}, {80, -6}, {80, -86}, {0, -86}, {0, -100}, {0, -100}}));
          connect(Fth, abs2.u) annotation(
            Line(points = {{-120, 80}, {-88, 80}, {-88, 80}, {-88, 80}}, color = {0, 255, 0}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{52, -4}, {48, -4}, {48, -30}, {-48, -30}, {-48, -30}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{67, 0}, {73, 0}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{86, 0}, {100, 0}}));
          connect(add1.y, product2.u1) annotation(
            Line(points = {{16, 4}, {32, 4}, {32, -66}, {52, -66}, {52, -66}}, color = {0, 255, 0}));
          connect(abs11.y, product2.u2) annotation(
            Line(points = {{-8, -46}, {20, -46}, {20, -74}, {52, -74}, {52, -74}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{66, -70}, {90, -70}, {90, -80}, {110, -80}, {110, -80}}, color = {191, 0, 0}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-100, 14}, {100, -14}}), Rectangle(origin = {-1, 42}, extent = {{-35, 42}, {35, -28}}), Rectangle(origin = {-1, -42}, extent = {{-35, 28}, {35, -42}}), Rectangle(origin = {-1, 23}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-35, -9}, {35, 11}}), Rectangle(origin = {-1, 75}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-35, -13}, {35, 9}}), Rectangle(origin = {-1, -23}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-35, -11}, {35, 9}}), Rectangle(origin = {-1, -73}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-35, -11}, {35, 11}}), Ellipse(origin = {0, -48}, fillColor = {255, 255, 255}, fillPattern = FillPattern.VerticalCylinder, extent = {{-20, 20}, {20, -20}}, endAngle = 360), Ellipse(origin = {0, 48}, fillColor = {255, 255, 255}, fillPattern = FillPattern.VerticalCylinder, extent = {{-20, 20}, {20, -20}}, endAngle = 360), Text(origin = {25, 138}, extent = {{-25, 12}, {35, -18}}, textString = "Fr"), Text(origin = {-135, 128}, extent = {{-25, 12}, {35, -18}}, textString = "Fth"), Text(origin = {-135, -22}, extent = {{-65, 12}, {35, -18}}, textString = "nu_oil_m2ps"), Text(origin = {0, -135}, lineColor = {0, 0, 255}, extent = {{-140, 25}, {140, -25}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)));
        end BRG_Angular;

        model BRG_Taper
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String BRG_Friction_Filename;
          constant Real w_Threshold = 0.2;
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {80, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {60, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-54, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-54, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {60, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, 8}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs2 annotation(
            Placement(visible = true, transformation(origin = {-80, 80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fr annotation(
            Placement(visible = true, transformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D2(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab2", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, -16}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fth annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Add add1 annotation(
            Placement(visible = true, transformation(origin = {10, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Support support annotation(
            Placement(visible = true, transformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-78, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-14, -46}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-100, -40}, extent = {{6, 6}, {-6, -6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs3 annotation(
            Placement(visible = true, transformation(origin = {-28, 80}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(add1.y, product3.u1) annotation(
            Line(points = {{16, 4}, {52, 4}, {52, 4}, {52, 4}}, color = {0, 255, 0}));
          connect(abs2.y, combiTable2D2.u2) annotation(
            Line(points = {{-74, 80}, {-38, 80}, {-38, 70}, {-32, 70}, {-32, -20}, {-22, -20}, {-22, -20}}, color = {0, 255, 0}));
          connect(abs3.y, combiTable2D2.u1) annotation(
            Line(points = {{-28, 74}, {-28, -12}, {-21, -12}}, color = {0, 255, 0}));
          connect(Fr, abs3.u) annotation(
            Line(points = {{-20, 120}, {-20, 120}, {-20, 94}, {-28, 94}, {-28, 88}, {-28, 88}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.flange_a, support) annotation(
            Line(points = {{-94, -40}, {-86, -40}, {-86, -56}, {0, -56}, {0, -100}, {0, -100}}));
          connect(flange_a, relSpeedSensor1.flange_b) annotation(
            Line(points = {{-120, 0}, {-110, 0}, {-110, -40}, {-106, -40}, {-106, -40}}));
          connect(relSpeedSensor1.w_rel, abs11.u) annotation(
            Line(points = {{-100, -34}, {-100, -34}, {-100, -28}, {-80, -28}, {-80, -46}, {-22, -46}, {-22, -46}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, gain1.u) annotation(
            Line(points = {{-100, -34}, {-100, -34}, {-100, 0}, {-86, 0}, {-86, 0}}, color = {0, 255, 0}));
          connect(combiTable2D2.y, add1.u2) annotation(
            Line(points = {{-7, -16}, {-2, -16}, {-2, 0}, {2, 0}}, color = {0, 255, 0}));
          connect(nu_oil_m2ps, combiTable2D1.u1) annotation(
            Line(points = {{-120, -60}, {-36, -60}, {-36, 12}, {-21, 12}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable2D1.u2) annotation(
            Line(points = {{-48, 4}, {-21, 4}}, color = {0, 255, 0}));
          connect(combiTable2D1.y, add1.u1) annotation(
            Line(points = {{-7, 8}, {2, 8}}, color = {0, 255, 0}));
          connect(gain1.y, combiTable1Ds2.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, -30}, {-62, -30}, {-62, -30}}, color = {0, 255, 0}));
          connect(gain1.y, abs1.u) annotation(
            Line(points = {{-72, 0}, {-66, 0}, {-66, 4}, {-62, 4}, {-62, 4}}, color = {0, 255, 0}));
          connect(flange_a, flange_b) annotation(
            Line(points = {{-120, 0}, {-110, 0}, {-110, 40}, {94, 40}, {94, 0}, {100, 0}}));
          connect(torque1.support, support) annotation(
            Line(points = {{80, -6}, {80, -6}, {80, -86}, {0, -86}, {0, -100}, {0, -100}}));
          connect(Fth, abs2.u) annotation(
            Line(points = {{-120, 80}, {-88, 80}, {-88, 80}, {-88, 80}}, color = {0, 255, 0}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{52, -4}, {48, -4}, {48, -30}, {-48, -30}, {-48, -30}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{67, 0}, {73, 0}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{86, 0}, {100, 0}}));
          connect(add1.y, product2.u1) annotation(
            Line(points = {{16, 4}, {32, 4}, {32, -66}, {52, -66}, {52, -66}}, color = {0, 255, 0}));
          connect(abs11.y, product2.u2) annotation(
            Line(points = {{-8, -46}, {20, -46}, {20, -74}, {52, -74}, {52, -74}}, color = {0, 255, 0}));
          connect(product2.y, PHI_W) annotation(
            Line(points = {{66, -70}, {90, -70}, {90, -80}, {110, -80}, {110, -80}}, color = {191, 0, 0}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-100, 14}, {100, -14}}), Rectangle(origin = {-8, -54}, rotation = -30, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-40, 16}, {40, -12}}), Rectangle(origin = {0, -40}, rotation = -30, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-24, 14}, {24, -14}}), Rectangle(origin = {-6, 50}, rotation = 30, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, extent = {{-40, 16}, {40, -12}}), Rectangle(origin = {1.77636e-15, 40}, rotation = 30, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, extent = {{-24, 14}, {24, -14}}), Text(origin = {45, 138}, extent = {{-25, 12}, {35, -18}}, textString = "Fr"), Text(origin = {-135, 128}, extent = {{-25, 12}, {35, -18}}, textString = "Fth"), Text(origin = {-135, -22}, extent = {{-65, 12}, {35, -18}}, textString = "nu_oil_m2ps"), Text(origin = {-75, -132}, lineColor = {0, 0, 255}, extent = {{-25, 12}, {175, -28}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)));
        end BRG_Taper;

        model BRG_ThrustNeedle
          constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
          parameter String BRG_Friction_Filename;
          constant Real w_Threshold = 0.2;
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {80, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {66, -80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {-50, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds2(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-50, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product3 annotation(
            Placement(visible = true, transformation(origin = {60, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab1", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, 26}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fr annotation(
            Placement(visible = true, transformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {-20, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable2D combiTable2D2(fileName = currDir + "/Tables/" + BRG_Friction_Filename, tableName = "tab2", tableOnFile = true) annotation(
            Placement(visible = true, transformation(origin = {-14, -2}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Fth annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Add add1 annotation(
            Placement(visible = true, transformation(origin = {10, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-90, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-74, 4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-54, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs3 annotation(
            Placement(visible = true, transformation(origin = {-28, 80}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(combiTable1Ds2.u, relSpeedSensor1.w_rel) annotation(
            Line(points = {{-58, -30}, {-90, -30}, {-90, 34}, {-90, 34}, {-90, 34}}, color = {0, 255, 0}));
          connect(add1.y, product3.u1) annotation(
            Line(points = {{16, 4}, {52, 4}, {52, 4}, {52, 4}}, color = {0, 255, 0}));
          connect(Fth, combiTable2D2.u2) annotation(
            Line(points = {{-120, 80}, {-38, 80}, {-38, 70}, {-32, 70}, {-32, -6}, {-22, -6}, {-22, -6}}, color = {0, 255, 0}));
          connect(abs3.y, combiTable2D2.u1) annotation(
            Line(points = {{-28, 74}, {-28, 74}, {-28, 2}, {-22, 2}, {-22, 2}}, color = {0, 255, 0}));
          connect(Fr, abs3.u) annotation(
            Line(points = {{-20, 120}, {-20, 120}, {-20, 94}, {-28, 94}, {-28, 88}, {-28, 88}}, color = {0, 255, 0}));
          connect(gain1.y, abs1.u) annotation(
            Line(points = {{-68, 4}, {-58, 4}, {-58, 4}, {-58, 4}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, gain1.u) annotation(
            Line(points = {{-90, 34}, {-90, 34}, {-90, 4}, {-82, 4}, {-82, 4}}, color = {0, 255, 0}));
          connect(abs11.u, relSpeedSensor1.w_rel) annotation(
            Line(points = {{-62, -70}, {-90, -70}, {-90, 33}}, color = {0, 255, 0}));
          connect(flange_a, relSpeedSensor1.flange_a) annotation(
            Line(points = {{-110, 0}, {-100, 0}, {-100, 40}, {-96, 40}}));
          connect(flange_b, relSpeedSensor1.flange_b) annotation(
            Line(points = {{100, 0}, {90, 0}, {90, 40}, {-84, 40}}));
          connect(torque1.support, flange_a) annotation(
            Line(points = {{80, -6}, {80, -40}, {-100, -40}, {-100, 0}, {-110, 0}}));
          connect(product3.u2, combiTable1Ds2.y[1]) annotation(
            Line(points = {{52, -4}, {48, -4}, {48, -30}, {-43, -30}}, color = {0, 255, 0}));
          connect(abs1.y, combiTable2D1.u2) annotation(
            Line(points = {{-43, 4}, {-40, 4}, {-40, 22}, {-21, 22}}, color = {0, 255, 0}));
          connect(combiTable2D2.y, add1.u2) annotation(
            Line(points = {{-8, -2}, {-2, -2}, {-2, 0}, {2, 0}, {2, 0}}, color = {0, 255, 0}));
          connect(combiTable2D1.y, add1.u1) annotation(
            Line(points = {{-8, 26}, {-2, 26}, {-2, 8}, {2, 8}, {2, 8}}, color = {0, 255, 0}));
          connect(product3.y, torque1.tau) annotation(
            Line(points = {{67, 0}, {73, 0}}, color = {0, 255, 0}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{86, 0}, {100, 0}}));
          connect(nu_oil_m2ps, combiTable2D1.u1) annotation(
            Line(points = {{-120, -60}, {-36, -60}, {-36, 30}, {-21, 30}}, color = {0, 255, 0}));
          connect(product2.u2, abs11.y) annotation(
            Line(points = {{58, -84}, {20, -84}, {20, -70}, {-48, -70}, {-48, -70}}, color = {0, 255, 0}));
          connect(product2.u1, add1.y) annotation(
            Line(points = {{58, -76}, {30, -76}, {30, 4}, {16, 4}, {16, 4}}, color = {0, 255, 0}));
          connect(PHI_W, product2.y) annotation(
            Line(points = {{110, -80}, {74, -80}, {74, -80}, {72, -80}}, color = {191, 0, 0}));
          annotation(
            Icon(coordinateSystem(initialScale = 0.1), graphics = {Polygon(origin = {-12, 0}, fillColor = {200, 200, 200}, fillPattern = FillPattern.Solid, points = {{20, 100}, {-19, 100}, {-25, 94}, {-25, -94}, {-19, -100}, {20, -100}, {20, 100}}), Rectangle(origin = {8, 0}, fillColor = {255, 255, 255}, fillPattern = FillPattern.VerticalCylinder, extent = {{25, 80}, {-25, -80}}), Line(origin = {67, 0}, points = {{33, 0}, {-33, 0}}), Text(origin = {25, 138}, extent = {{-25, 12}, {35, -18}}, textString = "Fr"), Text(origin = {-135, 128}, extent = {{-25, 12}, {35, -18}}, textString = "Fth"), Text(origin = {-135, -22}, extent = {{-65, 12}, {35, -18}}, textString = "nu_oil_m2ps"), Line(origin = {-69, 0}, points = {{31, 0}, {-31, 0}})}));
        end BRG_ThrustNeedle;

        model Clutch
          Modelica.Blocks.Interfaces.RealInput tau_clutch_cap annotation(
            Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-66, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {72, 4.44089e-16}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product1 annotation(
            Placement(visible = true, transformation(origin = {-12, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {34, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs11 annotation(
            Placement(visible = true, transformation(origin = {-12, -24}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Continuous.FirstOrder firstOrder2(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
            Placement(visible = true, transformation(origin = {-12, 90}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {70, -100}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));

          model Tanh
            Modelica.Blocks.Interfaces.RealInput u annotation(
              Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
            Modelica.Blocks.Interfaces.RealOutput y annotation(
              Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
            parameter Real Coeff = 1;
          equation
            y = tanh(Coeff * u);
            annotation(
              Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Line(points = {{0, -80}, {0, 68}}, color = {192, 192, 192}), Text(origin = {4, -2}, lineColor = {192, 192, 192}, extent = {{-88, 72}, {-16, 24}}, textString = "tanh"), Line(points = {{-80, -80}, {-47.8, -78.7}, {-35.8, -75.7}, {-27.7, -70.6}, {-22.1, -64.2}, {-17.3, -55.9}, {-12.5, -44.3}, {-7.64, -29.2}, {-1.21, -4.82}, {6.83, 26.3}, {11.7, 42}, {16.5, 54.2}, {21.3, 63.1}, {26.9, 69.9}, {34.2, 75}, {45.4, 78.4}, {72, 79.9}, {80, 80}}), Line(points = {{-90, 0}, {68, 0}}, color = {192, 192, 192}), Polygon(lineColor = {192, 192, 192}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, points = {{90, 0}, {68, 8}, {68, -8}, {90, 0}}), Polygon(origin = {0, 2}, rotation = 90, lineColor = {192, 192, 192}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, points = {{90, 0}, {68, 8}, {68, -8}, {90, 0}})}));
          end Tanh;

          TRAMI_L3_HEV.TransMission.Mechanics.Elements.Clutch.Tanh tanhCoeff(Coeff = -350) annotation(
            Placement(visible = true, transformation(origin = {-40, -4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        equation
          connect(product1.y, product2.u1) annotation(
            Line(points = {{-6, 0}, {12, 0}, {12, -16}, {26, -16}, {26, -16}}, color = {0, 255, 0}));
          connect(product1.y, torque1.tau) annotation(
            Line(points = {{-6, 0}, {64, 0}, {64, 0}, {64, 0}}, color = {0, 255, 0}));
          connect(firstOrder2.y, product1.u1) annotation(
            Line(points = {{-18, 90}, {-24, 90}, {-24, 4}, {-20, 4}, {-20, 4}}, color = {0, 255, 0}));
          connect(tau_clutch_cap, firstOrder2.u) annotation(
            Line(points = {{0, 120}, {0, 120}, {0, 90}, {-4, 90}, {-4, 90}}, color = {0, 255, 0}));
          connect(abs11.u, relSpeedSensor1.w_rel) annotation(
            Line(points = {{-20, -24}, {-66, -24}, {-66, 24}, {-66, 24}}, color = {0, 255, 0}));
          connect(product2.u2, abs11.y) annotation(
            Line(points = {{26, -24}, {-6, -24}, {-6, -24}, {-6, -24}}, color = {0, 255, 0}));
          connect(flange_a, relSpeedSensor1.flange_a) annotation(
            Line(points = {{-100, 0}, {-88, 0}, {-88, 30}, {-72, 30}}));
          connect(flange_b, relSpeedSensor1.flange_b) annotation(
            Line(points = {{100, 0}, {90, 0}, {90, 30}, {-60, 30}}));
          connect(torque1.support, flange_a) annotation(
            Line(points = {{72, -6}, {72, -40}, {-88, -40}, {-88, 0}, {-100, 0}}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{78, 0}, {100, 0}, {100, 0}, {100, 0}}));
          connect(product2.y, abs1.u) annotation(
            Line(points = {{41, -20}, {46, -20}, {46, -100}, {63, -100}}, color = {0, 255, 0}));
          connect(abs1.y, PHI_W) annotation(
            Line(points = {{76, -100}, {102, -100}, {102, -100}, {110, -100}}, color = {191, 0, 0}));
          connect(tanhCoeff.y, product1.u2) annotation(
            Line(points = {{-33, -4}, {-20, -4}}, color = {0, 255, 0}));
          connect(tanhCoeff.u, relSpeedSensor1.w_rel) annotation(
            Line(points = {{-48, -4}, {-66, -4}, {-66, 24}, {-66, 24}}, color = {0, 255, 0}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {0, -134}, lineColor = {0, 0, 255}, extent = {{-120, 26}, {120, -26}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)),
            Diagram,
            __OpenModelica_commandLineOptions = "",
            experiment(StartTime = 0, StopTime = 180, Tolerance = 1e-06, Interval = 0.1));
        end Clutch;

        model Synchronizer
          parameter String SynchroninzerLoss_Filename;
          parameter Real Oil_Viscosity_Breakpoint[:];
          constant Real w_Threshold = 0.2;
          parameter Real SynchroGain = 5;
          Modelica.Blocks.Interfaces.RealInput f_synchro_n annotation(
            Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
            Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
            Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sensors.RelSpeedSensor relSpeedSensor1 annotation(
            Placement(visible = true, transformation(origin = {-74, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds1(table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
            Placement(visible = true, transformation(origin = {-30, -4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Mechanics.Rotational.Sources.Torque torque1(useSupport = true) annotation(
            Placement(visible = true, transformation(origin = {72, 4.44089e-16}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product1 annotation(
            Placement(visible = true, transformation(origin = {-6, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs1 annotation(
            Placement(visible = true, transformation(origin = {70, -100}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product2 annotation(
            Placement(visible = true, transformation(origin = {40, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = SynchroGain) annotation(
            Placement(visible = true, transformation(origin = {-66, 72}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          TRAMI_L3_HEV.TransMission.Utilities.CombiTable3D combiTable3D1(filename = SynchroninzerLoss_Filename, z_ax = Oil_Viscosity_Breakpoint) annotation(
            Placement(visible = true, transformation(origin = {-66, 54}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Add add1 annotation(
            Placement(visible = true, transformation(origin = {-40, 64}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Continuous.FirstOrder firstOrder2(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
            Placement(visible = true, transformation(origin = {-40, 90}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
          Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
            Placement(visible = true, transformation(origin = {14, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput PHI_W annotation(
            Placement(visible = true, transformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          connect(product2.u1, firstOrder1.y) annotation(
            Line(points = {{32, -16}, {26, -16}, {26, 0}, {20, 0}, {20, 0}}, color = {0, 255, 0}));
          connect(firstOrder1.y, torque1.tau) annotation(
            Line(points = {{20, 0}, {64, 0}, {64, 0}, {64, 0}}, color = {0, 255, 0}));
          connect(product1.y, firstOrder1.u) annotation(
            Line(points = {{0, 0}, {6, 0}, {6, 0}, {6, 0}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, product2.u2) annotation(
            Line(points = {{-74, 24}, {-74, 24}, {-74, -24}, {32, -24}, {32, -24}}, color = {0, 255, 0}));
          connect(relSpeedSensor1.w_rel, combiTable1Ds1.u) annotation(
            Line(points = {{-74, 24}, {-74, 24}, {-74, -4}, {-38, -4}, {-38, -4}}, color = {0, 255, 0}));
          connect(firstOrder2.y, gain1.u) annotation(
            Line(points = {{-46, 90}, {-80, 90}, {-80, 72}, {-74, 72}, {-74, 72}}, color = {0, 255, 0}));
          connect(f_synchro_n, firstOrder2.u) annotation(
            Line(points = {{0, 120}, {0, 120}, {0, 90}, {-32, 90}, {-32, 90}}, color = {0, 255, 0}));
          connect(gain1.y, add1.u1) annotation(
            Line(points = {{-60, 72}, {-52, 72}, {-52, 68}, {-48, 68}, {-48, 68}}, color = {0, 255, 0}));
          connect(product1.u2, combiTable1Ds1.y[1]) annotation(
            Line(points = {{-13, -4}, {-23, -4}}, color = {0, 255, 0}));
          connect(torque1.support, flange_a) annotation(
            Line(points = {{72, -6}, {72, -42}, {-88, -42}, {-88, 0}, {-100, 0}}));
          connect(combiTable3D1.y, add1.u2) annotation(
            Line(points = {{-60, 54}, {-52, 54}, {-52, 60}, {-48, 60}, {-48, 60}}, color = {0, 255, 0}));
          connect(add1.y, product1.u1) annotation(
            Line(points = {{-36, 64}, {-20, 64}, {-20, 4}, {-14, 4}, {-14, 4}}, color = {0, 255, 0}));
          connect(nu_oil_m2ps, combiTable3D1.u2) annotation(
            Line(points = {{-120, 80}, {-88, 80}, {-88, 49}, {-73, 49}}, color = {0, 255, 0}));
          connect(product2.y, abs1.u) annotation(
            Line(points = {{47, -20}, {54, -20}, {54, -100}, {63, -100}}, color = {191, 0, 0}));
          connect(flange_b, relSpeedSensor1.flange_b) annotation(
            Line(points = {{100, 0}, {90, 0}, {90, 30}, {-68, 30}}));
          connect(flange_a, relSpeedSensor1.flange_a) annotation(
            Line(points = {{-100, 0}, {-88, 0}, {-88, 30}, {-80, 30}}));
          connect(torque1.flange, flange_b) annotation(
            Line(points = {{78, 0}, {100, 0}, {100, 0}, {100, 0}}));
          combiTable3D1.u = abs(der(flange_b.phi)) * 60 / (2 * Modelica.Constants.pi);
          combiTable3D1.u1 = relSpeedSensor1.w_rel * 60 / (2 * Modelica.Constants.pi);
          connect(abs1.y, PHI_W) annotation(
            Line(points = {{76, -100}, {104, -100}, {104, -100}, {110, -100}}, color = {191, 0, 0}));
          annotation(
            Icon(graphics = {Text(origin = {-150, 125}, extent = {{-50, 15}, {50, -15}}, textString = "nu_oil_m2ps"), Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {-30, -150}, lineColor = {0, 0, 255}, extent = {{-90, 40}, {150, -20}}, textString = "%name")}, coordinateSystem(initialScale = 0.1)));
        end Synchronizer;
      end Elements;

      package Calc
        model GearLoss_Calc
          parameter String Gear_Friction_Filename = Gear_Friction_Filename;
          parameter Real Oil_Viscosity_Breakpoint[:] = Oil_Viscosity_Breakpoint;
          /* = {8.6e-6, 1.1e-5, 1.7e-5, 3.1e-5, 6.5e-5}*/
          Modelica.Blocks.Interfaces.RealInput nu_oil_m2ps annotation(
            Placement(visible = true, transformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Math.Gain gain1(k = -1) annotation(
            Placement(visible = true, transformation(origin = {26, 26}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs_GearTorque(generateEvent = false) annotation(
            Placement(visible = true, transformation(origin = {-60, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Division division1 annotation(
            Placement(visible = true, transformation(origin = {6, 26}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Gear_Loss annotation(
            Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Math.Gain radps2rpm(k = 60 / (2 * Modelica.Constants.pi)) annotation(
            Placement(visible = true, transformation(origin = {-80, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Abs abs_Gear_rpm annotation(
            Placement(visible = true, transformation(origin = {-56, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Nonlinear.Limiter limiter1(limitsAtInit = true, uMax = 10000, uMin = 1e-6) annotation(
            Placement(visible = true, transformation(origin = {-22, 22}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Math.Product product1 annotation(
            Placement(visible = true, transformation(origin = {48, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          TRAMI_L3_HEV.TransMission.Utilities.CombiTable3D combiTable3D1(filename = Gear_Friction_Filename, z_ax = Oil_Viscosity_Breakpoint) annotation(
            Placement(visible = true, transformation(origin = {-20, -4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Nonlinear.Limiter limiter2(limitsAtInit = true, uMax = 1000, uMin = 0) annotation(
            Placement(visible = true, transformation(origin = {10, -4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Gear_w annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput Gear_Torque annotation(
            Placement(visible = true, transformation(origin = {-120, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, k = 1, y(fixed = true)) annotation(
            Placement(visible = true, transformation(origin = {76, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        equation
          connect(division1.y, gain1.u) annotation(
            Line(points = {{12.6, 26}, {17, 26}}, color = {0, 0, 127}));
          connect(gain1.y, product1.u1) annotation(
            Line(points = {{31, 26}, {35.6, 26}, {35.6, 6}, {41, 6}}, color = {0, 0, 127}));
          connect(firstOrder1.y, Gear_Loss) annotation(
            Line(points = {{83, 0}, {110, 0}}, color = {0, 0, 127}));
          connect(firstOrder1.u, product1.y) annotation(
            Line(points = {{69, 0}, {54.8, 0}}, color = {0, 0, 127}));
          connect(division1.u1, radps2rpm.y) annotation(
            Line(points = {{-2, 30}, {-8, 30}, {-8, 34}, {-68, 34}, {-68, 0}, {-74, 0}}, color = {0, 0, 127}));
          connect(Gear_Torque, abs_GearTorque.u) annotation(
            Line(points = {{-120, 60}, {-67, 60}}, color = {0, 0, 127}));
          connect(abs_GearTorque.y, combiTable3D1.u) annotation(
            Line(points = {{-53, 60}, {-40, 60}, {-40, 4}, {-30, 4}}, color = {0, 0, 127}));
          connect(abs_Gear_rpm.y, combiTable3D1.u1) annotation(
            Line(points = {{-50, 0}, {-44, 0}, {-44, -4}, {-30, -4}}, color = {0, 0, 127}));
          connect(limiter1.u, abs_Gear_rpm.y) annotation(
            Line(points = {{-30, 22}, {-44, 22}, {-44, 0}, {-50, 0}, {-50, 0}}, color = {0, 0, 127}));
          connect(combiTable3D1.y, limiter2.u) annotation(
            Line(points = {{-7, -4}, {3, -4}}, color = {0, 0, 127}));
          connect(nu_oil_m2ps, combiTable3D1.u2) annotation(
            Line(points = {{-120, -60}, {-40, -60}, {-40, -12}, {-30, -12}}, color = {0, 0, 127}));
          connect(limiter2.y, product1.u2) annotation(
            Line(points = {{19, -4}, {41, -4}}, color = {0, 0, 127}));
          connect(limiter1.y, division1.u2) annotation(
            Line(points = {{-15.4, 22}, {-11.9, 22}, {-11.9, 22}, {-8.4, 22}, {-8.4, 22}, {-1.4, 22}, {-1.4, 22}, {-1.4, 22}, {-1.4, 22}, {-1.4, 22}}, color = {0, 0, 127}));
          connect(radps2rpm.y, abs_Gear_rpm.u) annotation(
            Line(points = {{-74, 0}, {-64, 0}, {-64, 0}, {-64, 0}}, color = {0, 0, 127}));
          connect(Gear_w, radps2rpm.u) annotation(
            Line(points = {{-120, 0}, {-88, 0}, {-88, 0}, {-88, 0}}, color = {0, 0, 127}));
          annotation(
            Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {0, -134}, lineColor = {0, 0, 255}, extent = {{-140, 26}, {140, -26}}, textString = "%name"), Text(origin = {0, 10}, extent = {{-100, 40}, {100, -10}}, textString = "Gear"), Text(origin = {0, -40}, extent = {{-100, 40}, {100, -10}}, textString = "Loss")}, coordinateSystem(initialScale = 0.1)));
        end GearLoss_Calc;

        model Brg_Load_Distribution_T1T2
          Modelica.Blocks.Interfaces.RealInput G6[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 90}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 90}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G3[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 30}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G7[3] annotation(
            Placement(visible = true, transformation(origin = {-120, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G9[3] annotation(
            Placement(visible = true, transformation(origin = {-120, -90}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -90}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Real F_6r_T1, F_6r_T2, F_3r_T1, F_3r_T2, F_7r_T1, F_7r_T2, F_9r_T1, F_9r_T2;
          Real Phi_T1, Phi_T2, Psi_T1, Psi_T2;
          Real Fth_out;
          Real Fpre_T1, Fpre_T2;
          //
          //201223スズキ工藤追加
          Real Ft_T1, Ft_T2;
          //201223ここまで
          //
          parameter Real a_T1, a_T2, b_T1, b_T2;
          parameter Real alpha_3, alpha_6, alpha_7, alpha_9;
          parameter Real beta_3, beta_6, beta_7, beta_9;
          parameter Real gamma_3, gamma_6, gamma_7, gamma_9;
          parameter Real omega;
          parameter Real Y_1, Y_2;
          Modelica.Blocks.Interfaces.RealInput Toil annotation(
            Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput Fr_T1 annotation(
            Placement(visible = true, transformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fr_T2 annotation(
            Placement(visible = true, transformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_T1 annotation(
            Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_T2 annotation(
            Placement(visible = true, transformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          F_6r_T1 = sqrt(((1 - alpha_6) * G6[1]) ^ 2 + ((1 - alpha_6) * G6[2] - gamma_6 * G6[3]) ^ 2);
          F_6r_T2 = sqrt((alpha_6 * G6[1]) ^ 2 + (alpha_6 * G6[2] + gamma_6 * G6[3]) ^ 2);
          F_3r_T1 = sqrt(((1 - alpha_3) * G3[1]) ^ 2 + ((1 - alpha_3) * G3[2] - gamma_3 * G3[3]) ^ 2);
          F_3r_T2 = sqrt((alpha_3 * G3[1]) ^ 2 + (alpha_3 * G3[2] + gamma_3 * G3[3]) ^ 2);
          F_7r_T1 = sqrt(((1 - alpha_7) * G7[1]) ^ 2 + ((1 - alpha_7) * G7[2] - gamma_7 * G7[3]) ^ 2);
          F_7r_T2 = sqrt((alpha_7 * G7[1]) ^ 2 + (alpha_7 * G7[2] + gamma_7 * G7[3]) ^ 2);
          F_9r_T1 = sqrt(((1 - alpha_9) * G9[1]) ^ 2 + ((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) ^ 2);
          F_9r_T2 = sqrt((alpha_9 * G9[1]) ^ 2 + (alpha_9 * G9[2] + gamma_9 * G9[3]) ^ 2);
//
//201223スズキ工藤追加
          Ft_T1 = (1 - alpha_6) * G6[1] + (1 - alpha_3) * G3[1] + (1 - alpha_7) * G7[1];
          Ft_T2 = alpha_6 * G6[1] + alpha_3 * G3[1] + alpha_7 * G7[1];
          Phi_T1 = atan(tanh(Ft_T1) * ((1 - alpha_6) * G6[2] - gamma_6 * G6[3] + (1 - alpha_3) * G3[2] - gamma_3 * G3[3] + (1 - alpha_7) * G7[2] - gamma_7 * G7[3]) / (1e-3 + abs(Ft_T1)));
          Phi_T2 = atan(tanh(Ft_T2) * (alpha_6 * G6[2] + gamma_6 * G6[3] + alpha_3 * G3[2] + gamma_3 * G3[3] + alpha_7 * G7[2] + gamma_7 * G7[3]) / (1e-3 + abs(Ft_T2)));
          Psi_T1 = atan(tanh((1 - alpha_9) * G9[1]) * ((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) / (1e-3 + abs((1 - alpha_9) * G9[1])));
          Psi_T2 = atan(tanh(alpha_9 * G9[1]) * (alpha_9 * G9[2] + gamma_9 * G9[3]) / (1e-3 + abs(alpha_9 * G9[1])));
//201223下記コメントアウト
//  Phi_T1 = atan(((1 - alpha_6) * G6[2] - gamma_6 * G6[3] + (1 - alpha_3) * G3[2] - gamma_3 * G3[3] + (1 - alpha_7) * G7[2] - gamma_7 * G7[3]) / ((1 - alpha_6) * G6[1] + (1 - alpha_3) * G3[1] + (1 - alpha_7) * G7[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin(((1 - alpha_6) * G6[2] - gamma_6 * G6[3] + (1 - alpha_3) * G3[2] - gamma_3 * G3[3] + (1 - alpha_7) * G7[2] - gamma_7 * G7[3]) / (F_6r_T1 + F_3r_T1 + F_7r_T1));
//  Phi_T2 = atan((alpha_6 * G6[2] + gamma_6 * G6[3] + alpha_3 * G3[2] + gamma_3 * G3[3] + alpha_7 * G7[2] + gamma_7 * G7[3]) / (alpha_6 * G6[1] + alpha_3 * G3[1] + alpha_7 * G7[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin((alpha_6 * G6[2] + gamma_6 * G6[3] + alpha_3 * G3[2] + gamma_3 * G3[3] + alpha_7 * G7[2] + gamma_7 * G7[3]) / (F_6r_T2 + F_3r_T2 + F_7r_T2));
//  Psi_T1 = atan(((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) / ((1 - alpha_9) * G9[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin(((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) / F_9r_T1);
//  Psi_T2 = atan((alpha_9 * G9[2] + gamma_9 * G9[3]) / (alpha_9 * G9[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin((alpha_9 * G9[2] + gamma_9 * G9[3]) / F_9r_T2);
// 驛｢��ｧ��ｽ��ｽ��ｮ驛｢譎｢��ｽ��､驍ｵ��ｺ��ｽ��ｽ��ｧ鬨ｾ蜈ｷ��ｽ��ｺ鬨ｾ蠅難ｽｺ蛟ｪ��ｽ��ｽ驛｢��ｧ闕ｵ譁溷ｸｷ��ｹ��ｧ��ｽ��ｽ��ｸ驛｢��ｧ��ｽ��ｽ��｢驛｢譎｢��ｽ��ｫ鬮｣蛹��ｽｽ��ｷ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ��ｽ��ｽ��ｽ
//201223ここまで修正
//
          Fr_T1 = sqrt((F_6r_T1 + F_3r_T1 + F_7r_T1) ^ 2 + F_9r_T1 ^ 2 - 2 * (F_6r_T1 + F_3r_T1 + F_7r_T1) * F_9r_T1 * cos(Modelica.Constants.pi - Phi_T1 - Psi_T1 - omega));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽsqrt((F_6r_T1 + F_3r_T1 + F_7r_T1) ^ 2 + F_9r_T1 ^ 2 - 2 * (F_6r_T1 + F_3r_T1 + F_7r_T1) * F_9r_T1 * cos(Phi_T1 + Psi_T1 + omega));
          Fr_T2 = sqrt((F_6r_T2 + F_3r_T2 + F_7r_T2) ^ 2 + F_9r_T2 ^ 2 - 2 * (F_6r_T2 + F_3r_T2 + F_7r_T2) * F_9r_T2 * cos(Modelica.Constants.pi - Phi_T2 - Psi_T2 - omega));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽsqrt((F_6r_T2 + F_3r_T2 + F_7r_T2) ^ 2 + F_9r_T2 ^ 2 - 2 * (F_6r_T2 + F_3r_T2 + F_7r_T2) * F_9r_T2 * cos(Phi_T2 + Psi_T2 + omega));
// 驛｢��ｧ��ｽ��ｽ��ｮ驛｢譎｢��ｽ��､驍ｵ��ｺ��ｽ��ｽ��ｧ鬨ｾ蜈ｷ��ｽ��ｺ鬨ｾ蠅難ｽｺ蛟ｪ��ｽ��ｽ驛｢��ｧ闕ｵ譏ｴ笳矩Δ譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ陝ｾ��ｮ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ隴会ｽｦ��ｽ��ｽ��ｼ鬩幢ｿｽ��ｽ��ｽ��ｪ陋滂ｽｩ��ｽ��ｽ��ｵ��ｽ��ｽ��ｷ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎冗樟遶企����ｸ��ｺ陷会ｽｱ��ｽ��ｽ��ｽ遶丞｣ｹ笙�驛｢譎｢��ｽ��ｳ驛｢��ｧ��ｽ��ｽ��ｸ驛｢譎｢��ｽ��ｳ驍ｵ��ｺ��ｽ��ｽ��ｫ髯ｷ��ｷ闔会ｽ｣��ゑｽｰ驍ｵ��ｺ��ｽ��ｽ��ｽ��ｽ��ｽ��ｽ陝���ｿ髯ｷ��ｷ闔会ｽ｣遯ｶ��ｲ鬮ｮ蜈ｷ��ｿ��ｽ）
          Fth_out = beta_6 * G6[3] + beta_3 * G3[3] + beta_7 * G7[3] - beta_9 * G9[3];
// BRG驍ｵ��ｺ��ｽ��ｽ��ｮ髯ｷ��ｿ陷会ｽｱ￠髫ｰ蝠擾ｿｽ��ｽ隨��ｿｽ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ陝ｾ��ｮ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ隴会ｽｦ��ｽ��ｽ��ｼ鬩幢ｿｽ��ｽ��ｽ��ｪ陋滂ｽｩ��ｽ��ｽ��ｵ��ｽ��ｽ��ｷ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ��ｽ��ｽ��ｽ��ｽ��ｽ��ｽ隲ｷ��ｮ）
          Fpre_T1 = a_T1 * Toil + b_T1;
          Fpre_T2 = a_T2 * Toil + b_T2;
          Fth_T1 = (1 + tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_T2 / Y_2 - Fth_out + Fpre_T1) + (1 - tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_T1 / Y_1 + Fpre_T1);
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽ(tanh(Fth_out) + 1) / 2 * ((tanh(Fr_T2 / Y_2 - Fr_T1 / Y_1) + 1) / 2 * (tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T2 / Y_2 - abs(Fth_out) + Fpre_T1) + (1 - (tanh(Fr_T2 / Y_2 - Fr_T1 / Y_1) + 1) / 2 * (tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T1 / Y_1 + Fpre_T1)) + (1 - (tanh(Fth_out) + 1) / 2) * ((tanh(Fr_T1 / Y_1 - Fr_T2 / Y_2) + 1) / 2 * (tanh(0.5 * (Fr_T1 / Y_1 - Fr_T2 / Y_2) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T1 / Y_1 + Fpre_T1) + (1 - (tanh(Fr_T1 / Y_1 - Fr_T2 / Y_2) + 1) / 2 * (tanh(0.5 * (Fr_T1 / Y_1 - Fr_T2 / Y_2) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T2 / Y_2 + abs(Fth_out) + Fpre_T1));
          Fth_T2 = (1 + tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_T2 / Y_2 + Fpre_T2) + (1 - tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_T1 / Y_1 + Fth_out + Fpre_T2);
//驍ｵ��ｲ��ｽ��ｽ��ｽ200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽ(tanh(Fth_out) + 1) / 2 * ((tanh(Fr_T2 / Y_2 - Fr_T1 / Y_1) + 1) / 2 * (tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T2 / Y_2 + Fpre_T2) + (1 - (tanh(Fr_T2 / Y_2 - Fr_T1 / Y_1) + 1) / 2 * (tanh(0.5 * (Fr_T2 / Y_2 - Fr_T1 / Y_1) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T1 / Y_1 + abs(Fth_out) + Fpre_T2)) + (1 - (tanh(Fth_out) + 1) / 2) * ((tanh(Fr_T1 / Y_1 - Fr_T2 / Y_2) + 1) / 2 * (tanh(0.5 * (Fr_T1 / Y_1 - Fr_T2 / Y_2) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T1 / Y_1 - abs(Fth_out) + Fpre_T2) + (1 - (tanh(Fr_T1 / Y_1 - Fr_T2 / Y_2) + 1) / 2 * (tanh(0.5 * (Fr_T1 / Y_1 - Fr_T2 / Y_2) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T2 / Y_2 + Fpre_T2));
        end Brg_Load_Distribution_T1T2;

        model Brg_Load_Distribution_T3T4
          Modelica.Blocks.Interfaces.RealInput G4[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G2[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G1[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G5[3] annotation(
            Placement(visible = true, transformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G10[3] annotation(
            Placement(visible = true, transformation(origin = {-120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Real F_4r_T3, F_4r_T4, F_2r_T3, F_2r_T4, F_1r_T3, F_1r_T4, F_5r_T3, F_5r_T4, F_10r_T3, F_10r_T4;
          Real Phi_T3, Phi_T4, Psi_T3, Psi_T4;
          Real Fth_out;
          Real Fpre_T3, Fpre_T4;
          //
          //201223スズキ工藤追加
          Real Ft_T3, Ft_T4;
          //201223ここまで
          //
          parameter Real a_T3, a_T4, b_T3, b_T4;
          parameter Real alpha_1, alpha_2, alpha_4, alpha_5, alpha_10;
          parameter Real beta_1, beta_2, beta_4, beta_5, beta_10;
          parameter Real gamma_1, gamma_2, gamma_4, gamma_5, gamma_10;
          parameter Real omega;
          parameter Real Y_3, Y_4;
          Modelica.Blocks.Interfaces.RealInput Toil annotation(
            Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput Fr_T3 annotation(
            Placement(visible = true, transformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fr_T4 annotation(
            Placement(visible = true, transformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_T3 annotation(
            Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_T4 annotation(
            Placement(visible = true, transformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          F_4r_T3 = sqrt(((1 - alpha_4) * G4[1]) ^ 2 + ((1 - alpha_4) * G4[2] - gamma_4 * G4[3]) ^ 2);
          F_4r_T4 = sqrt((alpha_4 * G4[1]) ^ 2 + (alpha_4 * G4[2] + gamma_4 * G4[3]) ^ 2);
          F_2r_T3 = sqrt(((1 - alpha_2) * G2[1]) ^ 2 + ((1 - alpha_2) * G2[2] - gamma_2 * G2[3]) ^ 2);
          F_2r_T4 = sqrt((alpha_2 * G2[1]) ^ 2 + (alpha_2 * G2[2] + gamma_2 * G2[3]) ^ 2);
          F_1r_T3 = sqrt(((1 - alpha_1) * G1[1]) ^ 2 + ((1 - alpha_1) * G1[2] - gamma_1 * G1[3]) ^ 2);
          F_1r_T4 = sqrt((alpha_1 * G1[1]) ^ 2 + (alpha_1 * G1[2] + gamma_1 * G1[3]) ^ 2);
          F_5r_T3 = sqrt(((1 - alpha_5) * G5[1]) ^ 2 + ((1 - alpha_5) * G5[2] - gamma_5 * G5[3]) ^ 2);
          F_5r_T4 = sqrt((alpha_5 * G5[1]) ^ 2 + (alpha_5 * G5[2] + gamma_5 * G5[3]) ^ 2);
          F_10r_T3 = sqrt(((1 - alpha_10) * G10[1]) ^ 2 + ((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) ^ 2);
          F_10r_T4 = sqrt((alpha_10 * G10[1]) ^ 2 + (alpha_10 * G10[2] + gamma_10 * G10[3]) ^ 2);
//
//201223スズキ工藤追加
          Ft_T3 = (1 - alpha_4) * G4[1] + (1 - alpha_2) * G2[1] + (1 - alpha_1) * G1[1] + (1 - alpha_5) * G5[1];
          Ft_T4 = alpha_4 * G4[1] + alpha_2 * G2[1] + alpha_1 * G1[1] + alpha_5 * G5[1];
          Phi_T3 = atan(tanh(Ft_T3) * ((1 - alpha_4) * G4[2] - gamma_4 * G4[3] + (1 - alpha_2) * G2[2] - gamma_2 * G2[3] + (1 - alpha_1) * G1[2] - gamma_1 * G1[3] + (1 - alpha_5) * G5[2] - gamma_5 * G5[3]) / (1e-3 + abs(Ft_T3)));
          Phi_T4 = atan(tanh(Ft_T4) * (alpha_4 * G4[2] + gamma_4 * G4[3] + alpha_2 * G2[2] + gamma_2 * G2[3] + alpha_1 * G1[2] + gamma_1 * G1[3] + alpha_5 * G5[2] + gamma_5 * G5[3]) / (1e-3 + abs(Ft_T4)));
          Psi_T3 = atan(tanh((1 - alpha_10) * G10[1]) * ((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) / (1e-3 + abs((1 - alpha_10) * G10[1])));
          Psi_T4 = atan(tanh(alpha_10 * G10[1]) * (alpha_10 * G10[2] + gamma_10 * G10[3]) / (1e-3 + abs(alpha_10 * G10[1])));
//201223下記コメントアウト
//  Phi_T3 = atan(((1 - alpha_4) * G4[2] - gamma_4 * G4[3] + (1 - alpha_2) * G2[2] - gamma_2 * G2[3] + (1 - alpha_1) * G1[2] - gamma_1 * G1[3] + (1 - alpha_5) * G5[2] - gamma_5 * G5[3]) / ((1 - alpha_4) * G4[1] + (1 - alpha_2) * G2[1] + (1 - alpha_1) * G1[1] + (1 - alpha_5) * G5[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin(((1 - alpha_4) * G4[2] - gamma_4 * G4[3] + (1 - alpha_2) * G2[2] - gamma_2 * G2[3] + (1 - alpha_1) * G1[2] - gamma_1 * G1[3] + (1 - alpha_5) * G5[2] - gamma_5 * G5[3]) / (F_4r_T3 + F_2r_T3 + F_1r_T3 + F_5r_T3));
//  Phi_T4 = atan((alpha_4 * G4[2] + gamma_4 * G4[3] + alpha_2 * G2[2] + gamma_2 * G2[3] + alpha_1 * G1[2] + gamma_1 * G1[3] + alpha_5 * G5[2] + gamma_5 * G5[3]) / (alpha_4 * G4[1] + alpha_2 * G2[1] + alpha_1 * G1[1] + alpha_5 * G5[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin((alpha_4 * G4[2] + gamma_4 * G4[3] + alpha_2 * G2[2] + gamma_2 * G2[3] + alpha_1 * G1[2] + gamma_1 * G1[3] + alpha_5 * G5[2] + gamma_5 * G5[3]) / (F_4r_T4 + F_2r_T4 + F_1r_T4 + F_5r_T4));
//  Psi_T3 = atan(((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) / ((1 - alpha_10) * G10[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin(((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) / F_10r_T3);
//  Psi_T4 = atan((alpha_10 * G10[2] + gamma_10 * G10[3]) / (alpha_10 * G10[1]));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽasin((alpha_10 * G10[2] + gamma_10 * G10[3]) / F_10r_T4);
// 驛｢��ｧ��ｽ��ｽ��ｮ驛｢譎｢��ｽ��､驍ｵ��ｺ��ｽ��ｽ��ｧ鬨ｾ蜈ｷ��ｽ��ｺ鬨ｾ蠅難ｽｺ蛟ｪ��ｽ��ｽ驛｢��ｧ闕ｵ譁溷ｸｷ��ｹ��ｧ��ｽ��ｽ��ｸ驛｢��ｧ��ｽ��ｽ��｢驛｢譎｢��ｽ��ｫ鬮｣蛹��ｽｽ��ｷ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ��ｽ��ｽ��ｽ
//201223ここまで修正
//
          Fr_T3 = sqrt((F_4r_T3 + F_2r_T3 + F_1r_T3 + F_5r_T3) ^ 2 + F_10r_T3 ^ 2 - 2 * (F_4r_T3 + F_2r_T3 + F_1r_T3 + F_5r_T3) * F_10r_T3 * cos(Modelica.Constants.pi + Phi_T3 + Psi_T3 - omega));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽsqrt((F_4r_T3 + F_2r_T3 + F_1r_T3 + F_5r_T3) ^ 2 + F_10r_T3 ^ 2 - 2 * (F_4r_T3 + F_2r_T3 + F_1r_T3 + F_5r_T3) * F_10r_T3 * cos((-Phi_T3) - Psi_T3 + omega));
          Fr_T4 = sqrt((F_4r_T4 + F_2r_T4 + F_1r_T4 + F_5r_T4) ^ 2 + F_10r_T4 ^ 2 - 2 * (F_4r_T4 + F_2r_T4 + F_1r_T4 + F_5r_T4) * F_10r_T4 * cos(Modelica.Constants.pi + Phi_T4 + Psi_T4 - omega));
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽsqrt((F_4r_T4 + F_2r_T4 + F_1r_T4 + F_5r_T4) ^ 2 + F_10r_T4 ^ 2 - 2 * (F_4r_T4 + F_2r_T4 + F_1r_T4 + F_5r_T4) * F_10r_T4 * cos((-Phi_T4) - Psi_T4 + omega));
// 驛｢��ｧ��ｽ��ｽ��ｮ驛｢譎｢��ｽ��､驍ｵ��ｺ��ｽ��ｽ��ｧ鬨ｾ蜈ｷ��ｽ��ｺ鬨ｾ蠅難ｽｺ蛟ｪ��ｽ��ｽ驛｢��ｧ闕ｵ譏ｴ笳矩Δ譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ陝ｾ��ｮ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ隴会ｽｦ��ｽ��ｽ��ｼ鬩幢ｿｽ��ｽ��ｽ��ｪ陋滂ｽｩ��ｽ��ｽ��ｵ��ｽ��ｽ��ｷ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎冗樟遶企����ｸ��ｺ陷会ｽｱ��ｽ��ｽ��ｽ遶丞｣ｹ笙�驛｢譎｢��ｽ��ｳ驛｢��ｧ��ｽ��ｽ��ｸ驛｢譎｢��ｽ��ｳ驍ｵ��ｺ��ｽ��ｽ��ｫ髯ｷ��ｷ闔会ｽ｣��ゑｽｰ驍ｵ��ｺ��ｽ��ｽ��ｽ��ｽ��ｽ��ｽ陝���ｿ髯ｷ��ｷ闔会ｽ｣遯ｶ��ｲ鬮ｮ蜈ｷ��ｿ��ｽ）
          Fth_out = beta_4 * G4[3] + beta_2 * G2[3] + beta_1 * G1[3] + beta_5 * G5[3] - beta_10 * G10[3];
// BRG驍ｵ��ｺ��ｽ��ｽ��ｮ髯ｷ��ｿ陷会ｽｱ￠髫ｰ蝠擾ｿｽ��ｽ隨��ｿｽ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ陝ｾ��ｮ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ隴会ｽｦ��ｽ��ｽ��ｼ鬩幢ｿｽ��ｽ��ｽ��ｪ陋滂ｽｩ��ｽ��ｽ��ｵ��ｽ��ｽ��ｷ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ��ｽ��ｽ��ｽ��ｽ��ｽ��ｽ隲ｷ��ｮ）
          Fpre_T3 = a_T3 * Toil + b_T3;
          Fpre_T4 = a_T4 * Toil + b_T4;
          Fth_T3 = (1 + tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - Fth_out)) / 2 * (0.5 * Fr_T4 / Y_4 - Fth_out + Fpre_T3) + (1 - tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - Fth_out)) / 2 * (0.5 * Fr_T3 / Y_3 + Fpre_T3);
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽ(tanh(Fth_out) + 1) / 2 * ((tanh(Fr_T4 / Y_4 - Fr_T3 / Y_3) + 1) / 2 * (tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T4 / Y_4 - abs(Fth_out) + Fpre_T3) + (1 - (tanh(Fr_T4 / Y_4 - Fr_T3 / Y_3) + 1) / 2 * (tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T3 / Y_3 + Fpre_T3)) + (1 - (tanh(Fth_out) + 1) / 2) * ((tanh(Fr_T3 / Y_3 - Fr_T4 / Y_4) + 1) / 2 * (tanh(0.5 * (Fr_T3 / Y_3 - Fr_T4 / Y_4) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T3 / Y_3 + Fpre_T3) + (1 - (tanh(Fr_T3 / Y_3 - Fr_T4 / Y_4) + 1) / 2 * (tanh(0.5 * (Fr_T3 / Y_3 - Fr_T4 / Y_4) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T4 / Y_4 + abs(Fth_out) + Fpre_T3));
          Fth_T4 = (1 + tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - Fth_out)) / 2 * (0.5 * Fr_T4 / Y_4 + Fpre_T4) + (1 - tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - Fth_out)) / 2 * (0.5 * Fr_T3 / Y_3 + Fth_out + Fpre_T4);
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽ(tanh(Fth_out) + 1) / 2 * ((tanh(Fr_T4 / Y_4 - Fr_T3 / Y_3) + 1) / 2 * (tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T4 / Y_4 + Fpre_T4) + (1 - (tanh(Fr_T4 / Y_4 - Fr_T3 / Y_3) + 1) / 2 * (tanh(0.5 * (Fr_T4 / Y_4 - Fr_T3 / Y_3) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T3 / Y_3 + abs(Fth_out) + Fpre_T4)) + (1 - (tanh(Fth_out) + 1) / 2) * ((tanh(Fr_T3 / Y_3 - Fr_T4 / Y_4) + 1) / 2 * (tanh(0.5 * (Fr_T3 / Y_3 - Fr_T4 / Y_4) - abs(Fth_out)) + 1) / 2 * (0.5 * Fr_T3 / Y_3 - abs(Fth_out) + Fpre_T4) + (1 - (tanh(Fr_T3 / Y_3 - Fr_T4 / Y_4) + 1) / 2 * (tanh(0.5 * (Fr_T3 / Y_3 - Fr_T4 / Y_4) - abs(Fth_out)) + 1) / 2) * (0.5 * Fr_T4 / Y_4 + Fpre_T4));
          annotation(
            experiment(StartTime = 0, StopTime = 6.9, Tolerance = 1e-06, Interval = 0.1));
        end Brg_Load_Distribution_T3T4;

        model Brg_Load_Distribution_T5T6
          Modelica.Blocks.Interfaces.RealInput G9[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G10[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Real F_9r_T5, F_9r_T6, F_10r_T5, F_10r_T6;
          Real Phi_T5, Phi_T6, Psi_T5, Psi_T6;
          Real Fth_out;
          Real Fpre_T5, Fpre_T6;
          parameter Real a_T5, a_T6, b_T5, b_T6;
          parameter Real alpha_9, alpha_10;
          parameter Real beta_9, beta_10;
          parameter Real gamma_9, gamma_10;
          parameter Real omega;
          parameter Real Y_5, Y_6;
          Modelica.Blocks.Interfaces.RealInput Toil annotation(
            Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput Fr_T5 annotation(
            Placement(visible = true, transformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fr_T6 annotation(
            Placement(visible = true, transformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_T5 annotation(
            Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_T6 annotation(
            Placement(visible = true, transformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          F_9r_T5 = sqrt(((1 - alpha_9) * G9[1]) ^ 2 + ((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) ^ 2);
          F_9r_T6 = sqrt((alpha_9 * G9[1]) ^ 2 + (alpha_9 * G9[2] + gamma_9 * G9[3]) ^ 2);
          F_10r_T5 = sqrt(((1 - alpha_10) * G10[1]) ^ 2 + ((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) ^ 2);
          F_10r_T6 = sqrt((alpha_10 * G10[1]) ^ 2 + (alpha_10 * G10[2] + gamma_10 * G10[3]) ^ 2);
//
//201223スズキ工藤追加
          Phi_T5 = atan(tanh((1 - alpha_9) * G9[1]) * ((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) / (1e-3 + abs((1 - alpha_9) * G9[1])));
          Phi_T6 = atan(tanh(alpha_9 * G9[1]) * (alpha_9 * G9[2] + gamma_9 * G9[3]) / (1e-3 + abs(alpha_9 * G9[1])));
          Psi_T5 = atan(tanh((1 - alpha_10) * G10[1]) * ((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) / (1e-3 + abs((1 - alpha_10) * G10[1])));
          Psi_T6 = atan(tanh(alpha_10 * G10[1]) * (alpha_10 * G10[2] + gamma_10 * G10[3]) / (1e-3 + abs(alpha_10 * G10[1])));
//201223下記コメントアウト
//  Phi_T5 = atan(((1 - alpha_9) * G9[2] - gamma_9 * G9[3]) / ((1 - alpha_9) * G9[1]));
//  Phi_T6 = atan((alpha_9 * G9[2] + gamma_9 * G9[3]) / (alpha_9 * G9[1]));
//  Psi_T5 = atan(((1 - alpha_10) * G10[2] - gamma_10 * G10[3]) / ((1 - alpha_10) * G10[1]));
//  Psi_T6 = atan((alpha_10 * G10[2] + gamma_10 * G10[3]) / (alpha_10 * G10[1]));
//201223ここまで修正
//
          Fr_T5 = sqrt(F_9r_T5 ^ 2 + F_10r_T5 ^ 2 + 2 * F_9r_T5 * F_10r_T5 * cos((-Phi_T5) + Psi_T5 + omega));
          Fr_T6 = sqrt(F_9r_T6 ^ 2 + F_10r_T6 ^ 2 + 2 * F_9r_T6 * F_10r_T6 * cos((-Phi_T6) + Psi_T6 + omega));
          Fth_out = (-beta_9 * G9[3]) - beta_10 * G10[3];
          Fpre_T5 = a_T5 * Toil + b_T5;
          Fpre_T6 = a_T6 * Toil + b_T6;
          Fth_T5 = (1 + tanh(0.5 * (Fr_T6 / Y_6 - Fr_T5 / Y_5) - Fth_out)) / 2 * (0.5 * Fr_T6 / Y_6 - Fth_out + Fpre_T5) + (1 - tanh(0.5 * (Fr_T6 / Y_6 - Fr_T5 / Y_5) - Fth_out)) / 2 * (0.5 * Fr_T5 / Y_5 + Fpre_T5);
          Fth_T6 = (1 + tanh(0.5 * (Fr_T6 / Y_6 - Fr_T5 / Y_5) - Fth_out)) / 2 * (0.5 * Fr_T6 / Y_6 + Fpre_T6) + (1 - tanh(0.5 * (Fr_T6 / Y_6 - Fr_T5 / Y_5) - Fth_out)) / 2 * (0.5 * Fr_T5 / Y_5 + Fth_out + Fpre_T6);
        end Brg_Load_Distribution_T5T6;

        model Brg_Load_Distribution_A1A2
          Modelica.Blocks.Interfaces.RealInput G1[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G5[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G3[3] annotation(
            Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G7[3] annotation(
            Placement(visible = true, transformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G4[3] annotation(
            Placement(visible = true, transformation(origin = {-120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealInput G2[3] annotation(
            Placement(visible = true, transformation(origin = {-50, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 90), iconTransformation(origin = {-50, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 90)));
          Modelica.Blocks.Interfaces.RealInput G6[3] annotation(
            Placement(visible = true, transformation(origin = {0, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 90), iconTransformation(origin = {0, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 90)));
          Real F_1r_A1, F_1r_A2, F_5r_A1, F_5r_A2, F_3r_A1, F_3r_A2, F_7r_A1, F_7r_A2, F_4r_A1, F_4r_A2, F_2r_A1, F_2r_A2, F_6r_A1, F_6r_A2;
          Real Phi_A1, Phi_A2, Psi_A1, Psi_A2;
          Real Fth_out;
          Real Fpre_A1, Fpre_A2;
          //
          //201223スズキ工藤追加
          Real Ft_Upper_A1, Ft_Upper_A2, Ft_Lower_A1, Ft_Lower_A2;
          //201223ここまで
          //
          parameter Real a_A1, a_A2, b_A1, b_A2;
          parameter Real alpha_1, alpha_2, alpha_3, alpha_4, alpha_5, alpha_6, alpha_7;
          parameter Real beta_1, beta_2, beta_3, beta_4, beta_5, beta_6, beta_7;
          parameter Real gamma_1, gamma_2, gamma_3, gamma_4, gamma_5, gamma_6, gamma_7;
          parameter Real omega;
          parameter Real Y_1, Y_2;
          Modelica.Blocks.Interfaces.RealInput Toil annotation(
            Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
          Modelica.Blocks.Interfaces.RealOutput Fr_A1 annotation(
            Placement(visible = true, transformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fr_A2 annotation(
            Placement(visible = true, transformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_A1 annotation(
            Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
          Modelica.Blocks.Interfaces.RealOutput Fth_A2 annotation(
            Placement(visible = true, transformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        equation
          F_1r_A1 = sqrt(((1 - alpha_1) * G1[1]) ^ 2 + ((1 - alpha_1) * G1[2] - gamma_1 * G1[3]) ^ 2);
          F_1r_A2 = sqrt((alpha_1 * G1[1]) ^ 2 + (alpha_1 * G1[2] + gamma_1 * G1[3]) ^ 2);
          F_5r_A1 = sqrt(((1 - alpha_5) * G5[1]) ^ 2 + ((1 - alpha_5) * G5[2] - gamma_5 * G5[3]) ^ 2);
          F_5r_A2 = sqrt((alpha_5 * G5[1]) ^ 2 + (alpha_5 * G5[2] + gamma_5 * G5[3]) ^ 2);
          F_3r_A1 = sqrt(((1 - alpha_3) * G3[1]) ^ 2 + ((1 - alpha_3) * G3[2] - gamma_3 * G3[3]) ^ 2);
          F_3r_A2 = sqrt((alpha_3 * G3[1]) ^ 2 + (alpha_3 * G3[2] + gamma_3 * G3[3]) ^ 2);
          F_7r_A1 = sqrt(((1 - alpha_7) * G7[1]) ^ 2 + ((1 - alpha_7) * G7[2] - gamma_7 * G7[3]) ^ 2);
          F_7r_A2 = sqrt((alpha_7 * G7[1]) ^ 2 + (alpha_7 * G7[2] + gamma_7 * G7[3]) ^ 2);
          F_4r_A1 = sqrt(((1 - alpha_4) * G4[1]) ^ 2 + ((1 - alpha_4) * G4[2] - gamma_4 * G4[3]) ^ 2);
          F_4r_A2 = sqrt((alpha_4 * G4[1]) ^ 2 + (alpha_4 * G4[2] + gamma_4 * G4[3]) ^ 2);
          F_2r_A1 = sqrt(((1 - alpha_2) * G2[1]) ^ 2 + ((1 - alpha_2) * G2[2] - gamma_2 * G2[3]) ^ 2);
          F_2r_A2 = sqrt((alpha_2 * G2[1]) ^ 2 + (alpha_2 * G2[2] + gamma_2 * G2[3]) ^ 2);
          F_6r_A1 = sqrt(((1 - alpha_6) * G6[1]) ^ 2 + ((1 - alpha_6) * G6[2] - gamma_6 * G6[3]) ^ 2);
          F_6r_A2 = sqrt((alpha_6 * G6[1]) ^ 2 + (alpha_6 * G6[2] + gamma_6 * G6[3]) ^ 2);
//
//201223スズキ工藤追加
          Ft_Upper_A1 = (1 - alpha_6) * G6[1] + (1 - alpha_3) * G3[1] + (1 - alpha_7) * G7[1];
          Ft_Upper_A2 = alpha_6 * G6[1] + alpha_3 * G3[1] + alpha_7 * G7[1];
          Ft_Lower_A1 = (1 - alpha_4) * G4[1] + (1 - alpha_2) * G2[1] + (1 - alpha_1) * G1[1] + (1 - alpha_5) * G5[1];
          Ft_Lower_A2 = alpha_4 * G4[1] + alpha_2 * G2[1] + alpha_1 * G1[1] + alpha_5 * G5[1];
          Phi_A1 = atan(tanh(Ft_Upper_A1) * ((1 - alpha_6) * G6[2] - gamma_6 * G6[3] + (1 - alpha_3) * G3[2] - gamma_3 * G3[3] + (1 - alpha_7) * G7[2] - gamma_7 * G7[3]) / (1e-3 + abs(Ft_Upper_A1)));
          Phi_A2 = atan(tanh(Ft_Upper_A2) * (alpha_6 * G6[2] + gamma_6 * G6[3] + alpha_3 * G3[2] + gamma_3 * G3[3] + alpha_7 * G7[2] + gamma_7 * G7[3]) / (1e-3 + abs(Ft_Upper_A2)));
          Psi_A1 = atan(tanh(Ft_Lower_A1) * ((1 - alpha_4) * G4[2] - gamma_4 * G4[3] + (1 - alpha_2) * G2[2] - gamma_2 * G2[3] + (1 - alpha_1) * G1[2] - gamma_1 * G1[3] + (1 - alpha_5) * G5[2] - gamma_5 * G5[3]) / (1e-3 + abs(Ft_Lower_A1)));
          Psi_A2 = atan(tanh(Ft_Lower_A1) * (alpha_4 * G4[2] + gamma_4 * G4[3] + alpha_2 * G2[2] + gamma_2 * G2[3] + alpha_1 * G1[2] + gamma_1 * G1[3] + alpha_5 * G5[2] + gamma_5 * G5[3]) / (1e-3 + abs(Ft_Lower_A2)));
//201223下記コメントアウト
//  Phi_A1 = atan(((1 - alpha_6) * G6[2] - gamma_6 * G6[3] + (1 - alpha_3) * G3[2] - gamma_3 * G3[3] + (1 - alpha_7) * G7[2] - gamma_7 * G7[3]) / ((1 - alpha_6) * G6[1] + (1 - alpha_3) * G3[1] + (1 - alpha_7) * G7[1]));
//  Phi_A2 = atan((alpha_6 * G6[2] + gamma_6 * G6[3] + alpha_3 * G3[2] + gamma_3 * G3[3] + alpha_7 * G7[2] + gamma_7 * G7[3]) / (alpha_6 * G6[1] + alpha_3 * G3[1] + alpha_7 * G7[1]));
//  Psi_A1 = atan(((1 - alpha_4) * G4[2] - gamma_4 * G4[3] + (1 - alpha_2) * G2[2] - gamma_2 * G2[3] + (1 - alpha_1) * G1[2] - gamma_1 * G1[3] + (1 - alpha_5) * G5[2] - gamma_5 * G5[3]) / ((1 - alpha_4) * G4[1] + (1 - alpha_2) * G2[1] + (1 - alpha_1) * G1[1] + (1 - alpha_5) * G5[1]));
//  Psi_A2 = atan((alpha_4 * G4[2] + gamma_4 * G4[3] + alpha_2 * G2[2] + gamma_2 * G2[3] + alpha_1 * G1[2] + gamma_1 * G1[3] + alpha_5 * G5[2] + gamma_5 * G5[3]) / (alpha_4 * G4[1] + alpha_2 * G2[1] + alpha_1 * G1[1] + alpha_5 * G5[1]));
// 驛｢��ｧ��ｽ��ｽ��ｮ驛｢譎｢��ｽ��､驍ｵ��ｺ��ｽ��ｽ��ｧ鬨ｾ蜈ｷ��ｽ��ｺ鬨ｾ蠅難ｽｺ蛟ｪ��ｽ��ｽ驛｢��ｧ闕ｵ譁溷ｸｷ��ｹ��ｧ��ｽ��ｽ��ｸ驛｢��ｧ��ｽ��ｽ��｢驛｢譎｢��ｽ��ｫ鬮｣蛹��ｽｽ��ｷ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ��ｽ��ｽ��ｽ
//201223ここまで修正
//
          Fr_A1 = sqrt((F_6r_A1 + F_3r_A1 + F_7r_A1) ^ 2 + (F_4r_A1 + F_2r_A1 + F_1r_A1 + F_5r_A1) ^ 2 + 2 * (F_6r_A1 + F_3r_A1 + F_7r_A1) * (F_4r_A1 + F_2r_A1 + F_1r_A1 + F_5r_A1) * cos((-Phi_A1) + Psi_A1 + omega));
          Fr_A2 = sqrt((F_6r_A2 + F_3r_A2 + F_7r_A2) ^ 2 + (F_4r_A2 + F_2r_A2 + F_1r_A2 + F_5r_A2) ^ 2 + 2 * (F_6r_A2 + F_3r_A2 + F_7r_A2) * (F_4r_A2 + F_2r_A2 + F_1r_A2 + F_5r_A2) * cos((-Phi_A2) + Psi_A2 + omega));
// 驛｢��ｧ��ｽ��ｽ��ｮ驛｢譎｢��ｽ��､驍ｵ��ｺ��ｽ��ｽ��ｧ鬨ｾ蜈ｷ��ｽ��ｺ鬨ｾ蠅難ｽｺ蛟ｪ��ｽ��ｽ驛｢��ｧ闕ｵ譏ｴ笳矩Δ譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ陝ｾ��ｮ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ隴会ｽｦ��ｽ��ｽ��ｼ鬩幢ｿｽ��ｽ��ｽ��ｪ陋滂ｽｩ��ｽ��ｽ��ｵ��ｽ��ｽ��ｷ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎冗樟遶企����ｸ��ｺ陷会ｽｱ��ｽ��ｽ��ｽ遶丞｣ｹ笙�驛｢譎｢��ｽ��ｳ驛｢��ｧ��ｽ��ｽ��ｸ驛｢譎｢��ｽ��ｳ驍ｵ��ｺ��ｽ��ｽ��ｫ髯ｷ��ｷ闔会ｽ｣��ゑｽｰ驍ｵ��ｺ��ｽ��ｽ��ｽ��ｽ��ｽ��ｽ陝���ｿ髯ｷ��ｷ闔会ｽ｣遯ｶ��ｲ鬮ｮ蜈ｷ��ｿ��ｽ）
          Fth_out = beta_1 * G1[3] + beta_5 * G5[3] + beta_3 * G3[3] + beta_7 * G7[3] + beta_4 * G4[3] + beta_2 * G2[3] + beta_6 * G6[3];
// BRG驍ｵ��ｺ��ｽ��ｽ��ｮ髯ｷ��ｿ陷会ｽｱ￠髫ｰ蝠擾ｿｽ��ｽ隨��ｿｽ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ陝ｾ��ｮ鬯ｩ��･陝�雜｣��ｽ��ｨ髢ｧ��ｲ��ｽ��ｽ��ｮ隴会ｽｦ��ｽ��ｽ��ｼ鬩幢ｿｽ��ｽ��ｽ��ｪ陋滂ｽｩ��ｽ��ｽ��ｵ��ｽ��ｽ��ｷ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎｢��ｽ��ｩ驛｢��ｧ��ｽ��ｽ��ｹ驛｢譎槭Γ��ｽ��ｽ��ｽ��ｽ��ｽ��ｽ隲ｷ��ｮ）
          Fpre_A1 = a_A1 * Toil + b_A1;
          Fpre_A2 = a_A2 * Toil + b_A2;
//
//201223スズキ工藤追加
          Fth_A1 = abs(0.5 * Fth_out);
          Fth_A2 = abs(0.5 * Fth_out);
//201223下記コメントアウト
//  Fth_A1 = (1 + tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_A2 / Y_2 - Fth_out + Fpre_A1) + (1 - tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_A1 / Y_1 + Fpre_A1);
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽ(1 + tanh(Fth_out)) / 2 * (1 + tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - abs(Fth_out))) / 2 * (0.5 * Fr_A2 / Y_2 - abs(Fth_out) + Fpre_A1) + (1 + tanh(Fth_out)) / 2 * (1 - tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - abs(Fth_out))) / 2 * (0.5 * Fr_A1 / Y_1 + Fpre_A1) + (1 - tanh(Fth_out)) / 2 * (1 + tanh(0.5 * (Fr_A1 / Y_1 - Fr_A2 / Y_2) - abs(Fth_out))) / 2 * (0.5 * Fr_A1 / Y_1 + Fpre_A1) + (1 - tanh(Fth_out)) / 2 * (1 - tanh(0.5 * (Fr_A1 / Y_1 - Fr_A2 / Y_2) - abs(Fth_out))) / 2 * (0.5 * Fr_A2 / Y_2 + abs(Fth_out) + Fpre_A1);
//  Fth_A2 = (1 + tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_A2 / Y_2 + Fpre_A2) + (1 - tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - Fth_out)) / 2 * (0.5 * Fr_A1 / Y_1 + Fth_out + Fpre_A2);
// 200324驛｢譎｢��ｽ��｢驛｢譎｢��ｿ��ｽ��ｽ��ｽ��ｽ��取凵蟆��ｿｽ��ｽ��ｮ髮趣ｿｽ��ｽ��ｽ��｣鬩阪ｑ��ｿ��ｽ��ｽ��ｽ��ｽ陜ｨ��ｽ(confidential).xlsx鬯ｩ蛹��ｽｽ��ｩ鬨ｾ蛹��ｽｽ��ｨ髯ｷ鮃ｹ莠ゑｿｽ��ｽ��ｽ��ｽ��ｽ��ｽ(1 + tanh(Fth_out)) / 2 * (1 + tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - abs(Fth_out))) / 2 * (0.5 * Fr_A2 / Y_2 + Fpre_A2) + (1 + tanh(Fth_out)) / 2 * (1 - tanh(0.5 * (Fr_A2 / Y_2 - Fr_A1 / Y_1) - abs(Fth_out))) / 2 * (0.5 * Fr_A1 / Y_1 + abs(Fth_out) + Fpre_A2) + (1 - tanh(Fth_out)) / 2 * (1 + tanh(0.5 * (Fr_A1 / Y_1 - Fr_A2 / Y_2) - abs(Fth_out))) / 2 * (0.5 * Fr_A1 / Y_1 - abs(Fth_out) + Fpre_A2) + (1 - tanh(Fth_out)) / 2 * (1 - tanh(0.5 * (Fr_A1 / Y_1 - Fr_A2 / Y_2) - abs(Fth_out))) / 2 * (0.5 * Fr_A2 / Y_2 + Fpre_A2);
//201223ここまで修正
//
        end Brg_Load_Distribution_A1A2;
      end Calc;

      model ClutchSig
        constant Real w_Threshold = 0.2;
        Modelica.Blocks.Math.Add add(k1 = 1, k2 = -1) annotation(
          Placement(visible = true, transformation(origin = {-60, -4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Gain gain(k = -1) annotation(
          Placement(visible = true, transformation(origin = {-26, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput T1 annotation(
          Placement(visible = true, transformation(origin = {-110, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, -40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput w2 annotation(
          Placement(visible = true, transformation(origin = {120, 40}, extent = {{20, -20}, {-20, 20}}, rotation = 0), iconTransformation(origin = {120, 40}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
        Modelica.Blocks.Math.Product product1 annotation(
          Placement(visible = true, transformation(origin = {28, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput T2 annotation(
          Placement(visible = true, transformation(origin = {110, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.02, k = 1, y(fixed = true), y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-24, 78}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput Tc annotation(
          Placement(visible = true, transformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90), iconTransformation(origin = {0, 120}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
        Modelica.Blocks.Interfaces.RealInput w1 annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds1(smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, table = [-1, 1; -w_Threshold, 1; 0, 0; w_Threshold, -1; 1, -1]) annotation(
          Placement(visible = true, transformation(origin = {-34, -4}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(add.y, combiTable1Ds1.u) annotation(
          Line(points = {{-48, -4}, {-40, -4}, {-40, -4}, {-42, -4}}, color = {0, 0, 127}));
        connect(w2, add.u1) annotation(
          Line(points = {{120, 40}, {-80, 40}, {-80, 2}, {-72, 2}, {-72, 2}}, color = {0, 0, 127}));
        connect(gain.u, product1.y) annotation(
          Line(points = {{-14, -40}, {68, -40}, {68, 0}, {34, 0}}, color = {0, 0, 127}));
        connect(Tc, firstOrder1.u) annotation(
          Line(points = {{0, 120}, {0, 120}, {0, 78}, {-16, 78}, {-16, 78}}, color = {0, 0, 127}));
        connect(w1, add.u2) annotation(
          Line(points = {{-120, 40}, {-88, 40}, {-88, -10}, {-72, -10}, {-72, -10}}, color = {0, 0, 127}));
        connect(firstOrder1.y, product1.u1) annotation(
          Line(points = {{-30, 78}, {-42, 78}, {-42, 58}, {14, 58}, {14, 4}, {20, 4}}, color = {0, 0, 127}));
        connect(combiTable1Ds1.y[1], product1.u2) annotation(
          Line(points = {{-28, -4}, {21, -4}}, color = {0, 0, 127}, thickness = 0.5));
        connect(product1.y, T2) annotation(
          Line(points = {{34, 0}, {68, 0}, {68, -40}, {110, -40}, {110, -40}}, color = {0, 0, 127}));
        connect(gain.y, T1) annotation(
          Line(points = {{-38, -40}, {-102, -40}, {-102, -40}, {-110, -40}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Rectangle(origin = {30, 0}, fillPattern = FillPattern.Solid, extent = {{-10, 80}, {10, -80}}), Rectangle(origin = {-30, 0}, fillPattern = FillPattern.Solid, extent = {{-10, 80}, {10, -80}})}));
      end ClutchSig;
    end Mechanics;

    package Electrics
      model Actuator_eLoss
        Modelica.Blocks.Interfaces.RealInput I_actuator_A annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput V_BT_PNT_Lo_V annotation(
          Placement(visible = true, transformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PHI_TM_PNT_Actuator_W annotation(
          Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Product lossPower annotation(
          Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-58, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(firstOrder1.y, lossPower.u1) annotation(
          Line(points = {{-52, 40}, {-20, 40}, {-20, 6}, {-12, 6}, {-12, 6}}, color = {0, 0, 127}));
        connect(I_actuator_A, firstOrder1.u) annotation(
          Line(points = {{-120, 40}, {-66, 40}, {-66, 40}, {-66, 40}}, color = {0, 0, 127}));
        connect(lossPower.y, PHI_TM_PNT_Actuator_W) annotation(
          Line(points = {{12, 0}, {102, 0}, {102, 0}, {110, 0}}, color = {0, 0, 127}));
        connect(V_BT_PNT_Lo_V, lossPower.u2) annotation(
          Line(points = {{-120, -40}, {-20, -40}, {-20, -6}, {-12, -6}, {-12, -6}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(lineColor = {0, 0, 255}, extent = {{-100, 40}, {100, -40}}, textString = "%name")}));
      end Actuator_eLoss;

      model EOP_eLoss
        Modelica.Blocks.Interfaces.RealInput I_EOP_A annotation(
          Placement(visible = true, transformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput V_BT_PNT_Lo_V annotation(
          Placement(visible = true, transformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput PHI_TM_PNT_EOP_W annotation(
          Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Math.Product lossPower annotation(
          Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, k = 1, y(fixed = true), y_start = 0) annotation(
          Placement(visible = true, transformation(origin = {-58, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      equation
        connect(firstOrder1.y, lossPower.u1) annotation(
          Line(points = {{-52, 40}, {-20, 40}, {-20, 6}, {-12, 6}, {-12, 6}}, color = {0, 0, 127}));
        connect(I_EOP_A, firstOrder1.u) annotation(
          Line(points = {{-120, 40}, {-66, 40}, {-66, 40}, {-66, 40}}, color = {0, 0, 127}));
        connect(lossPower.y, PHI_TM_PNT_EOP_W) annotation(
          Line(points = {{12, 0}, {102, 0}, {102, 0}, {110, 0}}, color = {0, 0, 127}));
        connect(V_BT_PNT_Lo_V, lossPower.u2) annotation(
          Line(points = {{-120, -40}, {-20, -40}, {-20, -6}, {-12, -6}, {-12, -6}}, color = {0, 0, 127}));
        annotation(
          Icon(graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(lineColor = {0, 0, 255}, extent = {{-100, 40}, {100, -40}}, textString = "%name")}));
      end EOP_eLoss;
    end Electrics;

    package Utilities
      model CombiTable3D
        Modelica.Blocks.Interfaces.RealInput u annotation(
          Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput u1 annotation(
          Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealInput u2 annotation(
          Placement(visible = true, transformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
        Modelica.Blocks.Interfaces.RealOutput y annotation(
          Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
        constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
        parameter Real z_ax[:] = {10, 20, 40, 50};
        parameter Integer nz = size(z_ax, 1) "number of zi";
        parameter String filename = "NoName" "File where matrix is stored" annotation(
          Dialog(group = "Table data definition", enable = tableOnFile, loadSelector(filter = "Text files (*.txt);;MATLAB MAT-files (*.mat)", caption = "Open file in which table is present")));
        parameter String tableName = "tab(i) for i=1:nz" "Table name on file" annotation(
          Dialog(group = "Table data definition", enable = tableOnFile));
        parameter Boolean verboseRead = true "= true, if info message that file is loading is to be printed" annotation(
          Dialog(group = "Table data definition", enable = tableOnFile));
        parameter Modelica.Blocks.Types.Smoothness smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments "Smoothness of table interpolation" annotation(
          Dialog(group = "Table data interpretation"));
        parameter Modelica.Blocks.Types.Extrapolation extrapolation = Modelica.Blocks.Types.Extrapolation.LastTwoPoints "Extrapolation of data outside the definition range" annotation(
          Dialog(group = "Table data interpretation"));
        parameter Boolean verboseExtrapolation = false "= true, if warning messages are to be printed if table input is outside the definition range" annotation(
          Dialog(group = "Table data interpretation", enable = extrapolation == Modelica.Blocks.Types.Extrapolation.LastTwoPoints or extrapolation == Modelica.Blocks.Types.Extrapolation.HoldLastPoint));

        class ExternalCombiTable3D
          extends ExternalObject;

          function constructor
            extends Modelica.Icons.Function;
            input String tableName;
            input String fileName;
            input Real z_ax[:];
            input Integer nz;
            input Real table[:, :];
            input Modelica.Blocks.Types.Smoothness smoothness;
            input Modelica.Blocks.Types.Extrapolation extrapolation = Modelica.Blocks.Types.Extrapolation.LastTwoPoints;
            input Boolean verbosRead = true;
            output ExternalCombiTable3D tableID;
          
            external "C" tableID = createCombiTable3D(fileName, tableName, z_ax, nz, table, size(table, 1), size(table, 2), smoothness, extrapolation, verbosRead);
            annotation(
              Include = "#include <CombiTable3D.c>",
              IncludeDirectory = "modelica://TRAMI_L3_HEV/library_etc");
          end constructor;

          function destructor
            extends Modelica.Icons.Function;
            input ExternalCombiTable3D tableID;
          
            external "C" deleteCombiTable3D(tableID);
            annotation(
              Include = "#include <CombiTable3D.c>",
              IncludeDirectory = "modelica://TRAMI_L3_HEV/library_etc");
          end destructor;
        end ExternalCombiTable3D;

        function CombiTable3D_getValue
          extends Modelica.Icons.Function;
          input ExternalCombiTable3D tableID;
          input Real u1;
          input Real u2;
          input Real u3;
          output Real out;
        
          external "C" out = combiTable3D_getValue(tableID, u1, u2, u3);
          annotation(
            Include = "#include <CombiTable3D.c>",
            IncludeDirectory = "modelica://TRAMI_L3_HEV/library_etc");
        end CombiTable3D_getValue;
      protected
        parameter Boolean tableOnFile = true "= true, if table is defined on file or in function usertab" annotation(
          Dialog(group = "Table data definition"));
        parameter Real table[:, :] = fill(0.0, 0, 2) "Table matrix (grid u1 = first column, grid u2 = first row; e.g., table=[0, 0; 0, 1])" annotation(
          Dialog(group = "Table data definition", enable = not tableOnFile));
        parameter ExternalCombiTable3D tableID = ExternalCombiTable3D(if tableOnFile then tableName else "NoName", if tableOnFile and filename <> "NoName" and not Modelica.Utilities.Strings.isEmpty(filename) then currDir + "/Tables/" + filename else "NoName", z_ax, nz, table, smoothness, extrapolation, if tableOnFile then verboseRead else false);
      equation
        y = CombiTable3D_getValue(tableID, u, u1, u2);
        annotation(
          Icon(coordinateSystem(initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Line(origin = {-16, -8}, points = {{-60, 40}, {-60, -40}, {60, -40}, {60, 40}, {30, 40}, {30, -40}, {-30, -40}, {-30, 40}, {-60, 40}, {-60, 20}, {60, 20}, {60, 0}, {-60, 0}, {-60, -20}, {60, -20}, {60, -40}, {-60, -40}, {-60, 40}, {60, 40}, {60, -40}}), Line(origin = {-16, -8}, points = {{0, 40}, {0, -40}}), Line(origin = {-16, -8}, points = {{-60, 40}, {-30, 20}}), Line(origin = {-16, -8}, points = {{-30, 40}, {-60, 20}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, 0}, {-32.3077, 20}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, -20}, {-32.3077, 0}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, -40}, {-32.3077, -20}}), Rectangle(origin = {-16, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-30, 20}, {0, 40}}), Rectangle(origin = {-16, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 20}, {30, 40}}), Line(origin = {-2, 4}, points = {{-60, 40}, {-60, 28}, {60, 28}, {60, 40}, {30, 40}, {30, 28}, {-30, 28}, {-30, 40}, {-60, 40}, {-60, 28}, {60, 28}, {60, 0}, {46, 0}, {46, -20}, {60, -20}, {60, -40}, {46, -40}, {46, 40}, {60, 40}, {60, -40}}), Rectangle(origin = {-2, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Rectangle(origin = {-32, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Line(origin = {-2, 4}, points = {{-60, 40}, {-44, 28}}), Line(origin = {-2, 4}, points = {{-30, 40}, {-48, 28}}), Line(origin = {12, 16}, points = {{-60, 40}, {-60, 28}, {60, 28}, {60, 40}, {30, 40}, {30, 28}, {-30, 28}, {-30, 40}, {-60, 40}, {-60, 28}, {60, 28}, {60, 0}, {46, 0}, {46, -20}, {60, -20}, {60, -40}, {46, -40}, {46, 40}, {60, 40}, {60, -40}}), Rectangle(origin = {12, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Rectangle(origin = {-18, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Line(origin = {12, 16}, points = {{-60, 40}, {-44, 28}}), Rectangle(origin = {9.692, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Rectangle(origin = {-4.308, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Rectangle(origin = {-18.308, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Line(origin = {11.9666, 16.1}, points = {{-30, 40}, {-48, 28}}), Text(origin = {0, 133}, lineColor = {0, 0, 255}, extent = {{-140, 23}, {140, -23}}, textString = "%name")}),
          Diagram(coordinateSystem(initialScale = 0.1)),
          uses(Modelica(version = "3.2.2")));
      end CombiTable3D;

      //  model CombiTable3D
      //    parameter String filename;
      //    constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      //    parameter Real z_ax[:] = {10, 20, 40, 50};
      //    Modelica.Blocks.Tables.CombiTable2D combiTable2D1[nz](each fileName = currDir + "/Tables/" + filename, each smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = {"tab" + String(i) for i in 1:nz}, each tableOnFile = true) annotation(
      //      Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      //    Modelica.Blocks.Interfaces.RealInput u annotation(
      //      Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      //    Modelica.Blocks.Interfaces.RealInput u1 annotation(
      //      Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      //    Modelica.Blocks.Interfaces.RealInput u2 annotation(
      //      Placement(visible = true, transformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      //    parameter Boolean noExtrapolate = true;
      //    parameter Integer nz = size(z_ax, 1) "number of zi";
      //    Real coef[nz - 1];
      //    Real coef_sum;
      //    Real y_u2[nz - 1];
      //    Modelica.Blocks.Interfaces.RealOutput y annotation(
      //      Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      //    Real y_z[nz];
      //  equation
      //    for i in 1:nz loop
      //      combiTable2D1[i].u1 = u;
      //      combiTable2D1[i].u2 = u1;
      //      y_z[i] = combiTable2D1[i].y;
      //    end for;
      //    coef[1] = (1 + sign(z_ax[2] - u2)) / 2;
      //    for i in 2:nz - 2 loop
      //      coef[i] = (1 + sign(u2 - z_ax[i])) / 2 * ((1 + sign(z_ax[i + 1] - u2)) / 2);
      //    end for;
      //    coef[nz - 1] = (1 + sign(u2 - z_ax[nz - 1])) / 2;
      //    coef_sum = sum(coef);
      //    for i in 1:nz - 1 loop
      //      y_u2[i] = y_z[i] + (y_z[i + 1] - y_z[i]) / (z_ax[i + 1] - z_ax[i]) * (u2 - z_ax[i]);
      //    end for;
      //    if noExtrapolate and (u2 < z_ax[1] or u2 >= z_ax[nz]) then
      //      if u2 < z_ax[1] then
      //        y = combiTable2D1[1].y;
      //      else
      //        y = combiTable2D1[nz].y;
      //      end if;
      //    else
      //      y = coef * y_u2;
      //    end if;
      //    annotation(
      //      Icon(coordinateSystem(initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Line(origin = {-16, -8}, points = {{-60, 40}, {-60, -40}, {60, -40}, {60, 40}, {30, 40}, {30, -40}, {-30, -40}, {-30, 40}, {-60, 40}, {-60, 20}, {60, 20}, {60, 0}, {-60, 0}, {-60, -20}, {60, -20}, {60, -40}, {-60, -40}, {-60, 40}, {60, 40}, {60, -40}}), Line(origin = {-16, -8}, points = {{0, 40}, {0, -40}}), Line(origin = {-16, -8}, points = {{-60, 40}, {-30, 20}}), Line(origin = {-16, -8}, points = {{-30, 40}, {-60, 20}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, 0}, {-32.3077, 20}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, -20}, {-32.3077, 0}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, -40}, {-32.3077, -20}}), Rectangle(origin = {-16, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-30, 20}, {0, 40}}), Rectangle(origin = {-16, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 20}, {30, 40}}), Line(origin = {-2, 4}, points = {{-60, 40}, {-60, 28}, {60, 28}, {60, 40}, {30, 40}, {30, 28}, {-30, 28}, {-30, 40}, {-60, 40}, {-60, 28}, {60, 28}, {60, 0}, {46, 0}, {46, -20}, {60, -20}, {60, -40}, {46, -40}, {46, 40}, {60, 40}, {60, -40}}), Rectangle(origin = {-2, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Rectangle(origin = {-32, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Line(origin = {-2, 4}, points = {{-60, 40}, {-44, 28}}), Line(origin = {-2, 4}, points = {{-30, 40}, {-48, 28}}), Line(origin = {12, 16}, points = {{-60, 40}, {-60, 28}, {60, 28}, {60, 40}, {30, 40}, {30, 28}, {-30, 28}, {-30, 40}, {-60, 40}, {-60, 28}, {60, 28}, {60, 0}, {46, 0}, {46, -20}, {60, -20}, {60, -40}, {46, -40}, {46, 40}, {60, 40}, {60, -40}}), Rectangle(origin = {12, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Rectangle(origin = {-18, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Line(origin = {12, 16}, points = {{-60, 40}, {-44, 28}}), Rectangle(origin = {9.692, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Rectangle(origin = {-4.308, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Rectangle(origin = {-18.308, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Line(origin = {11.9666, 16.1}, points = {{-30, 40}, {-48, 28}}), Text(origin = {0, 133}, lineColor = {0, 0, 255}, extent = {{-140, 23}, {140, -23}}, textString = "%name")}),
      //      Diagram(coordinateSystem(initialScale = 0.1)),
      //      uses(Modelica(version = "3.2.2")),
      //      experiment(StartTime = 0, StopTime = 1, Tolerance = 1e-6, Interval = 0.002));
      //  end CombiTable3D;
    end Utilities;
  end TransMission;

  package Control
    block TM_CNT
      extends Modelica.Blocks.Interfaces.DiscreteBlock;

      function TCU_Main_AT_DCT_FUNC
        output Real trans_gear;
        output Real trans_gear_ratio;
        output Real tau_clutch_cap[12];
        output Real f_synchro_n[11];
        output Real tau_k0_clutch_cap;
        output Real tau_p2m_target;
        output Real p_line_pa;
        output Real p_pulley_pri_pa;
        output Real p_pulley_sec_pa;
        output Real i_actuator_ampere;
        output Real i_eop_ampere;
        output Real qv_cooler_trans_fluid_m3ps;
        output Real qv_cooler_eng_water_m3ps;
        output Real trans_torq_gain;
        output Real flag_shift;
        output Real tau_engine_max_req;
        output Real tau_engine_min_req;
        output Real w_engine_target_radps;
        output Real tau_trans_input;
        output Real flag_trans_lock_up;
        output Real obs_tcu[10];
        input Real flag_initialize;
        input Real w_starting_device_input_radps;
        input Real w_gearbox_input_radps;
        input Real w_gearbox_output_radps;
        input Real w_synchoro_dif_radps[:];
        input Real t_trans_fluid_k;
        input Real t_engine_water_k;
        input Real v_vehicle_mps;
        input Real tau_brake;
        input Real accel_position_per;
        input Real trans_shifter_position;
        input Real w_engine_radps;
        input Real w_engine_idle_radps;
        input Real tau_engine_target;
        input Real tau_engine;
        input Real tau_engine_min_pos;
        input Real tau_engine_max_pos;
        input Real tau_p2m_req;
        input Real flag_k0_clutch_open;
        input Real drive_mode;
        input Real T;
      
        external "C" TCU_IF(trans_gear, trans_gear_ratio, tau_clutch_cap, f_synchro_n, tau_k0_clutch_cap, tau_p2m_target, p_line_pa, p_pulley_pri_pa, p_pulley_sec_pa, i_actuator_ampere, i_eop_ampere, qv_cooler_trans_fluid_m3ps, qv_cooler_eng_water_m3ps, trans_torq_gain, flag_shift, tau_engine_max_req, tau_engine_min_req, w_engine_target_radps, tau_trans_input, flag_trans_lock_up, flag_initialize, w_starting_device_input_radps, w_gearbox_input_radps, w_gearbox_output_radps, w_synchoro_dif_radps, t_trans_fluid_k, t_engine_water_k, v_vehicle_mps, tau_brake, accel_position_per, trans_shifter_position, w_engine_radps, w_engine_idle_radps, tau_engine_target, tau_engine, tau_engine_min_pos, tau_engine_max_pos, tau_p2m_req, flag_k0_clutch_open, drive_mode, obs_tcu, T);
        annotation(
          Include = "#include <TCU_IF.c>",
          IncludeDirectory = "modelica://TRAMI_L3_HEV/library_etc");
      end TCU_Main_AT_DCT_FUNC;

      Real T(start = 0, fixed = true);
      Modelica.Blocks.Interfaces.RealInput flag_initialize annotation(
        Placement(visible = true, transformation(origin = {-120, 580}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 580}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_starting_device_input_radps annotation(
        Placement(visible = true, transformation(origin = {-120, 540}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 520}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_gearbox_input_radps annotation(
        Placement(visible = true, transformation(origin = {-120, 500}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 460}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput trans_gear annotation(
        Placement(visible = true, transformation(origin = {120, 580}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 580}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput trans_gear_ratio annotation(
        Placement(visible = true, transformation(origin = {120, 540}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 520}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_gearbox_output_radps annotation(
        Placement(visible = true, transformation(origin = {-120, 460}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 402}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_synchoro_dif_radps[11] annotation(
        Placement(visible = true, transformation(origin = {-120, 420}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 340}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput t_trans_fluid_k annotation(
        Placement(visible = true, transformation(origin = {-120, 380}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 280}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput t_engine_water_k annotation(
        Placement(visible = true, transformation(origin = {-120, 340}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 220}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput v_vehicle_mps annotation(
        Placement(visible = true, transformation(origin = {-120, 300}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_brake annotation(
        Placement(visible = true, transformation(origin = {-120, 260}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput accel_position_per annotation(
        Placement(visible = true, transformation(origin = {-120, 220}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput trans_shifter_position annotation(
        Placement(visible = true, transformation(origin = {-120, 180}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_engine_radps annotation(
        Placement(visible = true, transformation(origin = {-120, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine_target annotation(
        Placement(visible = true, transformation(origin = {-120, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_engine_idle_radps annotation(
        Placement(visible = true, transformation(origin = {-120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine annotation(
        Placement(visible = true, transformation(origin = {-120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -260}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine_max_pos annotation(
        Placement(visible = true, transformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -380}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine_min_pos annotation(
        Placement(visible = true, transformation(origin = {-120, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -320}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_p2m_req annotation(
        Placement(visible = true, transformation(origin = {-120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -440}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_k0_clutch_open annotation(
        Placement(visible = true, transformation(origin = {-120, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -500}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput drive_mode annotation(
        Placement(visible = true, transformation(origin = {-120, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -560}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_clutch_cap[12] annotation(
        Placement(visible = true, transformation(origin = {120, 500}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 460}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_p2m_target annotation(
        Placement(visible = true, transformation(origin = {120, 380}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 280}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_k0_clutch_cap annotation(
        Placement(visible = true, transformation(origin = {120, 420}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 340}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput f_synchro_n[11] annotation(
        Placement(visible = true, transformation(origin = {120, 460}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 400}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput i_actuator_ampere annotation(
        Placement(visible = true, transformation(origin = {120, 220}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput p_pulley_sec_pa annotation(
        Placement(visible = true, transformation(origin = {120, 260}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput p_pulley_pri_pa annotation(
        Placement(visible = true, transformation(origin = {120, 300}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 160}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput p_line_pa annotation(
        Placement(visible = true, transformation(origin = {120, 340}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, 220}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput trans_torq_gain annotation(
        Placement(visible = true, transformation(origin = {120, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput qv_cooler_eng_water_m3ps annotation(
        Placement(visible = true, transformation(origin = {120, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput qv_cooler_trans_fluid_m3ps annotation(
        Placement(visible = true, transformation(origin = {120, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput i_eop_ampere annotation(
        Placement(visible = true, transformation(origin = {120, 180}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_engine_target_radps annotation(
        Placement(visible = true, transformation(origin = {120, -100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -440}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_engine_min_req annotation(
        Placement(visible = true, transformation(origin = {120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -380}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_engine_max_req annotation(
        Placement(visible = true, transformation(origin = {120, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -320}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput flag_shift annotation(
        Placement(visible = true, transformation(origin = {120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -260}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput flag_trans_lock_up annotation(
        Placement(visible = true, transformation(origin = {120, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -558}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_trans_input annotation(
        Placement(visible = true, transformation(origin = {120, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -500}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput obs_tcu[10] annotation(
        Placement(visible = true, transformation(origin = {120, -220}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120, -620}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    equation
      when {sampleTrigger, initial()} then
        (trans_gear, trans_gear_ratio, tau_clutch_cap, f_synchro_n, tau_k0_clutch_cap, tau_p2m_target, p_line_pa, p_pulley_pri_pa, p_pulley_sec_pa, i_actuator_ampere, i_eop_ampere, qv_cooler_trans_fluid_m3ps, qv_cooler_eng_water_m3ps, trans_torq_gain, flag_shift, tau_engine_max_req, tau_engine_min_req, w_engine_target_radps, tau_trans_input, flag_trans_lock_up, obs_tcu) = TCU_Main_AT_DCT_FUNC(flag_initialize, w_starting_device_input_radps, w_gearbox_input_radps, w_gearbox_output_radps, w_synchoro_dif_radps, t_trans_fluid_k, t_engine_water_k, v_vehicle_mps, tau_brake, accel_position_per, trans_shifter_position, w_engine_radps, w_engine_idle_radps, tau_engine_target, tau_engine, tau_engine_min_pos, tau_engine_max_pos, tau_p2m_req, flag_k0_clutch_open, drive_mode, T);
//
//
        T = pre(T) + 1;
      end when;
      annotation(
        Icon(graphics = {Text(origin = {-18, 6}, extent = {{-82, 24}, {108, -50}}, textString = "TCU"), Rectangle(fillColor = {85, 255, 255}, fillPattern = FillPattern.Solid, lineThickness = 0.5, extent = {{-100, 600}, {100, -600}}), Text(origin = {-47, 9}, extent = {{-55, 99}, {145, -119}}, textString = "TCU", textStyle = {TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold})}, coordinateSystem(extent = {{-100, -600}, {100, 600}}, preserveAspectRatio = false, initialScale = 0.1)),
        Diagram(coordinateSystem(extent = {{-100, -600}, {100, 600}}, preserveAspectRatio = false)));
    end TM_CNT;
  end Control;

  package Vehicle
    model ENGINE
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      parameter String Engine_Trq_Map = "ENGINE_TRQ_MAP.txt";
      parameter String Engine_Trq_Table = "ENGINE_TRQ_MAP";
      Modelica.Blocks.Interfaces.RealInput accel_position_per annotation(
        Placement(visible = true, transformation(origin = {-114, 80}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-94, 60}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
      Modelica.Blocks.Math.Gain rpm(k = 60 / (2 * Modelica.Constants.pi)) annotation(
        Placement(visible = true, transformation(origin = {68, 36}, extent = {{-10, 10}, {10, -10}}, rotation = 180)));
      Modelica.Blocks.Nonlinear.Limiter limiter1(limitsAtInit = true, uMax = 6300, uMin = -5) annotation(
        Placement(visible = true, transformation(origin = {36, 36}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_ENG_PNT_radps annotation(
        Placement(visible = true, transformation(origin = {110, 36}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {90, 60}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_engine annotation(
        Placement(visible = true, transformation(origin = {110, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.Limiter limiter2(limitsAtInit = true, uMax = 1000, uMin = -100) annotation(
        Placement(visible = true, transformation(origin = {-80, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_eng_target annotation(
        Placement(visible = true, transformation(origin = {-114, -20}, extent = {{-14, -14}, {14, 14}}, rotation = 0), iconTransformation(origin = {-94, -40}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D(table = [-100, 100; 0, 0; 200, -100; 250, -100; 600, 0; 7000, 0]) annotation(
        Placement(visible = true, transformation(origin = {-12, 36}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add annotation(
        Placement(visible = true, transformation(origin = {-12, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.05, initType = Modelica.Blocks.Types.Init.InitialOutput, k = 1, y(start = 0), y_start = 0) annotation(
        Placement(visible = true, transformation(origin = {-50, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      TRAMI_L3_HEV.Vehicle.HeatFlow heatFlow annotation(
        Placement(visible = true, transformation(origin = {50, -70}, extent = {{-10, -10}, {18, 10}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {20, -14}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput Engine_Q annotation(
        Placement(visible = true, transformation(origin = {110, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(rpm.y, limiter1.u) annotation(
        Line(points = {{57, 36}, {48, 36}}, color = {0, 0, 127}));
      connect(limiter1.y, combiTable1D.u[1]) annotation(
        Line(points = {{25, 36}, {0, 36}}, color = {0, 0, 127}));
      connect(tau_eng_target, limiter2.u) annotation(
        Line(points = {{-114, -20}, {-92, -20}}, color = {0, 0, 127}));
      connect(add.y, tau_engine) annotation(
        Line(points = {{0, -14}, {110, -14}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, rpm.u) annotation(
        Line(points = {{110, 36}, {80, 36}}, color = {0, 0, 127}));
      connect(combiTable1D.y[1], add.u1) annotation(
        Line(points = {{-22, 36}, {-36, 36}, {-36, -8}, {-24, -8}, {-24, -8}}, color = {0, 0, 127}));
      connect(limiter2.y, firstOrder.u) annotation(
        Line(points = {{-69, -20}, {-57, -20}}, color = {0, 0, 127}));
      connect(firstOrder.y, add.u2) annotation(
        Line(points = {{-44, -20}, {-24, -20}, {-24, -20}, {-24, -20}}, color = {0, 0, 127}));
      connect(add.y, heatFlow.tau_engine) annotation(
        Line(points = {{0, -14}, {20, -14}, {20, -64}, {38, -64}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, heatFlow.w_ENG_PNT_radps) annotation(
        Line(points = {{110, 36}, {90, 36}, {90, 0}, {10, 0}, {10, -76}, {38, -76}}, color = {0, 0, 127}));
      connect(heatFlow.coolant_thermal_flow, Engine_Q) annotation(
        Line(points = {{70, -70}, {100, -70}, {100, -70}, {110, -70}}, color = {0, 0, 127}));
    protected
      annotation(
        Icon(graphics = {Rectangle(origin = {9, 2}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-89, 98}, {71, -102}}), Rectangle(origin = {3, 48}, fillColor = {176, 176, 176}, fillPattern = FillPattern.Solid, extent = {{-43, 38}, {37, -46}}), Rectangle(origin = {2, 39}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-26, 35}, {24, -37}}), Rectangle(origin = {0, 34}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-24, 14}, {26, -14}}), Ellipse(origin = {1, 21}, lineColor = {117, 117, 117}, fillColor = {117, 117, 117}, fillPattern = FillPattern.Solid, extent = {{-5, 5}, {5, -5}}, endAngle = 360), Ellipse(origin = {-31, -37}, fillPattern = FillPattern.Solid, extent = {{-21, 23}, {55, -55}}, endAngle = 360), Rectangle(origin = {6, -57}, lineColor = {255, 255, 255}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-20, 45}, {18, -35}}), Ellipse(origin = {-19, -49}, lineColor = {117, 117, 117}, fillColor = {117, 117, 117}, fillPattern = FillPattern.Solid, extent = {{-7, 7}, {15, -15}}, endAngle = 360), Polygon(origin = {17, -20}, lineColor = {117, 117, 117}, fillColor = {117, 117, 117}, fillPattern = FillPattern.Solid, points = {{-11, 42}, {23, -30}, {3, -42}, {-21, 40}, {-13, 42}, {-11, 42}}), Polygon(origin = {2, -53}, lineColor = {117, 117, 117}, fillColor = {117, 117, 117}, fillPattern = FillPattern.Solid, points = {{-16, 11}, {26, 11}, {24, -11}, {-16, -11}, {-16, 11}}), Ellipse(origin = {25, -49}, lineColor = {117, 117, 117}, fillColor = {117, 117, 117}, fillPattern = FillPattern.Solid, extent = {{-7, 7}, {15, -15}}, endAngle = 360), Ellipse(origin = {-25, -43}, fillPattern = FillPattern.Solid, extent = {{5, -5}, {15, -15}}, endAngle = 360), Ellipse(origin = {19, -43}, fillPattern = FillPattern.Solid, extent = {{3, -3}, {15, -15}}, endAngle = 360), Ellipse(origin = {-7, 29}, fillPattern = FillPattern.Solid, extent = {{5, -5}, {11, -11}}, endAngle = 360)}, coordinateSystem(initialScale = 0.1)),
        Diagram(graphics = {Text(origin = {-166, 36}, lineColor = {255, 0, 0}, extent = {{80, -2}, {122, -18}}, textString = "Starting torque")}, coordinateSystem(initialScale = 0.1)));
    end ENGINE;

    model ECU
      parameter Real Target_Idle_Speed = 650;
      Modelica.Blocks.Sources.Constant targetIdleSpeed(k = Target_Idle_Speed) annotation(
        Placement(visible = true, transformation(origin = {-294, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback1 annotation(
        Placement(visible = true, transformation(origin = {-126, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_eng_target annotation(
        Placement(visible = true, transformation(origin = {394, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_ENG_PNT_radps annotation(
        Placement(visible = true, transformation(origin = {-318, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-40, -18}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_engine_idle_radps annotation(
        Placement(visible = true, transformation(origin = {112, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_eng_req annotation(
        Placement(visible = true, transformation(origin = {-318, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine_max_req annotation(
        Placement(visible = true, transformation(origin = {-192, 126}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 200}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Continuous.PI pi(T = 1, k = 0.5, x(fixed = true)) annotation(
        Placement(visible = true, transformation(origin = {72, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {358, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {24, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Min min annotation(
        Placement(visible = true, transformation(origin = {260, -108}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine_min_req annotation(
        Placement(visible = true, transformation(origin = {-192, 96}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Max max annotation(
        Placement(visible = true, transformation(origin = {-160, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_vcu_eng_speed_req annotation(
        Placement(visible = true, transformation(origin = {-320, -160}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -98}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_vcu_k0_open_req annotation(
        Placement(visible = true, transformation(origin = {-320, -200}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -158}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Max max1 annotation(
        Placement(visible = true, transformation(origin = {220, -114}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Max max2 annotation(
        Placement(visible = true, transformation(origin = {-196, -14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_engine_target_radps annotation(
        Placement(visible = true, transformation(origin = {-320, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -38}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_trans_lock_up annotation(
        Placement(visible = true, transformation(origin = {-320, -240}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -218}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_trans_input annotation(
        Placement(visible = true, transformation(origin = {-320, -280}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -278}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch12 annotation(
        Placement(visible = true, transformation(origin = {314, -116}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add2 annotation(
        Placement(visible = true, transformation(origin = {168, -160}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.Limiter limiter(limitsAtInit = true, uMax = 500, uMin = -500) annotation(
        Placement(visible = true, transformation(origin = {114, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Or or12 annotation(
        Placement(visible = true, transformation(origin = {-138, -152}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.LessThreshold lessThreshold1(threshold = -999) annotation(
        Placement(visible = true, transformation(origin = {-120, -80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D(table = [-100, 100; 0, 0; 200, -10; 500, -10; 7000, -10]) annotation(
        Placement(visible = true, transformation(origin = {310, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold1(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-180, -240}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Not not1 annotation(
        Placement(visible = true, transformation(origin = {-136, -210}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-184, -160}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold2(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-184, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Or or1 annotation(
        Placement(visible = true, transformation(origin = {-94, -180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.UnitConversions.From_rpm from_rpm annotation(
        Placement(visible = true, transformation(origin = {-226, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.UnitConversions.To_rpm to_rpm annotation(
        Placement(visible = true, transformation(origin = {266, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Not not11 annotation(
        Placement(visible = true, transformation(origin = {-86, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Or or11 annotation(
        Placement(visible = true, transformation(origin = {-42, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add annotation(
        Placement(visible = true, transformation(origin = {224, -148}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {-260, -160}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot1 annotation(
        Placement(visible = true, transformation(origin = {-284, -120}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot3 annotation(
        Placement(visible = true, transformation(origin = {-148, -80}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot4 annotation(
        Placement(visible = true, transformation(origin = {-126, -40}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot5 annotation(
        Placement(visible = true, transformation(origin = {194, -120}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot6 annotation(
        Placement(visible = true, transformation(origin = {-104, -80}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot2 annotation(
        Placement(visible = true, transformation(origin = {-160, -240}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    equation
      connect(switch11.y, pi.u) annotation(
        Line(points = {{35, 0}, {60, 0}}, color = {0, 0, 127}));
      connect(tau_engine_max_req, min.u1) annotation(
        Line(points = {{-192, 126}, {236, 126}, {236, -102}, {248, -102}}, color = {0, 0, 127}));
      connect(max.y, feedback1.u1) annotation(
        Line(points = {{-149, 8}, {-134, 8}}, color = {0, 0, 127}));
      connect(const.y, switch11.u3) annotation(
        Line(points = {{-29, -18}, {-24, -18}, {-24, -8}, {12, -8}}, color = {0, 0, 127}));
      connect(feedback1.y, switch11.u1) annotation(
        Line(points = {{-117, 8}, {12, 8}}, color = {0, 0, 127}));
      connect(max1.y, min.u2) annotation(
        Line(points = {{231, -114}, {248, -114}}, color = {0, 0, 127}));
      connect(tau_engine_min_req, max1.u1) annotation(
        Line(points = {{-192, 96}, {196, 96}, {196, -108}, {208, -108}}, color = {0, 0, 127}));
      connect(w_engine_target_radps, max2.u1) annotation(
        Line(points = {{-320, -120}, {-284, -120}, {-284, -8}, {-208, -8}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, feedback1.u2) annotation(
        Line(points = {{-318, -40}, {-126, -40}, {-126, 0}}, color = {0, 0, 127}));
      connect(max2.y, max.u2) annotation(
        Line(points = {{-185, -14}, {-182, -14}, {-182, 2}, {-172, 2}}, color = {0, 0, 127}));
      connect(pi.y, limiter.u) annotation(
        Line(points = {{83, 0}, {102, 0}}, color = {0, 0, 127}));
      connect(limiter.y, add2.u1) annotation(
        Line(points = {{125, 0}, {142, 0}, {142, -154}, {156, -154}}, color = {0, 0, 127}));
      connect(switch1.y, tau_eng_target) annotation(
        Line(points = {{369, -80}, {394, -80}}, color = {0, 0, 127}));
      connect(tau_eng_req, lessThreshold1.u) annotation(
        Line(points = {{-318, -80}, {-132, -80}}, color = {0, 0, 127}));
      connect(lessThreshold1.y, switch1.u2) annotation(
        Line(points = {{-109, -80}, {346, -80}}, color = {255, 0, 255}));
      connect(combiTable1D.y[1], switch1.u1) annotation(
        Line(points = {{321, -40}, {332, -40}, {332, -72}, {346, -72}}, color = {0, 0, 127}));
      connect(flag_trans_lock_up, greaterThreshold1.u) annotation(
        Line(points = {{-320, -240}, {-192, -240}}, color = {0, 0, 127}));
      connect(switch12.y, switch1.u3) annotation(
        Line(points = {{325, -116}, {336, -116}, {336, -88}, {346, -88}}, color = {0, 0, 127}));
      connect(greaterThreshold1.y, switch12.u2) annotation(
        Line(points = {{-169, -240}, {280, -240}, {280, -116}, {302, -116}}, color = {255, 0, 255}));
      connect(min.y, switch12.u1) annotation(
        Line(points = {{271, -108}, {302, -108}}, color = {0, 0, 127}));
      connect(greaterThreshold1.y, not1.u) annotation(
        Line(points = {{-169, -240}, {-160, -240}, {-160, -210}, {-148, -210}}, color = {255, 0, 255}));
      connect(tau_trans_input, add2.u2) annotation(
        Line(points = {{-320, -280}, {142, -280}, {142, -166}, {156, -166}}, color = {0, 0, 127}));
      connect(tau_eng_req, max1.u2) annotation(
        Line(points = {{-318, -80}, {-148, -80}, {-148, -120}, {208, -120}}, color = {0, 0, 127}));
      connect(w_engine_target_radps, greaterThreshold2.u) annotation(
        Line(points = {{-320, -120}, {-196, -120}}, color = {0, 0, 127}));
      connect(greaterThreshold2.y, or12.u1) annotation(
        Line(points = {{-173, -120}, {-162, -120}, {-162, -152}, {-150, -152}}, color = {255, 0, 255}));
      connect(greaterThreshold.y, or12.u2) annotation(
        Line(points = {{-173, -160}, {-150, -160}}, color = {255, 0, 255}));
      connect(or12.y, or1.u1) annotation(
        Line(points = {{-127, -152}, {-114, -152}, {-114, -178}, {-106, -178}, {-106, -180}}, color = {255, 0, 255}));
      connect(not1.y, or1.u2) annotation(
        Line(points = {{-125, -210}, {-114, -210}, {-114, -188}, {-106, -188}}, color = {255, 0, 255}));
      connect(w_vcu_eng_speed_req, greaterThreshold.u) annotation(
        Line(points = {{-320, -160}, {-196, -160}, {-196, -160}, {-196, -160}}, color = {0, 0, 127}));
      connect(w_vcu_eng_speed_req, max2.u2) annotation(
        Line(points = {{-320, -160}, {-260, -160}, {-260, -20}, {-208, -20}}, color = {0, 0, 127}));
      connect(targetIdleSpeed.y, from_rpm.u) annotation(
        Line(points = {{-283, 14}, {-238, 14}}, color = {0, 0, 127}));
      connect(from_rpm.y, max.u1) annotation(
        Line(points = {{-215, 14}, {-172, 14}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, to_rpm.u) annotation(
        Line(points = {{-318, -40}, {254, -40}, {254, -40}, {254, -40}}, color = {0, 0, 127}));
      connect(to_rpm.y, combiTable1D.u[1]) annotation(
        Line(points = {{278, -40}, {300, -40}, {300, -40}, {298, -40}}, color = {0, 0, 127}));
      connect(or11.y, switch11.u2) annotation(
        Line(points = {{-30, -60}, {-6, -60}, {-6, 0}, {12, 0}}, color = {255, 0, 255}));
      connect(not11.y, or11.u1) annotation(
        Line(points = {{-75, -60}, {-54, -60}}, color = {255, 0, 255}));
      connect(or1.y, or11.u2) annotation(
        Line(points = {{-82, -180}, {-70, -180}, {-70, -68}, {-54, -68}, {-54, -68}}, color = {255, 0, 255}));
      connect(add2.y, add.u2) annotation(
        Line(points = {{180, -160}, {194, -160}, {194, -154}, {212, -154}}, color = {0, 0, 127}));
      connect(add.y, switch12.u3) annotation(
        Line(points = {{235, -148}, {296, -148}, {296, -124}, {302, -124}}, color = {0, 0, 127}));
      connect(tau_eng_req, add.u1) annotation(
        Line(points = {{-318, -80}, {-148, -80}, {-148, -120}, {194, -120}, {194, -142}, {212, -142}}, color = {0, 0, 127}));
      connect(from_rpm.y, w_engine_idle_radps) annotation(
        Line(points = {{-214, 14}, {-194, 14}, {-194, 70}, {112, 70}, {112, 70}}, color = {0, 0, 127}));
      connect(lessThreshold1.y, not11.u) annotation(
        Line(points = {{-108, -80}, {-104, -80}, {-104, -60}, {-98, -60}, {-98, -60}}, color = {255, 0, 255}));
      annotation(
        Icon(graphics = {Text(origin = {-33, 1}, extent = {{-47, 19}, {121, -93}}, textString = "ECU", textStyle = {TextStyle.Bold, TextStyle.Bold}), Rectangle(fillColor = {255, 255, 255}, extent = {{-100, 220}, {100, -300}})}, coordinateSystem(extent = {{-100, -300}, {100, 220}}, preserveAspectRatio = false, initialScale = 0.1)),
        Diagram(coordinateSystem(extent = {{-400, -400}, {400, 300}})),
        __OpenModelica_commandLineOptions = "",
        uses(Modelica(version = "3.2.3")));
    end ECU;

    model VEHICLE
      parameter Real Mv = 1710;
      parameter Real Rt = 0.3192;
      parameter Real Coef_A = 153.3;
      parameter Real Coef_B = 0.53989;
      parameter Real Coef_C = 0.0179;
      Modelica.Blocks.Math.Gain gain1(k = 1 / 100) annotation(
        Placement(visible = true, transformation(origin = {-195, -131}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Math.Atan atan1 annotation(
        Placement(visible = true, transformation(origin = {-179, -131}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant CAR_WEIGHT(k = Mv) annotation(
        Placement(visible = true, transformation(origin = {-154, -110}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant ROAD_GRADIENT(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-211, -131}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Math.Gain TIRE_R2(k = Rt) annotation(
        Placement(visible = true, transformation(origin = {40, 54}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain2(k = 3.6) annotation(
        Placement(visible = true, transformation(origin = {64, 54}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain TIRE_R3(k = Rt) annotation(
        Placement(visible = true, transformation(origin = {40, 28}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain3(k = 1 / 9.8) annotation(
        Placement(visible = true, transformation(origin = {66, 28}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Cd(k = Coef_C) annotation(
        Placement(visible = true, transformation(origin = {-165, -67}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Math.Product product7 annotation(
        Placement(visible = true, transformation(origin = {-132, -60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product8 annotation(
        Placement(visible = true, transformation(origin = {-132, -120}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Sin sin1 annotation(
        Placement(visible = true, transformation(origin = {-153, -131}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput v_vehicle_mps annotation(
        Placement(visible = true, transformation(origin = {118, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {106, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain8(k = -9.8) annotation(
        Placement(visible = true, transformation(origin = {-104, -120}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain7(k = -Rt) annotation(
        Placement(visible = true, transformation(origin = {-154, 6}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product9 annotation(
        Placement(visible = true, transformation(origin = {-189, -53}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput out_vehicle_G_g annotation(
        Placement(visible = true, transformation(origin = {118, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {106, -20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Sensors.TorqueSensor torqueSensor1 annotation(
        Placement(visible = true, transformation(origin = {-56, 100}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia1(J = Mv * Rt ^ 2 + 3.05, phi(fixed = true, start = 0), w(start = 0)) annotation(
        Placement(visible = true, transformation(origin = {-6, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Damper damper1(d = 0, w_rel(fixed = true)) annotation(
        Placement(visible = true, transformation(origin = {76, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Fixed fixed1 annotation(
        Placement(visible = true, transformation(origin = {116, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Sources.Torque LoadTorque annotation(
        Placement(visible = true, transformation(origin = {-34, 12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Sensors.SpeedSensor WheelSpeedW annotation(
        Placement(visible = true, transformation(origin = {26, 80}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Mechanics.Rotational.Sensors.AccSensor accSensor1 annotation(
        Placement(visible = true, transformation(origin = {14, 48}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Add add1 annotation(
        Placement(visible = true, transformation(origin = {-81, -45}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Math.Add add2 annotation(
        Placement(visible = true, transformation(origin = {-17, -53}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Brake brake1(cgeo = 1, fn_max = 2000, mue_pos = [0, 1], peak = 1, sa(start = 0)) annotation(
        Placement(visible = true, transformation(origin = {-148, 100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_brake annotation(
        Placement(visible = true, transformation(origin = {-220, 132}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-110, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_DS_PNT_out_Nm annotation(
        Placement(visible = true, transformation(origin = {-238, 82}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_DS_PNT_out_radps annotation(
        Placement(visible = true, transformation(origin = {-238, 102}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, -20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain9(k = 1000 / 3600) annotation(
        Placement(visible = true, transformation(origin = {96, 54}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = Coef_A) annotation(
        Placement(visible = true, transformation(origin = {-121, -41}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor1 annotation(
        Placement(visible = true, transformation(origin = {-172, 70}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
      Modelica.Blocks.Math.Product product1 annotation(
        Placement(visible = true, transformation(origin = {-102, 12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.TorqueToAngleAdaptor torqueToAngleAdaptor1(use_a = false, use_w = true) annotation(
        Placement(visible = true, transformation(origin = {-188, 100}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain4(k = -1) annotation(
        Placement(visible = true, transformation(origin = {-210, 82}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds1(table = [-1, -1; -0.1, -1; 0, 0; 0.1, 1; 1, 1]) annotation(
        Placement(visible = true, transformation(origin = {-150, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = 1 / 2000) annotation(
        Placement(visible = true, transformation(origin = {-162, 132}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Add add annotation(
        Placement(visible = true, transformation(origin = {-55, -49}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {-104, -82}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = Coef_B) annotation(
        Placement(visible = true, transformation(origin = {-143, -93}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
    equation
      connect(combiTable1Ds1.y[1], product1.u1) annotation(
        Line(points = {{-138, 34}, {-126, 34}, {-126, 18}, {-114, 18}, {-114, 18}}, color = {0, 0, 127}, thickness = 0.5));
      connect(speedSensor1.w, combiTable1Ds1.u) annotation(
        Line(points = {{-172, 60}, {-172, 60}, {-172, 34}, {-162, 34}, {-162, 34}}, color = {0, 0, 127}));
      connect(torqueToAngleAdaptor1.flange, speedSensor1.flange) annotation(
        Line(points = {{-186, 100}, {-172, 100}, {-172, 80}, {-172, 80}}));
      connect(gain7.y, product1.u2) annotation(
        Line(points = {{-148, 6}, {-114, 6}, {-114, 6}, {-114, 6}}, color = {0, 0, 127}));
      connect(add2.y, gain7.u) annotation(
        Line(points = {{-9, -53}, {0, -53}, {0, -26}, {-176, -26}, {-176, 6}, {-161, 6}}, color = {0, 0, 127}));
      connect(gain4.y, torqueToAngleAdaptor1.tau) annotation(
        Line(points = {{-204, 82}, {-198, 82}, {-198, 92}, {-192, 92}, {-192, 92}}, color = {0, 0, 127}));
      connect(tau_DS_PNT_out_Nm, gain4.u) annotation(
        Line(points = {{-238, 82}, {-218, 82}, {-218, 82}, {-218, 82}}, color = {0, 0, 127}));
      connect(product1.y, LoadTorque.tau) annotation(
        Line(points = {{-90, 12}, {-48, 12}, {-48, 12}, {-46, 12}}, color = {0, 0, 127}));
      connect(torqueToAngleAdaptor1.flange, brake1.flange_a) annotation(
        Line(points = {{-186, 100}, {-158, 100}, {-158, 100}, {-158, 100}}));
      connect(w_DS_PNT_out_radps, torqueToAngleAdaptor1.w) annotation(
        Line(points = {{-238, 102}, {-208, 102}, {-208, 102}, {-192, 102}, {-192, 104}}, color = {0, 0, 127}));
      connect(LoadTorque.flange, inertia1.flange_a) annotation(
        Line(points = {{-24, 12}, {-16, 12}, {-16, 100}, {-16, 100}}));
      connect(brake1.flange_b, torqueSensor1.flange_a) annotation(
        Line(points = {{-138, 100}, {-66, 100}, {-66, 100}, {-66, 100}}));
      connect(gain8.y, add2.u2) annotation(
        Line(points = {{-97, -120}, {-39.4, -120}, {-39.4, -62}, {-25, -62}, {-25, -57}}, color = {0, 0, 127}));
      connect(const.y, add1.u1) annotation(
        Line(points = {{-115.5, -41}, {-89, -41}}, color = {0, 0, 127}));
      connect(product7.y, add1.u2) annotation(
        Line(points = {{-125, -60}, {-113.4, -60}, {-113.4, -49}, {-89, -49}}, color = {0, 0, 127}));
      connect(product9.y, product7.u1) annotation(
        Line(points = {{-183.5, -53}, {-150, -53}, {-150, -56}, {-139, -56}}, color = {0, 0, 127}));
      connect(gain2.y, product9.u1) annotation(
        Line(points = {{70, 54}, {80, 54}, {80, -146}, {-238, -146}, {-238, -50}, {-195, -50}}, color = {0, 0, 127}));
      connect(gain2.y, product9.u2) annotation(
        Line(points = {{70, 54}, {80, 54}, {80, -146}, {-238, -146}, {-238, -56}, {-195, -56}}, color = {0, 0, 127}));
      connect(product8.y, gain8.u) annotation(
        Line(points = {{-125.4, -120}, {-111, -120}}, color = {0, 0, 127}));
      connect(sin1.y, product8.u2) annotation(
        Line(points = {{-147.5, -131}, {-146.375, -131}, {-146.375, -131}, {-145.25, -131}, {-145.25, -131}, {-143, -131}, {-143, -124}, {-141.5, -124}, {-141.5, -124}, {-140, -124}}, color = {0, 0, 127}));
      connect(atan1.y, sin1.u) annotation(
        Line(points = {{-173.5, -131}, {-159.5, -131}}, color = {0, 0, 127}));
      connect(CAR_WEIGHT.y, product8.u1) annotation(
        Line(points = {{-147.4, -110}, {-143.4, -110}, {-143.4, -116}, {-139.4, -116}, {-139.4, -116}, {-139.4, -116}, {-139.4, -116}}, color = {0, 0, 127}));
      connect(ROAD_GRADIENT.y, gain1.u) annotation(
        Line(points = {{-205.5, -131}, {-201.5, -131}}, color = {0, 0, 127}));
      connect(gain1.y, atan1.u) annotation(
        Line(points = {{-189.5, -131}, {-185.5, -131}}, color = {0, 0, 127}));
      connect(torqueSensor1.flange_b, inertia1.flange_a) annotation(
        Line(points = {{-46, 100}, {-16, 100}}));
      connect(accSensor1.a, TIRE_R3.u) annotation(
        Line(points = {{14, 38}, {14, 38}, {14, 28}, {32, 28}, {32, 28}}, color = {0, 0, 127}));
      connect(gain9.y, v_vehicle_mps) annotation(
        Line(points = {{102, 54}, {112, 54}, {112, 54}, {118, 54}}, color = {0, 0, 127}));
      connect(gain9.u, gain2.y) annotation(
        Line(points = {{88, 54}, {70, 54}, {70, 54}, {70, 54}}, color = {0, 0, 127}));
      connect(inertia1.flange_b, accSensor1.flange) annotation(
        Line(points = {{4, 100}, {14, 100}, {14, 58}, {14, 58}}));
      connect(gain3.y, out_vehicle_G_g) annotation(
        Line(points = {{73, 28}, {116, 28}}, color = {0, 0, 127}));
      connect(TIRE_R2.u, WheelSpeedW.w) annotation(
        Line(points = {{33, 54}, {26, 54}, {26, 69}}, color = {0, 0, 127}));
      connect(inertia1.flange_b, WheelSpeedW.flange) annotation(
        Line(points = {{4, 100}, {26, 100}, {26, 90}}));
      connect(TIRE_R3.y, gain3.u) annotation(
        Line(points = {{47, 28}, {59, 28}}, color = {0, 0, 127}));
      connect(TIRE_R2.y, gain2.u) annotation(
        Line(points = {{47, 54}, {57, 54}}, color = {0, 0, 127}));
      connect(inertia1.flange_b, damper1.flange_a) annotation(
        Line(points = {{4, 100}, {66, 100}}));
      connect(damper1.flange_b, fixed1.flange) annotation(
        Line(points = {{86, 100}, {116, 100}, {116, 100}, {116, 100}}));
      connect(tau_brake, gain.u) annotation(
        Line(points = {{-220, 132}, {-170, 132}, {-170, 132}, {-170, 132}}, color = {0, 0, 127}));
      connect(gain.y, brake1.f_normalized) annotation(
        Line(points = {{-156, 132}, {-148, 132}, {-148, 112}, {-148, 112}}, color = {0, 0, 127}));
      connect(add1.y, add.u1) annotation(
        Line(points = {{-73, -45}, {-63, -45}}, color = {0, 0, 127}));
      connect(add.y, add2.u1) annotation(
        Line(points = {{-47, -49}, {-25, -49}}, color = {0, 0, 127}));
      connect(Cd.y, product7.u2) annotation(
        Line(points = {{-159.5, -67}, {-148, -67}, {-148, -64}, {-139, -64}}, color = {0, 0, 127}));
      connect(const1.y, product.u2) annotation(
        Line(points = {{-138, -92}, {-122, -92}, {-122, -86}, {-112, -86}, {-112, -86}}, color = {0, 0, 127}));
      connect(product.y, add.u2) annotation(
        Line(points = {{-98, -82}, {-70, -82}, {-70, -52}, {-64, -52}, {-64, -54}}, color = {0, 0, 127}));
      connect(gain2.y, product.u1) annotation(
        Line(points = {{70, 54}, {80, 54}, {80, -146}, {-238, -146}, {-238, -78}, {-112, -78}, {-112, -78}}, color = {0, 0, 127}));
      annotation(
        Icon(graphics = {Polygon(origin = {3, 42}, fillColor = {0, 170, 255}, fillPattern = FillPattern.Solid, points = {{-43, 30}, {7, 30}, {37, -2}, {77, -2}, {77, -36}, {-83, -36}, {-83, -2}, {-63, -2}, {-43, 30}}), Polygon(origin = {11, 54}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, points = {{-31, 14}, {-5, 14}, {21, -14}, {-31, -14}, {-31, 14}}), Polygon(origin = {-39, 54}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, points = {{1, 14}, {-15, -14}, {15, -14}, {15, 14}, {1, 14}}), Ellipse(origin = {-45, 7}, fillPattern = FillPattern.Solid, extent = {{-15, 15}, {15, -15}}, endAngle = 360), Ellipse(origin = {47, 7}, fillPattern = FillPattern.Solid, extent = {{-15, 15}, {15, -15}}, endAngle = 360), Rectangle(origin = {0, 30}, extent = {{-100, 70}, {100, -70}})}, coordinateSystem(extent = {{-100, -40}, {100, 100}}, preserveAspectRatio = false, initialScale = 0.05)),
        Diagram(coordinateSystem(extent = {{-300, -240}, {200, 140}}, preserveAspectRatio = false, initialScale = 0.05)),
        __OpenModelica_commandLineOptions = "");
    end VEHICLE;

    model Driver
      parameter Real Jfw = 0.29;
      parameter Real Mv = 1710;
      parameter Real Rt = 0.3192;
      parameter Real Final_GearRatio = 3.066;
      parameter Real Coef_A = 153.3;
      parameter Real Coef_B = 0.053989;
      parameter Real Coef_C = 0.03179;
      parameter String Accelerator_FileName;
      parameter String Accelerator_tabName;
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      Modelica.Blocks.Interfaces.RealInput Target_Speed annotation(
        Placement(visible = true, transformation(origin = {-322, 122}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, 180}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput v_vehicle_mps annotation(
        Placement(visible = true, transformation(origin = {-318, -124}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Gain kph2mps(k = 1000 / 3600) annotation(
        Placement(visible = true, transformation(origin = {-260, 122}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Continuous.Der der1 annotation(
        Placement(visible = true, transformation(origin = {-218, 122}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = Mv) annotation(
        Placement(visible = true, transformation(origin = {-226, 104}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product1 annotation(
        Placement(visible = true, transformation(origin = {-192, 108}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product2 annotation(
        Placement(visible = true, transformation(origin = {-232, 84}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = Coef_C) annotation(
        Placement(visible = true, transformation(origin = {-288, 76}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product3 annotation(
        Placement(visible = true, transformation(origin = {-212, 80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const2(k = Coef_A) annotation(
        Placement(visible = true, transformation(origin = {-222, 44}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant TireRadius(k = Rt) annotation(
        Placement(visible = true, transformation(origin = {-168, 52}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Add3 add31 annotation(
        Placement(visible = true, transformation(origin = {-168, 76}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product tire_torque annotation(
        Placement(visible = true, transformation(origin = {-142, 72}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput torque_gain_drivetrain annotation(
        Placement(visible = true, transformation(origin = {-318, -66}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_ENG_PNT_radps annotation(
        Placement(visible = true, transformation(origin = {-318, -156}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Gain radps2rpm(k = 60 / (2 * Modelica.Constants.pi)) annotation(
        Placement(visible = true, transformation(origin = {-244, -156}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Division EngineOutputTorque annotation(
        Placement(visible = true, transformation(origin = {-50, 68}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback1 annotation(
        Placement(visible = true, transformation(origin = {-214, -112}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds1(table = [-1, 0; 0, 0; 0.1, 1; 1, 1]) annotation(
        Placement(visible = true, transformation(origin = {-228, 24}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product5 annotation(
        Placement(visible = true, transformation(origin = {-198, 28}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Abs abs1 annotation(
        Placement(visible = true, transformation(origin = {-162, -78}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch12 annotation(
        Placement(visible = true, transformation(origin = {-108, -78}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.LessThreshold lessThreshold1(threshold = 1e-3) annotation(
        Placement(visible = true, transformation(origin = {-142, -78}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const6(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-136, -48}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const8(k = Jfw) annotation(
        Placement(visible = true, transformation(origin = {-116, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Add torque_Total annotation(
        Placement(visible = true, transformation(origin = {-20, 42}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Division tire_radps2 annotation(
        Placement(visible = true, transformation(origin = {-140, 46}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product torque_FlyWheel annotation(
        Placement(visible = true, transformation(origin = {-50, 38}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product EngineOutput_radps2 annotation(
        Placement(visible = true, transformation(origin = {-102, 42}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Add add2 annotation(
        Placement(visible = true, transformation(origin = {68, 38}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_drive_shaft_target annotation(
        Placement(visible = true, transformation(origin = {310, 184}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Continuous.PID PID1(Nd = 10, Td = 0.05, Ti = 1, initType = Modelica.Blocks.Types.InitPID.InitialState, k = 20, y_start = 0) annotation(
        Placement(visible = true, transformation(origin = {14, -106}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_gearbox_input_target annotation(
        Placement(visible = true, transformation(origin = {312, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Division division1 annotation(
        Placement(visible = true, transformation(origin = {260, 44}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant MAX_Torque(k = 350 / 100) annotation(
        Placement(visible = true, transformation(origin = {232, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput accel_position_per annotation(
        Placement(visible = true, transformation(origin = {310, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.Limiter limiter(limitsAtInit = true, uMax = 100, uMin = 0) annotation(
        Placement(visible = true, transformation(origin = {284, 44}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {228, 184}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_shift annotation(
        Placement(visible = true, transformation(origin = {-316, -186}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, -120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold2(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-216, -186}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {-18, -106}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const10(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-54, -90}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput drive_mode annotation(
        Placement(visible = true, transformation(origin = {294, -226}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-212, -66}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Division division annotation(
        Placement(visible = true, transformation(origin = {-142, 2}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Continuous.Derivative derivative(x(fixed = true)) annotation(
        Placement(visible = true, transformation(origin = {-44, -6}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product7 annotation(
        Placement(visible = true, transformation(origin = {-18, -2}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product8 annotation(
        Placement(visible = true, transformation(origin = {14, 12}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.Limiter limiter1(limitsAtInit = true, uMax = 350, uMin = -20000) annotation(
        Placement(visible = true, transformation(origin = {188, 120}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.Limiter limiter2(limitsAtInit = true, uMax = 50, uMin = -50) annotation(
        Placement(visible = true, transformation(origin = {44, 12}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Math.Add add3 annotation(
        Placement(visible = true, transformation(origin = {-190, 76}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product4 annotation(
        Placement(visible = true, transformation(origin = {-212, 64}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const4(k = Coef_B) annotation(
        Placement(visible = true, transformation(origin = {-288, 50}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput drive_mode_req annotation(
        Placement(visible = true, transformation(origin = {-318, -226}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, -180}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {156, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold = 0.01) annotation(
        Placement(visible = true, transformation(origin = {50, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const5(k = -2000) annotation(
        Placement(visible = true, transformation(origin = {126, 98}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-272, -66}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_vcu_k0_open_req annotation(
        Placement(visible = true, transformation(origin = {-282, -266}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, -240}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold1(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-218, -266}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch13 annotation(
        Placement(visible = true, transformation(origin = {-78, 24}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const3(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-102, 28}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {-272, 80}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot1 annotation(
        Placement(visible = true, transformation(origin = {-272, 88}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot2 annotation(
        Placement(visible = true, transformation(origin = {-158, 52}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot3 annotation(
        Placement(visible = true, transformation(origin = {-158, 42}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot4 annotation(
        Placement(visible = true, transformation(origin = {-248, 6}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot5 annotation(
        Placement(visible = true, transformation(origin = {-248, 24}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot6 annotation(
        Placement(visible = true, transformation(origin = {-66, 24}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot7 annotation(
        Placement(visible = true, transformation(origin = {-206, 122}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot8 annotation(
        Placement(visible = true, transformation(origin = {-194, -66}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot9 annotation(
        Placement(visible = true, transformation(origin = {-194, -78}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot10 annotation(
        Placement(visible = true, transformation(origin = {208, 120}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot11 annotation(
        Placement(visible = true, transformation(origin = {-62, -78}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot12 annotation(
        Placement(visible = true, transformation(origin = {-62, -6}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput grade_per annotation(
        Placement(visible = true, transformation(origin = {-320, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-160, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Sources.RealExpression realExpression(y = grade_per) annotation(
        Placement(visible = true, transformation(origin = {-274, 180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain1(k = 1 / 100) annotation(
        Placement(visible = true, transformation(origin = {-234, 180}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Atan atan annotation(
        Placement(visible = true, transformation(origin = {-206, 180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Sin sin annotation(
        Placement(visible = true, transformation(origin = {-168, 180}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const7(k = Mv) annotation(
        Placement(visible = true, transformation(origin = {-170, 156}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product6 annotation(
        Placement(visible = true, transformation(origin = {-130, 170}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain2(k = 9.8) annotation(
        Placement(visible = true, transformation(origin = {-100, 170}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain3(k = Rt) annotation(
        Placement(visible = true, transformation(origin = {-72, 170}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Add add1 annotation(
        Placement(visible = true, transformation(origin = {24, 46}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Add add annotation(
        Placement(visible = true, transformation(origin = {100, 34}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    equation
      connect(TireRadius.y, tire_radps2.u2) annotation(
        Line(points = {{-161, 52}, {-158, 52}, {-158, 42}, {-147, 42}}, color = {0, 0, 127}));
      connect(torque_FlyWheel.y, torque_Total.u2) annotation(
        Line(points = {{-43, 38}, {-27, 38}}, color = {0, 0, 127}));
      connect(EngineOutput_radps2.y, torque_FlyWheel.u1) annotation(
        Line(points = {{-95, 42}, {-57, 42}}, color = {0, 0, 127}));
      connect(const6.y, switch12.u1) annotation(
        Line(points = {{-129, -48}, {-123.8, -48}, {-123.8, -73}, {-115, -73}}, color = {0, 0, 127}));
      connect(abs1.y, lessThreshold1.u) annotation(
        Line(points = {{-155, -78}, {-149, -78}}, color = {0, 0, 127}));
      connect(lessThreshold1.y, switch12.u2) annotation(
        Line(points = {{-135, -78}, {-115, -78}}, color = {255, 0, 255}));
      connect(TireRadius.y, tire_torque.u2) annotation(
        Line(points = {{-161, 52}, {-158, 52}, {-158, 68}, {-149, 68}}, color = {0, 0, 127}));
      connect(add31.y, tire_torque.u1) annotation(
        Line(points = {{-161, 76}, {-149, 76}}, color = {0, 0, 127}));
      connect(product5.y, add31.u3) annotation(
        Line(points = {{-191, 28}, {-180, 28}, {-180, 71}, {-175, 71}}, color = {0, 0, 127}));
      connect(const1.y, product3.u2) annotation(
        Line(points = {{-281, 76}, {-219, 76}}, color = {0, 0, 127}));
      connect(product2.y, product3.u1) annotation(
        Line(points = {{-225, 84}, {-219, 84}}, color = {0, 0, 127}));
      connect(Target_Speed, product2.u1) annotation(
        Line(points = {{-322, 122}, {-272, 122}, {-272, 88}, {-239, 88}}, color = {0, 0, 127}));
      connect(Target_Speed, product2.u2) annotation(
        Line(points = {{-322, 122}, {-272, 122}, {-272, 80}, {-239, 80}}, color = {0, 0, 127}));
      connect(kph2mps.y, combiTable1Ds1.u) annotation(
        Line(points = {{-253, 122}, {-248, 122}, {-248, 24}, {-235, 24}}, color = {0, 0, 127}));
      connect(kph2mps.y, der1.u) annotation(
        Line(points = {{-253, 122}, {-225, 122}}, color = {0, 0, 127}));
      connect(combiTable1Ds1.y[1], product5.u2) annotation(
        Line(points = {{-221, 24}, {-205, 24}}, color = {0, 0, 127}, thickness = 0.5));
      connect(const2.y, product5.u1) annotation(
        Line(points = {{-215, 44}, {-208, 44}, {-208, 32}, {-205, 32}}, color = {0, 0, 127}));
      connect(const.y, product1.u2) annotation(
        Line(points = {{-219, 104}, {-199, 104}}, color = {0, 0, 127}));
      connect(Target_Speed, kph2mps.u) annotation(
        Line(points = {{-322, 122}, {-267, 122}}, color = {0, 0, 127}));
      connect(v_vehicle_mps, feedback1.u2) annotation(
        Line(points = {{-318, -124}, {-214, -124}, {-214, -117}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, radps2rpm.u) annotation(
        Line(points = {{-318, -156}, {-251, -156}}, color = {0, 0, 127}));
      connect(division1.y, limiter.u) annotation(
        Line(points = {{267, 44}, {277, 44}}, color = {0, 0, 127}));
      connect(switch12.y, product.u2) annotation(
        Line(points = {{-101, -78}, {214, -78}, {214, 180}, {221, 180}}, color = {0, 0, 127}));
      connect(kph2mps.y, feedback1.u1) annotation(
        Line(points = {{-253, 122}, {-248, 122}, {-248, -112}, {-219, -112}}, color = {0, 0, 127}));
      connect(switch12.y, EngineOutputTorque.u2) annotation(
        Line(points = {{-101, -78}, {-62, -78}, {-62, 64}, {-57, 64}}, color = {0, 0, 127}));
      connect(der1.y, tire_radps2.u1) annotation(
        Line(points = {{-211, 122}, {-154, 122}, {-154, 50}, {-147, 50}}, color = {0, 0, 127}));
      connect(flag_shift, greaterThreshold2.u) annotation(
        Line(points = {{-316, -186}, {-228, -186}}, color = {0, 0, 127}));
      connect(greaterThreshold2.y, switch11.u2) annotation(
        Line(points = {{-205, -186}, {-122, -186}, {-122, -106}, {-28, -106}}, color = {255, 0, 255}));
      connect(switch11.y, PID1.u) annotation(
        Line(points = {{-9, -106}, {7, -106}}, color = {0, 0, 127}));
      connect(feedback1.y, switch11.u3) annotation(
        Line(points = {{-209, -112}, {-28, -112}}, color = {0, 0, 127}));
      connect(gain.y, abs1.u) annotation(
        Line(points = {{-205, -66}, {-194, -66}, {-194, -78}, {-169, -78}}, color = {0, 0, 127}));
      connect(gain.y, EngineOutput_radps2.u2) annotation(
        Line(points = {{-205, -66}, {-194, -66}, {-194, -10}, {-128, -10}, {-128, 38}, {-109, 38}}, color = {0, 0, 127}));
      connect(gain.y, switch12.u3) annotation(
        Line(points = {{-205, -66}, {-194, -66}, {-194, -91}, {-125.5, -91}, {-125.5, -83}, {-115, -83}}, color = {0, 0, 127}));
      connect(tire_torque.y, EngineOutputTorque.u1) annotation(
        Line(points = {{-135, 72}, {-57, 72}}, color = {0, 0, 127}));
      connect(tire_radps2.y, EngineOutput_radps2.u1) annotation(
        Line(points = {{-133, 46}, {-109, 46}}, color = {0, 0, 127}));
      connect(EngineOutputTorque.y, torque_Total.u1) annotation(
        Line(points = {{-43, 68}, {-40, 68}, {-40, 46}, {-27, 46}}, color = {0, 0, 127}));
      connect(TireRadius.y, division.u2) annotation(
        Line(points = {{-161, 52}, {-158, 52}, {-158, -2}, {-149, -2}}, color = {0, 0, 127}));
      connect(kph2mps.y, division.u1) annotation(
        Line(points = {{-253, 122}, {-248, 122}, {-248, 6}, {-149, 6}}, color = {0, 0, 127}));
      connect(switch12.y, derivative.u) annotation(
        Line(points = {{-101, -78}, {-62, -78}, {-62, -6}, {-51, -6}}, color = {0, 0, 127}));
      connect(division.y, product7.u1) annotation(
        Line(points = {{-135, 2}, {-25, 2}}, color = {0, 0, 127}));
      connect(derivative.y, product7.u2) annotation(
        Line(points = {{-37, -6}, {-25, -6}}, color = {0, 0, 127}));
      connect(product7.y, product8.u2) annotation(
        Line(points = {{-11, -2}, {-5, -2}, {-5, 8}, {7, 8}}, color = {0, 0, 127}));
      connect(limiter1.y, division1.u1) annotation(
        Line(points = {{197, 120}, {208, 120}, {208, 48}, {253, 48}}, color = {0, 0, 127}));
      connect(limiter1.y, product.u1) annotation(
        Line(points = {{197, 120}, {208, 120}, {208, 188}, {221, 188}}, color = {0, 0, 127}));
      connect(product8.y, limiter2.u) annotation(
        Line(points = {{21, 12}, {34, 12}}, color = {0, 0, 127}));
      connect(product.y, tau_drive_shaft_target) annotation(
        Line(points = {{235, 184}, {310, 184}}, color = {0, 0, 127}));
      connect(add3.y, add31.u2) annotation(
        Line(points = {{-183, 76}, {-175, 76}}, color = {0, 0, 127}));
      connect(product1.y, add31.u1) annotation(
        Line(points = {{-185, 108}, {-180, 108}, {-180, 79}, {-175.5, 79}, {-175.5, 81}, {-175, 81}}, color = {0, 0, 127}));
      connect(der1.y, product1.u1) annotation(
        Line(points = {{-211, 122}, {-206, 122}, {-206, 112}, {-199, 112}}, color = {0, 0, 127}));
      connect(product3.y, add3.u1) annotation(
        Line(points = {{-205, 80}, {-197, 80}}, color = {0, 0, 127}));
      connect(product4.y, add3.u2) annotation(
        Line(points = {{-205, 64}, {-202, 64}, {-202, 72}, {-197, 72}}, color = {0, 0, 127}));
      connect(const4.y, product4.u2) annotation(
        Line(points = {{-281, 50}, {-258.5, 50}, {-258.5, 60}, {-218, 60}, {-218, 65}, {-219, 65}, {-219, 60}}, color = {0, 0, 127}));
      connect(Target_Speed, product4.u1) annotation(
        Line(points = {{-322, 122}, {-272, 122}, {-272, 68}, {-219, 68}}, color = {0, 0, 127}));
      connect(drive_mode_req, drive_mode) annotation(
        Line(points = {{-318, -226}, {294, -226}}, color = {0, 0, 127}));
      connect(switch1.y, limiter1.u) annotation(
        Line(points = {{167, 120}, {178, 120}}, color = {0, 0, 127}));
      connect(greaterThreshold.y, switch1.u2) annotation(
        Line(points = {{62, 120}, {144, 120}}, color = {255, 0, 255}));
      connect(kph2mps.y, greaterThreshold.u) annotation(
        Line(points = {{-254, 122}, {-248, 122}, {-248, 142}, {8, 142}, {8, 120}, {38, 120}}, color = {0, 0, 127}));
      connect(const5.y, switch1.u3) annotation(
        Line(points = {{133, 98}, {137.5, 98}, {137.5, 112}, {144, 112}}, color = {0, 0, 127}));
      connect(limiter.y, accel_position_per) annotation(
        Line(points = {{291, 44}, {310, 44}}, color = {0, 0, 127}));
      connect(limiter1.y, tau_gearbox_input_target) annotation(
        Line(points = {{197, 120}, {312, 120}}, color = {0, 0, 127}));
      connect(torque_gain_drivetrain, zeroOrderHold.u) annotation(
        Line(points = {{-318, -66}, {-284, -66}}, color = {0, 0, 127}));
      connect(zeroOrderHold.y, gain.u) annotation(
        Line(points = {{-261, -66}, {-220, -66}}, color = {0, 0, 127}));
      connect(const10.y, switch11.u1) annotation(
        Line(points = {{-47, -90}, {-37.5, -90}, {-37.5, -100}, {-28, -100}}, color = {0, 0, 127}));
      connect(flag_vcu_k0_open_req, greaterThreshold1.u) annotation(
        Line(points = {{-282, -266}, {-230, -266}}, color = {0, 0, 127}));
      connect(switch13.y, torque_FlyWheel.u2) annotation(
        Line(points = {{-71, 24}, {-66, 24}, {-66, 34}, {-58, 34}}, color = {0, 0, 127}));
      connect(switch13.y, product8.u1) annotation(
        Line(points = {{-71, 24}, {-66, 24}, {-66, 16}, {7, 16}}, color = {0, 0, 127}));
      connect(const3.y, switch13.u1) annotation(
        Line(points = {{-96, 28}, {-85, 28}, {-85, 29}}, color = {0, 0, 127}));
      connect(const8.y, switch13.u3) annotation(
        Line(points = {{-109, 20}, {-92, 20}, {-92, 19}, {-85, 19}}, color = {0, 0, 127}));
      connect(greaterThreshold1.y, switch13.u2) annotation(
        Line(points = {{-206, -266}, {-88, -266}, {-88, 24}, {-86, 24}, {-86, 24}}, color = {255, 0, 255}));
      connect(MAX_Torque.y, division1.u2) annotation(
        Line(points = {{238, 30}, {244, 30}, {244, 40}, {253, 40}}, color = {0, 0, 127}));
      connect(limiter2.y, add2.u2) annotation(
        Line(points = {{52, 12}, {56, 12}, {56, 34}, {60, 34}, {60, 34}}, color = {0, 0, 127}));
      connect(realExpression.y, gain1.u) annotation(
        Line(points = {{-262, 180}, {-242, 180}, {-242, 180}, {-242, 180}}, color = {0, 0, 127}));
      connect(gain1.y, atan.u) annotation(
        Line(points = {{-228, 180}, {-216, 180}, {-216, 180}, {-218, 180}}, color = {0, 0, 127}));
      connect(atan.y, sin.u) annotation(
        Line(points = {{-194, 180}, {-182, 180}, {-182, 180}, {-180, 180}}, color = {0, 0, 127}));
      connect(sin.y, product6.u1) annotation(
        Line(points = {{-156, 180}, {-148, 180}, {-148, 174}, {-138, 174}, {-138, 174}}, color = {0, 0, 127}));
      connect(const7.y, product6.u2) annotation(
        Line(points = {{-164, 156}, {-146, 156}, {-146, 166}, {-138, 166}, {-138, 166}}, color = {0, 0, 127}));
      connect(product6.y, gain2.u) annotation(
        Line(points = {{-124, 170}, {-108, 170}, {-108, 170}, {-108, 170}}, color = {0, 0, 127}));
      connect(gain2.y, gain3.u) annotation(
        Line(points = {{-94, 170}, {-80, 170}, {-80, 170}, {-80, 170}}, color = {0, 0, 127}));
      connect(torque_Total.y, add1.u2) annotation(
        Line(points = {{-14, 42}, {16, 42}, {16, 42}, {16, 42}}, color = {0, 0, 127}));
      connect(add1.y, add2.u1) annotation(
        Line(points = {{30, 46}, {42, 46}, {42, 42}, {60, 42}, {60, 42}}, color = {0, 0, 127}));
      connect(gain3.y, add1.u1) annotation(
        Line(points = {{-66, 170}, {-4, 170}, {-4, 50}, {17, 50}}, color = {0, 0, 127}));
      connect(add.y, switch1.u1) annotation(
        Line(points = {{107, 34}, {112, 34}, {112, 128}, {144, 128}}, color = {0, 0, 127}));
      connect(add2.y, add.u1) annotation(
        Line(points = {{74, 38}, {93, 38}}, color = {0, 0, 127}));
      connect(PID1.y, add.u2) annotation(
        Line(points = {{20, -106}, {80, -106}, {80, 30}, {93, 30}}, color = {0, 0, 127}));
      annotation(
        uses(Modelica(version = "3.2.3")),
        Diagram(coordinateSystem(extent = {{-300, -200}, {300, 200}}, preserveAspectRatio = false, initialScale = 0.1), graphics = {Text(origin = {-202, 99}, extent = {{-14, 1}, {20, -5}}, textString = "Inertia"), Text(origin = {-202, 55}, extent = {{-20, 5}, {20, -5}}, textString = "Air Resistance"), Text(origin = {-198, 17}, extent = {{-20, 5}, {24, -7}}, textString = "Rolling Resistance"), Text(origin = {259, -258}, extent = {{-31, 18}, {89, -16}}, textString = "０=EV：1=HEV：2=Power Mode")}),
        version = "",
        __OpenModelica_commandLineOptions = "",
        experiment(StartTime = 0, StopTime = 20, Tolerance = 1e-06, Interval = 0.1),
        Icon(coordinateSystem(extent = {{-140, -260}, {140, 200}}, preserveAspectRatio = false, initialScale = 0.1), graphics = {Rectangle(extent = {{-140, 200}, {140, -258}}), Text(origin = {-8, -5}, extent = {{-100, 59}, {106, -53}}, textString = "DRIVER", textStyle = {TextStyle.Bold, TextStyle.Bold, TextStyle.Bold, TextStyle.Bold})}),
        __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
    end Driver;

    model Flywheel
      parameter Modelica.SIunits.Inertia Jfw = 0.4;
      /*initType = Modelica.Blocks.Types.Init.SteadyState,*/
      Modelica.Mechanics.Rotational.Components.Inertia inertia_FlyWheel(J = Jfw, phi(fixed = true, start = 0), w(fixed = true, start = 0)) annotation(
        Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.TorqueToAngleAdaptor torqueToAngleAdaptor1 annotation(
        Placement(visible = true, transformation(origin = {-60, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.TorqueToAngleAdaptor torqueToAngleAdaptor2(use_a = false, use_w = true) annotation(
        Placement(visible = true, transformation(origin = {60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput trq_ENG_PNT_in_Nm annotation(
        Placement(visible = true, transformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_ENG_PNT_radps annotation(
        Placement(visible = true, transformation(origin = {-110, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0), iconTransformation(origin = {-110, 40}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_TM_PNT_FW_radps annotation(
        Placement(visible = true, transformation(origin = {110, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput trq_TM_PNT_FW_Nm annotation(
        Placement(visible = true, transformation(origin = {120, -40}, extent = {{20, -20}, {-20, 20}}, rotation = 0), iconTransformation(origin = {120, -40}, extent = {{20, -20}, {-20, 20}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain1(k = -1) annotation(
        Placement(visible = true, transformation(origin = {-80, -8}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain2(k = -1) annotation(
        Placement(visible = true, transformation(origin = {80, -8}, extent = {{6, -6}, {-6, 6}}, rotation = 0)));
    equation
      connect(gain2.u, trq_TM_PNT_FW_Nm) annotation(
        Line(points = {{88, -8}, {94, -8}, {94, -40}, {120, -40}, {120, -40}}, color = {0, 0, 127}));
      connect(torqueToAngleAdaptor2.tau, gain2.y) annotation(
        Line(points = {{64, -8}, {74, -8}, {74, -8}, {74, -8}}, color = {0, 0, 127}));
      connect(gain1.y, torqueToAngleAdaptor1.tau) annotation(
        Line(points = {{-74, -8}, {-64, -8}, {-64, -8}, {-64, -8}}, color = {0, 0, 127}));
      connect(trq_ENG_PNT_in_Nm, gain1.u) annotation(
        Line(points = {{-120, -40}, {-94, -40}, {-94, -8}, {-88, -8}, {-88, -8}}, color = {0, 0, 127}));
      connect(inertia_FlyWheel.flange_b, torqueToAngleAdaptor2.flange) annotation(
        Line(points = {{10, 0}, {56, 0}}));
      connect(w_TM_PNT_FW_radps, torqueToAngleAdaptor2.w) annotation(
        Line(points = {{110, 40}, {80, 40}, {80, 2}, {61, 2}, {61, 3}}, color = {0, 0, 127}));
      connect(inertia_FlyWheel.flange_a, torqueToAngleAdaptor1.flange) annotation(
        Line(points = {{-10, 0}, {-60, 0}}));
      connect(w_ENG_PNT_radps, torqueToAngleAdaptor1.w) annotation(
        Line(points = {{-110, 40}, {-80, 40}, {-80, 2}, {-65, 2}, {-65, 3}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(initialScale = 0.1), graphics = {Text(origin = {0, -134}, lineColor = {0, 0, 255}, extent = {{-144, 24}, {144, -24}}, textString = "%name"), Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Line(rotation = 90, points = {{0, 50}, {0, -50}}), Rectangle(origin = {2, -1}, fillColor = {163, 163, 163}, fillPattern = FillPattern.Solid, extent = {{-22, 65}, {18, -65}}), Text(origin = {-122, 6}, extent = {{-18, 2}, {22, -28}}, textString = "T"), Text(origin = {-122, 76}, extent = {{-18, 2}, {22, -28}}, textString = "w"), Text(origin = {118, 76}, extent = {{-18, 2}, {22, -28}}, textString = "w"), Text(origin = {118, 6}, extent = {{-18, 2}, {22, -28}}, textString = "T")}),
        uses(Modelica(version = "3.2.3")));
    end Flywheel;

    model HeatFlow
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      Modelica.Blocks.Tables.CombiTable2D combiTable2D(fileName = currDir + "/Tables/Eng_BSFC_fix.txt", tableName = "BSFC", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-22, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain3(k = 1 / 3600) annotation(
        Placement(visible = true, transformation(origin = {98, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain4(k = 34.6e6 / 0.73 * 0.25) annotation(
        Placement(visible = true, transformation(origin = {134, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_engine annotation(
        Placement(visible = true, transformation(origin = {-120, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_ENG_PNT_radps annotation(
        Placement(visible = true, transformation(origin = {-120, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput coolant_thermal_flow annotation(
        Placement(visible = true, transformation(origin = {192, -74}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {190, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {-20, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product1 annotation(
        Placement(visible = true, transformation(origin = {54, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.UnitConversions.To_rpm to_rpm annotation(
        Placement(visible = true, transformation(origin = {-60, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain kw(k = 1 / 1000) annotation(
        Placement(visible = true, transformation(origin = {14, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain kg(k = 1 / 1000) annotation(
        Placement(visible = true, transformation(origin = {14, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.01) annotation(
        Placement(visible = true, transformation(origin = {144, -74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {-84, -6}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot1 annotation(
        Placement(visible = true, transformation(origin = {-44, 20}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    equation
      connect(gain3.y, gain4.u) annotation(
        Line(points = {{109, 40}, {122, 40}}, color = {0, 0, 127}));
      connect(tau_engine, combiTable2D.u1) annotation(
        Line(points = {{-120, 20}, {-44, 20}, {-44, 6}, {-34, 6}, {-34, 6}}, color = {0, 0, 127}));
      connect(tau_engine, product.u2) annotation(
        Line(points = {{-120, 20}, {-44, 20}, {-44, 54}, {-32, 54}, {-32, 54}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, product.u1) annotation(
        Line(points = {{-120, -20}, {-84, -20}, {-84, 66}, {-32, 66}, {-32, 66}}, color = {0, 0, 127}));
      connect(to_rpm.y, combiTable2D.u2) annotation(
        Line(points = {{-48, -6}, {-34, -6}, {-34, -6}, {-34, -6}}, color = {0, 0, 127}));
      connect(w_ENG_PNT_radps, to_rpm.u) annotation(
        Line(points = {{-120, -20}, {-84, -20}, {-84, -6}, {-72, -6}, {-72, -6}}, color = {0, 0, 127}));
      connect(combiTable2D.y, kg.u) annotation(
        Line(points = {{-10, 0}, {2, 0}, {2, 0}, {2, 0}}, color = {0, 0, 127}));
      connect(product.y, kw.u) annotation(
        Line(points = {{-8, 60}, {0, 60}, {0, 60}, {2, 60}}, color = {0, 0, 127}));
      connect(kw.y, product1.u1) annotation(
        Line(points = {{26, 60}, {32, 60}, {32, 46}, {42, 46}, {42, 46}}, color = {0, 0, 127}));
      connect(kg.y, product1.u2) annotation(
        Line(points = {{26, 0}, {34, 0}, {34, 34}, {42, 34}, {42, 34}}, color = {0, 0, 127}));
      connect(product1.y, gain3.u) annotation(
        Line(points = {{66, 40}, {84, 40}, {84, 40}, {86, 40}}, color = {0, 0, 127}));
      connect(firstOrder.y, coolant_thermal_flow) annotation(
        Line(points = {{156, -74}, {182, -74}, {182, -74}, {192, -74}, {192, -74}}, color = {0, 0, 127}));
      connect(gain4.y, firstOrder.u) annotation(
        Line(points = {{146, 40}, {160, 40}, {160, -20}, {106, -20}, {106, -74}, {132, -74}, {132, -74}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(preserveAspectRatio = false, extent = {{-100, -100}, {180, 100}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, extent = {{-100, 100}, {180, -100}}), Text(origin = {3, 2}, extent = {{-75, 20}, {145, -22}}, textString = "HEAT_FLOW")}));
    end HeatFlow;
  end Vehicle;

  package Enviroment
    model Enviroment
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      Modelica.Blocks.Sources.Clock clock(offset = 0, startTime = 0) annotation(
        Placement(visible = true, transformation(origin = {-72, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1Ds combiTable1Ds(columns = 2:12, fileName = currDir + "/ModelicaInputData/" + "ModelicaInputData_NewFormat.txt", smoothness = Modelica.Blocks.Types.Smoothness.MonotoneContinuousDerivative1, tableName = "tab1", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-16, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput v_vehicle_target_kph annotation(
        Placement(visible = true, transformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput grade_per annotation(
        Placement(visible = true, transformation(origin = {110, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput user_set_drive_mode annotation(
        Placement(visible = true, transformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput user_set_cablin_deg_c annotation(
        Placement(visible = true, transformation(origin = {110, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput t_ambient_deg_k annotation(
        Placement(visible = true, transformation(origin = {110, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput trans_shifter_position annotation(
        Placement(visible = true, transformation(origin = {110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput t_eng_case annotation(
        Placement(visible = true, transformation(origin = {110, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput p_vehicle_consumption annotation(
        Placement(visible = true, transformation(origin = {110, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput key_position annotation(
        Placement(visible = true, transformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput t_trans_out_air annotation(
        Placement(visible = true, transformation(origin = {110, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -110}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput t_eng_clank annotation(
        Placement(visible = true, transformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.UnitConversions.From_degC from_degC annotation(
        Placement(visible = true, transformation(origin = {68, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = 1) annotation(
        Placement(visible = true, transformation(origin = {56, 38}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-24, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain1(k = 1) annotation(
        Placement(visible = true, transformation(origin = {56, 90}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {22, 70}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot1 annotation(
        Placement(visible = true, transformation(origin = {22, 50}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot2 annotation(
        Placement(visible = true, transformation(origin = {22, 38}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot3 annotation(
        Placement(visible = true, transformation(origin = {22, 10}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot4 annotation(
        Placement(visible = true, transformation(origin = {22, -10}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot5 annotation(
        Placement(visible = true, transformation(origin = {22, -30}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot6 annotation(
        Placement(visible = true, transformation(origin = {22, -50}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot7 annotation(
        Placement(visible = true, transformation(origin = {22, -70}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot8 annotation(
        Placement(visible = true, transformation(origin = {22, -90}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      Modelica.Blocks.Math.Division division annotation(
        Placement(visible = true, transformation(origin = {58, -56}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = 12) annotation(
        Placement(visible = true, transformation(origin = {-26, -62}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(clock.y, combiTable1Ds.u) annotation(
        Line(points = {{-61, 70}, {-28, 70}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[2], grade_per) annotation(
        Line(points = {{-5, 70}, {110, 70}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[3], trans_shifter_position) annotation(
        Line(points = {{-5, 70}, {22, 70}, {22, 50}, {110, 50}}, color = {0, 0, 127}));
      connect(from_degC.y, t_ambient_deg_k) annotation(
        Line(points = {{79, 10}, {110, 10}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[5], from_degC.u) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, 10}, {56, 10}, {56, 10}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[6], user_set_cablin_deg_c) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, -10}, {110, -10}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[7], key_position) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, -30}, {110, -30}, {110, -30}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[9], t_eng_case) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, -70}, {110, -70}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[10], t_eng_clank) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, -90}, {110, -90}, {110, -90}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[11], t_trans_out_air) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, -110}, {110, -110}, {110, -110}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[4], gain.u) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, 38}, {48, 38}, {48, 38}}, color = {0, 0, 127}));
      connect(const.y, user_set_drive_mode) annotation(
        Line(points = {{-13, 30}, {110, 30}}, color = {0, 0, 127}));
      connect(gain1.y, v_vehicle_target_kph) annotation(
        Line(points = {{62, 90}, {100, 90}, {100, 90}, {110, 90}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[1], gain1.u) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, 90}, {48, 90}, {48, 90}}, color = {0, 0, 127}));
      connect(const1.y, division.u2) annotation(
        Line(points = {{-15, -62}, {46, -62}}, color = {0, 0, 127}));
      connect(combiTable1Ds.y[8], division.u1) annotation(
        Line(points = {{-4, 70}, {22, 70}, {22, -50}, {46, -50}, {46, -50}}, color = {0, 0, 127}));
      connect(division.y, p_vehicle_consumption) annotation(
        Line(points = {{70, -56}, {84, -56}, {84, -50}, {110, -50}, {110, -50}}, color = {0, 0, 127}));
      annotation(
        Diagram(graphics = {Text(origin = {168, 85}, extent = {{-32, 9}, {10, 1}}, textString = "Target Speed [km/h]"), Text(origin = {170, 51}, extent = {{-32, 9}, {10, -9}}, textString = "Shift Psition"), Text(origin = {164, 65}, extent = {{-32, 9}, {10, 1}}, textString = "Slope [%]"), Text(origin = {174, 27}, extent = {{-32, 9}, {6, -1}}, textString = "Drive Mode"), Text(origin = {170, 15}, extent = {{-32, 9}, {26, -13}}, textString = "Outside Temp [K]"), Text(origin = {172, -101}, extent = {{-32, 9}, {56, -27}}, textString = "トランスミッション雰囲気温度"), Text(origin = {172, -11}, extent = {{-32, 11}, {30, -9}}, textString = "Aircon set temp [c]"), Text(origin = {170, -27}, extent = {{-32, 9}, {32, -15}}, textString = "Ignition Key Position"), Text(origin = {174, -83}, extent = {{-32, 9}, {54, -27}}, textString = "エンジンクランクシャフト端温度"), Text(origin = {174, -75}, extent = {{-32, 9}, {26, -5}}, textString = "エンジンケース温度"), Text(origin = {172, -47}, extent = {{-32, 9}, {48, -17}}, textString = "Low Voltage Consumption"), Text(origin = {-55, 8}, extent = {{-31, 18}, {67, -10}}, textString = "０=EV：1=HEV：2=Power Mode")}, coordinateSystem(initialScale = 0.1)),
        Icon(coordinateSystem(preserveAspectRatio = false, initialScale = 0.1), graphics = {Rectangle(origin = {0, -10}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 110}, {100, -110}}), Text(origin = {-3, 0}, extent = {{-61, 20}, {61, -20}}, textString = "ENV")}));
    end Enviroment;
  end Enviroment;

  package HEVElectricElements
    model HEVElectricSystem
      Modelica.Blocks.Interfaces.RealInput HiBatCur annotation(
        Placement(visible = true, transformation(origin = {-210, 9}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -20}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput HiBatSoc annotation(
        Placement(visible = true, transformation(origin = {210, 26}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {211, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add3 add31(k1 = -1, k2 = -1, k3 = +1) annotation(
        Placement(visible = true, transformation(origin = {-148, 17}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput HiBatLoss annotation(
        Placement(visible = true, transformation(origin = {210, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {211, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      TRAMI_L3_HEV.HEVElectricElements.HighBattery highBattery1(MaxValue = 5.5 * 1000 / 350 * 3600, SOC0 = 80) annotation(
        Placement(visible = true, transformation(origin = {-102, 16}, extent = {{-18, -18}, {18, 18}}, rotation = 0)));
      HEVElectricElements.DCDCConverter dCDCConverter annotation(
        Placement(visible = true, transformation(origin = {-18.5, -31}, extent = {{-22.5, -15}, {22.5, 15}}, rotation = 0)));
      HEVElectricElements.LowBattery lowBattery(MaxValue = 40 * 3600, SOC0 = 95) annotation(
        Placement(visible = true, transformation(origin = {140, -73}, extent = {{-18, -12}, {18, 12}}, rotation = 0)));
      Modelica.Blocks.Math.Add add(k1 = +1, k2 = -1) annotation(
        Placement(visible = true, transformation(origin = {93, -73}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput DCDCLoss annotation(
        Placement(visible = true, transformation(origin = {210, -39}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {211, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput LowBatLoss annotation(
        Placement(visible = true, transformation(origin = {210, -78}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {211, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput LowBatSoc annotation(
        Placement(visible = true, transformation(origin = {210, -58}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {211, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput LowBatConsumption annotation(
        Placement(visible = true, transformation(origin = {-210, -114}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-220, -81}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput Viv annotation(
        Placement(visible = true, transformation(origin = {210, 121}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {210, 121}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput Iiv annotation(
        Placement(visible = true, transformation(origin = {-219, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-219, 120}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.01, initType = Modelica.Blocks.Types.Init.InitialState, k = 1, y(fixed = false), y_start = 0) annotation(
        Placement(visible = true, transformation(origin = {-155, 121}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, initType = Modelica.Blocks.Types.Init.InitialState, k = 1, y(fixed = false), y_start = 0) annotation(
        Placement(visible = true, transformation(origin = {46, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder2(T = 0.01, initType = Modelica.Blocks.Types.Init.InitialState, k = 1, y(fixed = false), y_start = 0) annotation(
        Placement(visible = true, transformation(origin = {37, -114}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(HiBatCur, add31.u3) annotation(
        Line(points = {{-210, 9}, {-160, 9}}, color = {0, 0, 127}));
      connect(highBattery1.HiBatSoc, HiBatSoc) annotation(
        Line(points = {{-83, 25}, {63, 25}, {63, 26}, {210, 26}}, color = {0, 0, 127}));
      connect(add31.y, highBattery1.HiBatCur) annotation(
        Line(points = {{-137, 17}, {-130, 17}, {-130, 16}, {-122, 16}}, color = {0, 0, 127}));
      connect(highBattery1.HiBatLoss, HiBatLoss) annotation(
        Line(points = {{-83, 7}, {63, 7}, {63, 8}, {210, 8}}, color = {0, 0, 127}));
      connect(highBattery1.HiBatVol, dCDCConverter.HiBatVol) annotation(
        Line(points = {{-83, 16}, {-69, 16}, {-69, -25}, {-44, -25}}, color = {0, 0, 127}));
      connect(dCDCConverter.DCDCHiCurCmp, add31.u1) annotation(
        Line(points = {{5.5, -23.5}, {9.25, -23.5}, {9.25, -24.5}, {13, -24.5}, {13, 39}, {-176, 39}, {-176, 25}, {-160, 25}}, color = {0, 0, 127}));
      connect(add.y, lowBattery.LowBatCur) annotation(
        Line(points = {{104, -73}, {120, -73}}, color = {0, 0, 127}));
      connect(dCDCConverter.DCDCLoss, DCDCLoss) annotation(
        Line(points = {{5.5, -39}, {210, -39}}, color = {0, 0, 127}));
      connect(lowBattery.LowBatLoss, LowBatLoss) annotation(
        Line(points = {{159, -78}, {210, -78}}, color = {0, 0, 127}));
      connect(dCDCConverter.LowBatVol, lowBattery.LowBatVol) annotation(
        Line(points = {{-44, -37}, {-66.5, -37}, {-66.5, -52}, {183, -52}, {183, -73}, {159, -73}}, color = {0, 0, 127}));
      connect(lowBattery.LowBatSoc, LowBatSoc) annotation(
        Line(points = {{159, -68}, {191, -68}, {191, -58}, {210, -58}}, color = {0, 0, 127}));
      connect(highBattery1.HiBatVol, Viv) annotation(
        Line(points = {{-83, 16}, {-35, 16}, {-35, 121}, {210, 121}}, color = {0, 0, 127}));
      connect(Iiv, firstOrder.u) annotation(
        Line(points = {{-219, 120}, {-169, 120}, {-169, 121}, {-167, 121}}, color = {0, 0, 127}));
      connect(firstOrder.y, add31.u2) annotation(
        Line(points = {{-144, 121}, {-131, 121}, {-131, 61}, {-185, 61}, {-185, 16}, {-160, 16}, {-160, 17}}, color = {0, 0, 127}));
      connect(dCDCConverter.DCDCLowCurCha, firstOrder1.u) annotation(
        Line(points = {{6, -31}, {24, -31}, {24, -19}, {34, -19}, {34, -20}}, color = {0, 0, 127}));
      connect(firstOrder1.y, add.u1) annotation(
        Line(points = {{57, -20}, {70, -20}, {70, -69}, {81, -69}, {81, -67}}, color = {0, 0, 127}));
      connect(firstOrder2.y, add.u2) annotation(
        Line(points = {{48, -114}, {70, -114}, {70, -79}, {81, -79}}, color = {0, 0, 127}));
      connect(LowBatConsumption, firstOrder2.u) annotation(
        Line(points = {{-210, -114}, {27, -114}, {27, -114}, {25, -114}, {25, -114}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}}, initialScale = 0.1), graphics = {Rectangle(origin = {1, 1}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-200, 150}, {200, -150}}), Text(origin = {5.5, 7}, extent = {{-113.5, 35}, {113.5, -35}}, textString = "HEVElectricSystem")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}})),
        __OpenModelica_commandLineOptions = "",
        __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl"));
    end HEVElectricSystem;

    model DCDCConverter
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      Modelica.Blocks.Interfaces.RealInput HiBatVol annotation(
        Placement(visible = true, transformation(origin = {-160, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-170, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput LowBatVol annotation(
        Placement(visible = true, transformation(origin = {-159, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-170, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput DCDCHiCurCmp annotation(
        Placement(visible = true, transformation(origin = {160, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput DCDCLowCurCha annotation(
        Placement(visible = true, transformation(origin = {160, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput DCDCLoss annotation(
        Placement(visible = true, transformation(origin = {160, -44}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add1(k1 = +1, k2 = +1) annotation(
        Placement(visible = true, transformation(origin = {106, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division1 annotation(
        Placement(visible = true, transformation(origin = {-67, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D(fileName = currDir + "/Tables/DCDCLowBatChargeAmp.txt", tableName = "Tab1", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-63, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.01, y(fixed = true), y_start = 12) annotation(
        Placement(visible = true, transformation(origin = {-109, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D1(fileName = currDir + "/Tables/DCDCEfficiency.txt", tableName = "Tab1", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-22, -74}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder1(T = 0.01, y(fixed = true), y_start = 395) annotation(
        Placement(visible = true, transformation(origin = {-111, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division annotation(
        Placement(visible = true, transformation(origin = {-4, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division2 annotation(
        Placement(visible = true, transformation(origin = {44, 67}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {99, -44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {-87, 40}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot1 annotation(
        Placement(visible = true, transformation(origin = {-86, -40}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot2 annotation(
        Placement(visible = true, transformation(origin = {-44, -26}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot3 annotation(
        Placement(visible = true, transformation(origin = {-44, -40}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot4 annotation(
        Placement(visible = true, transformation(origin = {-44, 0}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot5 annotation(
        Placement(visible = true, transformation(origin = {126, -44}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = 1.0) annotation(
        Placement(visible = true, transformation(origin = {-24, -43}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add(k1 = +1, k2 = -1) annotation(
        Placement(visible = true, transformation(origin = {14, -56}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product1 annotation(
        Placement(visible = true, transformation(origin = {50, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot6 annotation(
        Placement(visible = true, transformation(origin = {-86, -15}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    equation
      connect(LowBatVol, firstOrder.u) annotation(
        Line(points = {{-159, -40}, {-122, -40}, {-122, -40}, {-121, -40}}, color = {0, 0, 127}));
      connect(firstOrder.y, combiTable1D.u[1]) annotation(
        Line(points = {{-98, -40}, {-75, -40}}, color = {0, 0, 127}));
      connect(combiTable1D.y[1], combiTable1D1.u[1]) annotation(
        Line(points = {{-52, -40}, {-44, -40}, {-44, -74}, {-34, -74}}, color = {0, 0, 127}, thickness = 0.5));
      connect(combiTable1D.y[1], DCDCLowCurCha) annotation(
        Line(points = {{-52, -40}, {-44, -40}, {-44, 0}, {160, 0}}, color = {0, 0, 127}));
      connect(HiBatVol, firstOrder1.u) annotation(
        Line(points = {{-160, 40}, {-125, 40}, {-125, 40}, {-123, 40}}, color = {0, 0, 127}));
      connect(firstOrder.y, division1.u2) annotation(
        Line(points = {{-98, -40}, {-86, -40}, {-86, 4}, {-79, 4}}, color = {0, 0, 127}));
      connect(combiTable1D.y[1], division.u1) annotation(
        Line(points = {{-52, -40}, {-44, -40}, {-44, 34}, {-16, 34}}, color = {0, 0, 127}));
      connect(division1.y, division.u2) annotation(
        Line(points = {{-56, 10}, {-30, 10}, {-30, 22}, {-16, 22}}, color = {0, 0, 127}));
      connect(add1.y, DCDCHiCurCmp) annotation(
        Line(points = {{117, 34}, {150, 34}, {150, 34}, {160, 34}}, color = {0, 0, 127}));
      connect(product.y, DCDCLoss) annotation(
        Line(points = {{110, -44}, {160, -44}}, color = {0, 0, 127}));
      connect(product.y, division2.u1) annotation(
        Line(points = {{110, -44}, {126, -44}, {126, 13}, {19, 13}, {19, 74}, {32, 74}, {32, 73}}, color = {0, 0, 127}));
      connect(firstOrder1.y, division1.u1) annotation(
        Line(points = {{-100, 40}, {-87, 40}, {-87, 16}, {-79, 16}, {-79, 16}}, color = {0, 0, 127}));
      connect(firstOrder1.y, division2.u2) annotation(
        Line(points = {{-100, 40}, {-87, 40}, {-87, 61}, {32, 61}, {32, 61}}, color = {0, 0, 127}));
      connect(const.y, add.u1) annotation(
        Line(points = {{-13, -43}, {-6, -43}, {-6, -50}, {2, -50}}, color = {0, 0, 127}));
      connect(combiTable1D1.y[1], add.u2) annotation(
        Line(points = {{-11, -74}, {-5, -74}, {-5, -62}, {2, -62}}, color = {0, 0, 127}));
      connect(add.y, product1.u2) annotation(
        Line(points = {{25, -56}, {38, -56}}, color = {0, 0, 127}));
      connect(combiTable1D.y[1], product1.u1) annotation(
        Line(points = {{-52, -40}, {-44, -40}, {-44, -26}, {29, -26}, {29, -44}, {38, -44}}, color = {0, 0, 127}));
      connect(product1.y, product.u2) annotation(
        Line(points = {{61, -50}, {87, -50}}, color = {0, 0, 127}));
      connect(firstOrder.y, product.u1) annotation(
        Line(points = {{-98, -40}, {-86, -40}, {-86, -15}, {73, -15}, {73, -38}, {87, -38}, {87, -38}}, color = {0, 0, 127}));
      connect(division2.y, add1.u1) annotation(
        Line(points = {{55, 67}, {77, 67}, {77, 40}, {94, 40}, {94, 40}}, color = {0, 0, 127}));
      connect(division.y, add1.u2) annotation(
        Line(points = {{7, 28}, {94, 28}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-150, -100}, {150, 100}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 127}, fillPattern = FillPattern.Solid, extent = {{-150, 100}, {150, -100}}), Text(origin = {-53, 20.5}, extent = {{-54, 15.5}, {176, -48.5}}, textString = "DCDCConverter")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-150, -100}, {150, 100}})),
        __OpenModelica_commandLineOptions = "");
    end DCDCConverter;

    model HighBattery
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      parameter Real SOC0 = 50;
      parameter Real MaxValue = 10;
      Modelica.Blocks.Interfaces.RealInput HiBatCur annotation(
        Placement(visible = true, transformation(origin = {-159, 49}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-170, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput HiBatSoc annotation(
        Placement(visible = true, transformation(origin = {160, 75}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput HiBatVol annotation(
        Placement(visible = true, transformation(origin = {160, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput HiBatLoss annotation(
        Placement(visible = true, transformation(origin = {160, -32}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D2(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/HiBatOCV.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Tab1", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {44, 49}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add1 annotation(
        Placement(visible = true, transformation(origin = {128, 43}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D combiTable2D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/HiBatResistance.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Tab1", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {45, 4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product1 annotation(
        Placement(visible = true, transformation(origin = {85, -9}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product2 annotation(
        Placement(visible = true, transformation(origin = {127, -32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.LimIntegrator limIntegrator(initType = Modelica.Blocks.Types.Init.InitialState, k = 1, outMax = MaxValue, outMin = 0, y_start = MaxValue * SOC0 / 100) annotation(
        Placement(visible = true, transformation(origin = {-88, 49}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = MaxValue) annotation(
        Placement(visible = true, transformation(origin = {-89, 17}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division annotation(
        Placement(visible = true, transformation(origin = {-45, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = 100) annotation(
        Placement(visible = true, transformation(origin = {-12, 42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(product2.y, HiBatLoss) annotation(
        Line(points = {{138, -32}, {160, -32}}, color = {0, 0, 127}));
      connect(product2.u2, HiBatCur) annotation(
        Line(points = {{115, -38}, {-126, -38}, {-126, 49}, {-159, 49}}, color = {0, 0, 127}));
      connect(product1.y, product2.u1) annotation(
        Line(points = {{96, -9}, {105, -9}, {105, -26}, {115, -26}}, color = {0, 0, 127}));
      connect(combiTable2D1.y, product1.u1) annotation(
        Line(points = {{56, 4}, {63.5, 4}, {63.5, -3}, {73, -3}}, color = {0, 0, 127}));
      connect(HiBatCur, product1.u2) annotation(
        Line(points = {{-159, 49}, {-126, 49}, {-126, -15}, {73, -15}}, color = {0, 0, 127}));
      connect(add1.y, HiBatVol) annotation(
        Line(points = {{139, 43}, {152, 43}, {152, 44}, {160, 44}}, color = {0, 0, 127}));
      connect(combiTable1D2.y[1], add1.u1) annotation(
        Line(points = {{55, 49}, {116, 49}}, color = {0, 0, 127}, thickness = 0.5));
      connect(HiBatCur, combiTable2D1.u2) annotation(
        Line(points = {{-159, 49}, {-126, 49}, {-126, -0.25}, {33, -0.25}, {33, -2}}, color = {0, 0, 127}));
      connect(add1.u2, product1.y) annotation(
        Line(points = {{116, 37}, {105, 37}, {105, -9}, {96, -9}}, color = {0, 0, 127}));
      connect(HiBatCur, limIntegrator.u) annotation(
        Line(points = {{-159, 49}, {-101, 49}, {-101, 49}, {-100, 49}}, color = {0, 0, 127}));
      connect(limIntegrator.y, division.u1) annotation(
        Line(points = {{-77, 49}, {-59, 49}, {-59, 48}, {-57, 48}}, color = {0, 0, 127}));
      connect(const.y, division.u2) annotation(
        Line(points = {{-78, 17}, {-69, 17}, {-69, 36}, {-57, 36}, {-57, 36}}, color = {0, 0, 127}));
      connect(division.y, gain.u) annotation(
        Line(points = {{-34, 42}, {-26, 42}, {-26, 42}, {-24, 42}}, color = {0, 0, 127}));
      connect(gain.y, HiBatSoc) annotation(
        Line(points = {{-1, 42}, {14, 42}, {14, 76}, {160, 76}, {160, 75}}, color = {0, 0, 127}));
      connect(gain.y, combiTable1D2.u[1]) annotation(
        Line(points = {{-1, 42}, {14, 42}, {14, 49}, {32, 49}, {32, 49}}, color = {0, 0, 127}));
      connect(gain.y, combiTable2D1.u1) annotation(
        Line(points = {{-1, 42}, {14, 42}, {14, 10}, {33, 10}, {33, 10}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-150, -100}, {150, 100}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {85, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-150, 100}, {150, -100}}), Text(origin = {-32.5, 16}, extent = {{-75.5, 20}, {149.5, -47}}, textString = "HighBattery")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-150, -100}, {150, 100}})),
        __OpenModelica_commandLineOptions = "");
    end HighBattery;

    model LowBattery
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      parameter Real SOC0 = 50;
      parameter Real MaxValue = 10;
      Modelica.Blocks.Interfaces.RealInput LowBatCur annotation(
        Placement(visible = true, transformation(origin = {-160, 39}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-170, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput LowBatSoc annotation(
        Placement(visible = true, transformation(origin = {160, 75}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput LowBatVol annotation(
        Placement(visible = true, transformation(origin = {160, 33}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, -1}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput LowBatLoss annotation(
        Placement(visible = true, transformation(origin = {160, -47}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {160, -42}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D2(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/LowBatOCV.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Tab1", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {20, 39}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D combiTable2D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/LowBatResistance.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Tab1", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {20, -6}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product1 annotation(
        Placement(visible = true, transformation(origin = {65, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product2 annotation(
        Placement(visible = true, transformation(origin = {122, -47}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.LimIntegrator limIntegrator(initType = Modelica.Blocks.Types.Init.InitialState, k = 1, outMax = MaxValue, outMin = 0, y_start = MaxValue * SOC0 / 100) annotation(
        Placement(visible = true, transformation(origin = {-96, 39}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = MaxValue) annotation(
        Placement(visible = true, transformation(origin = {-96, 7}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division annotation(
        Placement(visible = true, transformation(origin = {-56, 33}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = 100) annotation(
        Placement(visible = true, transformation(origin = {-20, 33}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add1 annotation(
        Placement(visible = true, transformation(origin = {122, 33}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      ETC.Dot dot annotation(
        Placement(visible = true, transformation(origin = {-124, 39}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot1 annotation(
        Placement(visible = true, transformation(origin = {-124, -12}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot2 annotation(
        Placement(visible = true, transformation(origin = {-124, -26}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot3 annotation(
        Placement(visible = true, transformation(origin = {93, -20}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      ETC.Dot dot4 annotation(
        Placement(visible = true, transformation(origin = {0, 33}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
      TRAMI_L3_HEV.ETC.Dot dot5 annotation(
        Placement(visible = true, transformation(origin = {0, 39}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    equation
      connect(product2.u2, LowBatCur) annotation(
        Line(points = {{110, -53}, {-124, -53}, {-124, 39}, {-160, 39}}, color = {0, 0, 127}));
      connect(product2.y, LowBatLoss) annotation(
        Line(points = {{133, -47}, {160, -47}}, color = {0, 0, 127}));
      connect(product1.y, product2.u1) annotation(
        Line(points = {{76, -20}, {93, -20}, {93, -41}, {110, -41}}, color = {0, 0, 127}));
      connect(combiTable2D1.y, product1.u1) annotation(
        Line(points = {{31, -6}, {42, -6}, {42, -14}, {53, -14}}, color = {0, 0, 127}));
      connect(LowBatCur, product1.u2) annotation(
        Line(points = {{-160, 39}, {-124, 39}, {-124, -26}, {53, -26}}, color = {0, 0, 127}));
      connect(LowBatCur, combiTable2D1.u2) annotation(
        Line(points = {{-160, 39}, {-124, 39}, {-124, -12}, {8, -12}}, color = {0, 0, 127}));
      connect(LowBatCur, limIntegrator.u) annotation(
        Line(points = {{-160, 39}, {-109, 39}, {-109, 39}, {-108, 39}}, color = {0, 0, 127}));
      connect(limIntegrator.y, division.u1) annotation(
        Line(points = {{-85, 39}, {-70, 39}, {-70, 39}, {-68, 39}}, color = {0, 0, 127}));
      connect(const.y, division.u2) annotation(
        Line(points = {{-85, 7}, {-78, 7}, {-78, 26}, {-68, 26}, {-68, 27}}, color = {0, 0, 127}));
      connect(division.y, gain.u) annotation(
        Line(points = {{-45, 33}, {-33, 33}, {-33, 33}, {-32, 33}}, color = {0, 0, 127}));
      connect(gain.y, LowBatSoc) annotation(
        Line(points = {{-9, 33}, {0, 33}, {0, 75}, {160, 75}, {160, 75}}, color = {0, 0, 127}));
      connect(gain.y, combiTable1D2.u[1]) annotation(
        Line(points = {{-9, 33}, {0, 33}, {0, 39}, {8, 39}, {8, 39}}, color = {0, 0, 127}));
      connect(gain.y, combiTable2D1.u1) annotation(
        Line(points = {{-9, 33}, {0, 33}, {0, -1}, {8, -1}, {8, 0}}, color = {0, 0, 127}));
      connect(add1.y, LowBatVol) annotation(
        Line(points = {{133, 33}, {160, 33}}, color = {0, 0, 127}));
      connect(combiTable1D2.y[1], add1.u1) annotation(
        Line(points = {{31, 39}, {110, 39}}, color = {0, 0, 127}, thickness = 0.5));
      connect(add1.u2, product1.y) annotation(
        Line(points = {{110, 27}, {93, 27}, {93, -20}, {76, -20}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-150, -100}, {150, 100}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 170, 255}, fillPattern = FillPattern.Solid, extent = {{-150, 100}, {150, -100}}), Text(origin = {-27.5, 7.5}, extent = {{-72.5, 23.5}, {138.5, -34.5}}, textString = "LowBattery")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-150, -100}, {150, 100}})),
        __OpenModelica_commandLineOptions = "");
    end LowBattery;

    model LowElectricLoad
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      Modelica.Blocks.Interfaces.RealInput LowBatVol annotation(
        Placement(visible = true, transformation(origin = {-109, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput Plant_States annotation(
        Placement(visible = true, transformation(origin = {-110, 31}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 40}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput LowEleCurCmp annotation(
        Placement(visible = true, transformation(origin = {110, 25}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division1 annotation(
        Placement(visible = true, transformation(origin = {50, 25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D combiTable1D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/LowElectricLoad.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Tab1", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {-28, 31}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(division1.y, LowEleCurCmp) annotation(
        Line(points = {{61, 25}, {110, 25}}, color = {0, 0, 127}));
      connect(LowBatVol, division1.u2) annotation(
        Line(points = {{-109, -30}, {3, -30}, {3, 19}, {38, 19}}, color = {0, 0, 127}));
      connect(combiTable1D1.y[1], division1.u1) annotation(
        Line(points = {{-17, 31}, {37, 31}, {37, 31}, {38, 31}}, color = {0, 0, 127}, thickness = 0.5));
      connect(Plant_States, combiTable1D1.u[1]) annotation(
        Line(points = {{-110, 31}, {-41, 31}, {-41, 31}, {-40, 31}}, color = {0, 0, 127}));
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, initialScale = 0.1), graphics = {Rectangle(origin = {0, 0.5}, fillColor = {85, 255, 127}, fillPattern = FillPattern.Solid, extent = {{-100, 99.5}, {100, -100.5}}), Text(origin = {-8, 9}, extent = {{-68, 21}, {91, -27}}, textString = "LowElectricLoad")}),
        Diagram(coordinateSystem(grid = {1, 1})));
    end LowElectricLoad;

    model MotorGenerator
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      Modelica.Blocks.Interfaces.RealInput TargetTrq annotation(
        Placement(visible = true, transformation(origin = {-201, 77}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-181, 79}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput MotorW annotation(
        Placement(visible = true, transformation(origin = {-200, 18}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-180, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput HiBatVol annotation(
        Placement(visible = true, transformation(origin = {-202, -73}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-180, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput MotorCur annotation(
        Placement(visible = true, transformation(origin = {170, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {170, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput MotorTrq annotation(
        Placement(visible = true, transformation(origin = {170, 61}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {170, 61}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput MotorLoss annotation(
        Placement(visible = true, transformation(origin = {170, -27}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {170, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput InverterLoss annotation(
        Placement(visible = true, transformation(origin = {170, -53}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {170, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain1(k = 1) annotation(
        Placement(visible = true, transformation(origin = {106, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Division division1 annotation(
        Placement(visible = true, transformation(origin = {138, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {-7, 24}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      TRAMI_L3_HEV.HEVElectricElements.CombiTable3D combiTable3D(filename = "Motor_LossMap.txt", noExtrapolate = false, z_ax = {220, 225, 275, 425, 430}) annotation(
        Placement(visible = true, transformation(origin = {-7, -27}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      TRAMI_L3_HEV.HEVElectricElements.CombiTable3D combiTable3D1(filename = "Inverter_LossMap.txt", noExtrapolate = false, z_ax = {220, 225, 275, 425, 430}) annotation(
        Placement(visible = true, transformation(origin = {-7, -53}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add annotation(
        Placement(visible = true, transformation(origin = {39, -4}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Add add1 annotation(
        Placement(visible = true, transformation(origin = {74, 14}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {83, 96}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D combiTable2D(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/Motor_MaxTrqMap.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "powering", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {-95, 92}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.UnitConversions.To_rpm to_rpm annotation(
        Placement(visible = true, transformation(origin = {-159, 35}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Continuous.FirstOrder firstOrder(T = 0.01, initType = Modelica.Blocks.Types.Init.SteadyState, k = 1, y_start = 0) annotation(
        Placement(visible = true, transformation(origin = {132, 61}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Min min annotation(
        Placement(visible = true, transformation(origin = {-47, 103}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D combiTable2D1(extrapolation = Modelica.Blocks.Types.Extrapolation.HoldLastPoint, fileName = currDir + "/Tables/Motor_MaxTrqMap.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Regeneration", tableOnFile = true, verboseRead = true) annotation(
        Placement(visible = true, transformation(origin = {-95, 41}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Max max annotation(
        Placement(visible = true, transformation(origin = {-47, 47}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterEqual greaterEqual annotation(
        Placement(visible = true, transformation(origin = {30, 77}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-14, 64}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain A_Pmech(k = 1) annotation(
        Placement(visible = true, transformation(origin = {41, -99}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Gain A_Pele(k = 1) annotation(
        Placement(visible = true, transformation(origin = {137, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.Max max1 annotation(
        Placement(visible = true, transformation(origin = {75, -67}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = 0.1) annotation(
        Placement(visible = true, transformation(origin = {44, -61}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    equation
      connect(division1.y, MotorCur) annotation(
        Line(points = {{149, 8}, {170, 8}}, color = {0, 0, 127}));
      connect(gain1.y, division1.u1) annotation(
        Line(points = {{117, 14}, {126, 14}}, color = {0, 0, 127}));
      connect(combiTable3D.u2, HiBatVol) annotation(
        Line(points = {{-19, -35}, {-50, -35}, {-50, -73}, {-202, -73}}, color = {0, 0, 127}));
      connect(combiTable3D.y, MotorLoss) annotation(
        Line(points = {{4, -27}, {170, -27}}, color = {0, 0, 127}));
      connect(combiTable3D1.y, InverterLoss) annotation(
        Line(points = {{4, -53}, {170, -53}}, color = {0, 0, 127}));
      connect(combiTable3D1.u2, HiBatVol) annotation(
        Line(points = {{-19, -61}, {-50, -61}, {-50, -73}, {-202, -73}}, color = {0, 0, 127}));
      connect(combiTable3D.y, add.u1) annotation(
        Line(points = {{4, -27}, {16, -27}, {16, 2}, {27, 2}}, color = {0, 0, 127}));
      connect(combiTable3D1.y, add.u2) annotation(
        Line(points = {{4, -53}, {20, -53}, {20, -10}, {27, -10}}, color = {0, 0, 127}));
      connect(add.y, add1.u2) annotation(
        Line(points = {{50, -4}, {57, -4}, {57, 8}, {62, 8}}, color = {0, 0, 127}));
      connect(add1.y, gain1.u) annotation(
        Line(points = {{85, 14}, {93, 14}, {93, 14}, {94, 14}}, color = {0, 0, 127}));
      connect(MotorW, to_rpm.u) annotation(
        Line(points = {{-200, 18}, {-177, 18}, {-177, 34}, {-171, 34}, {-171, 35}}, color = {0, 0, 127}));
      connect(to_rpm.y, combiTable3D.u1) annotation(
        Line(points = {{-148, 35}, {-123, 35}, {-123, -26}, {-19, -26}, {-19, -27}}, color = {0, 0, 127}));
      connect(to_rpm.y, combiTable3D1.u1) annotation(
        Line(points = {{-148, 35}, {-123, 35}, {-123, -53}, {-19, -53}, {-19, -53}}, color = {0, 0, 127}));
      connect(product.y, add1.u1) annotation(
        Line(points = {{4, 24}, {57, 24}, {57, 20}, {62, 20}}, color = {0, 0, 127}));
      connect(MotorW, product.u2) annotation(
        Line(points = {{-200, 18}, {-19, 18}}, color = {0, 0, 127}));
      connect(switch1.y, firstOrder.u) annotation(
        Line(points = {{94, 96}, {94, 61}, {120, 61}}, color = {0, 0, 127}));
      connect(firstOrder.y, MotorTrq) annotation(
        Line(points = {{143, 61}, {170, 61}}, color = {0, 0, 127}));
      connect(firstOrder.y, product.u1) annotation(
        Line(points = {{143, 61}, {151, 61}, {151, 40}, {-30, 40}, {-30, 29}, {-19, 29}, {-19, 30}}, color = {0, 0, 127}));
      connect(firstOrder.y, combiTable3D.u) annotation(
        Line(points = {{143, 61}, {151, 61}, {151, 40}, {-30, 40}, {-30, -19}, {-19, -19}, {-19, -19}}, color = {0, 0, 127}));
      connect(firstOrder.y, combiTable3D1.u) annotation(
        Line(points = {{143, 61}, {151, 61}, {151, 40}, {-30, 40}, {-30, -46}, {-19, -46}, {-19, -45}}, color = {0, 0, 127}));
      connect(to_rpm.y, combiTable2D.u1) annotation(
        Line(points = {{-148, 35}, {-123, 35}, {-123, 98}, {-107, 98}}, color = {0, 0, 127}));
      connect(combiTable2D.y, min.u2) annotation(
        Line(points = {{-84, 92}, {-77, 92}, {-77, 97}, {-59, 97}}, color = {0, 0, 127}));
      connect(TargetTrq, min.u1) annotation(
        Line(points = {{-201, 77}, {-154, 77}, {-154, 109}, {-61, 109}, {-61, 109}, {-59, 109}}, color = {0, 0, 127}));
      connect(to_rpm.y, combiTable2D1.u1) annotation(
        Line(points = {{-148, 35}, {-123, 35}, {-123, 47}, {-107, 47}}, color = {0, 0, 127}));
      connect(TargetTrq, greaterEqual.u1) annotation(
        Line(points = {{-201, 77}, {18, 77}}, color = {0, 0, 127}));
      connect(const.y, greaterEqual.u2) annotation(
        Line(points = {{-3, 64}, {6, 64}, {6, 69}, {18, 69}, {18, 69}}, color = {0, 0, 127}));
      connect(greaterEqual.y, switch1.u2) annotation(
        Line(points = {{41, 77}, {49, 77}, {49, 96}, {71, 96}, {71, 96}}, color = {255, 0, 255}));
      connect(min.y, switch1.u1) annotation(
        Line(points = {{-36, 103}, {69, 103}, {69, 104}, {71, 104}}, color = {0, 0, 127}));
      connect(HiBatVol, combiTable2D.u2) annotation(
        Line(points = {{-202, -73}, {-118, -73}, {-118, 86}, {-107, 86}}, color = {0, 0, 127}));
      connect(HiBatVol, combiTable2D1.u2) annotation(
        Line(points = {{-202, -73}, {-118, -73}, {-118, 35}, {-107, 35}, {-107, 35}}, color = {0, 0, 127}));
      connect(TargetTrq, max.u1) annotation(
        Line(points = {{-201, 77}, {-72, 77}, {-72, 52}, {-59, 52}, {-59, 53}}, color = {0, 0, 127}));
      connect(max.y, switch1.u3) annotation(
        Line(points = {{-36, 47}, {57, 47}, {57, 88}, {71, 88}, {71, 88}}, color = {0, 0, 127}));
      connect(product.y, A_Pmech.u) annotation(
        Line(points = {{4, 24}, {10, 24}, {10, -99}, {29, -99}, {29, -99}}, color = {0, 0, 127}));
      connect(gain1.y, A_Pele.u) annotation(
        Line(points = {{117, 14}, {118, 14}, {118, -100}, {125, -100}, {125, -100}}, color = {0, 0, 127}));
      connect(HiBatVol, max1.u2) annotation(
        Line(points = {{-202, -73}, {63, -73}, {63, -73}, {63, -73}}, color = {0, 0, 127}));
      connect(const1.y, max1.u1) annotation(
        Line(points = {{51, -61}, {63, -61}}, color = {0, 0, 127}));
      connect(max1.y, division1.u2) annotation(
        Line(points = {{86, -67}, {112, -67}, {112, 1}, {126, 1}, {126, 2}}, color = {0, 0, 127}));
      connect(combiTable2D1.y, max.u2) annotation(
        Line(points = {{-84, 41}, {-61, 41}, {-61, 41}, {-59, 41}}, color = {0, 0, 127}));
    protected
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-180, -120}, {160, 120}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-160, 100}, {160, -100}}), Text(origin = {-32.5, 11.5}, extent = {{-82.5, 21.5}, {160.5, -41.5}}, textString = "MotorGenerator")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-180, -120}, {160, 120}})),
        __OpenModelica_commandLineOptions = "");
    end MotorGenerator;

    model CombiTable3D
      parameter String filename;
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      parameter Real z_ax[:] = {10, 20, 40, 50};
      Modelica.Blocks.Tables.CombiTable2D combiTable2D1[nz](each fileName = currDir + "/Tables/" + filename, each smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = {"tab" + String(i) for i in 1:nz}, each tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput u annotation(
        Placement(visible = true, transformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput u1 annotation(
        Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput u2 annotation(
        Placement(visible = true, transformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-120, -80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
      parameter Boolean noExtrapolate = true;
      parameter Integer nz = size(z_ax, 1) "number of zi";
      Modelica.Blocks.Interfaces.RealOutput y annotation(
        Placement(visible = true, transformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      if noExtrapolate and (u2 < z_ax[1] or u2 >= z_ax[nz]) then
        if u2 < z_ax[1] then
          y = combiTable2D1[1].y;
        else
          y = combiTable2D1[nz].y;
        end if;
      else
        y = Modelica.Math.Vectors.interpolate(z_ax, combiTable2D1.y, u2);
      end if;
      for i in 1:nz loop
        combiTable2D1[i].u1 = u;
        combiTable2D1[i].u2 = u1;
      end for;
      annotation(
        Icon(coordinateSystem(initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Line(origin = {-16, -8}, points = {{-60, 40}, {-60, -40}, {60, -40}, {60, 40}, {30, 40}, {30, -40}, {-30, -40}, {-30, 40}, {-60, 40}, {-60, 20}, {60, 20}, {60, 0}, {-60, 0}, {-60, -20}, {60, -20}, {60, -40}, {-60, -40}, {-60, 40}, {60, 40}, {60, -40}}), Line(origin = {-16, -8}, points = {{0, 40}, {0, -40}}), Line(origin = {-16, -8}, points = {{-60, 40}, {-30, 20}}), Line(origin = {-16, -8}, points = {{-30, 40}, {-60, 20}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, 0}, {-32.3077, 20}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, -20}, {-32.3077, 0}}), Rectangle(origin = {-13.6923, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-62.3077, -40}, {-32.3077, -20}}), Rectangle(origin = {-16, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{-30, 20}, {0, 40}}), Rectangle(origin = {-16, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 20}, {30, 40}}), Line(origin = {-2, 4}, points = {{-60, 40}, {-60, 28}, {60, 28}, {60, 40}, {30, 40}, {30, 28}, {-30, 28}, {-30, 40}, {-60, 40}, {-60, 28}, {60, 28}, {60, 0}, {46, 0}, {46, -20}, {60, -20}, {60, -40}, {46, -40}, {46, 40}, {60, 40}, {60, -40}}), Rectangle(origin = {-2, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Rectangle(origin = {-32, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Line(origin = {-2, 4}, points = {{-60, 40}, {-44, 28}}), Line(origin = {-2, 4}, points = {{-30, 40}, {-48, 28}}), Line(origin = {12, 16}, points = {{-60, 40}, {-60, 28}, {60, 28}, {60, 40}, {30, 40}, {30, 28}, {-30, 28}, {-30, 40}, {-60, 40}, {-60, 28}, {60, 28}, {60, 0}, {46, 0}, {46, -20}, {60, -20}, {60, -40}, {46, -40}, {46, 40}, {60, 40}, {60, -40}}), Rectangle(origin = {12, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Rectangle(origin = {-18, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{0, 28}, {30, 40}}), Line(origin = {12, 16}, points = {{-60, 40}, {-44, 28}}), Rectangle(origin = {9.692, 16}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Rectangle(origin = {-4.308, 4}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Rectangle(origin = {-18.308, -8}, fillColor = {255, 215, 136}, fillPattern = FillPattern.Solid, extent = {{32.3077, 20}, {62.3077, 40}}), Line(origin = {11.9666, 16.1}, points = {{-30, 40}, {-48, 28}})}),
        Diagram(coordinateSystem(initialScale = 0.1)),
        uses(Modelica(version = "3.2.2")));
    end CombiTable3D;
    annotation(
      Icon(coordinateSystem(grid = {1, 1})),
      Diagram(coordinateSystem(grid = {1, 1})),
      uses(Modelica(version = "3.2.2")));
  end HEVElectricElements;

  package Vehicle_control_Unit
    model VEHICLE_CNT
      final constant Real pi = 2 * Modelica.Math.asin(1.0);
      // 3.14159265358979;
      final constant Real inf = ModelicaServices.Machine.inf "Biggest Real number such that inf and -inf are representable on the machine";
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      parameter Real start_SOC = 70;
      Modelica.Blocks.Interfaces.RealInput w_P2M_PNT_radps annotation(
        Placement(visible = true, transformation(origin = {-261, -20}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput soc_hi_vol_batt annotation(
        Placement(visible = true, transformation(origin = {-228.5, -0.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-110, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput t_hi_vol_batt_k annotation(
        Placement(visible = true, transformation(origin = {-227, -140}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-110, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput torque_gain_drive_train annotation(
        Placement(visible = true, transformation(origin = {-228.5, -90.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-110, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput accel_position_per annotation(
        Placement(visible = true, transformation(origin = {-228.5, -70.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput v_vehicle_mps annotation(
        Placement(visible = true, transformation(origin = {-261, -50}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-110, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput drive_mode annotation(
        Placement(visible = true, transformation(origin = {-261.5, 21.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-110, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_gearbox_input_target annotation(
        Placement(visible = true, transformation(origin = {-228, 41}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-109.5, 90.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_p2m_req annotation(
        Placement(visible = true, transformation(origin = {260, 21}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_brake_target annotation(
        Placement(visible = true, transformation(origin = {260, -25}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_eng_req annotation(
        Placement(visible = true, transformation(origin = {259, 55}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput flag_vcu_k0_open_req annotation(
        Placement(visible = true, transformation(origin = {259, -65}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_vcu_eng_speed_req annotation(
        Placement(visible = true, transformation(origin = {259, -94}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {110, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput key_position annotation(
        Placement(visible = true, transformation(origin = {-227, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-110, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D combiTable2D(fileName = currDir + "/Tables/Motor_MaxTrqMap.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "powering", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {134, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput V_BT_Hi_vol annotation(
        Placement(visible = true, transformation(origin = {100.5, -39.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-110, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D combiTable2D1(fileName = currDir + "/Tables/Motor_MaxTrqMap.txt", smoothness = Modelica.Blocks.Types.Smoothness.LinearSegments, tableName = "Regeneration", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {134.5, 4.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.VariableLimiter variableLimiter(limitsAtInit = true) annotation(
        Placement(visible = true, transformation(origin = {163.5, 20.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Add total_tau annotation(
        Placement(visible = true, transformation(origin = {258.5, 37.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
      TRAMI_L3_HEV.Vehicle_control_Unit.Acceleration acceleration annotation(
        Placement(visible = true, transformation(origin = {-101.5, 11.125}, extent = {{-30.5, -22.875}, {30.5, 22.875}}, rotation = 0)));
      TRAMI_L3_HEV.Vehicle_control_Unit.Stop_and_Static_charge stop_and_Static_charge annotation(
        Placement(visible = true, transformation(origin = {49.3333, 11}, extent = {{-30.3333, -22.75}, {30.3333, 22.75}}, rotation = 0)));
      TRAMI_L3_HEV.Vehicle_control_Unit.Braking braking annotation(
        Placement(visible = true, transformation(origin = {-26.5, 11.125}, extent = {{-30.5, -22.875}, {30.5, 22.875}}, rotation = 0)));
      Modelica.Blocks.Math.Gain radps2rpm(k = 60 / (2 * pi)) annotation(
        Placement(visible = true, transformation(origin = {-222.5, -19.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Gain mps2kmph(k = 3.6) annotation(
        Placement(visible = true, transformation(origin = {-223.5, -49.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      TRAMI_L3_HEV.Vehicle_control_Unit.Vehicle_situation vehicle_situation annotation(
        Placement(visible = true, transformation(origin = {-130.5, 89.5}, extent = {{-20.5, -20.5}, {20.5, 20.5}}, rotation = 0)));
      TRAMI_L3_HEV.Vehicle_control_Unit.SOC_mode_change soc_mode_change annotation(
        Placement(visible = true, transformation(origin = {-166, 15}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, 40.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold1(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, 21.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold2(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, -0.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold3(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, -19.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold4(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, -49.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold5(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, -70.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Discrete.ZeroOrderHold zeroOrderHold6(samplePeriod = 0.01) annotation(
        Placement(visible = true, transformation(origin = {-201.5, -90.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
    equation
      connect(V_BT_Hi_vol, combiTable2D1.u2) annotation(
        Line(points = {{100.5, -39.5}, {122, -39.5}, {122, -2}}, color = {0, 0, 127}));
      connect(V_BT_Hi_vol, combiTable2D.u2) annotation(
        Line(points = {{100.5, -39.5}, {113, -39.5}, {113, 28}, {122, 28}}, color = {0, 0, 127}));
      connect(w_P2M_PNT_radps, radps2rpm.u) annotation(
        Line(points = {{-261, -20}, {-230, -20}, {-230, -19.5}}, color = {0, 0, 127}));
      connect(v_vehicle_mps, mps2kmph.u) annotation(
        Line(points = {{-261, -50}, {-217.5, -50}, {-217.5, -48}, {-231, -48}, {-231, -49.5}}, color = {0, 0, 127}));
      connect(acceleration.tau_p2m_HEV_target, braking.tau_vcu_p2m_req_input) annotation(
        Line(points = {{-71, 20}, {-57, 20}}, color = {0, 0, 127}));
      connect(acceleration.tau_vcu_brake_target, braking.tau_vcu_brake_target_input) annotation(
        Line(points = {{-71, 11}, {-57, 11}}, color = {0, 0, 127}));
      connect(acceleration.k0_open_HEV_target, braking.flag_vcu_k0_open_req_input) annotation(
        Line(points = {{-71, 2}, {-57, 2}}, color = {0, 0, 127}));
      connect(acceleration.w_vcu_eng_speed_req, braking.w_vcu_eng_speed_req_input) annotation(
        Line(points = {{-71, -7}, {-57, -7}}, color = {0, 0, 127}));
      connect(braking.tau_vcu_eng_req, stop_and_Static_charge.tau_vcu_eng_req_input) annotation(
        Line(points = {{4, 29}, {19, 29}}, color = {0, 0, 127}));
      connect(braking.tau_vcu_p2m_regenerative_torque_Nm, stop_and_Static_charge.tau_vcu_p2m_req_input) annotation(
        Line(points = {{4, 20}, {19, 20}}, color = {0, 0, 127}));
      connect(braking.flag_vcu_k0_open_req, stop_and_Static_charge.flag_vcu_k0_open_req_input) annotation(
        Line(points = {{4, 2}, {19, 2}}, color = {0, 0, 127}));
      connect(braking.w_vcu_eng_speed_req, stop_and_Static_charge.w_vcu_eng_speed_req_input) annotation(
        Line(points = {{4, -7}, {19, -7}}, color = {0, 0, 127}));
      connect(combiTable2D1.y, variableLimiter.limit2) annotation(
        Line(points = {{146, 5}, {151, 5}, {151, 15}, {156, 15}, {156, 15}}, color = {0, 0, 127}));
      connect(combiTable2D.y, variableLimiter.limit1) annotation(
        Line(points = {{145, 34}, {151, 34}, {151, 25}, {156, 25}, {156, 26}}, color = {0, 0, 127}));
      connect(vehicle_situation.vehicle_situation_output, acceleration.vehicle_situation_input) annotation(
        Line(points = {{-110, 89.5}, {-101.5, 89.5}, {-101.5, 34}}, color = {255, 127, 0}));
      connect(vehicle_situation.vehicle_situation_output, braking.vehicle_situation_input) annotation(
        Line(points = {{-110, 89.5}, {-26.5, 89.5}, {-26.5, 34}}, color = {255, 127, 0}));
      connect(vehicle_situation.vehicle_situation_output, stop_and_Static_charge.vehicle_situation_input) annotation(
        Line(points = {{-110, 89.5}, {49, 89.5}, {49, 34}}, color = {255, 127, 0}));
      connect(braking.tau_vcu_brake_torque_Nm, stop_and_Static_charge.tau_vcu_brake_req_input) annotation(
        Line(points = {{4, 11}, {18, 11}, {18, 11}, {19, 11}}, color = {0, 0, 127}));
      connect(stop_and_Static_charge.tau_vcu_p2m_req, variableLimiter.u) annotation(
        Line(points = {{80, 20}, {156, 20}, {156, 21}, {156, 21}}, color = {0, 0, 127}));
      connect(acceleration.tau_eng_HEV_target, braking.tau_vcu_eng_req_input) annotation(
        Line(points = {{-71, 29}, {-57, 29}, {-57, 30}, {-57, 30}}, color = {0, 0, 127}));
      connect(soc_mode_change.Auto_mode_select_result, acceleration.drive_mode) annotation(
        Line(points = {{-156, 15}, {-140, 15}, {-140, 23}, {-132, 23}, {-132, 23}}, color = {0, 0, 127}));
      connect(soc_mode_change.Auto_mode_select_result, stop_and_Static_charge.drive_mode) annotation(
        Line(points = {{-156, 15}, {-140, 15}, {-140, -35}, {37, -35}, {37, -12}, {37, -12}}, color = {0, 0, 127}));
      connect(soc_mode_change.Auto_mode_select_result, braking.drive_mode) annotation(
        Line(points = {{-156, 15}, {-137, 15}, {-137, -35}, {-38, -35}, {-38, -12}}, color = {0, 0, 127}));
      connect(tau_gearbox_input_target, zeroOrderHold.u) annotation(
        Line(points = {{-228, 41}, {-219, 41}, {-219, 40.5}, {-209, 40.5}}, color = {0, 0, 127}));
      connect(drive_mode, zeroOrderHold1.u) annotation(
        Line(points = {{-261, 22}, {-209, 22}, {-209, 22}, {-209, 22}}, color = {0, 0, 127}));
      connect(soc_hi_vol_batt, zeroOrderHold2.u) annotation(
        Line(points = {{-228, 0}, {-211, 0}, {-211, -1}, {-209, -1}}, color = {0, 0, 127}));
      connect(radps2rpm.y, zeroOrderHold3.u) annotation(
        Line(points = {{-215, -19}, {-210, -19}, {-210, -19}, {-209, -19}}, color = {0, 0, 127}));
      connect(mps2kmph.y, zeroOrderHold4.u) annotation(
        Line(points = {{-216, -49}, {-208, -49}, {-208, -49}, {-209, -49}}, color = {0, 0, 127}));
      connect(accel_position_per, zeroOrderHold5.u) annotation(
        Line(points = {{-228, -70}, {-211, -70}, {-211, -70}, {-209, -70}}, color = {0, 0, 127}));
      connect(torque_gain_drive_train, zeroOrderHold6.u) annotation(
        Line(points = {{-228, -90}, {-210, -90}, {-210, -90}, {-209, -90}}, color = {0, 0, 127}));
      connect(zeroOrderHold.y, vehicle_situation.tau_gearbox_input_torque) annotation(
        Line(points = {{-194, 41}, {-190, 41}, {-190, 90}, {-151, 90}, {-151, 89}}, color = {0, 0, 127}));
      connect(zeroOrderHold.y, acceleration.tau_gearbox_input_target) annotation(
        Line(points = {{-194, 41}, {-139, 41}, {-139, 29}, {-132, 29}, {-132, 29}}, color = {0, 0, 127}));
      connect(zeroOrderHold.y, stop_and_Static_charge.tau_gearbox_input_target) annotation(
        Line(points = {{-194, 41}, {-139, 41}, {-139, -15}, {31, -15}, {31, -12}, {31, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold.y, braking.tau_gearbox_torque_Nm) annotation(
        Line(points = {{-194, 41}, {-139, 41}, {-139, -15}, {-44, -15}, {-44, -12}, {-44, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold1.y, soc_mode_change.curr_dirve_mode) annotation(
        Line(points = {{-194, 22}, {-177, 22}, {-177, 21}, {-176, 21}}, color = {0, 0, 127}));
      connect(zeroOrderHold2.y, soc_mode_change.SOC_hi_vol_batt_per) annotation(
        Line(points = {{-194, -1}, {-185, -1}, {-185, 8}, {-176, 8}, {-176, 9}}, color = {0, 0, 127}));
      connect(zeroOrderHold2.y, stop_and_Static_charge.SOC_hi_vol_batt_per) annotation(
        Line(points = {{-194, -1}, {-141, -1}, {-141, -16}, {43, -16}, {43, -12}, {43, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold2.y, braking.SOC_hi_vol_per) annotation(
        Line(points = {{-194, -1}, {-141, -1}, {-141, -16}, {-33, -16}, {-33, -12}, {-32, -12}}, color = {0, 0, 127}));
      connect(acceleration.soc_hi_vol_batt, zeroOrderHold2.y) annotation(
        Line(points = {{-132, 17}, {-141, 17}, {-141, 0}, {-194, 0}, {-194, -1}}, color = {0, 0, 127}));
      connect(zeroOrderHold3.y, acceleration.w_p2m_rev_rpm) annotation(
        Line(points = {{-194, -19}, {-143, -19}, {-143, 11}, {-132, 11}, {-132, 11}}, color = {0, 0, 127}));
      connect(zeroOrderHold3.y, stop_and_Static_charge.w_P2M_PNT_rpm) annotation(
        Line(points = {{-194, -19}, {50, -19}, {50, -12}, {49, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold3.y, braking.w_P2M_PNT_rpm) annotation(
        Line(points = {{-194, -19}, {-27, -19}, {-27, -12}, {-26, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold4.y, acceleration.Vehicle_speed) annotation(
        Line(points = {{-194, -49}, {-144, -49}, {-144, 6}, {-132, 6}, {-132, 5}}, color = {0, 0, 127}));
      connect(zeroOrderHold4.y, stop_and_Static_charge.vehicle_speed) annotation(
        Line(points = {{-194, -49}, {56, -49}, {56, -12}, {55, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold4.y, braking.v_vehicle_kmph) annotation(
        Line(points = {{-194, -49}, {-21, -49}, {-21, -12}, {-20, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold5.y, acceleration.Accel_pedal_opening) annotation(
        Line(points = {{-194, -70}, {-146, -70}, {-146, -1}, {-132, -1}, {-132, -1}}, color = {0, 0, 127}));
      connect(zeroOrderHold5.y, stop_and_Static_charge.Accel_position_opening) annotation(
        Line(points = {{-194, -70}, {61, -70}, {61, -12}, {62, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold5.y, braking.accel_position_per) annotation(
        Line(points = {{-194, -70}, {-14, -70}, {-14, -12}, {-14, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold6.y, acceleration.Transmission_total_ratio) annotation(
        Line(points = {{-194, -90}, {-148, -90}, {-148, -8}, {-132, -8}, {-132, -7}}, color = {0, 0, 127}));
      connect(zeroOrderHold6.y, stop_and_Static_charge.torque_gin_drive_train) annotation(
        Line(points = {{-194, -90}, {68, -90}, {68, -12}, {68, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold6.y, braking.gearbox_total_ratio) annotation(
        Line(points = {{-194, -90}, {-8, -90}, {-8, -12}, {-8, -12}}, color = {0, 0, 127}));
      connect(zeroOrderHold3.y, combiTable2D.u1) annotation(
        Line(points = {{-194, -19}, {-170, -19}, {-170, -100}, {117, -100}, {117, 40}, {122, 40}, {122, 40}}, color = {0, 0, 127}));
      connect(zeroOrderHold3.y, combiTable2D1.u1) annotation(
        Line(points = {{-194, -19}, {-170, -19}, {-170, -100}, {117, -100}, {117, 11}, {122, 11}, {122, 11}}, color = {0, 0, 127}));
      connect(variableLimiter.y, tau_vcu_p2m_req) annotation(
        Line(points = {{171, 21}, {260, 21}}, color = {0, 0, 127}));
      connect(tau_vcu_brake_target, stop_and_Static_charge.tau_vcu_brake_target) annotation(
        Line(points = {{260, -25}, {111, -25}, {111, 11}, {80, 11}, {80, 11}}, color = {0, 0, 127}));
      connect(flag_vcu_k0_open_req, stop_and_Static_charge.flag_vcu_k0_open_req) annotation(
        Line(points = {{259, -65}, {91, -65}, {91, 2}, {80, 2}, {80, 2}}, color = {0, 0, 127}));
      connect(w_vcu_eng_speed_req, stop_and_Static_charge.w_vcu_eng_speed_req) annotation(
        Line(points = {{259, -94}, {84, -94}, {84, -7}, {80, -7}, {80, -7}}, color = {0, 0, 127}));
      connect(tau_vcu_eng_req, stop_and_Static_charge.tau_vcu_eng_req) annotation(
        Line(points = {{259, 55}, {91, 55}, {91, 30}, {80, 30}, {80, 29}}, color = {0, 0, 127}));
      connect(total_tau.u1, tau_vcu_eng_req) annotation(
        Line(points = {{252, 41}, {234, 41}, {234, 55}, {259, 55}, {259, 55}}, color = {0, 0, 127}));
      connect(total_tau.u2, tau_vcu_p2m_req) annotation(
        Line(points = {{252, 34}, {234, 34}, {234, 21}, {260, 21}, {260, 21}}, color = {0, 0, 127}));
    protected
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, preserveAspectRatio = false, initialScale = 0.1), graphics = {Rectangle(origin = {-74.5, 77}, fillColor = {255, 255, 255}, extent = {{-24.5, 24}, {173.5, -178}}), Text(origin = {-0.5, 2}, extent = {{-67.5, 26}, {67.5, -26}}, textString = "VCU")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}})));
    end VEHICLE_CNT;

    model SOC_mode_change
      parameter Real change_SOC_per = 22;
      Modelica.Blocks.Interfaces.RealInput SOC_hi_vol_batt_per annotation(
        Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-99.5, -59.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput curr_dirve_mode annotation(
        Placement(visible = true, transformation(origin = {-100, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-99.5, 60.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant mode_change_SOC(k = change_SOC_per) annotation(
        Placement(visible = true, transformation(origin = {-90, -50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput Auto_mode_select_result annotation(
        Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.And and1 annotation(
        Placement(visible = true, transformation(origin = {-25, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {17, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqual lessEqual annotation(
        Placement(visible = true, transformation(origin = {-57.5, -44.5}, extent = {{-7.5, -7.5}, {7.5, 7.5}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-54, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-24, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Discrete.TriggeredMax triggeredMax annotation(
        Placement(visible = true, transformation(origin = {48, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {64, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Not not1 annotation(
        Placement(visible = true, transformation(origin = {1, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(mode_change_SOC.y, lessEqual.u2) annotation(
        Line(points = {{-79, -50}, {-67, -50}, {-67, -51}, {-67, -51}}, color = {0, 0, 127}));
      connect(SOC_hi_vol_batt_per, lessEqual.u1) annotation(
        Line(points = {{-100, 0}, {-70, 0}, {-70, -45}, {-67, -45}, {-67, -44}}, color = {0, 0, 127}));
      connect(lessEqual.y, and1.u2) annotation(
        Line(points = {{-49, -44}, {-40, -44}, {-40, 22}, {-37, 22}}, color = {255, 0, 255}));
      connect(curr_dirve_mode, lessEqualThreshold.u) annotation(
        Line(points = {{-100, 80}, {-66, 80}}, color = {0, 0, 127}));
      connect(const.y, switch1.u1) annotation(
        Line(points = {{-13, 80}, {-8, 80}, {-8, 66}, {5, 66}}, color = {0, 0, 127}));
      connect(curr_dirve_mode, switch1.u3) annotation(
        Line(points = {{-100, 80}, {-74, 80}, {-74, 50}, {5, 50}}, color = {0, 0, 127}));
      connect(lessEqualThreshold.y, and1.u1) annotation(
        Line(points = {{-43, 80}, {-40, 80}, {-40, 30}, {-37, 30}}, color = {255, 0, 255}));
      connect(switch11.y, Auto_mode_select_result) annotation(
        Line(points = {{75, 0}, {91, 0}, {91, 0}, {100, 0}}, color = {0, 0, 127}));
      connect(and1.y, switch1.u2) annotation(
        Line(points = {{-14, 30}, {-5, 30}, {-5, 58}, {5, 58}, {5, 58}}, color = {255, 0, 255}));
      connect(lessEqualThreshold.y, not1.u) annotation(
        Line(points = {{-43, 80}, {-30, 80}, {-30, 0}, {-11, 0}}, color = {255, 0, 255}));
      connect(curr_dirve_mode, switch11.u1) annotation(
        Line(points = {{-100, 80}, {-74, 80}, {-74, 8}, {52, 8}, {52, 8}}, color = {0, 0, 127}));
      connect(not1.y, switch11.u2) annotation(
        Line(points = {{12, 0}, {51, 0}, {51, 0}, {52, 0}}, color = {255, 0, 255}));
      connect(switch1.y, triggeredMax.u) annotation(
        Line(points = {{28, 58}, {37, 58}, {37, 58}, {36, 58}}, color = {0, 0, 127}));
      connect(and1.y, triggeredMax.trigger) annotation(
        Line(points = {{-14, 30}, {48, 30}, {48, 46}, {48, 46}}, color = {255, 0, 255}));
      connect(triggeredMax.y, switch11.u3) annotation(
        Line(points = {{59, 58}, {65, 58}, {65, -20}, {30, -20}, {30, -8}, {52, -8}, {52, -8}}, color = {0, 0, 127}));
      annotation(
        Diagram(graphics = {Text(origin = {-110, -69}, fillColor = {255, 255, 0}, fillPattern = FillPattern.Solid, extent = {{-22, 7}, {60, -15}}, textString = "HEVモードに切り替えるSOC[%]を入力")}, coordinateSystem(grid = {1, 1}, initialScale = 0.1)),
        Icon(coordinateSystem(grid = {1, 1}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {1.5, 30.5}, extent = {{-86.5, 30.5}, {86.5, -30.5}}, textString = "Lo SOC"), Text(origin = {1, -50.5}, extent = {{-85, 32.5}, {85, -32.5}}, textString = "CD to CS")}));
    end SOC_mode_change;

    model Acceleration
      constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
      final constant Real inf = ModelicaServices.Machine.inf "Biggest Real number such that inf and -inf are representable on the machine";
      parameter Real SOC_sustain_limit = 22;
      parameter Real initial_SOC = 70;
      Modelica.Blocks.Interfaces.RealInput soc_hi_vol_batt annotation(
        Placement(visible = true, transformation(origin = {-170, 70}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-200, 39}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_gearbox_input_target annotation(
        Placement(visible = true, transformation(origin = {-169, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-199.5, 118.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_p2m_rev_rpm annotation(
        Placement(visible = true, transformation(origin = {-169, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-199.5, -0.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_p2m_HEV_target annotation(
        Placement(visible = true, transformation(origin = {222, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {201, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput k0_open_HEV_target annotation(
        Placement(visible = true, transformation(origin = {222, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant k0_bite(k = 0) annotation(
        Placement(visible = true, transformation(origin = {83.5, 19.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Nonlinear.VariableLimiter eng_suit_trq annotation(
        Placement(visible = true, transformation(origin = {-47, -77}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback annotation(
        Placement(visible = true, transformation(origin = {-34, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch suit_area_or_other annotation(
        Placement(visible = true, transformation(origin = {105, 110}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {104, 0}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant k0_free(k = 1) annotation(
        Placement(visible = true, transformation(origin = {83.5, -19.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput Vehicle_speed annotation(
        Placement(visible = true, transformation(origin = {-169, 140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-198.5, -40.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput Transmission_total_ratio annotation(
        Placement(visible = true, transformation(origin = {-170, 100}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-199, -120}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D EV_limit_HEV(fileName = currDir + "/Tables/CS_EV_limit_HEV.txt", tableName = "tab1", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-82, 90}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold = 0.1) annotation(
        Placement(visible = true, transformation(origin = {-25, 110}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant eng_OFF(k = -1000) annotation(
        Placement(visible = true, transformation(origin = {62, 89}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {105.5, 40.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D HEV_p2m_drive_regen_map(fileName = currDir + "/Tables/p2m_regen_assist_HEV.txt", tableName = "HEV_p2m", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-79.5, 19.5}, extent = {{-8.5, -8.5}, {8.5, 8.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch map_ro_diff_switch annotation(
        Placement(visible = true, transformation(origin = {33, 10}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant map_or_diff(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-79, -24}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold1(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-50.5, -24.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D eng_suit_area_drive_LL(fileName = currDir + "/Tables/Eng_suite_trq_LL_map.txt", tableName = "suit_Lower", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-88, -90}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable1D eng_suit_area_drive_UL(fileName = currDir + "/Tables/Eng_suite_trq_UL_map.txt", tableName = "suit_Upper", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-88, -60}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Math.Min min annotation(
        Placement(visible = true, transformation(origin = {-63.5, -86.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
      Modelica.Blocks.Math.Max max annotation(
        Placement(visible = true, transformation(origin = {-63.5, -63.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D EV_limit_power(fileName = currDir + "/Tables/CS_EV_limit_GTE.txt", tableName = "tab1", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-83, 136}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch12 annotation(
        Placement(visible = true, transformation(origin = {-53, 110}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput drive_mode annotation(
        Placement(visible = true, transformation(origin = {-271, 0}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-200, 79}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      Modelica.Blocks.Tables.CombiTable2D Power_p2m_drive_regen_map(fileName = currDir + "/Tables/p2m_regen_assist_GTE.txt", tableName = "GTE_p2m", tableOnFile = true) annotation(
        Placement(visible = true, transformation(origin = {-79, -2}, extent = {{-8, -8}, {8, 8}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch13 annotation(
        Placement(visible = true, transformation(origin = {-13, 26}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_eng_HEV_target annotation(
        Placement(visible = true, transformation(origin = {222, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {201, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = initial_SOC) annotation(
        Placement(visible = true, transformation(origin = {-126, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback1 annotation(
        Placement(visible = true, transformation(origin = {-10.5, 45.5}, extent = {{-7.5, 7.5}, {7.5, -7.5}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = -0.7) annotation(
        Placement(visible = true, transformation(origin = {34.5, 45.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch14 annotation(
        Placement(visible = true, transformation(origin = {-31, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = SOC_sustain_limit) annotation(
        Placement(visible = true, transformation(origin = {-126, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterEqual greaterEqual annotation(
        Placement(visible = true, transformation(origin = {-72, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {-120.5, 110.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold(threshold = 15) annotation(
        Placement(visible = true, transformation(origin = {-42.5, 89.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Add add annotation(
        Placement(visible = true, transformation(origin = {83, 51}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch15 annotation(
        Placement(visible = true, transformation(origin = {146, 68}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch16 annotation(
        Placement(visible = true, transformation(origin = {147, 8}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch17 annotation(
        Placement(visible = true, transformation(origin = {147, -52}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold2(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-209, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Or or1 annotation(
        Placement(visible = true, transformation(origin = {50.5, 110.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold3(threshold = 5) annotation(
        Placement(visible = true, transformation(origin = {-17, 130}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold1(threshold = 15) annotation(
        Placement(visible = true, transformation(origin = {-17, 150}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.And and1 annotation(
        Placement(visible = true, transformation(origin = {9, 140}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.And and11 annotation(
        Placement(visible = true, transformation(origin = {30, 95}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold = 2) annotation(
        Placement(visible = true, transformation(origin = {-209, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.And and12 annotation(
        Placement(visible = true, transformation(origin = {-166, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput Accel_pedal_opening annotation(
        Placement(visible = true, transformation(origin = {-270, -51}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-199, -81}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_brake_target annotation(
        Placement(visible = true, transformation(origin = {207, -109}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {202, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_vcu_eng_speed_req annotation(
        Placement(visible = true, transformation(origin = {207, -139}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {203, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.IntegerInput vehicle_situation_input annotation(
        Placement(visible = true, transformation(origin = {-235, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {0, 150}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
      Modelica.Blocks.Math.IntegerToReal integerToReal annotation(
        Placement(visible = true, transformation(origin = {-191, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold2(threshold = 1.5) annotation(
        Placement(visible = true, transformation(origin = {-148, -140}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const2(k = 0) annotation(
        Placement(visible = true, transformation(origin = {151, -125}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch18 annotation(
        Placement(visible = true, transformation(origin = {190, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch19 annotation(
        Placement(visible = true, transformation(origin = {190, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch110 annotation(
        Placement(visible = true, transformation(origin = {190, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold4(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-148, -170}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.And and13 annotation(
        Placement(visible = true, transformation(origin = {-111, -150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(tau_gearbox_input_target, eng_suit_trq.u) annotation(
        Line(points = {{-169, -30}, {-105, -30}, {-105, -77}, {-53, -77}}, color = {0, 0, 127}));
      connect(eng_suit_trq.y, feedback.u2) annotation(
        Line(points = {{-41.5, -77}, {-34, -77}, {-34, -48}}, color = {0, 0, 127}));
      connect(k0_bite.y, switch1.u1) annotation(
        Line(points = {{91, 19.5}, {97, 19.5}, {97, 5}}, color = {0, 0, 127}));
      connect(eng_OFF.y, suit_area_or_other.u3) annotation(
        Line(points = {{69, 89}, {69, 105}, {98, 105}}, color = {0, 0, 127}));
      connect(tau_gearbox_input_target, feedback.u1) annotation(
        Line(points = {{-169, -30}, {-105, -30}, {-105, -40}, {-42, -40}}, color = {0, 0, 127}));
      connect(tau_gearbox_input_target, HEV_p2m_drive_regen_map.u2) annotation(
        Line(points = {{-169, -30}, {-105, -30}, {-105, 14}, {-90, 14}}, color = {255, 0, 0}));
      connect(map_or_diff.y, greaterThreshold1.u) annotation(
        Line(points = {{-70, -24}, {-60, -24}, {-60, -24.5}, {-58, -24.5}}, color = {0, 0, 127}));
      connect(greaterThreshold1.y, map_ro_diff_switch.u2) annotation(
        Line(points = {{-43, -24.5}, {-30, -24.5}, {-30, 10}, {25, 10}}, color = {255, 0, 255}));
      connect(eng_suit_area_drive_UL.y[1], max.u1) annotation(
        Line(points = {{-79, -60}, {-70, -60}}, color = {0, 0, 127}));
      connect(eng_suit_area_drive_LL.y[1], min.u2) annotation(
        Line(points = {{-79, -90}, {-70, -90}}, color = {0, 0, 127}));
      connect(max.y, eng_suit_trq.limit1) annotation(
        Line(points = {{-57, -63.5}, {-56, -63.5}, {-56, -73}, {-53, -73}}, color = {0, 0, 127}));
      connect(min.y, eng_suit_trq.limit2) annotation(
        Line(points = {{-57, -86.5}, {-57, -81}, {-53, -81}}, color = {0, 0, 127}));
      connect(eng_suit_area_drive_UL.y[1], min.u1) annotation(
        Line(points = {{-79, -60}, {-74, -60}, {-74, -83}, {-70, -83}}, color = {0, 0, 127}));
      connect(eng_suit_area_drive_LL.y[1], max.u2) annotation(
        Line(points = {{-79, -90}, {-73, -90}, {-73, -67}, {-70, -67}}, color = {0, 0, 127}));
      connect(switch13.y, map_ro_diff_switch.u1) annotation(
        Line(points = {{-6, 26}, {9.5, 26}, {9.5, 16}, {25, 16}}, color = {0, 0, 127}));
      connect(HEV_p2m_drive_regen_map.y, switch13.u1) annotation(
        Line(points = {{-70, 19.5}, {-51.5, 19.5}, {-51.5, 31}, {-20, 31}}, color = {0, 0, 127}));
      connect(Power_p2m_drive_regen_map.y, switch13.u3) annotation(
        Line(points = {{-70, -2}, {-44.5, -2}, {-44.5, 21}, {-20, 21}}, color = {0, 0, 127}));
      connect(switch12.y, greaterThreshold.u) annotation(
        Line(points = {{-46, 110}, {-32, 110}}, color = {0, 0, 127}));
      connect(feedback1.y, gain.u) annotation(
        Line(points = {{-4, 45.5}, {28, 45.5}}, color = {0, 0, 127}));
      connect(const.y, greaterEqual.u1) annotation(
        Line(points = {{-119, 60}, {-79, 60}}, color = {0, 0, 127}));
      connect(greaterEqual.y, switch14.u2) annotation(
        Line(points = {{-65, 60}, {-38, 60}}, color = {255, 0, 255}));
      connect(const1.y, greaterEqual.u2) annotation(
        Line(points = {{-119, 40}, {-86, 40}, {-86, 55}, {-79, 55}}, color = {0, 0, 127}));
      connect(const1.y, switch14.u3) annotation(
        Line(points = {{-119, 40}, {-59, 40}, {-59, 55}, {-38, 55}}, color = {0, 0, 127}));
      connect(Transmission_total_ratio, product.u1) annotation(
        Line(points = {{-170, 100}, {-152.5, 100}, {-152.5, 114}, {-128, 114}}, color = {0, 0, 127}));
      connect(feedback.y, map_ro_diff_switch.u3) annotation(
        Line(points = {{-25, -40}, {-20, -40}, {-20, 4}, {25, 4}}, color = {0, 0, 127}));
      connect(add.y, switch11.u1) annotation(
        Line(points = {{91, 51}, {94.5, 51}, {94.5, 45}, {99, 45}}, color = {0, 0, 127}));
      connect(tau_gearbox_input_target, product.u2) annotation(
        Line(points = {{-169, -30}, {-140, -30}, {-140, 107}, {-128, 107}}, color = {255, 0, 0}));
      connect(product.y, EV_limit_power.u2) annotation(
        Line(points = {{-113, 111}, {-100, 111}, {-100, 131}, {-91, 131}, {-91, 132}}, color = {0, 0, 127}));
      connect(product.y, EV_limit_HEV.u2) annotation(
        Line(points = {{-113, 111}, {-100, 111}, {-100, 86}, {-90, 86}, {-90, 86}}, color = {0, 0, 127}));
      connect(EV_limit_power.y, switch12.u1) annotation(
        Line(points = {{-75, 136}, {-66, 136}, {-66, 115}, {-60, 115}, {-60, 115}}, color = {0, 0, 127}));
      connect(EV_limit_HEV.y, switch12.u3) annotation(
        Line(points = {{-74, 90}, {-66, 90}, {-66, 105}, {-60, 105}, {-60, 105}}, color = {0, 0, 127}));
      connect(switch1.y, switch17.u1) annotation(
        Line(points = {{111, 0}, {111, -46}, {139, -46}}, color = {0, 0, 127}));
      connect(switch11.y, switch16.u1) annotation(
        Line(points = {{112, 40.5}, {120, 40.5}, {120, 14}, {139, 14}}, color = {0, 0, 127}));
      connect(suit_area_or_other.y, switch15.u1) annotation(
        Line(points = {{112, 110}, {130, 110}, {130, 74}, {138, 74}}, color = {0, 0, 127}));
      connect(drive_mode, greaterThreshold2.u) annotation(
        Line(points = {{-271, 0}, {-221, 0}, {-221, 0}, {-221, 0}}, color = {0, 0, 127}));
      connect(k0_free.y, switch17.u3) annotation(
        Line(points = {{91, -19.5}, {100, -19.5}, {100, -58}, {139, -58}}, color = {0, 0, 127}));
      connect(eng_OFF.y, switch15.u3) annotation(
        Line(points = {{69, 89}, {123, 89}, {123, 62}, {138, 62}}, color = {0, 0, 127}));
      connect(greaterThreshold.y, or1.u1) annotation(
        Line(points = {{-18, 110}, {29, 110}, {29, 110.5}, {43, 110.5}}, color = {255, 0, 255}));
      connect(k0_free.y, switch1.u3) annotation(
        Line(points = {{91, -19.5}, {97, -19.5}, {97, -5}}, color = {0, 0, 127}));
      connect(or1.y, switch1.u2) annotation(
        Line(points = {{58, 110.5}, {61, 110.5}, {61, 0}, {97, 0}}, color = {255, 0, 255}));
      connect(or1.y, switch11.u2) annotation(
        Line(points = {{58, 110.5}, {61, 110.5}, {61, 40.5}, {99, 40.5}}, color = {255, 0, 255}));
      connect(or1.y, suit_area_or_other.u2) annotation(
        Line(points = {{58, 110.5}, {97, 110.5}, {97, 110}, {98, 110}}, color = {255, 0, 255}));
      connect(soc_hi_vol_batt, lessEqualThreshold.u) annotation(
        Line(points = {{-170, 70}, {-50, 70}, {-50, 89.5}}, color = {0, 170, 0}));
      connect(switch14.y, feedback1.u2) annotation(
        Line(points = {{-24, 60}, {-10, 60}, {-10, 52}}, color = {0, 0, 127}));
      connect(soc_hi_vol_batt, feedback1.u1) annotation(
        Line(points = {{-170, 70}, {-50, 70}, {-50, 46}, {-16.5, 46}, {-16.5, 45.5}}, color = {0, 170, 0}));
      connect(tau_gearbox_input_target, Power_p2m_drive_regen_map.u2) annotation(
        Line(points = {{-169, -30}, {-105, -30}, {-105, -7}, {-89, -7}}, color = {255, 0, 0}));
      connect(greaterThreshold2.y, switch17.u2) annotation(
        Line(points = {{-198, 0}, {-180, 0}, {-180, -120}, {130, -120}, {130, -52}, {139, -52}}, color = {255, 0, 255}));
      connect(greaterThreshold2.y, switch16.u2) annotation(
        Line(points = {{-198, 0}, {-180, 0}, {-180, -120}, {130, -120}, {130, 8}, {139, 8}}, color = {255, 0, 255}));
      connect(greaterThreshold2.y, switch15.u2) annotation(
        Line(points = {{-198, 0}, {-180, 0}, {-180, -120}, {130, -120}, {130, 68}, {138, 68}}, color = {255, 0, 255}));
      connect(tau_gearbox_input_target, switch16.u3) annotation(
        Line(points = {{-169, -30}, {-140, -30}, {-140, -111}, {120, -111}, {120, 2}, {139, 2}}, color = {255, 0, 0}));
      connect(tau_gearbox_input_target, switch11.u3) annotation(
        Line(points = {{-169, -30}, {-140, -30}, {-140, -111}, {70, -111}, {70, 36}, {99, 36}, {99, 36}}, color = {255, 0, 0}));
      connect(gain.y, add.u1) annotation(
        Line(points = {{41, 46}, {50, 46}, {50, 55}, {75, 55}, {75, 55}}, color = {0, 0, 127}));
      connect(map_ro_diff_switch.y, add.u2) annotation(
        Line(points = {{41, 10}, {55, 10}, {55, 47}, {75, 47}}, color = {0, 0, 127}));
      connect(const.y, switch14.u1) annotation(
        Line(points = {{-119, 60}, {-110, 60}, {-110, 64}, {-38, 64}, {-38, 65}}, color = {0, 0, 127}));
      connect(greaterThreshold3.y, and1.u2) annotation(
        Line(points = {{-9, 130}, {-5, 130}, {-5, 134}, {1, 134}, {1, 134}}, color = {255, 0, 255}));
      connect(lessEqualThreshold1.y, and1.u1) annotation(
        Line(points = {{-9, 150}, {-5, 150}, {-5, 140}, {1, 140}, {1, 140}}, color = {255, 0, 255}));
      connect(lessEqualThreshold.y, and11.u2) annotation(
        Line(points = {{-35, 90}, {20, 90}, {20, 89}, {22, 89}}, color = {255, 0, 255}));
      connect(and1.y, and11.u1) annotation(
        Line(points = {{17, 140}, {22, 140}, {22, 95}, {22, 95}}, color = {255, 0, 255}));
      connect(and11.y, or1.u2) annotation(
        Line(points = {{38, 95}, {39, 95}, {39, 106}, {43, 106}, {43, 105}}, color = {255, 0, 255}));
      connect(eng_suit_trq.y, suit_area_or_other.u1) annotation(
        Line(points = {{-41, -77}, {74, -77}, {74, 115}, {98, 115}, {98, 115}}, color = {0, 0, 127}));
      connect(drive_mode, lessThreshold.u) annotation(
        Line(points = {{-271, 0}, {-239, 0}, {-239, 30}, {-221, 30}, {-221, 30}}, color = {0, 0, 127}));
      connect(lessThreshold.y, and12.u1) annotation(
        Line(points = {{-198, 30}, {-179, 30}, {-179, 30}, {-178, 30}}, color = {255, 0, 255}));
      connect(greaterThreshold2.y, and12.u2) annotation(
        Line(points = {{-198, 0}, {-190, 0}, {-190, 22}, {-178, 22}, {-178, 22}}, color = {255, 0, 255}));
      connect(and12.y, switch12.u2) annotation(
        Line(points = {{-155, 30}, {-70, 30}, {-70, 110}, {-60, 110}, {-60, 110}}, color = {255, 0, 255}));
      connect(and12.y, switch13.u2) annotation(
        Line(points = {{-155, 30}, {-29, 30}, {-29, 26}, {-20, 26}, {-20, 26}}, color = {255, 0, 255}));
      connect(vehicle_situation_input, integerToReal.u) annotation(
        Line(points = {{-235, -140}, {-203, -140}}, color = {255, 127, 0}));
      connect(integerToReal.y, lessEqualThreshold2.u) annotation(
        Line(points = {{-180, -140}, {-160, -140}, {-160, -140}, {-160, -140}}, color = {0, 0, 127}));
      connect(const2.y, tau_vcu_brake_target) annotation(
        Line(points = {{162, -125}, {187, -125}, {187, -110}, {207, -110}, {207, -109}}, color = {0, 0, 127}));
      connect(const2.y, w_vcu_eng_speed_req) annotation(
        Line(points = {{162, -125}, {187.5, -125}, {187.5, -139}, {207, -139}}, color = {0, 0, 127}));
      connect(const2.y, switch18.u3) annotation(
        Line(points = {{162, -125}, {172, -125}, {172, 52}, {178, 52}}, color = {0, 0, 127}));
      connect(const2.y, switch19.u3) annotation(
        Line(points = {{162, -125}, {172, -125}, {172, -8}, {178, -8}}, color = {0, 0, 127}));
      connect(const2.y, switch110.u3) annotation(
        Line(points = {{162, -125}, {172, -125}, {172, -68}, {178, -68}}, color = {0, 0, 127}));
      connect(switch15.y, switch18.u1) annotation(
        Line(points = {{154, 68}, {179, 68}, {179, 68}, {178, 68}}, color = {0, 0, 127}));
      connect(switch16.y, switch19.u1) annotation(
        Line(points = {{155, 8}, {178, 8}, {178, 8}, {178, 8}}, color = {0, 0, 127}));
      connect(switch17.y, switch110.u1) annotation(
        Line(points = {{155, -52}, {176, -52}, {176, -52}, {178, -52}}, color = {0, 0, 127}));
      connect(switch18.y, tau_eng_HEV_target) annotation(
        Line(points = {{201, 60}, {215, 60}, {215, 60}, {222, 60}}, color = {0, 0, 127}));
      connect(switch19.y, tau_p2m_HEV_target) annotation(
        Line(points = {{201, 0}, {215, 0}, {215, 0}, {222, 0}}, color = {0, 0, 127}));
      connect(switch110.y, k0_open_HEV_target) annotation(
        Line(points = {{201, -60}, {218, -60}, {218, -60}, {222, -60}}, color = {0, 0, 127}));
      connect(w_p2m_rev_rpm, HEV_p2m_drive_regen_map.u1) annotation(
        Line(points = {{-169, -60}, {-119, -60}, {-119, 24}, {-90, 24}, {-90, 25}}, color = {0, 0, 127}));
      connect(w_p2m_rev_rpm, Power_p2m_drive_regen_map.u1) annotation(
        Line(points = {{-169, -60}, {-119, -60}, {-119, 2}, {-89, 2}, {-89, 3}}, color = {0, 0, 127}));
      connect(w_p2m_rev_rpm, eng_suit_area_drive_UL.u[1]) annotation(
        Line(points = {{-169, -60}, {-99, -60}, {-99, -60}, {-98, -60}}, color = {0, 0, 127}));
      connect(w_p2m_rev_rpm, eng_suit_area_drive_LL.u[1]) annotation(
        Line(points = {{-169, -60}, {-119, -60}, {-119, -90}, {-98, -90}, {-98, -90}}, color = {0, 0, 127}));
      connect(Vehicle_speed, EV_limit_power.u1) annotation(
        Line(points = {{-169, 140}, {-92, 140}, {-92, 140}, {-91, 140}}, color = {0, 0, 127}));
      connect(Vehicle_speed, lessEqualThreshold1.u) annotation(
        Line(points = {{-169, 140}, {-129, 140}, {-129, 150}, {-25, 150}, {-25, 150}}, color = {0, 0, 127}));
      connect(Vehicle_speed, greaterThreshold3.u) annotation(
        Line(points = {{-169, 140}, {-129, 140}, {-129, 150}, {-40, 150}, {-40, 129}, {-25, 129}, {-25, 130}}, color = {0, 0, 127}));
      connect(Vehicle_speed, EV_limit_HEV.u1) annotation(
        Line(points = {{-169, 140}, {-103, 140}, {-103, 95}, {-90, 95}, {-90, 94}}, color = {0, 0, 127}));
      connect(integerToReal.y, greaterThreshold4.u) annotation(
        Line(points = {{-180, -140}, {-171, -140}, {-171, -170}, {-160, -170}, {-160, -170}}, color = {0, 0, 127}));
      connect(lessEqualThreshold2.y, and13.u1) annotation(
        Line(points = {{-137, -140}, {-130, -140}, {-130, -151}, {-123, -151}, {-123, -150}}, color = {255, 0, 255}));
      connect(greaterThreshold4.y, and13.u2) annotation(
        Line(points = {{-137, -170}, {-130, -170}, {-130, -159}, {-123, -159}, {-123, -158}}, color = {255, 0, 255}));
      connect(and13.y, switch18.u2) annotation(
        Line(points = {{-100, -150}, {166, -150}, {166, 60}, {178, 60}, {178, 60}}, color = {255, 0, 255}));
      connect(and13.y, switch19.u2) annotation(
        Line(points = {{-100, -150}, {166, -150}, {166, 0}, {178, 0}, {178, 0}}, color = {255, 0, 255}));
      connect(and13.y, switch110.u2) annotation(
        Line(points = {{-100, -150}, {166, -150}, {166, -60}, {178, -60}, {178, -60}}, color = {255, 0, 255}));
    protected
      annotation(
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}}, initialScale = 0.1), graphics = {Rectangle(origin = {-80, 48}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-120, 102}, {280, -198}}), Text(origin = {5, 72.5}, extent = {{-184, 53.5}, {184, -53.5}}, textString = "Acceleration")}),
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}})));
    end Acceleration;

    model Braking
      parameter Real Regen_stop_speed_1 = 20;
      parameter Real Regen_stop_speed_2 = 5;
      final constant Real inf = ModelicaServices.Machine.inf;
      final constant Real pi = 2 * Modelica.Math.asin(1.0);
      // 3.14159265358979;
      Modelica.Blocks.Math.Feedback feedback_2 annotation(
        Placement(visible = true, transformation(origin = {-122, 44}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback_3 annotation(
        Placement(visible = true, transformation(origin = {-122, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Abs abs1 annotation(
        Placement(visible = true, transformation(origin = {-153, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Rebrake_Limit_upper(k = Regen_stop_speed_1) annotation(
        Placement(visible = true, transformation(origin = {-174, 40}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Re_brake_Limit_lower(k = Regen_stop_speed_2) annotation(
        Placement(visible = true, transformation(origin = {-174, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Division division_1 annotation(
        Placement(visible = true, transformation(origin = {-102, 40}, extent = {{-6, 6}, {6, -6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Regen_ON(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-79, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Regen_OFF(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-102, 2}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch2 annotation(
        Placement(visible = true, transformation(origin = {-60, 47}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold annotation(
        Placement(visible = true, transformation(origin = {-102, 60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold1 annotation(
        Placement(visible = true, transformation(origin = {-102, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_gearbox_torque_Nm annotation(
        Placement(visible = true, transformation(origin = {-199, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-118, -149}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput v_vehicle_kmph annotation(
        Placement(visible = true, transformation(origin = {-199, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {41, -149}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput gearbox_total_ratio annotation(
        Placement(visible = true, transformation(origin = {-199, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {120, -149}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput drive_mode annotation(
        Placement(visible = true, transformation(origin = {10, 110}, extent = {{-10, -10}, {10, 10}}, rotation = -90), iconTransformation(origin = {-78, -149}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_p2m_regenerative_torque_Nm annotation(
        Placement(visible = true, transformation(origin = {200, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {200, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_brake_torque_Nm annotation(
        Placement(visible = true, transformation(origin = {200.5, -69.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {200, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const_zero(k = 0) annotation(
        Placement(visible = true, transformation(origin = {3, 33}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Math.Feedback feedback_4 annotation(
        Placement(visible = true, transformation(origin = {-122, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {-78, 30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput SOC_hi_vol_per annotation(
        Placement(visible = true, transformation(origin = {-168, -29}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-39, -149}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      Modelica.Blocks.Nonlinear.VariableLimiter variableLimiter annotation(
        Placement(visible = true, transformation(origin = {32, 3}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {22, 22}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Logical.GreaterThreshold EV_or_other annotation(
        Placement(visible = true, transformation(origin = {26, 76}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Logical.LessThreshold lessThreshold(threshold = 2) annotation(
        Placement(visible = true, transformation(origin = {10, 76}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Logical.And and1 annotation(
        Placement(visible = true, transformation(origin = {22, 54}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant EV_or_Power_mode_limit(k = -330) annotation(
        Placement(visible = true, transformation(origin = {3, 55}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant HEV_mode_limit(k = -330) annotation(
        Placement(visible = true, transformation(origin = {42, 55}, extent = {{-6, -6}, {6, 6}}, rotation = -90)));
      Modelica.Blocks.Sources.Constant SOC_regen_decrease_limit(k = 90) annotation(
        Placement(visible = true, transformation(origin = {-164.5, -46.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback annotation(
        Placement(visible = true, transformation(origin = {-129.5, -46.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant SOC_full(k = 100) annotation(
        Placement(visible = true, transformation(origin = {-164.5, -69.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Product product3 annotation(
        Placement(visible = true, transformation(origin = {51.5, -14.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch12 annotation(
        Placement(visible = true, transformation(origin = {13.5, -24.5}, extent = {{-6.5, 6.5}, {6.5, -6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback2 annotation(
        Placement(visible = true, transformation(origin = {-129, -70}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = -1) annotation(
        Placement(visible = true, transformation(origin = {65, -56}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product annotation(
        Placement(visible = true, transformation(origin = {105.5, -70.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Feedback feedback3 annotation(
        Placement(visible = true, transformation(origin = {54, -74}, extent = {{-6, 6}, {6, -6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product5 annotation(
        Placement(visible = true, transformation(origin = {83, -60}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Math.Product product6 annotation(
        Placement(visible = true, transformation(origin = {73.5, -10.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterEqual greaterEqual annotation(
        Placement(visible = true, transformation(origin = {-129, -29}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-82.5, -17.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const2(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-82.5, -81.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch13 annotation(
        Placement(visible = true, transformation(origin = {-7.5, -40.5}, extent = {{-6.5, 6.5}, {6.5, -6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Division division annotation(
        Placement(visible = true, transformation(origin = {-99.5, -50.5}, extent = {{-6.5, 6.5}, {6.5, -6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold2 annotation(
        Placement(visible = true, transformation(origin = {-100, -70}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_P2M_PNT_rpm annotation(
        Placement(visible = true, transformation(origin = {-220, -130}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {0.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput accel_position_per annotation(
        Placement(visible = true, transformation(origin = {-220, -170}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {81, -149}, extent = {{-10, -10}, {10, 10}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_eng_req annotation(
        Placement(visible = true, transformation(origin = {202, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {200, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput flag_vcu_k0_open_req annotation(
        Placement(visible = true, transformation(origin = {202, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {200, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_vcu_eng_speed_req annotation(
        Placement(visible = true, transformation(origin = {201, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {200, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch14 annotation(
        Placement(visible = true, transformation(origin = {160, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch15 annotation(
        Placement(visible = true, transformation(origin = {159, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch16 annotation(
        Placement(visible = true, transformation(origin = {159, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.IntegerInput vehicle_situation_input annotation(
        Placement(visible = true, transformation(origin = {4, 150}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {0, 150}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
      Modelica.Blocks.Interfaces.RealInput tau_vcu_brake_target_input annotation(
        Placement(visible = true, transformation(origin = {120, -100}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-198, 1}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_vcu_p2m_req_input annotation(
        Placement(visible = true, transformation(origin = {120, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-198, 61}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_vcu_eng_req_input annotation(
        Placement(visible = true, transformation(origin = {100, 112}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-198.5, 120.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_vcu_k0_open_req_input annotation(
        Placement(visible = true, transformation(origin = {100, 82}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-198.5, -58.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_vcu_eng_speed_req_input annotation(
        Placement(visible = true, transformation(origin = {100, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-198.5, -118.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch17 annotation(
        Placement(visible = true, transformation(origin = {159, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch18 annotation(
        Placement(visible = true, transformation(origin = {160, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.IntegerToReal integerToReal annotation(
        Placement(visible = true, transformation(origin = {46, 150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {83, 150}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const3(k = 0) annotation(
        Placement(visible = true, transformation(origin = {64, 68}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const4(k = -1000) annotation(
        Placement(visible = true, transformation(origin = {63, 127}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const5(k = 1) annotation(
        Placement(visible = true, transformation(origin = {64, 98}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(abs1.y, feedback_3.u1) annotation(
        Line(points = {{-146, 60}, {-127, 60}}, color = {0, 0, 127}));
      connect(abs1.y, feedback_4.u1) annotation(
        Line(points = {{-146, 60}, {-138, 60}, {-138, 20}, {-127, 20}}, color = {0, 0, 127}));
      connect(Rebrake_Limit_upper.y, feedback_3.u2) annotation(
        Line(points = {{-167, 40}, {-137, 40}, {-137, 50}, {-122, 50}, {-122, 55}}, color = {0, 0, 127}));
      connect(Re_brake_Limit_lower.y, feedback_2.u2) annotation(
        Line(points = {{-167, 20}, {-139, 20}, {-139, 30}, {-122, 30}, {-122, 39}}, color = {0, 0, 127}));
      connect(Rebrake_Limit_upper.y, feedback_2.u1) annotation(
        Line(points = {{-167, 40}, {-137, 40}, {-137, 44}, {-127, 44}}, color = {0, 0, 127}));
      connect(Re_brake_Limit_lower.y, feedback_4.u2) annotation(
        Line(points = {{-167, 20}, {-139, 20}, {-139, 12}, {-122, 12}, {-122, 15}}, color = {0, 0, 127}));
      connect(feedback_3.y, greaterThreshold.u) annotation(
        Line(points = {{-117, 60}, {-109, 60}}, color = {0, 0, 127}));
      connect(feedback_4.y, greaterThreshold1.u) annotation(
        Line(points = {{-117, 20}, {-109, 20}}, color = {0, 0, 127}));
      connect(feedback_2.y, division_1.u2) annotation(
        Line(points = {{-117, 44}, {-109, 44}}, color = {0, 0, 127}));
      connect(division_1.y, switch11.u1) annotation(
        Line(points = {{-95, 40}, {-95, 37.5}, {-92, 37.5}, {-92, 35}, {-85, 35}}, color = {0, 0, 127}));
      connect(greaterThreshold1.y, switch11.u2) annotation(
        Line(points = {{-95, 20}, {-92, 20}, {-92, 30}, {-85, 30}}, color = {255, 0, 255}));
      connect(Regen_OFF.y, switch11.u3) annotation(
        Line(points = {{-95, 2}, {-85, 2}, {-85, 25}}, color = {0, 0, 127}));
      connect(greaterThreshold.y, switch2.u2) annotation(
        Line(points = {{-95, 60}, {-88, 60}, {-88, 47}, {-67, 47}}, color = {255, 0, 255}));
      connect(Regen_ON.y, switch2.u1) annotation(
        Line(points = {{-72, 60}, {-72, 56}, {-67, 56}, {-67, 52}}, color = {0, 0, 127}));
      connect(switch11.y, switch2.u3) annotation(
        Line(points = {{-71, 30}, {-67, 30}, {-67, 42}}, color = {0, 0, 127}));
      connect(drive_mode, lessThreshold.u) annotation(
        Line(points = {{10, 110}, {10, 83}}, color = {0, 0, 127}));
      connect(drive_mode, EV_or_other.u) annotation(
        Line(points = {{10, 110}, {10, 90}, {26, 90}, {26, 83}}, color = {0, 0, 127}));
      connect(lessThreshold.y, and1.u2) annotation(
        Line(points = {{10, 69}, {10, 65}, {17, 65}, {17, 61}}, color = {255, 0, 255}));
      connect(EV_or_other.y, and1.u1) annotation(
        Line(points = {{26, 69}, {26, 65}, {22, 65}, {22, 61}}, color = {255, 0, 255}));
      connect(and1.y, switch1.u2) annotation(
        Line(points = {{22, 47}, {22, 29}}, color = {255, 0, 255}));
      connect(EV_or_Power_mode_limit.y, switch1.u3) annotation(
        Line(points = {{3, 48}, {3, 45}, {17, 45}, {17, 29}}, color = {0, 0, 127}));
      connect(HEV_mode_limit.y, switch1.u1) annotation(
        Line(points = {{42, 48}, {42, 45}, {27, 45}, {27, 29}}, color = {0, 0, 127}));
      connect(switch1.y, variableLimiter.limit2) annotation(
        Line(points = {{22, 15}, {22, -2}, {25, -2}}, color = {0, 0, 127}));
      connect(variableLimiter.y, product3.u1) annotation(
        Line(points = {{39, 3}, {44, 3}, {44, -11}}, color = {0, 0, 127}));
      connect(tau_gearbox_torque_Nm, feedback3.u1) annotation(
        Line(points = {{-199, -10}, {-22, -10}, {-22, -74}, {49, -74}}, color = {0, 0, 127}));
      connect(product5.y, product.u1) annotation(
        Line(points = {{90, -60}, {94, -60}, {94, -67}, {98, -67}}, color = {0, 0, 127}));
      connect(const.y, product5.u1) annotation(
        Line(points = {{72, -56}, {76, -56}}, color = {0, 0, 127}));
      connect(gearbox_total_ratio, product5.u2) annotation(
        Line(points = {{-199, -90}, {76, -90}, {76, -64}}, color = {0, 0, 127}));
      connect(const_zero.y, variableLimiter.limit1) annotation(
        Line(points = {{3, 26}, {3, 8}, {25, 8}}, color = {0, 0, 127}));
      connect(tau_gearbox_torque_Nm, variableLimiter.u) annotation(
        Line(points = {{-199, -10}, {10, -10}, {10, 3}, {25, 3}}, color = {0, 0, 127}));
      connect(product3.y, product6.u2) annotation(
        Line(points = {{59, -14.5}, {59, -14.25}, {60, -14.25}, {60, -14}, {66, -14}}, color = {0, 0, 127}));
      connect(switch2.y, product6.u1) annotation(
        Line(points = {{-53, 47}, {-22, 47}, {-22, -6}, {66, -6}, {66, -7}}, color = {0, 0, 127}));
      connect(feedback3.y, product.u2) annotation(
        Line(points = {{59, -74}, {98, -74}}, color = {0, 0, 127}));
      connect(SOC_hi_vol_per, greaterEqual.u1) annotation(
        Line(points = {{-168, -29}, {-136, -29}}, color = {0, 0, 127}));
      connect(SOC_regen_decrease_limit.y, greaterEqual.u2) annotation(
        Line(points = {{-157, -46.5}, {-146, -46.5}, {-146, -34}, {-136, -34}}, color = {0, 0, 127}));
      connect(greaterEqual.y, switch12.u2) annotation(
        Line(points = {{-122, -29}, {6, -29}, {6, -24.5}}, color = {255, 0, 255}));
      connect(switch12.y, product3.u2) annotation(
        Line(points = {{21, -24.5}, {44, -24.5}, {44, -18}}, color = {0, 0, 127}));
      connect(const1.y, switch12.u3) annotation(
        Line(points = {{-75, -17.5}, {-10, -17.5}, {-10, -19}, {6, -19}}, color = {0, 0, 127}));
      connect(SOC_regen_decrease_limit.y, feedback.u1) annotation(
        Line(points = {{-157, -46.5}, {-135, -46.5}}, color = {0, 0, 127}));
      connect(SOC_full.y, feedback.u2) annotation(
        Line(points = {{-157, -69.5}, {-146, -69.5}, {-146, -58}, {-129, -58}, {-129, -52}, {-129.5, -52}}, color = {0, 0, 127}));
      connect(switch13.y, switch12.u1) annotation(
        Line(points = {{0, -40.5}, {0, -35.25}, {1, -35.25}, {1, -30}, {6, -30}}, color = {0, 0, 127}));
      connect(const2.y, switch13.u1) annotation(
        Line(points = {{-75, -81.5}, {-19, -81.5}, {-19, -46}, {-15, -46}}, color = {0, 0, 127}));
      connect(feedback.y, division.u2) annotation(
        Line(points = {{-124, -46.5}, {-108, -46.5}, {-108, -43.75}, {-107, -43.75}, {-107, -47}}, color = {0, 0, 127}));
      connect(division.y, switch13.u3) annotation(
        Line(points = {{-92, -50.5}, {30, -50.5}, {30, -36}, {-15, -36}, {-15, -35}}, color = {0, 0, 127}));
      connect(SOC_full.y, feedback2.u2) annotation(
        Line(points = {{-157, -69.5}, {-146, -69.5}, {-146, -81}, {-129, -81}, {-129, -76}}, color = {0, 0, 127}));
      connect(SOC_hi_vol_per, feedback2.u1) annotation(
        Line(points = {{-168, -29}, {-144, -29}, {-144, -41}, {-135, -41}, {-135, -70}}, color = {0, 0, 127}));
      connect(feedback2.y, division.u1) annotation(
        Line(points = {{-123, -70}, {-116, -70}, {-116, -54}, {-107, -54}}, color = {0, 0, 127}));
      connect(feedback2.y, greaterThreshold2.u) annotation(
        Line(points = {{-123, -70}, {-107, -70}}, color = {0, 0, 127}));
      connect(greaterThreshold2.y, switch13.u2) annotation(
        Line(points = {{-93, -70}, {-25, -70}, {-25, -41}, {-15, -41}, {-15, -40.5}}, color = {255, 0, 255}));
      connect(v_vehicle_kmph, abs1.u) annotation(
        Line(points = {{-199, 60}, {-160, 60}}, color = {0, 0, 127}));
      connect(feedback_4.y, division_1.u1) annotation(
        Line(points = {{-117, 20}, {-114, 20}, {-114, 37}, {-109, 37}, {-109, 36}}, color = {0, 0, 127}));
      connect(product6.y, feedback3.u2) annotation(
        Line(points = {{81, -10}, {90, -10}, {90, -40}, {54, -40}, {54, -69}}, color = {0, 0, 127}));
      connect(tau_vcu_eng_req_input, switch14.u3) annotation(
        Line(points = {{100, 112}, {148, 112}, {148, 112}, {148, 112}}, color = {0, 0, 127}));
      connect(flag_vcu_k0_open_req_input, switch15.u3) annotation(
        Line(points = {{100, 82}, {145, 82}, {145, 82}, {147, 82}}, color = {0, 0, 127}));
      connect(w_vcu_eng_speed_req_input, switch16.u3) annotation(
        Line(points = {{100, 52}, {147, 52}, {147, 52}, {147, 52}}, color = {0, 0, 127}));
      connect(switch14.y, tau_vcu_eng_req) annotation(
        Line(points = {{171, 120}, {198, 120}, {198, 120}, {202, 120}}, color = {0, 0, 127}));
      connect(switch15.y, flag_vcu_k0_open_req) annotation(
        Line(points = {{170, 90}, {197, 90}, {197, 90}, {202, 90}}, color = {0, 0, 127}));
      connect(switch16.y, w_vcu_eng_speed_req) annotation(
        Line(points = {{170, 60}, {201, 60}}, color = {0, 0, 127}));
      connect(switch17.y, tau_vcu_p2m_regenerative_torque_Nm) annotation(
        Line(points = {{170, -10}, {195, -10}, {195, -10}, {200, -10}}, color = {0, 0, 127}));
      connect(switch18.y, tau_vcu_brake_torque_Nm) annotation(
        Line(points = {{171, -70}, {193, -70}, {193, -69}, {201, -69}}, color = {0, 0, 127}));
      connect(vehicle_situation_input, integerToReal.u) annotation(
        Line(points = {{4, 150}, {33, 150}, {33, 150}, {34, 150}}, color = {255, 127, 0}));
      connect(integerToReal.y, lessEqualThreshold.u) annotation(
        Line(points = {{57, 150}, {70, 150}, {70, 150}, {71, 150}}, color = {0, 0, 127}));
      connect(lessEqualThreshold.y, switch14.u2) annotation(
        Line(points = {{94, 150}, {140, 150}, {140, 120}, {148, 120}, {148, 120}}, color = {255, 0, 255}));
      connect(lessEqualThreshold.y, switch15.u2) annotation(
        Line(points = {{94, 150}, {140, 150}, {140, 90}, {147, 90}, {147, 90}}, color = {255, 0, 255}));
      connect(lessEqualThreshold.y, switch16.u2) annotation(
        Line(points = {{94, 150}, {140, 150}, {140, 60}, {147, 60}, {147, 60}}, color = {255, 0, 255}));
      connect(lessEqualThreshold.y, switch17.u2) annotation(
        Line(points = {{94, 150}, {140, 150}, {140, -10}, {147, -10}, {147, -10}}, color = {255, 0, 255}));
      connect(lessEqualThreshold.y, switch18.u2) annotation(
        Line(points = {{94, 150}, {140, 150}, {140, -70}, {148, -70}, {148, -70}}, color = {255, 0, 255}));
      connect(tau_vcu_p2m_req_input, switch17.u3) annotation(
        Line(points = {{120, -40}, {135, -40}, {135, -18}, {147, -18}, {147, -18}}, color = {0, 0, 127}));
      connect(tau_vcu_brake_target_input, switch18.u3) annotation(
        Line(points = {{120, -100}, {135, -100}, {135, -78}, {148, -78}, {148, -78}}, color = {0, 0, 127}));
      connect(product6.y, switch17.u1) annotation(
        Line(points = {{81, -10}, {90, -10}, {90, -1}, {147, -1}, {147, -2}}, color = {0, 0, 127}));
      connect(product.y, switch18.u1) annotation(
        Line(points = {{113, -70}, {135, -70}, {135, -61}, {148, -61}, {148, -62}}, color = {0, 0, 127}));
      connect(const3.y, switch16.u1) annotation(
        Line(points = {{75, 68}, {147, 68}}, color = {0, 0, 127}));
      connect(const4.y, switch14.u1) annotation(
        Line(points = {{74, 127}, {145, 127}, {145, 129}, {148, 129}, {148, 128}}, color = {0, 0, 127}));
      connect(const5.y, switch15.u1) annotation(
        Line(points = {{75, 98}, {146, 98}, {146, 98}, {147, 98}}, color = {0, 0, 127}));
      annotation(
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}})),
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-200, 150}, {200, -150}}), Text(origin = {-5, 38.5}, extent = {{-177, 40.5}, {177, -40.5}}, textString = "Braking")}));
    end Braking;

    model Stop_and_Static_charge
      final constant Real pi = 2 * Modelica.Math.asin(1.0);
      // 3.14159265358979;
      parameter Real SOC_hi_vol_batt_Upper = 20;
      parameter Real static_power_generate_torque = 100;
      parameter Real static_power_generate_rev = 1407;
      Modelica.Blocks.Interfaces.RealInput vehicle_speed annotation(
        Placement(visible = true, transformation(origin = {-210, -30}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {40.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput drive_mode annotation(
        Placement(visible = true, transformation(origin = {-211, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-79.5, -148.5}, extent = {{10.5, -10.5}, {-10.5, 10.5}}, rotation = -90)));
      Modelica.Blocks.Interfaces.RealInput SOC_hi_vol_batt_per annotation(
        Placement(visible = true, transformation(origin = {-211, 20}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-40.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Logical.LessEqualThreshold soc_Upper(threshold = SOC_hi_vol_batt_Upper) annotation(
        Placement(visible = true, transformation(origin = {-64, 20}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant power_generate_trq(k = static_power_generate_torque) annotation(
        Placement(visible = true, transformation(origin = {14.5, 4.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold1(threshold = 1) annotation(
        Placement(visible = true, transformation(origin = {-21, -30}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant power_generate_rev(k = static_power_generate_rev) annotation(
        Placement(visible = true, transformation(origin = {14.5, -15.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Gain rpm2radps(k = pi / 30) annotation(
        Placement(visible = true, transformation(origin = {34.5, -15.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
      Modelica.Blocks.Math.Abs abs1 annotation(
        Placement(visible = true, transformation(origin = {-42, -30}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold = 0.5) annotation(
        Placement(visible = true, transformation(origin = {-63.5, 59.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.And and11 annotation(
        Placement(visible = true, transformation(origin = {36, -53}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const(k = 0) annotation(
        Placement(visible = true, transformation(origin = {14.5, -35.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {63.5, -30.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {63.5, -0.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_gearbox_input_target annotation(
        Placement(visible = true, transformation(origin = {-209, -70}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-119.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput w_P2M_PNT_rpm annotation(
        Placement(visible = true, transformation(origin = {-140, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {0.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput Accel_position_opening annotation(
        Placement(visible = true, transformation(origin = {-90, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {80.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Interfaces.RealInput torque_gin_drive_train annotation(
        Placement(visible = true, transformation(origin = {-191, -140}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {120.5, -148.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 90)));
      Modelica.Blocks.Interfaces.IntegerInput vehicle_situation_input annotation(
        Placement(visible = true, transformation(origin = {2, 149}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {0, 149}, extent = {{-20, -20}, {20, 20}}, rotation = -90)));
      Modelica.Blocks.Interfaces.RealInput tau_vcu_brake_req_input annotation(
        Placement(visible = true, transformation(origin = {127.5, -8.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-198, -1.77636e-15}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_vcu_p2m_req_input annotation(
        Placement(visible = true, transformation(origin = {128.5, 51.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0), iconTransformation(origin = {-199, 61}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_vcu_eng_req_input annotation(
        Placement(visible = true, transformation(origin = {128, 112}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-198, 121}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput flag_vcu_k0_open_req_input annotation(
        Placement(visible = true, transformation(origin = {128, -68}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-199, -60}, extent = {{-11, -11}, {11, 11}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput w_vcu_eng_speed_req_input annotation(
        Placement(visible = true, transformation(origin = {128, -129}, extent = {{-11, -11}, {11, 11}}, rotation = 0), iconTransformation(origin = {-198.5, -119.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_brake_target annotation(
        Placement(visible = true, transformation(origin = {201, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {201, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_p2m_req annotation(
        Placement(visible = true, transformation(origin = {200, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {200, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput tau_vcu_eng_req annotation(
        Placement(visible = true, transformation(origin = {201, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {201, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput flag_vcu_k0_open_req annotation(
        Placement(visible = true, transformation(origin = {201, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {201, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput w_vcu_eng_speed_req annotation(
        Placement(visible = true, transformation(origin = {200, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {200, -120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch12 annotation(
        Placement(visible = true, transformation(origin = {169, 120}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch13 annotation(
        Placement(visible = true, transformation(origin = {170, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch14 annotation(
        Placement(visible = true, transformation(origin = {169, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch15 annotation(
        Placement(visible = true, transformation(origin = {171, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch16 annotation(
        Placement(visible = true, transformation(origin = {170, -121}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.IntegerToReal integerToReal annotation(
        Placement(visible = true, transformation(origin = {44, 149}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterEqualThreshold greaterEqualThreshold(threshold = 1.5) annotation(
        Placement(visible = true, transformation(origin = {80, 149}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const1(k = 0) annotation(
        Placement(visible = true, transformation(origin = {14.5, -68.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.And and1 annotation(
        Placement(visible = true, transformation(origin = {-32.5, 25.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch17 annotation(
        Placement(visible = true, transformation(origin = {63.5, -79.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const2(k = 1) annotation(
        Placement(visible = true, transformation(origin = {14.5, -91.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant const3(k = -1000) annotation(
        Placement(visible = true, transformation(origin = {14, 25}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch18 annotation(
        Placement(visible = true, transformation(origin = {63.5, 30.5}, extent = {{-6.5, -6.5}, {6.5, 6.5}}, rotation = 0)));
      Modelica.Blocks.Math.Gain gain(k = -1) annotation(
        Placement(visible = true, transformation(origin = {41.5, 4.5}, extent = {{-5.5, -5.5}, {5.5, 5.5}}, rotation = 0)));
    equation
      connect(SOC_hi_vol_batt_per, soc_Upper.u) annotation(
        Line(points = {{-211, 20}, {-71, 20}}, color = {0, 0, 127}));
      connect(abs1.y, lessEqualThreshold1.u) annotation(
        Line(points = {{-34, -30}, {-28, -30}}, color = {0, 0, 127}));
      connect(lessEqualThreshold1.y, and11.u2) annotation(
        Line(points = {{-14, -30}, {-2, -30}, {-2, -58}, {29, -58}}, color = {255, 0, 255}));
      connect(and11.y, switch11.u2) annotation(
        Line(points = {{43, -53}, {43, 0}, {56, 0}}, color = {255, 0, 255}));
      connect(and11.y, switch1.u2) annotation(
        Line(points = {{43, -53}, {43, -31}, {56, -31}, {56, -30}}, color = {255, 0, 255}));
      connect(power_generate_rev.y, rpm2radps.u) annotation(
        Line(points = {{22, -15.5}, {28, -15.5}}, color = {0, 0, 127}));
      connect(const.y, switch1.u3) annotation(
        Line(points = {{22, -35}, {55, -35}, {55, -36}, {56, -36}}, color = {0, 0, 127}));
      connect(rpm2radps.y, switch1.u1) annotation(
        Line(points = {{41, -15}, {45, -15}, {45, -26}, {56, -26}, {56, -25}}, color = {0, 0, 127}));
      connect(flag_vcu_k0_open_req_input, switch15.u3) annotation(
        Line(points = {{128, -68}, {157, -68}, {157, -68}, {159, -68}}, color = {0, 0, 127}));
      connect(tau_vcu_brake_req_input, switch14.u3) annotation(
        Line(points = {{128, -8}, {156, -8}, {156, -8}, {157, -8}}, color = {0, 0, 127}));
      connect(tau_vcu_p2m_req_input, switch13.u3) annotation(
        Line(points = {{129, 52}, {157, 52}, {157, 52}, {158, 52}}, color = {0, 0, 127}));
      connect(tau_vcu_eng_req_input, switch12.u3) annotation(
        Line(points = {{128, 112}, {156, 112}, {156, 112}, {157, 112}}, color = {0, 0, 127}));
      connect(w_vcu_eng_speed_req_input, switch16.u3) annotation(
        Line(points = {{128, -129}, {157, -129}, {157, -129}, {158, -129}}, color = {0, 0, 127}));
      connect(switch16.y, w_vcu_eng_speed_req) annotation(
        Line(points = {{181, -121}, {192, -121}, {192, -120}, {200, -120}}, color = {0, 0, 127}));
      connect(switch15.y, flag_vcu_k0_open_req) annotation(
        Line(points = {{182, -60}, {193, -60}, {193, -60}, {201, -60}}, color = {0, 0, 127}));
      connect(switch14.y, tau_vcu_brake_target) annotation(
        Line(points = {{180, 0}, {196, 0}, {196, 0}, {201, 0}}, color = {0, 0, 127}));
      connect(switch13.y, tau_vcu_p2m_req) annotation(
        Line(points = {{181, 60}, {191, 60}, {191, 60}, {200, 60}}, color = {0, 0, 127}));
      connect(switch12.y, tau_vcu_eng_req) annotation(
        Line(points = {{180, 120}, {191, 120}, {191, 120}, {201, 120}}, color = {0, 0, 127}));
      connect(switch1.y, switch16.u1) annotation(
        Line(points = {{71, -30}, {100, -30}, {100, -113}, {158, -113}, {158, -113}}, color = {0, 0, 127}));
      connect(vehicle_situation_input, integerToReal.u) annotation(
        Line(points = {{2, 149}, {31, 149}, {31, 149}, {32, 149}}, color = {255, 127, 0}));
      connect(integerToReal.y, greaterEqualThreshold.u) annotation(
        Line(points = {{55, 149}, {67, 149}, {67, 149}, {68, 149}}, color = {0, 0, 127}));
      connect(greaterEqualThreshold.y, switch16.u2) annotation(
        Line(points = {{91, 149}, {146, 149}, {146, -121}, {158, -121}, {158, -121}}, color = {255, 0, 255}));
      connect(greaterEqualThreshold.y, switch15.u2) annotation(
        Line(points = {{91, 149}, {146, 149}, {146, -60}, {159, -60}, {159, -60}}, color = {255, 0, 255}));
      connect(greaterEqualThreshold.y, switch14.u2) annotation(
        Line(points = {{91, 149}, {146, 149}, {146, 0}, {157, 0}, {157, 0}}, color = {255, 0, 255}));
      connect(greaterEqualThreshold.y, switch13.u2) annotation(
        Line(points = {{91, 149}, {146, 149}, {146, 60}, {158, 60}, {158, 60}}, color = {255, 0, 255}));
      connect(greaterEqualThreshold.y, switch12.u2) annotation(
        Line(points = {{91, 149}, {146, 149}, {146, 120}, {157, 120}, {157, 120}}, color = {255, 0, 255}));
      connect(drive_mode, greaterThreshold.u) annotation(
        Line(points = {{-211, 60}, {-73, 60}, {-73, 60}, {-71, 60}}, color = {0, 0, 127}));
      connect(vehicle_speed, abs1.u) annotation(
        Line(points = {{-210, -30}, {-51, -30}, {-51, -30}, {-50, -30}}, color = {0, 0, 127}));
      connect(tau_gearbox_input_target, switch14.u1) annotation(
        Line(points = {{-209, -70}, {-80, -70}, {-80, -100}, {141, -100}, {141, 8}, {157, 8}, {157, 8}}, color = {0, 0, 127}));
      connect(soc_Upper.y, and1.u2) annotation(
        Line(points = {{-57, 20}, {-42, 20}, {-42, 20}, {-40, 20}}, color = {255, 0, 255}));
      connect(greaterThreshold.y, and1.u1) annotation(
        Line(points = {{-56, 60}, {-50, 60}, {-50, 25}, {-40, 25}, {-40, 26}}, color = {255, 0, 255}));
      connect(and1.y, and11.u1) annotation(
        Line(points = {{-25, 26}, {3, 26}, {3, -53}, {29, -53}}, color = {255, 0, 255}));
      connect(and11.y, switch17.u2) annotation(
        Line(points = {{43, -53}, {43, -80}, {56, -80}, {56, -79}}, color = {255, 0, 255}));
      connect(const2.y, switch17.u3) annotation(
        Line(points = {{22, -91}, {50, -91}, {50, -85}, {56, -85}, {56, -85}}, color = {0, 0, 127}));
      connect(const1.y, switch17.u1) annotation(
        Line(points = {{22, -68}, {50, -68}, {50, -76}, {56, -76}, {56, -74}}, color = {0, 0, 127}));
      connect(switch17.y, switch15.u1) annotation(
        Line(points = {{71, -79}, {91, -79}, {91, -52}, {159, -52}, {159, -52}}, color = {0, 0, 127}));
      connect(const3.y, switch18.u3) annotation(
        Line(points = {{22, 25}, {55, 25}, {55, 25}, {56, 25}}, color = {0, 0, 127}));
      connect(and11.y, switch18.u2) annotation(
        Line(points = {{43, -53}, {43, -53}, {43, 30}, {56, 30}, {56, 31}}, color = {255, 0, 255}));
      connect(gain.y, switch11.u1) annotation(
        Line(points = {{48, 5}, {56, 5}, {56, 5}, {56, 5}}, color = {0, 0, 127}));
      connect(power_generate_trq.y, gain.u) annotation(
        Line(points = {{22, 5}, {34, 5}, {34, 5}, {35, 5}}, color = {0, 0, 127}));
      connect(const.y, switch11.u3) annotation(
        Line(points = {{22, -35}, {50, -35}, {50, -6}, {56, -6}, {56, -6}}, color = {0, 0, 127}));
      connect(power_generate_trq.y, switch18.u1) annotation(
        Line(points = {{22, 5}, {29, 5}, {29, 36}, {56, 36}, {56, 36}}, color = {0, 0, 127}));
      connect(switch18.y, switch12.u1) annotation(
        Line(points = {{71, 31}, {100, 31}, {100, 128}, {157, 128}, {157, 128}}, color = {0, 0, 127}));
      connect(switch11.y, switch13.u1) annotation(
        Line(points = {{71, 0}, {116, 0}, {116, 68}, {158, 68}, {158, 68}}, color = {0, 0, 127}));
    protected
      annotation(
        Diagram(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}})),
        Icon(coordinateSystem(grid = {1, 1}, extent = {{-200, -150}, {200, 150}}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-199, 150}, {199, -150}}), Text(origin = {-19, 37.5}, extent = {{-52, 34.5}, {74, -30.5}}, textString = "Stop"), Text(origin = {-2.5, -16}, extent = {{-154.5, 24}, {174.5, -75}}, textString = "Static charge")}));
    end Stop_and_Static_charge;

    model Vehicle_situation
      Modelica.Blocks.Interfaces.IntegerOutput vehicle_situation_output annotation(
        Placement(visible = true, transformation(origin = {107, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput tau_gearbox_input_torque annotation(
        Placement(visible = true, transformation(origin = {-110, -40}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-98.5, -0.5}, extent = {{-10.5, -10.5}, {10.5, 10.5}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold greaterThreshold annotation(
        Placement(visible = true, transformation(origin = {-60, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Braking_signal(k = 0) annotation(
        Placement(visible = true, transformation(origin = {-60, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Accelaretion_signal(k = 1) annotation(
        Placement(visible = true, transformation(origin = {-60, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant Stop_and_static_charge_signal(k = 2) annotation(
        Placement(visible = true, transformation(origin = {19, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Math.RealToInteger realToInteger annotation(
        Placement(visible = true, transformation(origin = {78, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch1 annotation(
        Placement(visible = true, transformation(origin = {48, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch11 annotation(
        Placement(visible = true, transformation(origin = {-10, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.LessEqualThreshold lessEqualThreshold1(threshold = -1995) annotation(
        Placement(visible = true, transformation(origin = {-69, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(tau_gearbox_input_torque, greaterThreshold.u) annotation(
        Line(points = {{-110, -40}, {-72, -40}}, color = {0, 0, 127}));
      connect(realToInteger.y, vehicle_situation_output) annotation(
        Line(points = {{89, 30}, {107, 30}}, color = {255, 127, 0}));
      connect(realToInteger.u, switch1.y) annotation(
        Line(points = {{66, 30}, {59, 30}}, color = {0, 0, 127}));
      connect(switch11.y, switch1.u3) annotation(
        Line(points = {{1, -40}, {10, -40}, {10, 22}, {36, 22}}, color = {0, 0, 127}));
      connect(Stop_and_static_charge_signal.y, switch1.u1) annotation(
        Line(points = {{30, 80}, {30, 38}, {36, 38}}, color = {0, 0, 127}));
      connect(tau_gearbox_input_torque, lessEqualThreshold1.u) annotation(
        Line(points = {{-110, -40}, {-87, -40}, {-87, 31}, {-83, 31}, {-83, 30}, {-81, 30}}, color = {0, 0, 127}));
      connect(greaterThreshold.y, switch11.u2) annotation(
        Line(points = {{-49, -40}, {-24, -40}, {-24, -40}, {-22, -40}}, color = {255, 0, 255}));
      connect(Braking_signal.y, switch11.u3) annotation(
        Line(points = {{-49, -70}, {-35, -70}, {-35, -48}, {-22, -48}, {-22, -48}}, color = {0, 0, 127}));
      connect(Accelaretion_signal.y, switch11.u1) annotation(
        Line(points = {{-49, -10}, {-35, -10}, {-35, -32}, {-22, -32}, {-22, -32}}, color = {0, 0, 127}));
      connect(lessEqualThreshold1.y, switch1.u2) annotation(
        Line(points = {{-58, 30}, {35, 30}, {35, 30}, {36, 30}}, color = {255, 0, 255}));
      annotation(
        Diagram(coordinateSystem(grid = {1, 1})),
        Icon(coordinateSystem(grid = {1, 1}, initialScale = 0.1), graphics = {Rectangle(fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, 100}, {100, -100}}), Text(origin = {1, 46}, extent = {{-85, 37}, {85, -37}}, textString = "Braking→0"), Text(origin = {2.5, 1}, extent = {{-83.5, 35}, {83.5, -35}}, textString = "Acceleration→1"), Text(origin = {-1, -46.5}, extent = {{-82, 16.5}, {82, -16.5}}, textString = "Stop/StaticCharge→2")}));
    end Vehicle_situation;
    annotation(
      uses(Modelica(version = "3.2.3")));
  end Vehicle_control_Unit;

  model HEV_VehicleSystemModel
    constant String currDir = Modelica.Utilities.Files.loadResource("modelica://TRAMI_L3_HEV");
    parameter Real Oil_Viscosity_Breakpoint[:] = {6.7e-6, 8.2e-6, 11.2e-6, 16.9e-6, 31.2e-6, 65.9e-6};
    parameter Real P_synchoro_dif[:] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
    Modelica.Blocks.Interfaces.RealOutput y annotation(
      Placement(visible = true, transformation(origin = {336, -104}, extent = {{-6, -6}, {6, 6}}, rotation = 0), iconTransformation(origin = {336, -104}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    TRAMI_L3_HEV.Vehicle.Driver DRIVER(Accelerator_FileName = "Accelerator_open_per_MAP.txt", Accelerator_tabName = "Accelerator_open_per_MAP", Coef_A = vehicle.Coef_A, Coef_B = vehicle.Coef_B, Coef_C = vehicle.Coef_C, Final_GearRatio = 2.8, Jfw = 0.4, Mv = vehicle.Mv, Rt = vehicle.Rt) annotation(
      Placement(visible = true, transformation(origin = {-194, 20.0824}, extent = {{-14, -26.2275}, {14, 20.175}}, rotation = 0)));
    TRAMI_L3_HEV.Vehicle.ECU ECU(Target_Idle_Speed = 650) annotation(
      Placement(visible = true, transformation(origin = {-132, -104.72}, extent = {{-10, -27.2152}, {10, 19.9578}}, rotation = 0)));
    TRAMI_L3_HEV.Vehicle.ENGINE ENGINE annotation(
      Placement(visible = true, transformation(origin = {-50, -122}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
    TRAMI_L3_HEV.Vehicle.VEHICLE vehicle annotation(
      Placement(visible = true, transformation(origin = {276, -119.726}, extent = {{-19, -7.75636}, {19, 19.3909}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant dummy_Batt_V(k = 12) annotation(
      Placement(visible = true, transformation(origin = {150, -130}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput y2 annotation(
      Placement(visible = true, transformation(origin = {336, -119}, extent = {{-6, -6}, {6, 6}}, rotation = 0), iconTransformation(origin = {336, -119}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const5(k = 0) annotation(
      Placement(visible = true, transformation(origin = {-155, 70}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain(k = 3.6) annotation(
      Placement(visible = true, transformation(origin = {334, -86}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput A_Vkmh annotation(
      Placement(visible = true, transformation(origin = {350, -86}, extent = {{-6, -6}, {6, 6}}, rotation = 0), iconTransformation(origin = {350, -86}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot1 annotation(
      Placement(visible = true, transformation(origin = {-132, -46}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot9 annotation(
      Placement(visible = true, transformation(origin = {318, -104}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot13 annotation(
      Placement(visible = true, transformation(origin = {318, -86}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    discrete TRAMI_L3_HEV.Control.TM_CNT TM_CNT(samplePeriod = 0.01) annotation(
      Placement(visible = true, transformation(origin = {60, 52}, extent = {{-10, -60}, {10, 60}}, rotation = 0)));
    Modelica.Blocks.Sources.Step step(height = -1, offset = 1, startTime = 0.001) annotation(
      Placement(visible = true, transformation(origin = {-34, 110}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const6(k = 100) annotation(
      Placement(visible = true, transformation(origin = {-108, 80}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const4(k = 0) annotation(
      Placement(visible = true, transformation(origin = {-87, -110}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain1(k = 1 / 2000) annotation(
      Placement(visible = true, transformation(origin = {-24, 62}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot17 annotation(
      Placement(visible = true, transformation(origin = {20, 140}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot10 annotation(
      Placement(visible = true, transformation(origin = {24, -94}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant constant1(k = 0) annotation(
      Placement(visible = true, transformation(origin = {60, -176}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput A_Vtgt annotation(
      Placement(visible = true, transformation(origin = {-220, 158}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-220, 158}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    TRAMI_L3_HEV.HEVElectricElements.HEVElectricSystem hEVElectricSystem annotation(
      Placement(visible = true, transformation(origin = {118, -182}, extent = {{-20, -15}, {20, 15}}, rotation = 0)));
    TRAMI_L3_HEV.TransMission.Mechanics.TransMission transMission(Oil_Viscosity_Breakpoint = {8.5e-6, 10.6e-6, 17.8e-6, 34.0e-6, 78.1e-6}) annotation(
      Placement(visible = true, transformation(origin = {200, -102}, extent = {{-10, -30}, {10, 28}}, rotation = 0)));
    Modelica.Blocks.Routing.Multiplex2 multiplex2(n1 = 10, n2 = 1) annotation(
      Placement(visible = true, transformation(origin = {4, 92}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Routing.DeMultiplex2 deMultiplex2(n1 = 2, n2 = 10) annotation(
      Placement(visible = true, transformation(origin = {108, 102}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Routing.DeMultiplex2 deMultiplex21(n1 = 8, n2 = 3) annotation(
      Placement(visible = true, transformation(origin = {148, 92}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const(k = 0) annotation(
      Placement(visible = true, transformation(origin = {-34, 88}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot6 annotation(
      Placement(visible = true, transformation(origin = {0, -114}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.Vehicle_control_Unit.VEHICLE_CNT VCU(start_SOC = hEVElectricSystem.highBattery1.SOC0) annotation(
      Placement(visible = true, transformation(origin = {-100, 18}, extent = {{-22, -26}, {22, 26}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot2 annotation(
      Placement(visible = true, transformation(origin = {-42, 10}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot4 annotation(
      Placement(visible = true, transformation(origin = {-54, 34}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot12 annotation(
      Placement(visible = true, transformation(origin = {-162, 14}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot3 annotation(
      Placement(visible = true, transformation(origin = {-46, 18}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.Enviroment.Enviroment enviroment annotation(
      Placement(visible = true, transformation(origin = {-313, 1}, extent = {{-22, -35}, {22, 35}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const9(k = 0) annotation(
      Placement(visible = true, transformation(origin = {33, 20}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const10(k = 90) annotation(
      Placement(visible = true, transformation(origin = {-8, 74}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot8 annotation(
      Placement(visible = true, transformation(origin = {-144, 140}, extent = {{-4, 4}, {4, -4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot annotation(
      Placement(visible = true, transformation(origin = {-42, -30}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    ETC.Dot dot11 annotation(
      Placement(visible = true, transformation(origin = {0, -144}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    ETC.Dot dot15 annotation(
      Placement(visible = true, transformation(origin = {-164, -144}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    ETC.Dot dot16 annotation(
      Placement(visible = true, transformation(origin = {36, 118}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot18 annotation(
      Placement(visible = true, transformation(origin = {160, -170}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    ETC.Dot dot19 annotation(
      Placement(visible = true, transformation(origin = {42, 20}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    Modelica.Blocks.Sources.BooleanConstant booleanConstant(k = false) annotation(
      Placement(visible = true, transformation(origin = {255, -179}, extent = {{-7, -7}, {7, 7}}, rotation = 0)));
    Modelica.Blocks.Math.Add add annotation(
      Placement(visible = true, transformation(origin = {190, -264}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    Modelica.Blocks.Tables.CombiTable1D combiTable1D(fileName = currDir + "/param/pnt/K2OilViscosity.txt", tableName = "tab1", tableOnFile = true) annotation(
      Placement(visible = true, transformation(origin = {151, -87}, extent = {{-5, -5}, {5, 5}}, rotation = 0)));
    Modelica.Blocks.Math.UnitConversions.From_degC from_degC annotation(
      Placement(visible = true, transformation(origin = {-64, -216}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Math.UnitConversions.To_rpm to_rpm annotation(
      Placement(visible = true, transformation(origin = {192, -204}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    TRAMI_L3_HEV.ETC.Dot dot22 annotation(
      Placement(visible = true, transformation(origin = {-158, 20}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    ETC.Dot dot5 annotation(
      Placement(visible = true, transformation(origin = {-262, 38}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    ETC.Dot dot7 annotation(
      Placement(visible = true, transformation(origin = {134, -106}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    TRAMI_L3_HEV.Thermal.thermal_circuits.thermal_common thermal_common annotation(
      Placement(visible = true, transformation(origin = {307, -222}, extent = {{-25, -90}, {25, 50}}, rotation = 0)));
    Modelica.Blocks.Math.UnitConversions.From_degC from_degC1 annotation(
      Placement(visible = true, transformation(origin = {40, -304}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Math.UnitConversions.From_degC from_degC2 annotation(
      Placement(visible = true, transformation(origin = {22, -314}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
    Modelica.Blocks.Math.UnitConversions.From_degC from_degC3 annotation(
      Placement(visible = true, transformation(origin = {4, -326}, extent = {{-6, -6}, {6, 6}}, rotation = 0)));
  equation
    connect(vehicle.out_vehicle_G_g, y2) annotation(
      Line(points = {{296, -119}, {336, -119}}, color = {0, 0, 127}));
    connect(vehicle.v_vehicle_mps, DRIVER.v_vehicle_mps) annotation(
      Line(points = {{296, -104}, {318, -104}, {318, 140}, {-236, 140}, {-236, 20}, {-210, 20}}, color = {0, 0, 127}));
    connect(vehicle.v_vehicle_mps, y) annotation(
      Line(points = {{296, -104}, {336, -104}}, color = {0, 0, 127}));
    connect(vehicle.v_vehicle_mps, gain.u) annotation(
      Line(points = {{296, -104}, {318, -104}, {318, -86}, {327, -86}}, color = {0, 0, 127}));
    connect(gain.y, A_Vkmh) annotation(
      Line(points = {{341, -86}, {350, -86}}, color = {0, 0, 127}));
    connect(step.y, TM_CNT.flag_initialize) annotation(
      Line(points = {{-27, 110}, {48, 110}}, color = {0, 0, 127}));
    connect(const6.y, TM_CNT.t_trans_fluid_k) annotation(
      Line(points = {{-101, 80}, {48, 80}}, color = {0, 0, 127}));
    connect(gain1.y, TM_CNT.tau_brake) annotation(
      Line(points = {{-17, 62}, {48, 62}}, color = {0, 0, 127}));
    connect(DRIVER.accel_position_per, TM_CNT.accel_position_per) annotation(
      Line(points = {{-178, 20}, {-158, 20}, {-158, 56}, {48, 56}}, color = {0, 0, 127}));
    connect(vehicle.v_vehicle_mps, TM_CNT.v_vehicle_mps) annotation(
      Line(points = {{296, -104}, {318, -104}, {318, 140}, {20, 140}, {20, 68}, {48, 68}}, color = {0, 0, 127}));
    connect(TM_CNT.trans_torq_gain, DRIVER.torque_gain_drivetrain) annotation(
      Line(points = {{72, 32}, {118, 32}, {118, -46}, {-230, -46}, {-230, 26}, {-210, 26}}, color = {0, 0, 127}));
    connect(ECU.tau_eng_target, ENGINE.tau_eng_target) annotation(
      Line(points = {{-121, -104}, {-102, -104}, {-102, -128}, {-63, -128}}, color = {0, 0, 127}));
    connect(ENGINE.tau_engine, TM_CNT.tau_engine) annotation(
      Line(points = {{-37, -122}, {24, -122}, {24, 26}, {48, 26}}, color = {0, 0, 127}));
    connect(ECU.w_engine_idle_radps, TM_CNT.w_engine_idle_radps) annotation(
      Line(points = {{-121, -97}, {8, -97}, {8, 38}, {48, 38}}, color = {0, 0, 127}));
    connect(TM_CNT.tau_engine_min_req, ECU.tau_engine_min_req) annotation(
      Line(points = {{72, 14}, {100, 14}, {100, -70}, {-166, -70}, {-166, -92}, {-144, -92}}, color = {0, 0, 127}));
    connect(TM_CNT.w_engine_target_radps, ECU.w_engine_target_radps) annotation(
      Line(points = {{72, 8}, {94, 8}, {94, -54}, {-184, -54}, {-184, -108}, {-144, -108}}, color = {0, 0, 127}));
    connect(TM_CNT.flag_shift, DRIVER.flag_shift) annotation(
      Line(points = {{72, 26}, {112, 26}, {112, -42}, {-222, -42}, {-222, 8}, {-210, 8}}, color = {0, 0, 127}));
    connect(TM_CNT.tau_trans_input, ECU.tau_trans_input) annotation(
      Line(points = {{72, 2}, {84, 2}, {84, -38}, {-192, -38}, {-192, -130}, {-144, -130}}, color = {0, 0, 127}));
    connect(transMission.tau_DS_PNT_out_Nm, vehicle.tau_DS_PNT_out_Nm) annotation(
      Line(points = {{211, -100}, {256, -100}}, color = {0, 0, 127}));
    connect(TM_CNT.tau_k0_clutch_cap, transMission.Tc_K0) annotation(
      Line(points = {{72, 86}, {198, 86}, {198, -72}, {198, -72}}, color = {0, 0, 127}));
    connect(TM_CNT.tau_p2m_target, transMission.Tm_tgt) annotation(
      Line(points = {{72, 80}, {204, 80}, {204, -72}, {204, -72}}, color = {0, 0, 127}));
    connect(constant1.y, hEVElectricSystem.HiBatCur) annotation(
      Line(points = {{64, -176}, {76, -176}, {76, -184}, {96, -184}}, color = {0, 0, 127}));
    connect(transMission.w_gearbox_input_radps, TM_CNT.w_gearbox_input_radps) annotation(
      Line(points = {{212, -76}, {218, -76}, {218, 118}, {36, 118}, {36, 98}, {48, 98}}, color = {0, 0, 127}));
    connect(transMission.w_gearbox_output_radps, TM_CNT.w_gearbox_output_radps) annotation(
      Line(points = {{212, -82}, {222, -82}, {222, 122}, {32, 122}, {32, 92}, {48, 92}}, color = {0, 0, 127}));
    connect(transMission.w_ENG_PNT_radps, ENGINE.w_ENG_PNT_radps) annotation(
      Line(points = {{212, -94}, {220, -94}, {220, -144}, {0, -144}, {0, -114}, {-37, -114}}, color = {0, 0, 127}));
    connect(transMission.w_ENG_PNT_radps, ECU.w_ENG_PNT_radps) annotation(
      Line(points = {{212, -94}, {220, -94}, {220, -144}, {-164, -144}, {-164, -97}, {-144, -97}}, color = {0, 0, 127}));
    connect(vehicle.w_DS_PNT_out_radps, transMission.w_DS_PNT_out_radps) annotation(
      Line(points = {{256, -120}, {248, -120}, {248, -152}, {180, -152}, {180, -100}, {188, -100}}, color = {0, 0, 127}));
    connect(multiplex2.y, TM_CNT.w_synchoro_dif_radps) annotation(
      Line(points = {{11, 92}, {26, 92}, {26, 86}, {48, 86}}, color = {0, 0, 127}, thickness = 0.5));
    connect(transMission.w_synchro_dif_radps, multiplex2.u1) annotation(
      Line(points = {{212, -88}, {226, -88}, {226, 126}, {-10, 126}, {-10, 96}, {-4, 96}}, color = {0, 0, 127}, thickness = 0.5));
    connect(transMission.w_starting_device_input_radps, TM_CNT.w_starting_device_input_radps) annotation(
      Line(points = {{212, -130}, {230, -130}, {230, 130}, {40, 130}, {40, 104}, {48, 104}}, color = {0, 0, 127}));
    connect(TM_CNT.tau_clutch_cap, deMultiplex2.u) annotation(
      Line(points = {{72, 98}, {90, 98}, {90, 102}, {101, 102}}, color = {0, 0, 127}, thickness = 0.5));
    connect(TM_CNT.f_synchro_n, deMultiplex21.u) annotation(
      Line(points = {{72, 92}, {141, 92}}, color = {0, 0, 127}, thickness = 0.5));
    connect(deMultiplex2.y1, transMission.tau_clutch_cap) annotation(
      Line(points = {{115, 106}, {178, 106}, {178, -76}, {188, -76}}, color = {0, 0, 127}, thickness = 0.5));
    connect(deMultiplex21.y1, transMission.f_synchro_n) annotation(
      Line(points = {{155, 96}, {174, 96}, {174, -82}, {188, -82}}, color = {0, 0, 127}, thickness = 0.5));
    connect(ENGINE.tau_engine, transMission.trq_FW_PNT_in_Nm) annotation(
      Line(points = {{-37, -122}, {24, -122}, {24, -94}, {188, -94}}, color = {0, 0, 127}));
    connect(dummy_Batt_V.y, transMission.V_BT_PNT_Lo_V) annotation(
      Line(points = {{157, -130}, {188, -130}}, color = {0, 0, 127}));
    connect(TM_CNT.i_eop_ampere, transMission.I_EOP_A) annotation(
      Line(points = {{72, 50}, {162, 50}, {162, -124}, {188, -124}}, color = {0, 0, 127}));
    connect(transMission.I_actuator_A, TM_CNT.i_actuator_ampere) annotation(
      Line(points = {{188, -118}, {164, -118}, {164, 56}, {72, 56}, {72, 56}}, color = {0, 0, 127}));
    connect(TM_CNT.p_line_pa, transMission.p_line_Pa) annotation(
      Line(points = {{72, 74}, {168, 74}, {168, -112}, {188, -112}, {188, -112}}, color = {0, 0, 127}));
    connect(const.y, multiplex2.u2[1]) annotation(
      Line(points = {{-28, 88}, {-4, 88}, {-4, 88}, {-4, 88}}, color = {0, 0, 127}));
    connect(transMission.w_ENG_PNT_radps, DRIVER.w_ENG_PNT_radps) annotation(
      Line(points = {{212, -94}, {220, -94}, {220, -144}, {-226, -144}, {-226, 14}, {-210, 14}}, color = {0, 0, 127}));
    connect(transMission.w_ENG_PNT_radps, TM_CNT.w_engine_radps) annotation(
      Line(points = {{212, -94}, {220, -94}, {220, -144}, {0, -144}, {0, 44}, {46, 44}, {46, 44}, {48, 44}}, color = {0, 0, 127}));
    connect(hEVElectricSystem.Viv, transMission.Vm) annotation(
      Line(points = {{139, -170}, {196, -170}, {196, -134}}, color = {0, 0, 127}));
    connect(transMission.Im, hEVElectricSystem.Iiv) annotation(
      Line(points = {{204, -132}, {204, -158}, {88, -158}, {88, -170}, {96, -170}}, color = {0, 0, 127}));
    connect(VCU.tau_vcu_eng_req, TM_CNT.tau_engine_target) annotation(
      Line(points = {{-76, 34}, {-9.5, 34}, {-9.5, 32}, {48, 32}}, color = {0, 0, 127}));
    connect(VCU.tau_vcu_brake_target, vehicle.tau_brake) annotation(
      Line(points = {{-76, 18}, {16, 18}, {16, -148}, {244, -148}, {244, -108}, {256, -108}}, color = {0, 0, 127}));
    connect(VCU.tau_vcu_brake_target, gain1.u) annotation(
      Line(points = {{-76, 18}, {-46, 18}, {-46, 62}, {-32, 62}}, color = {0, 0, 127}));
    connect(VCU.tau_vcu_p2m_req, TM_CNT.tau_p2m_req) annotation(
      Line(points = {{-76, 26}, {-6, 26}, {-6, 8}, {48, 8}}, color = {0, 0, 127}));
    connect(VCU.flag_vcu_k0_open_req, TM_CNT.flag_k0_clutch_open) annotation(
      Line(points = {{-76, 10}, {-12, 10}, {-12, 2}, {48, 2}}, color = {0, 0, 127}));
    connect(VCU.flag_vcu_k0_open_req, ECU.flag_vcu_k0_open_req) annotation(
      Line(points = {{-76, 10}, {-42, 10}, {-42, -58}, {-180, -58}, {-180, -119}, {-144, -119}}, color = {0, 0, 127}));
    connect(VCU.w_vcu_eng_speed_req, ECU.w_vcu_eng_speed_req) annotation(
      Line(points = {{-76, 2}, {-48, 2}, {-48, -62}, {-176, -62}, {-176, -113}, {-144, -113}}, color = {0, 0, 127}));
    connect(VCU.tau_vcu_eng_req, ECU.tau_eng_req) annotation(
      Line(points = {{-76, 34}, {-54, 34}, {-54, -66}, {-172, -66}, {-172, -103}, {-144, -103}}, color = {0, 0, 127}));
    connect(DRIVER.tau_gearbox_input_target, VCU.tau_gearbox_input_target) annotation(
      Line(points = {{-178, 26}, {-166, 26}, {-166, 41}, {-124, 41}}, color = {0, 0, 127}));
    connect(hEVElectricSystem.HiBatSoc, VCU.soc_hi_vol_batt) annotation(
      Line(points = {{139, -180}, {154, -180}, {154, -206}, {-210, -206}, {-210, -20}, {-148, -20}, {-148, 31}, {-124, 31}}, color = {0, 0, 127}));
    connect(hEVElectricSystem.Viv, VCU.V_BT_Hi_vol) annotation(
      Line(points = {{139, -170}, {160, -170}, {160, -202}, {-206, -202}, {-206, -27}, {-137, -27}, {-137, -5}, {-124, -5}}, color = {0, 0, 127}));
    connect(DRIVER.accel_position_per, VCU.accel_position_per) annotation(
      Line(points = {{-178, 20}, {-151, 20}, {-151, 10}, {-124, 10}}, color = {0, 0, 127}));
    connect(VCU.t_hi_vol_batt_k, const5.y) annotation(
      Line(points = {{-124, 21}, {-140, 21}, {-140, 70}, {-149.5, 70}}, color = {0, 0, 127}));
    connect(transMission.w_gearbox_input_radps, VCU.w_P2M_PNT_radps) annotation(
      Line(points = {{212, -76}, {218, -76}, {218, 118}, {-136, 118}, {-136, 26}, {-124, 26}}, color = {0, 0, 127}));
    connect(TM_CNT.trans_torq_gain, VCU.torque_gain_drive_train) annotation(
      Line(points = {{72, 32}, {118, 32}, {118, -46}, {-132, -46}, {-132, 15}, {-124, 15}}, color = {0, 0, 127}));
    connect(VCU.v_vehicle_mps, vehicle.v_vehicle_mps) annotation(
      Line(points = {{-124, 5}, {-144, 5}, {-144, 140}, {318, 140}, {318, -104}, {296, -104}}, color = {0, 0, 127}));
    connect(TM_CNT.tau_engine_max_req, ECU.tau_engine_max_req) annotation(
      Line(points = {{72, 20}, {106, 20}, {106, -74}, {-162, -74}, {-162, -86}, {-144, -86}}, color = {0, 0, 127}));
    connect(DRIVER.drive_mode_req, TM_CNT.drive_mode) annotation(
      Line(points = {{-178, 14}, {-162, 14}, {-162, -34}, {40, -34}, {40, -4}, {48, -4}}, color = {0, 0, 127}));
    connect(DRIVER.drive_mode_req, VCU.drive_mode) annotation(
      Line(points = {{-178, 14}, {-162, 14}, {-162, 36}, {-124, 36}}, color = {0, 0, 127}));
    connect(enviroment.v_vehicle_target_kph, DRIVER.Target_Speed) annotation(
      Line(points = {{-289, 32.5}, {-262, 32.5}, {-262, 38}, {-210, 38}}, color = {0, 0, 127}));
    connect(const9.y, TM_CNT.tau_engine_min_pos) annotation(
      Line(points = {{38, 20}, {46, 20}, {46, 20}, {48, 20}}, color = {0, 0, 127}));
    connect(const9.y, TM_CNT.tau_engine_max_pos) annotation(
      Line(points = {{38, 20}, {42, 20}, {42, 12}, {48, 12}, {48, 14}}, color = {0, 0, 127}));
    connect(enviroment.trans_shifter_position, TM_CNT.trans_shifter_position) annotation(
      Line(points = {{-289, 18.5}, {-256, 18.5}, {-256, 50}, {48, 50}}, color = {0, 0, 127}));
    connect(const10.y, TM_CNT.t_engine_water_k) annotation(
      Line(points = {{-2, 74}, {46, 74}, {46, 74}, {48, 74}}, color = {0, 0, 127}));
    connect(enviroment.v_vehicle_target_kph, A_Vtgt) annotation(
      Line(points = {{-289, 32.5}, {-262, 32.5}, {-262, 158}, {-220, 158}}, color = {0, 0, 127}));
    connect(TM_CNT.flag_trans_lock_up, ECU.flag_trans_lock_up) annotation(
      Line(points = {{72, -4}, {78, -4}, {78, -50}, {-188, -50}, {-188, -124}, {-144, -124}}, color = {0, 0, 127}));
    connect(enviroment.key_position, VCU.key_position) annotation(
      Line(points = {{-288, -10}, {-266, -10}, {-266, -24}, {-142, -24}, {-142, 0}, {-124, 0}}, color = {0, 0, 127}));
    connect(VCU.flag_vcu_k0_open_req, DRIVER.flag_vcu_k0_open_req) annotation(
      Line(points = {{-76, 10}, {-42, 10}, {-42, -30}, {-218, -30}, {-218, -4}, {-210, -4}}, color = {0, 0, 127}));
    connect(const4.y, ENGINE.accel_position_per) annotation(
      Line(points = {{-80, -110}, {-74, -110}, {-74, -114}, {-63, -114}}, color = {0, 0, 127}));
    connect(hEVElectricSystem.DCDCLoss, add.u2) annotation(
      Line(points = {{139, -186}, {150, -186}, {150, -266}, {185, -266}}, color = {0, 0, 127}));
    connect(transMission.inv_loss, add.u1) annotation(
      Line(points = {{200, -132}, {200, -172}, {166, -172}, {166, -262}, {185, -262}}, color = {0, 0, 127}));
    connect(combiTable1D.y[1], transMission.nu_oil_m2ps) annotation(
      Line(points = {{157, -87}, {170, -87}, {170, -88}, {188, -88}}, color = {0, 0, 127}));
    connect(transMission.w_starting_device_input_radps, to_rpm.u) annotation(
      Line(points = {{212, -130}, {228, -130}, {228, -164}, {178, -164}, {178, -204}, {185, -204}}, color = {0, 0, 127}));
    connect(enviroment.user_set_cablin_deg_c, from_degC.u) annotation(
      Line(points = {{-288, -2}, {-258, -2}, {-258, -216}, {-71, -216}}, color = {0, 0, 127}));
    connect(enviroment.grade_per, DRIVER.grade_per) annotation(
      Line(points = {{-288, 26}, {-249, 26}, {-249, 32}, {-210, 32}}, color = {0, 0, 127}));
    connect(enviroment.user_set_drive_mode, DRIVER.drive_mode_req) annotation(
      Line(points = {{-288, 12}, {-244, 12}, {-244, 2}, {-210, 2}, {-210, 2}}, color = {0, 0, 127}));
    connect(enviroment.p_vehicle_consumption, hEVElectricSystem.LowBatConsumption) annotation(
      Line(points = {{-288, -16}, {-272, -16}, {-272, -190}, {96, -190}, {96, -190}}, color = {0, 0, 127}));
    connect(booleanConstant.y, thermal_common.ACONOFF) annotation(
      Line(points = {{263, -179}, {268, -179}, {268, -185}, {277, -185}}, color = {255, 0, 255}));
    connect(ENGINE.tau_engine, thermal_common.ENGTrq) annotation(
      Line(points = {{-38, -122}, {-14, -122}, {-14, -200}, {183.5, -200}, {183.5, -195}, {277, -195}}, color = {0, 0, 127}));
    connect(to_rpm.y, thermal_common.ENGrev) annotation(
      Line(points = {{199, -204}, {277, -204}}, color = {0, 0, 127}));
    connect(from_degC.y, thermal_common.AC_SET_TEMP) annotation(
      Line(points = {{-58, -216}, {274, -216}, {274, -213}, {277, -213}}, color = {0, 0, 127}));
    connect(transMission.Qf_SD_PNT_W, thermal_common.LAUNCH_Q) annotation(
      Line(points = {{212, -112}, {236, -112}, {236, -220}, {277, -220}, {277, -223}}, color = {0, 0, 127}));
    connect(transMission.Qf_GB_PNT_W, thermal_common.VARIATOR_Q) annotation(
      Line(points = {{212, -118}, {232, -118}, {232, -232}, {277, -232}}, color = {0, 0, 127}));
    connect(ENGINE.Engine_Q, thermal_common.Engine_Q) annotation(
      Line(points = {{-38, -130}, {-18, -130}, {-18, -250}, {277, -250}}, color = {0, 0, 127}));
    connect(transMission.mg_loss, thermal_common.MG_Q) annotation(
      Line(points = {{202, -132}, {200, -132}, {200, -259}, {277, -259}}, color = {0, 0, 127}));
    connect(add.y, thermal_common.DCDC_Q) annotation(
      Line(points = {{194, -264}, {241.5, -264}, {241.5, -268}, {277, -268}}, color = {0, 0, 127}));
    connect(hEVElectricSystem.HiBatLoss, thermal_common.LIBAT_Q) annotation(
      Line(points = {{140, -182}, {148, -182}, {148, -278}, {277, -278}}, color = {0, 0, 127}));
    connect(gain.y, thermal_common.VSP) annotation(
      Line(points = {{340, -86}, {344, -86}, {344, -334}, {250, -334}, {250, -287}, {277, -287}}, color = {0, 0, 127}));
    connect(thermal_common.OIL_TEMP, combiTable1D.u[1]) annotation(
      Line(points = {{335, -251}, {342, -251}, {342, -138}, {134, -138}, {134, -86}, {146, -86}}, color = {0, 0, 127}));
    connect(thermal_common.OIL_TEMP, transMission.ToutOil) annotation(
      Line(points = {{335, -251}, {342, -251}, {342, -138}, {134, -138}, {134, -106}, {188, -106}}, color = {0, 0, 127}));
    connect(enviroment.t_ambient_deg_k, thermal_common.AIR_TEMP) annotation(
      Line(points = {{-288, 4}, {-276, 4}, {-276, -296}, {277, -296}}, color = {0, 0, 127}));
    connect(from_degC1.y, thermal_common.ENG_CASE) annotation(
      Line(points = {{46, -304}, {165.5, -304}, {165.5, -306}, {277, -306}}, color = {0, 0, 127}));
    connect(from_degC2.y, thermal_common.ENG_CRANK) annotation(
      Line(points = {{29, -314}, {153.5, -314}, {153.5, -315}, {277, -315}}, color = {0, 0, 127}));
    connect(from_degC3.y, thermal_common.TRANS_AIR) annotation(
      Line(points = {{10, -326}, {143.5, -326}, {143.5, -324}, {277, -324}}, color = {0, 0, 127}));
    connect(enviroment.t_eng_case, from_degC1.u) annotation(
      Line(points = {{-288, -24}, {-280, -24}, {-280, -304}, {32, -304}, {32, -304}}, color = {0, 0, 127}));
    connect(enviroment.t_eng_clank, from_degC2.u) annotation(
      Line(points = {{-288, -30}, {-282, -30}, {-282, -314}, {14, -314}, {14, -314}}, color = {0, 0, 127}));
    connect(enviroment.t_trans_out_air, from_degC3.u) annotation(
      Line(points = {{-288, -38}, {-284, -38}, {-284, -326}, {-4, -326}, {-4, -326}}, color = {0, 0, 127}));
    connect(thermal_common.HYD_Q, transMission.Qf_HYD_W) annotation(
      Line(points = {{277, -241}, {224, -241}, {224, -124}, {212, -124}}, color = {0, 0, 127}));
  protected
    annotation(
      Diagram(coordinateSystem(extent = {{-350, -250}, {400, 200}}, initialScale = 0.1)),
      __OpenModelica_commandLineOptions = "",
      experiment(StartTime = 0, StopTime = 1800, Tolerance = 1e-06, Interval = 0.1),
      Icon(coordinateSystem(extent = {{-240, -200}, {280, 200}})),
      __OpenModelica_simulationFlags(lv = "LOG_STATS", outputFormat = "mat", s = "dassl", noEventEmit = "()"));
  end HEV_VehicleSystemModel;
  annotation(
    uses(Modelica(version = "3.2.3")));
end TRAMI_L3_HEV;
